(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    672317,      14093]*)
(*NotebookOutlinePosition[    673267,      14123]*)
(*  CellTagsIndexPosition[    673223,      14119]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["DifferentialEquations`LdeApprox`", "Subsection"],

Cell[TextData[{
  StyleBox["Copyright \[Copyright] 2003-2005 ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Graph Tree Ltd",
    ButtonData:>{
      URL[ "http://www.mathshop.digi-area.com/"], None},
    Active->True,
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[". All rights reserved.",
    FontSlant->"Italic"]
}], "SmallText",
  TextAlignment->Right],

Cell[TextData[{
  "The package provides some functions for finding polynomial approximation \
of solutions of a linear differential equation (LDE). The main function (",
  StyleBox["ApproxSol",
    FontFamily->"Courier New"],
  ") allows one to find polynomial approximation for solutions of an LDE with \
polynomial coefficients on a given interval. The main algorithm applied is so \
called ",
  StyleBox["a-method",
    FontFamily->"Courier New"],
  " (see [1]) which has the following special properties. \nThe method is \
numerically analytical one. It means that LDE coefficients, boundary or \
initial conditions and parameters of ",
  StyleBox["ApproxSol",
    FontFamily->"Courier New"],
  " function (except degree of approximation polynomial) can be either \
symbolical or numerical expressions (see ",
  ButtonBox["symbolic examples",
    ButtonData:>{"symbolic.nb", None},
    ButtonStyle->"Hyperlink"],
  " of the package).\nThe method gives the polynomial approximation which is \
very close to the uniform one. It means that the result is such a polynomial \
that minimizes the maximum value of the absolute error between the solution \
and a polynomial of the given degree over the interval under consideration \
(see ",
  ButtonBox["numerical examples",
    ButtonData:>{"numerical.nb", None},
    ButtonStyle->"Hyperlink"],
  " of the package).\nThe method is fast saturated. It means that the \
required precision can be reached very fast by increasing the degree of \
approximation polynomial [2].\nThe method can be applied to get approximation \
of either initial value problems (IVP) or boundary value problems (BVP) (see \
[3]). To receive normalized results of the solution of a homogeneous BVP one \
can use the package function ",
  StyleBox["Normalizes",
    FontFamily->"Courier New"],
  StyleBox[" (s",
    FontFamily->"Times New Roman"],
  "ee ",
  ButtonBox["BVP examples",
    ButtonData:>{"bvp.nb", None},
    ButtonStyle->"Hyperlink"],
  " of the package).\nThe method can be applied to get approximation of LDE's \
with regular singular points (see ",
  ButtonBox["RSP examples",
    ButtonData:>{"rsp.nb", None},
    ButtonStyle->"Hyperlink"],
  " of the package).\nThe method can be applied to get approximation of IVP \
or BVP even if the LDE has non-polynomial coefficients. To do this one can \
use the package function ",
  StyleBox["ToRatCoeffs",
    FontFamily->"Courier New"],
  " (which gives rational approximation of the LDE coefficients) and then \
apply ",
  StyleBox["ApproxSol",
    FontFamily->"Courier New"],
  " function to the result.\nThe so called ",
  StyleBox["modified a-method ",
    FontFamily->"Courier New"],
  "is also applied in the package (see ",
  ButtonBox["modified a-method examples",
    ButtonData:>{"modified.nb", None},
    ButtonStyle->"Hyperlink"],
  ")"
}], "Text"],

Cell["\<\
To present the package only LDEs with known analytical solutions are used.\
\>", "Text"],

Cell[TextData[{
  "The main function of the package ",
  StyleBox["ApproxSol",
    FontFamily->"Courier New"],
  " has the following syntax."
}], "Text"],

Cell[TextData[{
  "          ",
  Cell[BoxData[
      FormBox[
        StyleBox[GridBox[{
              {
                FormBox[\(ApproxSol[lde, y[x], {x, a, b}, n]\),
                  "TraditionalForm"]},
              {\(ApproxSol[{lde, Cond}, y[x], {x, a, b}, n]\)}
              },
            ColumnWidths->Automatic],
          FontFamily->"Courier New"], TraditionalForm]]],
  "          ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{\(gives\ n\), "-", 
                RowBox[{
                "degree", " ", "approximation", " ", "polynomial", " ", "for",
                   " ", 
                  StyleBox["lde",
                    FontFamily->"Courier New"], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman"], 
                  StyleBox["general",
                    FontFamily->"Times New Roman"], 
                  StyleBox[" ",
                    FontFamily->"Times New Roman"], "solution", " ", "on", 
                  " ", 
                  RowBox[{"interval", " ", 
                    StyleBox["[",
                      FontFamily->"Courier New"], 
                    StyleBox[\(a, b\),
                      FontFamily->"Courier New"], 
                    StyleBox["]",
                      FontFamily->"Courier New"]}]}]}]},
            {
              RowBox[{"the", " ", "same", " ", "but", " ", "for", 
                StyleBox[" ",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox["initial",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox[" ",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox["or",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox[" ",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox["boundary",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox[" ",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox["value",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox[" ",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox["problem",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox[" ",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox["with",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox[" ",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox["conditions",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox[" ",
                  GridBoxOptions->{ColumnWidths->Automatic}], 
                StyleBox["Cond",
                  FontFamily->"Courier New",
                  GridBoxOptions->{ColumnWidths->Automatic}]}]}
            }], TraditionalForm]],
    GridBoxOptions->{ColumnWidths->Automatic}]
}], "DefinitionBox"],

Cell["\<\
Finding polynomial approximation for solutions of an LDE with polynomial \
coefficients. \
\>", "Caption"],

Cell["This loads the package.", "MathCaption"],

Cell[BoxData[
    \(<< DifferentialEquations`LdeApprox`\)], "Input",
  CellLabel->"In[46]:="],

Cell["This declares a simple LDE.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lde = \(y''\)[x] - x*y[x] \[Equal] 0\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\(-x\)\ y[x]\), "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "==", 
      "0"}]], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[TextData[{
  "Now one can use ",
  StyleBox["ApproxSol",
    FontFamily->"Courier New"],
  " function to find polynomial approximation of solution of the following \
IVP: {",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\(-x\)\ y[x]\), "+", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}]]],
  ",",
  StyleBox["y[0]\[Equal]0,",
    FontFamily->"Courier New"],
  Cell[BoxData[
      SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None]]],
  StyleBox["[0]\[Equal]1}",
    FontFamily->"Courier New"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = 
      ApproxSol[{lde, y[0] \[Equal] 0, \(y'\)[0] \[Equal] 1}, 
        y[x], {x, \(-1\), 1}, 5]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \({{y[x] \[Rule] 
          143376\/90608760661 + \(90628433408\ x\)\/90608760661 - \(5898560\ \
x\^2\)\/271826281983 - \(157358080\ x\^3\)\/90608760661 + \(7554334848\ \
x\^4\)\/90608760661 + \(943996928\ x\^5\)\/271826281983}}\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get the exact solution of the IVP."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = 
      DSolve[{lde, y[0] \[Equal] 0, \(y'\)[0] \[Equal] 1}, y[x], 
        x]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \({{y[x] \[Rule] 
          1\/6\ \((\(-3\)\ 3\^\(1/3\)\ AiryAi[x]\ Gamma[1\/3] + 
                3\^\(5/6\)\ AiryBi[x]\ Gamma[1\/3])\)}}\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell["Now one can compare the results.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
            apr[\([1]\)])\), {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[50]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.308976 8809.58 [
[.02381 .29648 -6 -9 ]
[.02381 .29648 6 0 ]
[.2619 .29648 -12 -9 ]
[.2619 .29648 12 0 ]
[.7381 .29648 -9 -9 ]
[.7381 .29648 9 0 ]
[.97619 .29648 -3 -9 ]
[.97619 .29648 3 0 ]
[.4875 .04469 -48 -4.5 ]
[.4875 .04469 0 4.5 ]
[.4875 .13278 -48 -4.5 ]
[.4875 .13278 0 4.5 ]
[.4875 .22088 -48 -4.5 ]
[.4875 .22088 0 4.5 ]
[.4875 .39707 -42 -4.5 ]
[.4875 .39707 0 4.5 ]
[.4875 .48517 -42 -4.5 ]
[.4875 .48517 0 4.5 ]
[.4875 .57326 -42 -4.5 ]
[.4875 .57326 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30898 m
.02381 .31523 L
s
[(-1)] .02381 .29648 0 1 Mshowa
.2619 .30898 m
.2619 .31523 L
s
[(-0.5)] .2619 .29648 0 1 Mshowa
.7381 .30898 m
.7381 .31523 L
s
[(0.5)] .7381 .29648 0 1 Mshowa
.97619 .30898 m
.97619 .31523 L
s
[(1)] .97619 .29648 0 1 Mshowa
.125 Mabswid
.07143 .30898 m
.07143 .31273 L
s
.11905 .30898 m
.11905 .31273 L
s
.16667 .30898 m
.16667 .31273 L
s
.21429 .30898 m
.21429 .31273 L
s
.30952 .30898 m
.30952 .31273 L
s
.35714 .30898 m
.35714 .31273 L
s
.40476 .30898 m
.40476 .31273 L
s
.45238 .30898 m
.45238 .31273 L
s
.54762 .30898 m
.54762 .31273 L
s
.59524 .30898 m
.59524 .31273 L
s
.64286 .30898 m
.64286 .31273 L
s
.69048 .30898 m
.69048 .31273 L
s
.78571 .30898 m
.78571 .31273 L
s
.83333 .30898 m
.83333 .31273 L
s
.88095 .30898 m
.88095 .31273 L
s
.92857 .30898 m
.92857 .31273 L
s
.25 Mabswid
0 .30898 m
1 .30898 L
s
.5 .04469 m
.50625 .04469 L
s
[(-0.00003)] .4875 .04469 1 0 Mshowa
.5 .13278 m
.50625 .13278 L
s
[(-0.00002)] .4875 .13278 1 0 Mshowa
.5 .22088 m
.50625 .22088 L
s
[(-0.00001)] .4875 .22088 1 0 Mshowa
.5 .39707 m
.50625 .39707 L
s
[(0.00001)] .4875 .39707 1 0 Mshowa
.5 .48517 m
.50625 .48517 L
s
[(0.00002)] .4875 .48517 1 0 Mshowa
.5 .57326 m
.50625 .57326 L
s
[(0.00003)] .4875 .57326 1 0 Mshowa
.125 Mabswid
.5 .06231 m
.50375 .06231 L
s
.5 .07993 m
.50375 .07993 L
s
.5 .09755 m
.50375 .09755 L
s
.5 .11517 m
.50375 .11517 L
s
.5 .1504 m
.50375 .1504 L
s
.5 .16802 m
.50375 .16802 L
s
.5 .18564 m
.50375 .18564 L
s
.5 .20326 m
.50375 .20326 L
s
.5 .2385 m
.50375 .2385 L
s
.5 .25612 m
.50375 .25612 L
s
.5 .27374 m
.50375 .27374 L
s
.5 .29136 m
.50375 .29136 L
s
.5 .3266 m
.50375 .3266 L
s
.5 .34421 m
.50375 .34421 L
s
.5 .36183 m
.50375 .36183 L
s
.5 .37945 m
.50375 .37945 L
s
.5 .41469 m
.50375 .41469 L
s
.5 .43231 m
.50375 .43231 L
s
.5 .44993 m
.50375 .44993 L
s
.5 .46755 m
.50375 .46755 L
s
.5 .50279 m
.50375 .50279 L
s
.5 .52041 m
.50375 .52041 L
s
.5 .53803 m
.50375 .53803 L
s
.5 .55564 m
.50375 .55564 L
s
.5 .02707 m
.50375 .02707 L
s
.5 .00945 m
.50375 .00945 L
s
.5 .59088 m
.50375 .59088 L
s
.5 .6085 m
.50375 .6085 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05656 m
.02846 .16893 L
.03279 .25784 L
.03793 .34554 L
.04262 .40989 L
.04754 .46326 L
.0522 .50161 L
.05711 .53068 L
.05988 .54242 L
.06244 .55051 L
.06369 .55354 L
.06487 .55591 L
.06623 .55803 L
.06747 .55942 L
.06864 .56027 L
.06972 .56067 L
.07091 .5607 L
.07218 .56028 L
.0729 .55983 L
.07357 .55929 L
.07507 .55763 L
.0764 .55569 L
.0778 .55316 L
.0829 .54022 L
.08824 .52117 L
.09323 .49927 L
.10458 .43889 L
.14349 .20617 L
.15366 .15566 L
.16473 .11043 L
.1698 .09347 L
.17518 .07818 L
.18022 .06645 L
.18485 .05793 L
.18941 .0516 L
.19171 .0492 L
.19422 .04716 L
.19554 .04633 L
.19675 .04573 L
.19742 .04545 L
.19814 .0452 L
.19945 .04488 L
.20068 .04472 L
.20198 .04471 L
.2031 .04483 L
.20432 .04509 L
.20554 .04549 L
.2067 .04599 L
.20887 .04726 L
.21121 .0491 L
Mistroke
.21376 .05165 L
.21835 .0576 L
.2226 .06465 L
.23319 .08807 L
.24316 .11685 L
.26178 .18406 L
.30038 .34891 L
.31997 .4286 L
.33034 .46609 L
.34144 .50129 L
.35215 .52956 L
.3619 .54992 L
.3666 .55777 L
.37171 .56482 L
.37653 .57002 L
.38098 .57357 L
.38341 .57499 L
.38563 .57596 L
.38679 .57636 L
.38807 .57669 L
.38871 .57682 L
.3894 .57693 L
.39063 .57705 L
.3918 .57708 L
.39307 .57702 L
.39427 .57687 L
.39538 .57666 L
.39637 .5764 L
.39747 .57604 L
.39968 .57511 L
.40237 .57357 L
.40482 .57179 L
.41034 .56648 L
.41545 .55999 L
.4203 .55247 L
.44018 .50885 L
.4586 .45286 L
.49783 .30376 L
.53555 .1596 L
.55487 .0999 L
.56482 .07526 L
.57009 .06418 L
.57572 .05395 L
.58115 .04573 L
.58608 .03972 L
.58846 .03734 L
.59105 .03513 L
.59347 .03343 L
.59574 .03216 L
.59827 .03111 L
Mistroke
.59962 .03072 L
.60037 .03054 L
.60106 .03042 L
.60178 .03032 L
.60245 .03025 L
.60318 .03022 L
.60396 .03021 L
.6047 .03024 L
.6054 .03031 L
.6067 .0305 L
.60794 .03079 L
.60924 .03119 L
.61157 .03218 L
.61408 .03363 L
.61683 .03568 L
.62207 .0409 L
.62704 .04743 L
.63635 .06372 L
.64637 .08696 L
.65727 .11844 L
.69807 .27982 L
.71834 .37207 L
.73736 .45468 L
.75576 .52252 L
.76501 .54957 L
.77513 .57222 L
.78019 .58049 L
.78297 .5841 L
.7856 .58687 L
.78804 .58888 L
.78933 .58972 L
.7907 .59043 L
.79184 .59089 L
.79311 .59125 L
.79425 .59144 L
.79533 .59151 L
.79647 .59145 L
.79772 .59123 L
.7989 .59088 L
.79999 .59043 L
.80206 .58926 L
.80425 .58752 L
.80685 .58482 L
.80928 .58164 L
.81384 .57401 L
.81851 .56387 L
.82364 .55008 L
.83397 .51388 L
.85246 .42319 L
.87366 .28851 L
Mistroke
.89296 .15782 L
.90256 .09937 L
.90762 .07263 L
.91299 .04858 L
.91768 .03206 L
.92034 .02487 L
.92162 .02204 L
.92284 .01975 L
.92393 .01804 L
.92513 .01656 L
.92621 .01558 L
.92722 .01499 L
.92842 .01472 L
.9295 .01487 L
.93076 .01554 L
.93194 .01668 L
.9331 .01829 L
.93434 .02058 L
.93659 .02626 L
.93926 .03573 L
.94169 .04713 L
.94423 .06199 L
.94699 .08184 L
.95201 .12867 L
.95666 .18571 L
.9616 .26235 L
.97048 .44741 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[50]:=",
  ImageSize->{216, 133.375},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>0000YR000`400?l00000o`00003oQ`3oool0
0`000000oooo0?ooo`240?ooo`00Q`3oool00`000000oooo0?ooo`240?ooo`00Q`3oool2000008D0
oooo00270?ooo`030000003oool0oooo08@0oooo00270?ooo`030000003oool0oooo06h0oooo0`00
000C0?ooo`00Q`3oool00`000000oooo0?ooo`1^0?ooo`040000003oool0oooo00000180oooo0027
0?ooo`030000003oool0oooo06h0oooo00@000000?ooo`3oool000004P3oool008L0oooo0P00001^
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool008L0oooo00<000000?oo
o`3oool05P3oool500000540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0?0?oo
o`00C@3oool4000000D0oooo0P0000050?ooo`@00000103oool4000000@0oooo100000040?ooo`@0
0000103oool3000000L0oooo00<000000?ooo`3oool05@3oool2000000@0oooo0P00001?0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool004`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00l0oooo001<0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0
oooo000e0?ooo`@000002`3oool600000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`8000004`3oool2000000X0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo000d0?ooo`8000000`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool003<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00070?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00d0oooo00070?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`@00000303oool4000000@0oooo1000
00040?ooo`@00000103oool4000000@0oooo0`0000070?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03@3oool000L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo04P0oooo0P00000@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00070?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03@3oool000L0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0=0?ooo`001`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00d0oooo00070?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`160?ooo`8000003`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`001`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00070?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool03@3oool000L0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0=0?ooo`001`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo
00070?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`140?ooo`800000303oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`001`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00`0oooo00070?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0303oool000L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`00
1`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00`0oooo00080?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`120?ooo`8000002`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0<0?ooo`00203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0203oool4000000D0oooo0P0000050?ooo`@00000103oool4
000000@0oooo100000040?ooo`@000000`3oool5000000H0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0;0?ooo`00203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo0P0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02`3oool000P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0D0?ooo`L000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo00080?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00/0oooo
00080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`060?ooo`@00000303oool40000
00@0oooo100000040?ooo`@00000103oool4000000@0oooo0`0000070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool02`3oool000P0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0400oooo0P0000080?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0
oooo00080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02`3oool000P0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`00203oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool02P3oool000P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo03h0oooo0P0000060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool000P0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0:0?ooo`00203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00X0oooo00080?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool000P0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0
oooo0P0000050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02P3oool000P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0:0?ooo`00203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00080?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0l0?oo
o`800000103oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0:0?ooo`00203oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
7`3oool010000000oooo0?ooo`3oool4000000D0oooo0P0000050?ooo`@00000103oool4000000@0
oooo100000040?ooo`@00000103oool5000000D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0:0?ooo`00203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01l0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00090?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool07`3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?oo
o`002@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo1P0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool02P3oool000T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0P
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00090?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool08@3oool00`000000oooo000000040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0240oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0`000007
0?ooo`050000003oool0oooo0?ooo`000000;@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool02@3oool000T0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@00000303oool4000000@0oooo10000004
0?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool0000002d0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00T0oooo00090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`0j0?ooo`80000000<0oooo0000003oool0;@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool000T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo00@000000?oo
o`3oool00000;P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02@3oool000T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo03T0oooo00@000000?ooo`3oool00000;`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool000T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03T0oooo00@000000?oo
o`3oool00000;`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool02@3oool000T0oooo1@00000G0?ooo`030000003oool0oooo01T0oooo100000050?oo
o`8000001@3oool400000380oooo0`00000`0?ooo`030000003oool0000000<000001@3oool20000
00D0oooo1000000L0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`000000100000050?oo
o`002@3oool00`000000oooo0000000I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`000000<03oool2000000@0oooo00<000000?ooo`3o
ool00P3oool2000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000070?ooo`002@3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0000000a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo000000070?oo
o`001P0000030?ooo`030000003oool0000001P0oooo00<000000?ooo`3oool04@3oool600000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0000000a0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01<0
oooo00D000000?ooo`3oool0oooo000000070?ooo`002@3oool00`000000oooo0000000H0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo1000000b0?ooo`800000<P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00T0oooo1000000L0?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`002@3oool00`000000oooo0000000H0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0<`3oool200000380oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool01@000000
oooo0?ooo`3oool0000000L0oooo00090?ooo`<00000603oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
03D0oooo0P00000b0?ooo`8000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0503oool00`000000oooo00000002000000L0oooo000:0?ooo`80
0000603oool00`000000oooo0?ooo`0J0?ooo`@00000203oool010000000oooo0?ooo`3oool50000
0340oooo0P00000c0?ooo`@00000303oool5000001X0oooo00<000000?ooo`3oool0503oool01@00
0000oooo0?ooo`3oool0000000L0oooo000:0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo000:0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00T0oooo000:0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0f0?ooo`800000=03oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool000X0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0203o
ool000X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo03D0oooo0P00000e0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0=@3oool2000003D0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0e0?ooo`800000=@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool000030?oo
o`00000000000?l000003000000000L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo
0?ooo`0:0?ooo`8000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000L0oooo000:0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0000003H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0000003H0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00800000=@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo0340oooo00@000000?ooo`3oool00000=`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool000/0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0340oooo00@0
00000?ooo`3oool00000=`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo0340oooo00@000000?ooo`3oool00000=`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool000/0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02l0oooo00D0
00000?ooo`3oool0oooo0000000g0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0;`3oool010000000oooo0?ooo`3oool2000003H0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00P0oooo
000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0_0?ooo`050000003oool0oooo0?ooo`000000>03oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0203oool000/0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00P0oooo000;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool000/0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool00P3oool2000003L0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo000;0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool01`3oool000/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`070?ooo`002`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00L0oooo000;0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0103oool2000003P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00L0oooo000<0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
:`3oool400000080oooo00<000000?ooo`3oool00P0000050?ooo`@00000103oool4000000@0oooo
100000040?ooo`@00000103oool5000000D0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01`3oool000`0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`0000000P3oool2000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`030?ooo`8000001P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo0P00000i0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`070?ooo`00303oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000007
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool01`3oool000`0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0`000007
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00L0oooo000<0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0;03oool4000000@0oooo00<000000?ooo`3oool01@3oool4000000@0oooo100000040?oo
o`@00000103oool4000000D0oooo0P0000070?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo000<0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo00H0oooo0P00000j0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`070?ooo`00303oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00H0oooo000<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3o
ool000`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`00303oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000<0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo0P00000l0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`060?ooo`00303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo
000=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01P3oool000d0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`060?ooo`003@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`090?oo
o`800000?@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool01P3oool000d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`00
3@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo000=0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool01P3oool000d0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`060?ooo`003@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`800000?P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool000d0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`060?ooo`003P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02l0oooo100000050?ooo`8000000P3oool00`000000oooo
0?ooo`04000000@0oooo100000040?ooo`@00000103oool500000080oooo1@0000060?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00H0oooo000>0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003o
ool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00H0oooo000>0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool01P3oool000h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool2000000@0oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`800000?`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01P3oool000h0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01`3oool2000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00040?ooo`040000003oool0oooo000000<0oooo0P0000050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool01P3oool000l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool2000000@0oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00<0oooo0P0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool000l0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?ooo`8000000P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool000l0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0`0?ooo`@000002`3oool5000000@0oooo1000
00040?ooo`@00000103oool4000000@0oooo0`0000070?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo000?
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00d0oooo0P0000110?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`060?ooo`003`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00H0oooo000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01P3oool000l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`060?ooo`00403o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0?0?ooo`800000@P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool01P3oool00100oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`060?ooo`00403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00D0oooo000@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01@3oool00100oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`004@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0A0?ooo`800000A03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool01@3oool00140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`05
0?ooo`004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00D0oooo000A0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool00180oooo00@000000?ooo`3oool0
0000C03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool01@3oool00180oooo00@000000?ooo`3oool00000C@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01@0oooo0P0000160?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`050?ooo`004`3oool2000003P0oooo100000050?ooo`800000
1@3oool400000080oooo00<000000?ooo`0000000`0000040?ooo`@00000103oool4000000@0oooo
0`0000070?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00D0oooo001<0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`050?ooo`00C03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`050?ooo`00C03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`02000000<0oooo00<000000?ooo`3oool00`0000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`800000A`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01@3oool0
04`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool000000?ooo`07000000@0oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`020?ooo`8000001`3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`050?ooo`00C03oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool01@3oool004`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00D0oooo001=0?ooo`@00000303oool4000000@0oooo10000004
0?ooo`@00000103oool4000000@0oooo0`0000070?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool00P3oool2000002`0oooo00<000000?ooo`3oool01@3oool008L0oooo0P00001;0?oo
o`@00000;P3oool00`000000oooo0?ooo`050?ooo`00Q`3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo00D0oooo00270?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
1@3oool008L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`050?ooo`00Q`3oool0
0`000000oooo0?ooo`240?ooo`00Q`3oool2000008D0oooo00270?ooo`030000003oool0oooo08@0
oooo00270?ooo`030000003oool0oooo08@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 269}, {165.688, 0}} -> {-1.0588, -3.51008*^-05, \
0.00979932, 5.2969*^-07}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell["\<\
The a-method is fast saturated. To see this one can try to calculate the \
approximation polynomial of 16-degree or higher.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = 
      ApproxSol[{lde, y[0] \[Equal] 0, \(y'\)[0] \[Equal] 1}, 
        y[x], {x, \(-1\), 1}, 16]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \({{y[x] \[Rule] 
          25948377022598952453760320\/\
56557850105578144099339872405247135733587027 + \
\(56557850105578031170446961908896751239814144\ \
x\)\/56557850105578144099339872405247135733587027 - \
\(4203637077661030297509171840\ \
x\^2\)\/56557850105578144099339872405247135733587027 + \
\(5335883958814218816415999856640\ \
x\^3\)\/56557850105578144099339872405247135733587027 + \
\(673307739352135432551331112364189930652416\ \
x\^4\)\/8079692872225449157048553200749590819083861 - \
\(1493424387712161590140363898880\ \
x\^5\)\/1154241838889349879578364742964227259869123 - \
\(972999619079168112015311050752\ \
x\^6\)\/56557850105578144099339872405247135733587027 + \
\(112217957005883938994565130894947894067200\ \
x\^7\)\/56557850105578144099339872405247135733587027 + \
\(4611974666098589267520095539200\ \
x\^8\)\/56557850105578144099339872405247135733587027 - \
\(204432661119206409009907156254720\ \
x\^9\)\/8079692872225449157048553200749590819083861 + \
\(178123738836534091435579618385381376000\ \
x\^10\)\/8079692872225449157048553200749590819083861 + \
\(362402575303449294466393813549056\ \
x\^11\)\/8079692872225449157048553200749590819083861 + \
\(370909322555991128801075036160\ \
x\^12\)\/1154241838889349879578364742964227259869123 + \
\(1141471935549081920175740104558510080\ \
x\^13\)\/8079692872225449157048553200749590819083861 - \
\(14758268528238429864339774111744\ \
x\^14\)\/56557850105578144099339872405247135733587027 + \
\(1040738335970463508181897434890240\ \
x\^15\)\/56557850105578144099339872405247135733587027 + \
\(33308236429043866742991173109940224\ \
x\^16\)\/56557850105578144099339872405247135733587027}}\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
            apr[\([1]\)])\), {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[52]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 3.31354e+014 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .0605 -55.5 -6.25 ]
[.4875 .0605 0 6.25 ]
[.4875 .14334 -43.5 -6.25 ]
[.4875 .14334 0 6.25 ]
[.4875 .22618 -55.5 -6.25 ]
[.4875 .22618 0 6.25 ]
[.4875 .39186 -49.5 -6.25 ]
[.4875 .39186 0 6.25 ]
[.4875 .47469 -37.5 -6.25 ]
[.4875 .47469 0 6.25 ]
[.4875 .55753 -49.5 -6.25 ]
[.4875 .55753 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .0605 m
.50625 .0605 L
s
gsave
.4875 .0605 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-16) show
grestore
.5 .14334 m
.50625 .14334 L
s
gsave
.4875 .14334 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-16) show
grestore
.5 .22618 m
.50625 .22618 L
s
gsave
.4875 .22618 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-16) show
grestore
.5 .39186 m
.50625 .39186 L
s
gsave
.4875 .39186 -49.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-16) show
grestore
.5 .47469 m
.50625 .47469 L
s
gsave
.4875 .47469 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-16) show
grestore
.5 .55753 m
.50625 .55753 L
s
gsave
.4875 .55753 -49.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-16) show
grestore
.125 Mabswid
.5 .07707 m
.50375 .07707 L
s
.5 .09364 m
.50375 .09364 L
s
.5 .1102 m
.50375 .1102 L
s
.5 .12677 m
.50375 .12677 L
s
.5 .15991 m
.50375 .15991 L
s
.5 .17648 m
.50375 .17648 L
s
.5 .19304 m
.50375 .19304 L
s
.5 .20961 m
.50375 .20961 L
s
.5 .24275 m
.50375 .24275 L
s
.5 .25931 m
.50375 .25931 L
s
.5 .27588 m
.50375 .27588 L
s
.5 .29245 m
.50375 .29245 L
s
.5 .32558 m
.50375 .32558 L
s
.5 .34215 m
.50375 .34215 L
s
.5 .35872 m
.50375 .35872 L
s
.5 .37529 m
.50375 .37529 L
s
.5 .40842 m
.50375 .40842 L
s
.5 .42499 m
.50375 .42499 L
s
.5 .44156 m
.50375 .44156 L
s
.5 .45813 m
.50375 .45813 L
s
.5 .49126 m
.50375 .49126 L
s
.5 .50783 m
.50375 .50783 L
s
.5 .5244 m
.50375 .5244 L
s
.5 .54097 m
.50375 .54097 L
s
.5 .04393 m
.50375 .04393 L
s
.5 .02737 m
.50375 .02737 L
s
.5 .0108 m
.50375 .0108 L
s
.5 .5741 m
.50375 .5741 L
s
.5 .59067 m
.50375 .59067 L
s
.5 .60724 m
.50375 .60724 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .19865 m
.02499 .27223 L
.02605 .30902 L
.02729 .16187 L
.02846 .27223 L
.02954 .27223 L
.03053 .19865 L
.03163 .38259 L
.03279 .30902 L
.03395 .27223 L
.0352 .3458 L
.03638 .23544 L
.03746 .27223 L
.03873 .30902 L
.03944 .30902 L
.04011 .16187 L
.04132 .30902 L
.04262 .30902 L
.04387 .19865 L
.04519 .27223 L
.04588 .16187 L
.04664 .12508 L
.04733 .19865 L
.04797 .30902 L
.04925 .27223 L
.05041 .27223 L
.05105 .19865 L
.05175 .27223 L
.05302 .23544 L
.05414 .16187 L
.05539 .27223 L
.05669 .27223 L
.05791 .30902 L
.05905 .27223 L
.06009 .19865 L
.06124 .23544 L
.06244 .23544 L
.06369 .27223 L
.06439 .16187 L
.06504 .41938 L
.06623 .30902 L
.06748 .19865 L
.06818 .30902 L
.06883 .27223 L
.06954 .41938 L
.07031 .23544 L
.07099 .23544 L
.07165 .23544 L
.07287 .23544 L
.07403 .30902 L
Mistroke
.07512 .27223 L
.07637 .23544 L
.07751 .23544 L
.07877 .27223 L
.08013 .30902 L
.0814 .3458 L
.08257 .30902 L
.08384 .27223 L
.08456 .30902 L
.08521 .38259 L
.08648 .19865 L
.08768 .27223 L
.08835 .30902 L
.08907 .27223 L
.09036 .27223 L
.09105 .16187 L
.09177 .30902 L
.09256 .23544 L
.09328 .27223 L
.09392 .27223 L
.0946 .23544 L
.09536 .3458 L
.09605 .38259 L
.09675 .38259 L
.09742 .19865 L
.09865 .38259 L
.09937 .27223 L
.10014 .27223 L
.10079 .38259 L
.1015 .30902 L
.10227 .38259 L
.10309 .27223 L
.10387 .23544 L
.10458 .3458 L
.10575 .23544 L
.10686 .23544 L
.10807 .08829 L
.10938 .12508 L
.11067 .27223 L
.11132 .27223 L
.11204 .23544 L
.1133 .23544 L
.11448 .19865 L
.11567 .23544 L
.1168 .19865 L
.11781 .12508 L
.11891 .27223 L
.1201 .16187 L
.12137 .16187 L
.12245 .16187 L
Mistroke
.12364 .23544 L
.1243 .19865 L
.12502 .19865 L
.12634 .23544 L
.12762 .19865 L
.12881 .16187 L
.12953 .19865 L
.13022 .19865 L
.13149 .19865 L
.13221 .19865 L
.13287 .30902 L
.13359 .12508 L
.13436 .27223 L
.13555 .30902 L
.13683 .23544 L
.13804 .16187 L
.13914 .27223 L
.14044 .19865 L
.14116 .16187 L
.14184 .19865 L
.14308 .12508 L
.14439 .12508 L
.14896 .12508 L
.15017 .16187 L
.15146 .27223 L
.15267 .16187 L
.15377 .12508 L
.15507 .01472 L
.15629 .23544 L
.15761 .19865 L
.15836 .38259 L
.15905 .30902 L
.16016 .01472 L
.16139 .27223 L
.16268 .12508 L
.16388 .23544 L
.16501 .19865 L
.16624 .12508 L
.16741 .19865 L
.16849 .23544 L
.16956 .3458 L
.17053 .19865 L
.17164 .23544 L
.1727 .27223 L
.17385 .19865 L
.17507 .30902 L
.17611 .27223 L
.17725 .19865 L
.17848 .16187 L
.17979 .08829 L
Mistroke
.18103 .23544 L
.18216 .23544 L
.18336 .23544 L
.18466 .16187 L
.18588 .30902 L
.18699 .27223 L
.18824 .23544 L
.18943 .30902 L
.19071 .41938 L
.19144 .12508 L
.19211 .23544 L
.19331 .19865 L
.19444 .27223 L
.19546 .23544 L
.19656 .27223 L
.19776 .30902 L
.19903 .27223 L
.20011 .41938 L
.2013 .27223 L
.20197 .38259 L
.20269 .19865 L
.20401 .3458 L
.2053 .3458 L
.20649 .19865 L
.20777 .38259 L
.2085 .23544 L
.20918 .27223 L
.2099 .27223 L
.21056 .30902 L
.21128 .3458 L
.21205 .3458 L
.21325 .30902 L
.21453 .3458 L
.21574 .38259 L
.21684 .23544 L
.21813 .30902 L
.21886 .19865 L
.21953 .23544 L
.22077 .27223 L
.22208 .16187 L
.22329 .23544 L
.22461 .3458 L
.22585 .3458 L
.22701 .27223 L
.22815 .23544 L
.22919 .3458 L
.23039 .30902 L
.23151 .30902 L
.23275 .30902 L
.23405 .3458 L
Mistroke
.23516 .30902 L
.23638 .45617 L
.2377 .23544 L
.23843 .27223 L
.23911 .30902 L
.24041 .16187 L
.24165 .19865 L
.2427 .19865 L
.24386 .19865 L
.24507 .30902 L
.24621 .27223 L
.24726 .16187 L
.24824 .30902 L
.2493 .30902 L
.25042 .23544 L
.25156 .30902 L
.25278 .19865 L
.25393 .19865 L
.25498 .23544 L
.25621 .19865 L
.2569 .12508 L
.25754 .27223 L
.25871 .23544 L
.25996 .25384 L
.26117 .25384 L
.26249 .29062 L
.26374 .19865 L
.2649 .27223 L
.26594 .29062 L
.26709 .27223 L
.26828 .19865 L
.26941 .21705 L
.27065 .29062 L
.27196 .19865 L
.27307 .19865 L
.27429 .27223 L
.27561 .23544 L
.27634 .27223 L
.27702 .19865 L
.27766 .23544 L
.27835 .21705 L
.27956 .16187 L
.2807 .21705 L
.28176 .21705 L
.28293 .27223 L
.28419 .10668 L
.2855 .23544 L
.28675 .30902 L
.28787 .18026 L
.28909 .18026 L
Mistroke
.29023 .23544 L
.2913 .27223 L
.29253 .23544 L
.29365 .18026 L
.29471 .23544 L
.29568 .18026 L
.29675 .21705 L
.29788 .21705 L
.2991 .25384 L
.29975 .23544 L
.30043 .29062 L
.30168 .29062 L
.30284 .27223 L
.30388 .23544 L
.30499 .23544 L
.30622 .27223 L
.30736 .29062 L
.3086 .25384 L
.3093 .23544 L
.30995 .23544 L
.31126 .23544 L
.312 .29062 L
.31267 .19865 L
.31387 .16187 L
.31517 .25384 L
.31639 .23544 L
.31753 .23544 L
.31858 .29062 L
.31972 .23544 L
.32079 .25384 L
.32177 .29062 L
.32291 .27223 L
.32416 .27223 L
.32534 .25384 L
.32643 .30902 L
.32767 .27223 L
.32883 .30902 L
.32987 .25384 L
.331 .27223 L
.33223 .30902 L
.33353 .30902 L
.33465 .29062 L
.33586 .29062 L
.33717 .29062 L
.33838 .3642 L
.33902 .30902 L
.33971 .29062 L
.34044 .25384 L
.34112 .30902 L
.34237 .27223 L
Mistroke
.34352 .32741 L
.34484 .30902 L
.3461 .3458 L
.34722 .23544 L
.34841 .3642 L
.34953 .29062 L
.35055 .27223 L
.35175 .27223 L
.35306 .27223 L
.35428 .38259 L
.35542 .30902 L
.35663 .32741 L
.35792 .30902 L
.35904 .29062 L
.36027 .27223 L
.36101 .25384 L
.36169 .32741 L
.36235 .30902 L
.36305 .38259 L
.36426 .32741 L
.36489 .32741 L
.36559 .25384 L
.36627 .32741 L
.36698 .32741 L
.36826 .3458 L
.36898 .30902 L
.36975 .3458 L
.37048 .29062 L
.37114 .30902 L
.37242 .38259 L
.37315 .30902 L
.37382 .30902 L
.37504 .3458 L
.37635 .3458 L
.38577 .3458 L
.38697 .29982 L
.38826 .30902 L
.38899 .29982 L
.38966 .29982 L
.39097 .31821 L
.39219 .29982 L
.39351 .30902 L
.39476 .3642 L
.3959 .3458 L
.39706 .3642 L
.39831 .29062 L
.39948 .29062 L
.40055 .29062 L
.40168 .26303 L
.4029 .29062 L
Mistroke
.40422 .25384 L
.40547 .30902 L
.40651 .33661 L
.40767 .29982 L
.40888 .30902 L
.41001 .29982 L
.41106 .28143 L
.41203 .30902 L
.41309 .26303 L
.41421 .28143 L
.41545 .28143 L
.41614 .29982 L
.41679 .30902 L
.41797 .28143 L
.41922 .22624 L
.42034 .29982 L
.42139 .31821 L
.42253 .27223 L
.42377 .28143 L
.42508 .30902 L
.42582 .32741 L
.4265 .25384 L
.42776 .19865 L
.42847 .25384 L
.4291 .22624 L
.43031 .29062 L
.43161 .28143 L
.43284 .27223 L
.43397 .27223 L
.43504 .30902 L
.43618 .21705 L
.43726 .24464 L
.43824 .28143 L
.43939 .26303 L
.44064 .23544 L
.44182 .29062 L
.44292 .26303 L
.44404 .29982 L
.44509 .26303 L
.44635 .27683 L
.44749 .18946 L
.44869 .24924 L
.44983 .24464 L
.45103 .22624 L
.45235 .29522 L
.45299 .23084 L
.45367 .25843 L
.4549 .31362 L
.45621 .22165 L
.45696 .18946 L
Mistroke
.45766 .19865 L
.45892 .26303 L
.46007 .21245 L
.46071 .29062 L
.4614 .22165 L
.46266 .30442 L
.46378 .34121 L
.46502 .25384 L
.46631 .26763 L
.46752 .27683 L
.46865 .28602 L
.46968 .23544 L
.47082 .25154 L
.47201 .26303 L
.47333 .27223 L
.47452 .25843 L
.47518 .24924 L
.4759 .30902 L
.4772 .26303 L
.47842 .29752 L
.47971 .29292 L
.48082 .30442 L
.48203 .32971 L
.48276 .28373 L
.48346 .32281 L
.48476 .29982 L
.48549 .29867 L
.48616 .32511 L
.4869 .25613 L
.48769 .27108 L
.48838 .31936 L
.48912 .31132 L
.48982 .25039 L
.49047 .32396 L
.49169 .26533 L
.49299 .32109 L
.49421 .30039 L
.4949 .25441 L
.49554 .3481 L
.49671 .33115 L
.49796 .32109 L
.49907 .27309 L
.50011 .32795 L
.50126 .30873 L
.50249 .33747 L
.50372 .30557 L
.50442 .2751 L
.50508 .36707 L
.50639 .30154 L
.50713 .32396 L
Mistroke
.5078 .33776 L
.509 .28488 L
.5103 .31017 L
.51152 .29982 L
.51266 .3619 L
.51373 .30672 L
.51487 .36075 L
.51614 .28832 L
.5173 .32741 L
.51851 .27453 L
.51982 .28832 L
.52106 .3458 L
.52221 .3688 L
.52325 .32971 L
.52424 .31132 L
.52531 .355 L
.52647 .31362 L
.52762 .3688 L
.52884 .3734 L
.52987 .34121 L
.53101 .3642 L
.53232 .30442 L
.53353 .37799 L
.53417 .30902 L
.53487 .355 L
.5356 .3688 L
.53628 .31362 L
.53753 .3688 L
.53868 .3504 L
.53931 .34121 L
.54 .40099 L
.54126 .3504 L
.54249 .34121 L
.5436 .31821 L
.54489 .38259 L
.5461 .33661 L
.54722 .3596 L
.54826 .38719 L
.54939 .33201 L
.55059 .37799 L
.55189 .33661 L
.55308 .38259 L
.55374 .3596 L
.55445 .32741 L
.55575 .28143 L
.55697 .37799 L
.55826 .3688 L
.55936 .31821 L
.56057 .40099 L
.56126 .30902 L
Mistroke
.56199 .33661 L
.56329 .3642 L
.56402 .3458 L
.56469 .38259 L
.56543 .3458 L
.56623 .355 L
.56691 .33661 L
.56766 .32741 L
.56836 .33661 L
.569 .3734 L
.57023 .355 L
.57153 .32741 L
.57274 .38259 L
.57406 .30902 L
.57531 .355 L
.57646 .31821 L
.57761 .355 L
.57865 .32741 L
.57985 .33661 L
.58097 .33661 L
.58221 .31821 L
.58351 .29982 L
.58463 .32741 L
.58585 .32741 L
.58717 .32741 L
.5879 .32741 L
.58857 .27223 L
.58988 .29982 L
.59111 .27223 L
.59217 .33661 L
.59333 .29982 L
.59454 .27223 L
.59568 .3458 L
.59674 .32741 L
.59771 .30902 L
.59883 .31821 L
.5999 .29062 L
.60104 .355 L
.60226 .32741 L
.60341 .29982 L
.60445 .25384 L
.60568 .29062 L
.60633 .26303 L
.60702 .32741 L
.60827 .29062 L
.60943 .355 L
.61065 .31821 L
.61134 .29982 L
.61197 .33661 L
.61314 .21705 L
Mistroke
.61438 .29062 L
.61549 .30902 L
.61653 .28143 L
.61767 .28143 L
.6189 .29062 L
.62148 .30902 L
.62216 .21705 L
.62289 .29062 L
.6242 .32741 L
.62541 .27223 L
.62652 .23544 L
.62782 .25384 L
.62906 .29062 L
.63011 .23544 L
.63128 .27223 L
.63249 .25384 L
.63363 .25384 L
.63469 .29062 L
.63566 .30902 L
.63679 .27223 L
.63785 .29062 L
.64006 .29062 L
.64129 .29062 L
.64241 .3642 L
.64305 .29062 L
.64374 .21705 L
.64499 .23544 L
.64624 .27223 L
.64739 .32741 L
.64865 .30902 L
.64985 .29062 L
.65093 .32741 L
.6521 .21705 L
.65337 .32741 L
.65401 .23544 L
.65472 .29062 L
.65597 .32741 L
.65714 .27223 L
.65825 .3642 L
.65943 .25384 L
.66043 .29062 L
.66152 .32741 L
.6627 .3458 L
.66396 .30902 L
.66516 .3458 L
.66624 .27223 L
.66753 .29062 L
.66818 .27223 L
.66889 .38259 L
.67016 .3642 L
Mistroke
.67134 .32741 L
.67206 .32741 L
.67274 .32741 L
.67401 .29062 L
.67472 .38259 L
.67538 .3458 L
.67611 .3458 L
.67687 .32741 L
.67806 .32741 L
.67933 .32741 L
.68054 .32741 L
.68164 .30902 L
.68287 .38259 L
.68356 .3642 L
.68421 .3642 L
.68551 .32741 L
.68624 .29062 L
.68691 .32741 L
.6881 .32741 L
.68921 .3642 L
.69043 .27223 L
.69174 .3458 L
.6924 .40099 L
.69311 .3642 L
.69442 .3642 L
.69569 .32741 L
.69687 .30902 L
.69807 .38259 L
.6992 .41938 L
.70022 .3458 L
.70132 .3458 L
.70606 .3458 L
.72684 .3458 L
.72807 .32741 L
.72876 .3642 L
.7294 .29062 L
.73057 .3642 L
.73182 .40099 L
.7325 .3642 L
.73315 .41938 L
.73385 .41938 L
.73461 .41938 L
.73526 .3642 L
.73594 .27223 L
.73715 .27223 L
.73831 .30902 L
.73954 .38259 L
.7407 .3458 L
.74175 .41938 L
.74299 .38259 L
Mistroke
.74369 .3458 L
.74434 .38259 L
.74553 .3458 L
.74678 .3458 L
.74797 .38259 L
.74925 .38259 L
.75046 .3458 L
.75156 .41938 L
.75286 .3458 L
.75359 .38259 L
.75426 .30902 L
.7555 .27223 L
.75683 .30902 L
.75752 .30902 L
.75826 .3458 L
.75906 .27223 L
.75981 .27223 L
.7605 .3458 L
.76114 .30902 L
.76185 .27223 L
.76261 .30902 L
.76329 .3458 L
.76402 .30902 L
.76471 .27223 L
.76535 .30902 L
.76656 .3458 L
.76785 .19865 L
.76899 .23544 L
.77024 .3458 L
.77154 .30902 L
.77275 .23544 L
.77389 .3458 L
.77493 .27223 L
.77612 .27223 L
.77724 .19865 L
.77847 .27223 L
.77977 .3458 L
.78088 .30902 L
.7821 .30902 L
.78341 .27223 L
.78415 .19865 L
.78482 .3458 L
.78612 .38259 L
.78736 .23544 L
.78841 .27223 L
.78956 .3458 L
.79077 .30902 L
.79191 .23544 L
.79296 .30902 L
.79393 .3458 L
Mistroke
.795 .3458 L
.79612 .30902 L
.79725 .3458 L
.79832 .23544 L
.79955 .38259 L
.80067 .19865 L
.80191 .3458 L
.80261 .23544 L
.80325 .3458 L
.80442 .23544 L
.80565 .38259 L
.80686 .3458 L
.80818 .30902 L
.80942 .41938 L
.81058 .38259 L
.81169 .30902 L
.81289 .23544 L
.81403 .27223 L
.81508 .27223 L
.81633 .30902 L
.81765 .38259 L
.81876 .3458 L
.81998 .23544 L
.82129 .38259 L
.82202 .3458 L
.82268 .38259 L
.82398 .3458 L
.82521 .30902 L
.82626 .30902 L
.82742 .27223 L
.82863 .27223 L
.82976 .38259 L
.83082 .23544 L
.83179 .38259 L
.83286 .3458 L
.83398 .23544 L
.83512 .45617 L
.83634 .38259 L
.83749 .38259 L
.83853 .38259 L
.83976 .3458 L
.84045 .3458 L
.84109 .45617 L
.84227 .19865 L
.84351 .3458 L
.84472 .3458 L
.84605 .3458 L
.84729 .38259 L
.84845 .45617 L
.8496 .41938 L
Mistroke
.85063 .41938 L
.85183 .38259 L
.85296 .30902 L
.8542 .41938 L
.8555 .3458 L
.85662 .3458 L
.85784 .38259 L
.85915 .3458 L
.85989 .38259 L
.86056 .41938 L
.86187 .3458 L
.8631 .30902 L
.86416 .38259 L
.86532 .41938 L
.86653 .30902 L
.86767 .41938 L
.86873 .19865 L
.8697 .3458 L
.87082 .41938 L
.87189 .3458 L
.87303 .45617 L
.87425 .3458 L
.8754 .30902 L
.87644 .30902 L
.87768 .49296 L
.87837 .23544 L
.87901 .30902 L
.88018 .23544 L
.88142 .3458 L
.88264 .27223 L
.88333 .3458 L
.88397 .3458 L
.88638 .3458 L
.89089 .3458 L
.89582 .3458 L
.89831 .3458 L
.89899 .3458 L
.89972 .3458 L
.90042 .3458 L
.90105 .19865 L
.90212 .27223 L
.90326 .30902 L
.90434 .3458 L
.90532 .27223 L
.90647 .23544 L
.90772 .23544 L
.90889 .3458 L
.90998 .30902 L
.9111 .27223 L
.91216 .30902 L
Mistroke
.91331 .3458 L
.91455 .30902 L
.91584 .49296 L
.91707 .38259 L
.91818 .41938 L
.91938 .3458 L
.92003 .41938 L
.92072 .38259 L
.92194 .30902 L
.92326 .3458 L
.92471 .38259 L
.92713 .45617 L
.92777 .38259 L
.92846 .19865 L
.92972 .52974 L
.93104 .45617 L
.93226 .38259 L
.93338 .38259 L
.93457 .3458 L
.93568 .41938 L
.93672 .30902 L
.93786 .45617 L
.93909 .38259 L
.94041 .3458 L
.94164 .30902 L
.94235 .41938 L
.94299 .41938 L
.94373 .38259 L
.94443 .45617 L
.94511 .52974 L
.94583 .38259 L
.94712 .45617 L
.94779 .45617 L
.94851 .52974 L
.9493 .52974 L
.95004 .30902 L
.95133 .38259 L
.95206 .52974 L
.95273 .38259 L
.95397 .38259 L
.95529 .38259 L
.95646 .23544 L
.95756 .30902 L
.95877 .52974 L
.96007 .30902 L
.96101 .60332 L
.96201 .52974 L
.96296 .23544 L
.96382 .23544 L
.96483 .23544 L
Mistroke
.96593 .38259 L
.96696 .45617 L
.96792 .30902 L
.96891 .38259 L
.96983 .23544 L
.97084 .38259 L
.97193 .23544 L
.97307 .45617 L
.97416 .38259 L
.97513 .23544 L
.97619 .45617 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{229.875, 142.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0000/B000`400?l00000o`00003oS`3oool0
0`000000oooo0?ooo`2=0?ooo`00S`3oool00`000000oooo0?ooo`2=0?ooo`00S`3oool00`000000
oooo0?ooo`2=0?ooo`00S`3oool2000008h0oooo000/0?ooo`030000003oool000000600oooo00<0
00000?ooo`3oool0S@3oool002`0oooo00<000000?ooo`000000H03oool00`000000oooo0?ooo`2=
0?ooo`00;03oool00`000000oooo0000001P0?ooo`030000003oool0oooo08d0oooo000/0?ooo`03
0000003oool000000600oooo00<000000?ooo`3oool0S@3oool002`0oooo00<000000?ooo`000000
H03oool2000008h0oooo000/0?ooo`030000003oool000000600oooo00<000000?ooo`3oool0S@3o
ool002`0oooo00<000000?ooo`000000H03oool00`000000oooo0?ooo`2=0?ooo`00;03oool00`00
0000oooo0000001P0?ooo`030000003oool0oooo08d0oooo000/0?ooo`030000003oool000000600
oooo00<000000?ooo`3oool0S@3oool002`0oooo00<000000?ooo`0000008`3oool00`000000oooo
0?ooo`040?ooo`8000001@3oool4000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`D0
00000`3oool4000001<0oooo0P00002>0?ooo`00;03oool00`000000oooo0000000S0?ooo`030000
003oool0oooo00@0oooo0P0000040?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0
oooo0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0S@3oool002`0oooo00<000000?ooo`00
00008`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`2=0?ooo`00;03oool00`000000oooo0000000H0?ooo`H00000
1P3oool00`000000oooo0?ooo`0>0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo08d0oooo000/0?ooo`030000003oool0000002@0oooo00<000000?ooo`3o
ool02P3oool4000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`<00000S@3oool002`0
oooo00<000000?ooo`0000009@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0S@3oool002`0oooo00<000000?ooo`000000803oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool3000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`D0000000<0oooo000000000000
103oool00`000000oooo0?ooo`2=0?ooo`00;03oool00`000000oooo0000000P0?ooo`H000002`3o
ool5000000d0oooo00<000000?ooo`3oool00`3oool4000000T0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0S@3oool002`0oooo00<000000?ooo`000000
D03oool3000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?oo
o`3oool0S@3oool002`0oooo00<000000?ooo`000000EP3oool010000000oooo0?ooo`3oool20000
00@0oooo0P00002>0?ooo`00;03oool00`000000oooo0000001F0?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo0?ooo`2=0?ooo`00;03oool00`000000oooo0000001E0?ooo`80
0000103oool2000000<0oooo00<000000?ooo`3oool0S@3oool001l0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo000000050?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
S@3oool001l0oooo00<000000?ooo`3oool02P3oool00`000000oooo000000050?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0S@3oool001l0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo000000050?ooo`030000003oool0oooo05P0oooo0P00002>0?ooo`007`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`2=0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`2=0?ooo`007`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo08d0oooo000O0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`0000001@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03/0oooo0P00
002>0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo08d0oooo000O0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0S@3oool001l0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo000000050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`2=0?ooo`007`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo08d0oooo000>0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0800000080oooo0P0000020?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0k0?ooo`800000SP3oool000h0oooo00<0
00000?ooo`3oool03P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0000003o
ool01P0000020?ooo`8000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool02`3oool4000000<0oooo00D000000?ooo`3oool0oooo000000040?oo
o`D000000`3oool4000001@0oooo00<000000?ooo`3oool0S@3oool000h0oooo00<000000?ooo`3o
ool03P3oool010000000oooo0?ooo`0000030?ooo`050000003oool0oooo0000003oool01P000002
0?ooo`8000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo
000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo08d0oooo000>0?ooo`030000003oool0oooo00h0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`000000oooo00H000000P3oool200000080
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo08d0
oooo000>0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`000000oooo00H000000P3oool200000080oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo1P0000070?ooo`070000003oool0oooo
0?ooo`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo08d0oooo000=0?ooo`800000403oool0
10000000oooo0?ooo`0000030?ooo`050000003oool0oooo0000003oool01P0000020?ooo`800000
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2`3oool4000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`<00000S@3oool000d0oooo
0P00000@0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool000000?ooo`060000
0080oooo0P0000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0S@3oool000d0
oooo0P00000@0?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool000000?ooo`06
00000080oooo0P0000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo0`0000040?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool5000000030?ooo`000000000000D0oooo00<00000
0?ooo`3oool0S@3oool000d0oooo0P00000@0?ooo`040000003oool0oooo000000<0oooo00D00000
0?ooo`3oool000000?ooo`0600000080oooo0P0000020?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`D000003@3oool00`000000oooo0?oo
o`030?ooo`@000002@3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000
oooo0?ooo`2=0?ooo`003@3oool200000100oooo00@000000?ooo`3oool000000`3oool01@000000
oooo0?ooo`000000oooo00H000000P3oool200000080oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo0`0000030?ooo`070000003oool0oooo
0?ooo`000000oooo000000040?ooo`030000003oool0oooo08d0oooo00080?ooo`040000003oool0
oooo0?ooo`<0000000D0oooo0000003oool0oooo000000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P000000103oool000000000003oool2000000030?ooo`000000000000@0
00000P3oool3000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000020?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`030000003oool0oooo02L0
oooo00@000000?ooo`3oool0oooo0P0000050?ooo`800000SP3oool000P0oooo00@000000?ooo`3o
ool0oooo0`0000001@3oool000000?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`02000000040?ooo`00000000000?ooo`80000000<0oooo0000000000001000
00020?ooo`<0000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool000000?ooo`8000001@3oool2000000P0oooo00<000000?ooo`3oool09`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0S@3oool000P0oooo00@000000?ooo`3oool0
oooo0`0000001@3oool000000?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`02000000040?ooo`00000000000?ooo`80000000<0oooo00000000000010000002
0?ooo`<0000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
00000?ooo`8000001@3oool2000000P0oooo00<000000?ooo`3oool09P3oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo08d0oooo00080?ooo`040000003oool0oooo0?ooo`<0000000D0
oooo0000003oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P000000103oool000000000003oool2000000030?ooo`000000000000@000000P3oool300000003
0?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0000003oool20000
00D0oooo0`0000070?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0S@3oool000P0
oooo00@000000?ooo`3oool0oooo0`0000001@3oool000000?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`02000000040?ooo`00000000000?ooo`80000000<0
oooo000000000000100000020?ooo`<0000000<0oooo0000003oool01`3oool00`000000oooo0?oo
o`020?ooo`040000003oool000000?ooo`8000001@3oool3000000L0oooo00<000000?ooo`3oool0
<P3oool2000008h0oooo00080?ooo`040000003oool0oooo0?ooo`<0000000D0oooo0000003oool0
oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P000000103oool0
00000000003oool2000000030?ooo`000000000000@000000P3oool3000000030?ooo`000000oooo
00L0oooo00<000000?ooo`3oool00P3oool010000000oooo0000003oool2000000D0oooo1P000004
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0S@3oool000P0oooo00@000000?oo
o`3oool0oooo0`0000001@3oool000000?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`02000000040?ooo`00000000000?ooo`80000000<0oooo000000000000
100000020?ooo`<0000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`020?ooo`040000
003oool000000?ooo`8000001@3oool6000000@0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`2=0?ooo`00203oool010000000oooo0?ooo`3oool3000000050?ooo`000000oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080000000@0oooo0000
00000000oooo0P0000000`3oool000000000000400000080oooo0`0000000`3oool000000?ooo`07
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo0P0000050?ooo`H00000103o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo08d0oooo00080?ooo`040000003oool0
oooo0?ooo`<0000000D0oooo0000003oool0oooo000000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P000000103oool000000000003oool2000000030?ooo`000000000000@0
00000P3oool3000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool00P3oool010000000
oooo0000003oool2000000D0oooo1P0000040?ooo`030000003oool0oooo02<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`2=0?ooo`00203oool010000000oooo0?ooo`3oool3
000000050?ooo`000000oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080000000@0oooo000000000000oooo0P0000000`3oool000000000000400000080oooo
0`0000000`3oool000000?ooo`070?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000
oooo0P0000050?ooo`H00000103oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo0000
00/0oooo0P00002>0?ooo`00203oool010000000oooo0?ooo`3oool3000000050?ooo`000000oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080000000@0oooo
000000000000oooo0P0000000`3oool000000000000400000080oooo0`0000000`3oool000000?oo
o`070?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000oooo0P0000050?ooo`H00000
103oool00`000000oooo0?ooo`0S0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3o
ool0S@3oool000L0oooo0`0000020?ooo`H0000000<0oooo0000003oool0103oool2000000060?oo
o`000000oooo0?ooo`000000oooo2@0000000`3oool0000000000009000000040?ooo`000000oooo
0?ooo`8000000`3oool2000000@0oooo1P0000000`3oool0000000000008000000@0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool0BP3oool01@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0C0?ooo`001`3oool300000080oooo1P0000000`3oool000000?oo
o`040?ooo`80000000@0oooo0000003oool0oooo2P0000020?ooo`/0000000@0oooo0000003oool0
oooo0P0000030?ooo`800000103oool6000000030?ooo`000000000000P00000103oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`1:0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01<0oooo00070?ooo`<000000P3oool6000000030?ooo`000000oooo
00@0oooo0P000000103oool000000?ooo`3oool:00000080oooo2`000000103oool000000?ooo`3o
ool2000000<0oooo0P0000040?ooo`H0000000<0oooo000000000000200000040?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo04X0oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04`3oool000L0oooo0`0000020?ooo`H0000000<0oooo0000003oool0
103oool2000000040?ooo`000000oooo0?ooo`X000000P3oool;000000040?ooo`000000oooo0?oo
o`8000000`3oool2000000@0oooo1P0000000`3oool0000000000008000000<0oooo0P0000050?oo
o`@000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo1@0000030?ooo`@00000103oool0
10000000oooo0?ooo`00000;0?ooo`800000B`3oool01@000000oooo0000003oool0000000@0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`001`3oool300000080oooo1P00
00000`3oool000000?ooo`040?ooo`80000000@0oooo0000003oool0oooo2P0000020?ooo`/00000
00@0oooo0000003oool0oooo0P0000030?ooo`800000103oool6000000030?ooo`000000000000P0
00000`3oool2000000@0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`02000000X0oooo00<000000?ooo`3oool0BP3oool01@000000oooo
0000003oool0000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`00
1`3oool300000080oooo200000050?ooo`80000000@0oooo0000003oool0oooo100000000`3oool0
00000?ooo`0300000080oooo00<000000?ooo`00000020000000103oool000000?ooo`3oool20000
00<0oooo0P0000040?ooo`H0000000<0oooo000000000000200000040?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00<000000?ooo`3oool00P00000:
0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0000
000Q0?ooo`050000003oool000000?ooo`000000103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo01<0oooo00070?ooo`<000000P3oool8000000D0oooo0P000000103oool000000?oo
o`3oool4000000030?ooo`000000oooo00<000000P3oool00`000000oooo00000008000000040?oo
o`000000oooo0?ooo`8000000`3oool2000000@0oooo4@0000040?ooo`030000003oool0oooo00L0
oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`000000oooo008000000P3oool00`000000oooo0?ooo`02000000X0oooo00<0
00000?ooo`3oool07@3oool010000000oooo0?ooo`0000050?ooo`030000003oool000000240oooo
00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool04`3oool000L0oooo0`0000020?ooo`P000001@3oool2000000040?ooo`000000oooo0?ooo`@0
000000<0oooo0000003oool00`0000020?ooo`030000003oool0000000P0000000@0oooo0000003o
ool0oooo0P0000030?ooo`800000103oool6000000030?ooo`000000000000P00000103oool00`00
0000oooo0?ooo`030?ooo`@000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`000000oooo008000000P3oool00`000000oooo0?oo
o`02000000X0oooo00<000000?ooo`3oool07@3oool010000000oooo0?ooo`0000050?ooo`030000
003oool000000240oooo00D000000?ooo`000000oooo000000040?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool04`3oool000L0oooo0`0000020?ooo`P000001@3oool2000000040?oo
o`000000oooo0?ooo`@0000000<0oooo0000003oool00`0000020?ooo`030000003oool0000000P0
000000@0oooo0000003oool0oooo0P0000030?ooo`800000103oool6000000030?ooo`0000000000
00P00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00P3oool2000000030?ooo`0000000000008000000P3oool2000000030?ooo`0000000000
00X0oooo0`00000M0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000008@3oool0
1@000000oooo0000003oool0000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0C0?ooo`001`3oool300000080oooo200000050?ooo`80000000@0oooo0000003oool0oooo1000
00000`3oool000000?ooo`0300000080oooo00<000000?ooo`00000020000000103oool000000?oo
o`3oool2000000<0oooo0P0000040?ooo`H0000000<0oooo000000000000200000040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool3000000@0oooo0P0000000`3oool00000
0000000200000080oooo1@00000:0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0000000Q0?ooo`050000003oool000000?ooo`000000103oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo00070?ooo`<0000000<0oooo00000000
00002P0000020?ooo`@0000000<0oooo0000000000000`0000000`3oool000000?ooo`0300000080
oooo00<000000?ooo`0000002`0000001@3oool00000000000000000oooo00@000000P3oool00`00
0000oooo00000004000000030?ooo`000000000000X0000000<0oooo0000000000000P0000030?oo
o`D000003@3oool00`000000oooo0?ooo`030?ooo`@0000000@0oooo000000000000oooo20000000
0`3oool00000000000040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`000003
0?ooo`040000003oool0000000000200oooo0`0000001@3oool00000000000000000oooo00<00000
00@0oooo0000003oool000000P3oool200000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`02000000D0oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000100000070?ooo`001`3oool3000000030?ooo`000000000000X000000P3oool4000000060?oo
o`000000oooo0000003oool000000`3oool300000080oooo00D000000?ooo`00000000000?ooo`04
000000030?ooo`00000000000080000000D0oooo00000000000000000?ooo`0400000080oooo00<0
00000?ooo`0000000P0000000`3oool000000?ooo`04000000030?ooo`00000000000080000000@0
oooo000000000000oooo100000060?ooo`030000003oool0oooo0180oooo00D000000?ooo`000000
00000?ooo`02000000030?ooo`000000000000D000000P3oool00`000000oooo000000030?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool00`0000030?ooo`040000003oool000000000
0200oooo1`000000203oool00000000000000000oooo0000003oool000000P3oool200000080oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02000000D0oooo0P0000050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`000000100000070?ooo`001`3oool3000000030?ooo`00
0000000000X000000P3oool4000000060?ooo`000000oooo0000003oool000000`3oool300000080
oooo00D000000?ooo`00000000000?ooo`04000000030?ooo`00000000000080000000D0oooo0000
0000000000000?ooo`0400000080oooo00<000000?ooo`0000000P0000000`3oool000000?ooo`04
000000030?ooo`00000000000080000000@0oooo000000000000oooo100000060?ooo`030000003o
ool0oooo0180oooo00D000000?ooo`00000000000?ooo`0:00000080oooo00<000000?ooo`000000
0`3oool2000001h0oooo00<000000?ooo`3oool00`0000030?ooo`040000003oool0000000000200
oooo1`000000203oool00000000000000000oooo0000003oool000000P3oool200000080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`02000000D0oooo0P0000050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`000000100000070?ooo`001`3oool3000000030?ooo`000000
000000X000000P3oool4000000060?ooo`000000oooo0000003oool000000`3oool300000080oooo
00D000000?ooo`00000000000?ooo`04000000030?ooo`00000000000080000000D0oooo00000000
000000000?ooo`0400000080oooo00<000000?ooo`0000000P0000000`3oool00000000000040000
00030?ooo`00000000000080000000<0oooo0000000000001@0000060?ooo`030000003oool0oooo
0180oooo00D000000?ooo`00000000000?ooo`02000000030?ooo`000000000000H0000000<0oooo
000000000000103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<000000`3oool0
10000000oooo00000000000P0?ooo`L0000000P0oooo00000000000000000?ooo`000000oooo0000
0080oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P0000050?oo
o`8000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000@000001`3oool000L0
oooo0`0000000`3oool000000000000:00000080oooo100000001P3oool000000?ooo`000000oooo
000000<0oooo0`0000020?ooo`050000003oool000000000003oool0100000000`3oool000000000
0002000000050?ooo`00000000000000003oool0100000020?ooo`030000003oool0000000800000
00<0oooo000000000000100000000`3oool0000000000002000000030?ooo`000000000000D00000
1P3oool00`000000oooo0?ooo`0B0?ooo`050000003oool000000000003oool00P0000000`3oool0
00000000000800000080oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`030000
00<0oooo00@000000?ooo`0000000000803oool7000000080?ooo`00000000000000003oool00000
0?ooo`0000020?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
00001@3oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo00000004000000L0
oooo00070?ooo`<0000000<0oooo0000000000002P0000020?ooo`@0000000H0oooo0000003oool0
00000?ooo`0000030?ooo`<000000P3oool01@000000oooo000000000000oooo00@0000000<0oooo
0000000000000P0000001@3oool00000000000000000oooo00@000000P3oool00`000000oooo0000
0002000000030?ooo`000000000000@0000000<0oooo0000000000000P0000000`3oool000000000
000700000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000000:0?ooo`060000003o
ool0oooo0?ooo`000000oooo0P000000103oool000000000003oool9000000040?ooo`0000000000
00000080oooo00<000000?ooo`3oool06`3oool00`000000oooo000000020?ooo`@000000P3oool0
1P000000oooo000000000000oooo000001h0oooo1`000000203oool00000000000000000oooo0000
003oool000000P3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
000000D0oooo0P0000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00000010000007
0?ooo`001`3oool3000000030?ooo`000000000000/0000000<0oooo0000000000000P0000001P3o
ool000000?ooo`000000oooo000000<0oooo0`0000020?ooo`050000003oool000000000003oool0
100000000`3oool0000000000002000000050?ooo`00000000000000003oool0100000020?ooo`03
0000003oool000000080000000D0oooo00000000000000000?ooo`02000000040?ooo`0000000000
00000080oooo100000000`3oool000000000000200000080oooo00<000000?ooo`0000000`3oool0
0`000000oooo0000000:0?ooo`060000003oool0oooo0?ooo`000000oooo0P000000103oool00000
0000003oool900000080oooo0P0000000`3oool000000000000M0?ooo`050000003oool000000000
003oool0100000020?ooo`@0000000<0oooo0000003oool07@3oool7000000050?ooo`0000000000
0000003oool00`0000020?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo008000001@3oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo00000004
000000L0oooo00070?oooa40000000<0oooo0000000000000P0000001P3oool000000?ooo`000000
oooo000000<0oooo0`0000020?ooo`050000003oool000000000003oool0100000000`3oool00000
00000002000000050?ooo`00000000000000003oool0100000020?ooo`D0000000D0oooo00000000
000000000?ooo`02000000050?ooo`00000000000000003oool01@0000000`3oool0000000000002
00000080oooo00<000000?ooo`0000000`3oool00`000000oooo0000000:0?ooo`060000003oool0
oooo0?ooo`000000oooo0P000000103oool000000000003oool900000080oooo0P000000103oool0
000000000000000L0?ooo`050000003oool000000000003oool0100000020?ooo`@0000000<0oooo
0000003oool02P3oool4000000D0oooo0P0000050?ooo`X0000000D0oooo00000000000000000?oo
o`0300000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00
00050?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000H000001@3o
ool000L0oooo0`0000000`3oool000000000000;000000030?ooo`00000000000080000000H0oooo
0000003oool000000?ooo`0000030?ooo`<000000P3oool01@000000oooo000000000000oooo00@0
000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00@000000P3oool00`00
0000oooo00000006000000040?ooo`00000000000?ooo`@0000000<0oooo0000000000000P000000
0`3oool000000000000200000080oooo00<000000?ooo`0000000`3oool00`000000oooo00000009
0?ooo`80000000D0oooo0000003oool000000?ooo`0?00000080oooo0P0000000`3oool000000000
000M0?ooo`050000003oool000000000003oool0100000020?ooo`@0000000<0oooo0000003oool0
2@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`040000
003oool0oooo0?ooo`L0000000D0oooo00000000000000000?ooo`0300000080oooo0P0000020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P0000050?ooo`8000001@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0000000@000001`3oool000L0oooo0`0000000`3oool0
00000000000;000000030?ooo`00000000000080000000H0oooo0000003oool000000?ooo`000003
0?ooo`<000000P3oool01@000000oooo000000000000oooo00@0000000<0oooo0000000000000P00
00001@3oool00000000000000000oooo00@000000P3oool00`000000oooo00000006000000040?oo
o`00000000000?ooo`<000000P3oool4000000030?ooo`000000000000<0000000@0oooo0000003o
ool000000`3oool00`000000oooo000000090?ooo`80000000D0oooo0000003oool000000?ooo`0?
00000080oooo1@00000M0?ooo`050000003oool000000000003oool0100000020?ooo`@0000000<0
oooo0000003oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo1`00
00001@3oool00000000000000000oooo00<000000P3oool200000080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`02000000D0oooo0P0000050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`000000100000070?ooo`001P0000001@3oool00000000000000000oooo00d00000
00<0oooo0000000000000P0000001P3oool000000?ooo`000000oooo000000<0oooo0`0000020?oo
o`050000003oool000000000003oool0100000000`3oool0000000000002000000030?ooo`000000
000000H000000P3oool00`000000oooo00000006000000040?ooo`00000000000?ooo`<000000P3o
ool4000000030?ooo`000000000000<0000000@0oooo0000003oool000000`3oool00`000000oooo
000000090?ooo`80000000D0oooo0000003oool000000?ooo`09000000030?ooo`000000000000<0
00000P3oool5000001d0oooo00D000000?ooo`00000000000?ooo`0400000080oooo100000000`3o
ool000000?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool70000
00050?ooo`00000000000000003oool00`0000020?ooo`8000000P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo008000001@3oool2000000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo00000004000000L0oooo00070?oooaP0000000@0oooo0000003oool000000`3oool3
00000080oooo00D000000?ooo`00000000000?ooo`04000000030?ooo`000000000000H0000000<0
oooo0000000000000P0000020?ooo`030000003oool0000000H0000000@0oooo000000000000oooo
0`0000000`3oool0000000000003000000030?ooo`000000000000<0000000<0oooo000000000000
0`000000103oool000000?ooo`0000090?ooo`80000000<0oooo0000000000002`0000000`3oool0
00000000000300000080oooo1@0000040?ooo`030000003oool0oooo0140oooo0`0000020?ooo`05
0000003oool000000000003oool01@0000000`3oool0000000000006000000D0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`020?ooo`800000103oool?000000040?ooo`000000
000000000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P00
00040?ooo`@00000103oool00`000000oooo0?ooo`050?ooo`L000001`3oool000L0oooo1P000000
0`3oool000000?ooo`02000000030?ooo`000000000000X000001`3oool2000000D0oooo0P000000
0`3oool0000000000002000000030?ooo`000000000000H0000000<0oooo0000000000000P000002
0?ooo`030000003oool0000000<0000000D0oooo000000000000oooo000000030?ooo`030000003o
ool0oooo00D0000000<0oooo0000000000000`0000000`3oool0000000000003000000040?ooo`00
0000oooo000000T0oooo0P0000000`3oool000000000000;000000060?ooo`00000000000000003o
ool000000P3oool6000000<0oooo00<000000?ooo`3oool04@3oool300000080oooo00D000000?oo
o`00000000000?ooo`05000000030?ooo`000000000000H000001@3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo0P0000040?ooo`l0000000@0oooo0000000000000000
0P3oool200000080oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000000000@0oooo
100000040?ooo`030000003oool0oooo00D0oooo1`0000070?ooo`001`3oool6000000030?ooo`00
0000oooo0080000000<0oooo0000000000002P0000070?ooo`8000001@3oool2000000030?ooo`00
000000000080000000<0oooo0000000000001P0000000`3oool000000000000200000080oooo00<0
00000?ooo`0000000`0000001@3oool000000000003oool0000000<0oooo00<000000?ooo`3oool0
1@0000000`3oool0000000000003000000030?ooo`000000000000<0000000@0oooo0000003oool0
00002@3oool2000000030?ooo`000000000000P0000000@0oooo000000000000oooo0`000000103o
ool000000?ooo`3oool6000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`06
0?ooo`<000000P3oool00`000000oooo00000007000000030?ooo`000000000000H000001@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P0000040?ooo`l0000000@0
oooo00000000000000000P3oool200000080oooo00<000000?ooo`3oool0103oool2000000030?oo
o`000000000000@0oooo100000040?ooo`030000003oool0oooo00D0oooo1`0000070?ooo`001`3o
ool6000000030?ooo`000000oooo0080000000<0oooo0000000000002P0000070?ooo`8000001@3o
ool2000000030?ooo`00000000000080000000<0oooo0000000000001P0000000`3oool000000000
000200000080oooo1@0000020?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0?oo
o`05000000030?ooo`000000000000<0000000<0oooo0000000000000`000000103oool000000?oo
o`0000090?ooo`80000000<0oooo0000000000001@000000103oool000000000003oool200000005
0?ooo`00000000000000003oool02@0000000`3oool000000?ooo`02000000T0oooo00<000000?oo
o`3oool01P3oool300000080oooo00<000000?ooo`0000001`0000000`3oool00000000000060000
00D0oooo00@000000?ooo`3oool0oooo100000050?ooo`800000103oool?000000040?ooo`000000
000000000080oooo0P0000020?ooo`030000003oool0oooo00@0oooo0P0000000`3oool000000000
00040?ooo`@00000103oool00`000000oooo0?ooo`050?ooo`L000001`3oool000L0oooo1P000000
0`3oool000000?ooo`02000000030?ooo`000000000000X000001`3oool2000000D0oooo0P000000
0`3oool0000000000002000000030?ooo`000000000000H0000000<0oooo0000000000000P000002
0?ooo`030000003oool00000008000000P3oool2000000030?ooo`000000oooo0080oooo00H00000
0?ooo`3oool0oooo0000003oool2000000030?ooo`000000000000<0000000<0oooo000000000000
0`000000103oool000000?ooo`0000090?ooo`80000000<0oooo0000000000001@000000103oool0
00000000003oool2000000050?ooo`00000000000000003oool02@0000000`3oool000000?ooo`02
000000T0oooo00<000000?ooo`3oool01P3oool300000080oooo00<000000?ooo`0000001`000000
0`3oool0000000000006000000D0oooo00<000000?ooo`3oool02P3oool2000000@0oooo3`000000
103oool000000000000000020?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`80000000<0
oooo000000000000103oool4000000@0oooo00<000000?ooo`3oool01@3oool7000000L0oooo0007
0?ooo`H0000000<0oooo0000003oool00P0000001@3oool00000000000000000oooo00P000001`3o
ool2000000D0oooo0P000000103oool000000000000000020?ooo`P0000000<0oooo000000000000
0P0000020?ooo`030000003oool00000008000000P3oool2000000030?ooo`000000oooo0080oooo
00H000000?ooo`3oool0oooo0000003oool2000000030?ooo`000000000000T0000000<0oooo0000
000000000P0000070?ooo`/0000000@0oooo000000000000oooo0P0000000`3oool0000000000002
0?ooo`T0000000<0oooo0000003oool00P0000090?ooo`030000003oool0oooo00H0oooo0`000000
0`3oool000000000000B000000040?ooo`000000oooo0?ooo`8000002`3oool3000000@0oooo3`00
00001@3oool00000000000000000oooo00<000000P3oool00`000000oooo0?ooo`040?ooo`800000
00<0oooo000000000000103oool4000000@0oooo00<000000?ooo`3oool01@3oool7000000L0oooo
00080?ooo`D0000000H0oooo0000003oool0oooo0000003oool3000000030?ooo`000000000000H0
00001`3oool2000000D0oooo0P0000020?ooo`8000000P3oool3000000030?ooo`00000000000080
000000<0oooo0000000000000`0000000`3oool000000?ooo`03000000T0oooo00<000000?ooo`3o
ool0203oool9000000030?ooo`0000000000008000001`3oool00`000000oooo0000000600000006
0?ooo`000000oooo0?ooo`000000oooo0P0000000`3oool00000000000020?ooo`T0000000<0oooo
0000003oool00P0000090?ooo`030000003oool0oooo00H0oooo0`0000000`3oool0000000000006
000000030?ooo`000000000000T0000000@0oooo0000003oool0oooo0P00000;0?ooo`<00000103o
ool?000000050?ooo`00000000000000003oool00`0000020?ooo`030000003oool0oooo00@0oooo
0P0000000`3oool00000000000040?ooo`D000000`3oool00`000000oooo0?ooo`050?ooo`L00000
1`3oool000P0oooo1@0000001P3oool000000?ooo`3oool000000?ooo`<0000000<0oooo00000000
00001P0000070?ooo`8000001@3oool200000080oooo0P0000020?ooo`<0000000<0oooo00000000
00000P0000000`3oool0000000000003000000030?ooo`000000oooo00<000002@3oool00`000000
oooo0?ooo`080?ooo`T0000000<0oooo0000000000000P0000070?ooo`030000003oool0000000H0
000000D0oooo0000003oool0oooo000000020?ooo`040000003oool0000000000080oooo2@000000
0`3oool000000?ooo`02000000T0oooo00<000000?ooo`3oool01P3oool3000000030?ooo`000000
000000H0000000<0oooo0000000000002@000000103oool000000?ooo`3oool2000000/0oooo0`00
00040?ooo`l0000000D0oooo00000000000000000?ooo`0300000080oooo00<000000?ooo`3oool0
103oool2000000030?ooo`000000000000@0oooo1@0000030?ooo`030000003oool0oooo00D0oooo
1`0000070?ooo`00203oool5000000060?ooo`000000oooo0?ooo`000000oooo0`0000000`3oool0
000000000006000000L0oooo0P0000050?ooo`8000000P3oool200000080oooo0`0000000`3oool0
000000000002000000030?ooo`000000000000<0000000<0oooo0000003oool00`0000090?ooo`03
0000003oool0oooo00P0oooo0`0000000`3oool0000000000004000000040?ooo`00000000000000
00@0oooo0P0000000`3oool000000?ooo`07000000050?ooo`000000oooo0?ooo`0000000P3oool0
10000000oooo0000000000020?ooo`030000003oool0000000P0000000<0oooo0000000000002@3o
ool00`000000oooo0?ooo`050?ooo`@0000000<0oooo0000000000000`0000000`3oool000000?oo
o`020?ooo`X0000000@0oooo0000003oool0oooo0P00000;0?ooo`<00000103oool?000000050?oo
o`00000000000000003oool00`0000020?ooo`030000003oool0oooo00@0oooo0P0000000`3oool0
0000000000040?ooo`D000000`3oool00`000000oooo0?ooo`050?ooo`L000001`3oool000P0oooo
1@0000001P3oool000000?ooo`3oool000000?ooo`<0000000<0oooo0000000000001P0000070?oo
o`8000001@3oool200000080oooo0P0000020?ooo`<0000000<0oooo0000000000000P0000000`3o
ool0000000000003000000030?ooo`000000oooo00<000002@3oool00`000000oooo0?ooo`080?oo
o`<0000000<0oooo00000000000010000000103oool000000000000000040?ooo`80000000<0oooo
0000003oool01`0000000`3oool000000?ooo`040?ooo`040000003oool0000000000080oooo00<0
00000?ooo`000000200000000`3oool00000000000020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool:000000030?ooo`000000oooo0080oooo2P000000103oool000000?oo
o`3oool2000000/0oooo0`0000040?ooo`l0000000D0oooo00000000000000000?ooo`0300000080
oooo00<000000?ooo`3oool0103oool2000000030?ooo`000000000000@0oooo1@0000030?ooo`03
0000003oool0oooo00D0oooo1`0000070?ooo`00o`00000P000000001`3oool010000000oooo0000
000000080?ooo`<0000000D0oooo00000000000000000?ooo`04000000<0oooo00<000000?ooo`3o
ool0203oool2000000030?ooo`000000000000@0oooo0P0000000`3oool000000000000400000003
0?ooo`000000000000<000001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0
oooo1P0000000`3oool0000000000002000000<0oooo100000000`3oool00000000000030?ooo`80
00001P3oool2000000030?ooo`000000000000@0oooo3@0000000`3oool00000000000030?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000900000080oooo00<000000?oo
o`3oool00P3oool;000000030?ooo`000000000000<000002@3oool3000000@0oooo1P0000000`3o
ool000000000000>00000080oooo00@000000?ooo`3oool000000P3oool6000000@0oooo0P000000
0`3oool00000000000020?ooo`8000000P3oool200000080oooo200000070?ooo`001`3oool01000
0000oooo0000000000080?ooo`8000000P3oool3000000030?ooo`0000000000008000003P3oool2
00000080oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000000000@0000000<0oooo
0000000000000`0000060?ooo`030000003oool0oooo01<0oooo1P0000000`3oool0000000000002
000000<0oooo100000000`3oool00000000000030?ooo`8000001`3oool010000000oooo00000000
00040?oooa0000001@3oool00`000000oooo000000020?ooo`030000003oool0000000H0000000<0
oooo0000000000000P3oool00`000000oooo0?ooo`020?ooo`/0000000<0oooo0000000000000`00
00090?ooo`<00000103oool6000000030?ooo`000000000000h000000P3oool010000000oooo0?oo
o`0000020?ooo`H00000103oool2000000030?ooo`00000000000080oooo0P0000020?ooo`800000
0P3oool8000000L0oooo00090?ooo`800000203oool200000080oooo0`0000000`3oool000000000
0002000000h0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P0000000`3oool000000000
0004000000030?ooo`000000000000<00000703oool6000000030?ooo`0000000000008000000`3o
ool4000000030?ooo`000000oooo00<0oooo0P0000090?ooo`800000103oool@000000030?ooo`00
0000oooo0080oooo0`0000020?ooo`T0000000<0oooo0000000000000P3oool00`000000oooo0?oo
o`020?ooo`/0000000<0oooo0000000000000`0000090?ooo`<00000103oool6000000030?ooo`00
0000000000h000000P3oool010000000oooo0?ooo`0000020?ooo`H00000103oool2000000030?oo
o`00000000000080oooo0P0000020?ooo`8000000P3oool8000000L0oooo00090?ooo`800000203o
ool200000080oooo0`0000000`3oool0000000000002000000h0oooo0P0000020?ooo`030000003o
ool0oooo0080oooo0P0000000`3oool0000000000004000000030?ooo`000000000000<00000703o
ool6000000030?ooo`0000000000008000000`3oool01P000000oooo000000000000oooo000000D0
oooo00<000000?ooo`3oool01`3oool2000000@0oooo400000000`3oool000000?ooo`020?ooo`<0
00000P3oool9000000030?ooo`00000000000080oooo00<000000?ooo`3oool00P3oool;00000003
0?ooo`000000000000<000002@3oool3000000@0oooo1P0000000`3oool000000000000>00000080
oooo00@000000?ooo`3oool000000P3oool6000000@0oooo0P0000000`3oool00000000000020?oo
o`8000000P3oool200000080oooo200000070?ooo`002@3oool2000000P0oooo0P0000020?ooo`<0
000000<0oooo0000000000000P00000>0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`80
000000<0oooo000000000000100000000`3oool0000000000003000001`0oooo1P0000000`3oool0
00000000000200000080oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`040?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool200000080oooo300000000`3oool0
00000?ooo`020?ooo`h0000000<0oooo0000000000000P3oool00`000000oooo0?ooo`020?oooa40
0000203oool4000000@0oooo1P0000000`3oool000000000000>00000080oooo00@000000?ooo`3o
ool000000P3oool6000000@0oooo0P0000000`3oool00000000000020?ooo`8000000P3oool20000
0080oooo200000070?ooo`002@3oool2000000P0oooo0P0000020?ooo`<0000000<0oooo00000000
00000P00000>0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`80000000<0oooo00000000
0000100000000`3oool0000000000003000001`0oooo00<000000?ooo`0000000`0000000`3oool0
00000000000200000080oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`0?0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool0oooo1P0000000`3oool00000000000030000
00030?ooo`000000oooo0080oooo200000020?ooo`@0000000<0oooo000000000000203oool01000
0000oooo0?ooo`3oool<000000P0oooo100000040?ooo`H0000000<0oooo0000000000003P000000
0`3oool00000000000020?ooo`030000003oool0000000H00000103oool2000000030?ooo`000000
00000080oooo0P0000020?ooo`8000000P3oool8000000L0oooo00090?ooo`800000203oool20000
0080oooo0`0000000`3oool0000000000002000000h0oooo0P0000020?ooo`030000003oool0oooo
0080oooo0P0000000`3oool0000000000004000000030?ooo`000000000000<00000703oool00`00
0000oooo00000003000000030?ooo`0000000000008000000P3oool00`000000oooo0?ooo`020000
00030?ooo`000000oooo00l0oooo00<000000?ooo`3oool01P3oool4000000030?ooo`000000oooo
00D0000000D0oooo0000003oool000000?ooo`0800000080oooo100000000`3oool0000000000008
0?ooo`040000003oool0oooo0?ooo``00000203oool4000000@0oooo1P0000000`3oool000000000
000>000000030?ooo`00000000000080oooo00<000000?ooo`0000001P0000040?ooo`80000000<0
oooo0000000000000P3oool200000080oooo0P0000020?ooo`P000001`3oool000T0oooo0P000008
0?ooo`8000000P3oool3000000030?ooo`0000000000008000003P3oool200000080oooo00<00000
0?ooo`3oool00P3oool2000000030?ooo`000000000000@0000000<0oooo0000000000000`00000L
0?ooo`030000003oool0000000<0000000<0oooo0000000000000P0000020?ooo`030000003oool0
oooo0080000000<0oooo0000003oool03`3oool00`000000oooo0?ooo`060?ooo`@0000000<0oooo
0000003oool01@0000000`3oool000000000000:00000080oooo0P0000000`3oool000000?ooo`02
000000P0oooo00@000000?ooo`3oool0oooo1P0000000`3oool0000000000003000000P0oooo1000
00040?ooo`H0000000<0oooo0000000000003P0000000`3oool00000000000020?ooo`030000003o
ool0000000H00000103oool2000000030?ooo`00000000000080oooo0P0000020?ooo`8000000P3o
ool8000000L0oooo00090?ooo`800000203oool200000080oooo0`0000000`3oool0000000000002
000000h0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P0000000`3oool0000000000004
000000030?ooo`000000000000<00000703oool00`000000oooo00000003000000030?ooo`000000
0000008000000P3oool00`000000oooo0?ooo`0200000180oooo00<000000?ooo`3oool01P3oool3
00000080oooo00<000000?ooo`000000400000040?ooo`050000003oool000000?ooo`0000002@3o
ool010000000oooo0?ooo`3oool6000000030?ooo`000000000000<00000203oool4000000@0oooo
1P0000000`3oool000000000000>000000030?ooo`00000000000080oooo00<000000?ooo`000000
1P0000040?ooo`80000000<0oooo0000000000000P3oool200000080oooo0P0000020?ooo`P00000
1`3oool000T0oooo0P0000080?ooo`8000000P3oool3000000030?ooo`0000000000008000003P3o
ool200000080oooo00<000000?ooo`3oool00P3oool2000000030?ooo`000000000000@0000000<0
oooo0000000000000`00000L0?ooo`030000003oool0000000<0000000<0oooo0000000000000P00
00020?ooo`030000003oool0oooo008000006`3oool300000080oooo00<000000?ooo`0000004000
00040?ooo`050000003oool000000?ooo`0000002@3oool010000000oooo0?ooo`3oool600000003
0?ooo`000000000000<00000203oool4000000@0oooo1P0000000`3oool000000000000>00000003
0?ooo`00000000000080oooo00<000000?ooo`0000001P0000040?ooo`80000000<0oooo00000000
00000P3oool200000080oooo0P0000020?ooo`P000001`3oool000T0oooo0P0000080?ooo`800000
0P3oool010000000oooo0000003oool4000000h0oooo00D000000?ooo`3oool0oooo000000040?oo
o`80000000<0oooo000000000000100000000`3oool0000000000003000001`0oooo00<000000?oo
o`0000000P0000020?ooo`L000000P3oool2000001/0oooo0`0000020?ooo`030000003oool00000
01000000103oool01@000000oooo0000003oool0000000T0oooo00@000000?ooo`3oool0oooo1P00
00000`3oool000000000000A000000030?ooo`000000oooo00D0000000<0oooo0000000000002000
00000`3oool000000000000G000000040?ooo`00000000000?ooo`<0000000@0oooo000000000000
00000P3oool8000000L0oooo00090?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`030000
003oool00000008000003`3oool00`000000oooo0?ooo`060?ooo`80000000@0oooo000000000000
oooo0`0000040?ooo`800000703oool00`000000oooo0?ooo`0200000080oooo00@000000?ooo`3o
ool000001@3oool2000001`0oooo0P0000020?ooo`030000003oool00000010000001P3oool00`00
0000oooo000000090?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000030?ooo`000000
000000@000001`3oool6000000030?ooo`000000oooo00L0oooo0P0000030?ooo`@0000000<0oooo
0000000000001@0000000`3oool0000000000008000000T0oooo00<000000?ooo`0000000P000000
103oool000000000000000020?ooo`P000001`3oool000T0oooo00<000000?ooo`3oool01`3oool2
000000@0oooo00<000000?ooo`0000000P00000?0?ooo`030000003oool0oooo00H0oooo0P000000
103oool000000000003oool3000000@0oooo0P00000L0?ooo`030000003oool0oooo008000000P3o
ool010000000oooo0?ooo`0000050?ooo`800000703oool200000080oooo00<000000?ooo`000000
400000060?ooo`030000003oool0000000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0
000000<0oooo000000000000100000070?ooo`H0000000<0oooo0000003oool01`3oool2000000<0
oooo100000000`3oool0000000000005000000030?ooo`000000000000P000002@3oool00`000000
oooo00000002000000040?ooo`000000000000000080oooo200000070?ooo`002@3oool00`000000
oooo0?ooo`070?ooo`800000103oool00`000000oooo00000002000000l0oooo00<000000?ooo`3o
ool01P3oool2000000040?ooo`00000000000?ooo`<00000103oool2000001`0oooo00<000000?oo
o`3oool00P0000020?ooo`040000003oool0oooo000000D0oooo0P00000L0?ooo`8000000P3oool0
10000000oooo0000003oool>000001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`<00000
00<0oooo000000000000100000070?ooo`H0000000<0oooo0000003oool01`3oool2000000<0oooo
100000000`3oool0000000000005000000030?ooo`000000000000P000002@3oool00`000000oooo
00000002000000040?ooo`000000000000000080oooo200000070?ooo`002@3oool00`000000oooo
0?ooo`070?ooo`800000103oool00`000000oooo00000002000000l0oooo00<000000?ooo`3oool0
1P3oool2000000040?ooo`00000000000?ooo`<00000103oool2000001`0oooo00<000000?ooo`3o
ool00P0000020?ooo`040000003oool0oooo000000D0oooo0P00000L0?ooo`8000000P3oool01000
0000oooo0000003oool>000001<0oooo00D000000?ooo`3oool0oooo000000020?ooo`<0000000<0
oooo000000000000100000070?ooo`H0000000<0oooo0000003oool01`3oool2000000<0oooo1000
00000`3oool0000000000005000000030?ooo`000000000000P000002@3oool00`000000oooo0000
0002000000040?ooo`000000000000000080oooo200000070?ooo`002@3oool00`000000oooo0?oo
o`070?ooo`800000103oool00`000000oooo00000002000000l0oooo00<000000?ooo`3oool01P3o
ool2000000040?ooo`00000000000?ooo`<00000103oool2000001`0oooo00<000000?ooo`3oool0
0P0000020?ooo`040000003oool0oooo000000D0oooo0P00000L0?ooo`800000103oool00`000000
oooo0000000:000000030?ooo`000000000001<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`<0000000<0oooo000000000000100000070?ooo`P00000203oool2000000<0oooo10000000103o
ool000000000003oool4000000030?ooo`000000000000P000002@3oool00`000000oooo00000002
000000040?ooo`000000000000000080oooo200000070?ooo`002@3oool00`000000oooo0?ooo`07
0?ooo`800000103oool00`000000oooo0?ooo`02000000l0oooo00<000000?ooo`3oool01`3oool0
20000000oooo000000000000oooo0000003oool00000103oool200000200oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0Q0?ooo`800000103oool010000000oooo0000003oool9
000000030?ooo`000000000001X0oooo0`0000001`3oool000000?ooo`3oool000000?ooo`000000
203oool7000000T0oooo00@000000?ooo`3oool0oooo10000000103oool000000000003oool40000
00030?ooo`000000000000P000002@3oool00`000000oooo0000000600000080oooo200000070?oo
o`002@3oool00`000000oooo0?ooo`070?ooo`800000103oool00`000000oooo0?ooo`02000000l0
oooo00<000000?ooo`3oool01`3oool020000000oooo000000000000oooo0000003oool00000103o
ool200000200oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`000000200000000`3oool000000000000J0?ooo`<00000
00L0oooo0000003oool0oooo0000003oool0000000P0oooo1`0000090?ooo`040000003oool0oooo
0?ooo`@0000000@0oooo000000000000oooo100000000`3oool0000000000008000000T0oooo00<0
00000?ooo`0000001P0000020?ooo`P000001`3oool000T0oooo00<000000?ooo`3oool01`3oool2
000000@0oooo00<000000?ooo`3oool00P00000?0?ooo`030000003oool0oooo00L0oooo00P00000
0?ooo`00000000000?ooo`000000oooo000000@0oooo0P00000P0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool08@3oool2000000H0oooo00D000000?ooo`00000000000?ooo`06
000000030?ooo`000000000001X0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000P0oooo1`0000090?ooo`040000003oool0oooo0?ooo`@0000000@0oooo000000000000
oooo100000000`3oool0000000000008000000T0oooo00<000000?ooo`0000001P0000020?ooo`P0
00001`3oool000T0oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<000000?ooo`3oool0
0P00000?0?ooo`030000003oool0oooo00L0oooo00P000000?ooo`00000000000?ooo`000000oooo
000000@0oooo0P00000:0?ooo`D000001@3oool2000000D0oooo100000000`3oool000000?ooo`02
00000080oooo00<000000?ooo`3oool00P3oool5000000<0oooo1000000C0?ooo`030000003oool0
oooo00L0oooo0P0000000`3oool000000000000400000080oooo00<000000?ooo`3oool0603oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`000000203oool7000000T0oooo00@0
00000?ooo`3oool0oooo10000000103oool000000000003oool4000000030?ooo`000000000000P0
00002@3oool00`000000oooo0000000600000080oooo200000070?ooo`002@3oool00`000000oooo
0?ooo`070?ooo`800000103oool00`000000oooo0?ooo`02000000l0oooo00<000000?ooo`3oool0
1`3oool020000000oooo000000000000oooo0000003oool00000103oool2000000X0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`800000103oool00`000000oooo0?ooo`020?ooo`8000000P3o
ool010000000oooo0000000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
0P0000000`3oool00000000000020?ooo`030000003oool0oooo01P0oooo00D000000?ooo`000000
oooo000000020?ooo`030000003oool0000000P0oooo1`0000090?ooo`040000003oool0oooo0?oo
o`@0000000@0oooo000000000000oooo100000000`3oool0000000000008000000T0oooo2P000000
0`3oool0000000000006000000L0oooo000C0?ooo`8000008P3oool00`000000oooo0000000:0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`000000203oool2000000050?ooo`000000
oooo0?ooo`0000003`3oool2000000H0oooo0P0000001@3oool00000000000000000oooo00H00000
2@3oool:000000030?ooo`000000oooo00<0000000<0oooo0000000000001`3oool001<0oooo0P00
000R0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0@0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00P0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool00000
00P0oooo0P0000001@3oool000000?ooo`3oool0000000l0oooo0P0000060?ooo`80000000D0oooo
00000000000000000?ooo`06000000T0oooo2P0000000`3oool000000?ooo`03000000030?ooo`00
0000000000L0oooo000C0?ooo`8000008P3oool00`000000oooo0000000:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02`3oool4000000<0oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`<00000203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`000000203oool2000000050?ooo`000000oooo0?ooo`0000003`3oool2000000H0oooo
0P0000001@3oool00000000000000000oooo00H000002@3oool:000000030?ooo`000000oooo00<0
000000<0oooo0000000000001`3oool001<0oooo0P00000R0?ooo`030000003oool0000000X0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`000000203oool2000000050?ooo`000000oooo0?ooo`0000003`3oool2000000H0
oooo0P0000001@3oool00000000000000000oooo00H000002@3oool:000000030?ooo`000000oooo
00<0000000<0oooo0000000000001`3oool001<0oooo0P00000R0?ooo`030000003oool0000000X0
oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000`0oooo00<000000?oo
o`3oool03@3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`D0000000<0oooo000000000000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool08`3oool00`000000oooo000000080?ooo`80000000D0oooo0000
003oool0oooo0000000?0?ooo`8000001P3oool2000000050?ooo`00000000000000003oool01P00
00090?ooo`X0000000<0oooo0000003oool00`0000000`3oool00000000000070?ooo`004`3oool2
00000280oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`090?ooo`<000003@3oool5
000000d0oooo00<000000?ooo`3oool00`3oool4000000T0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`070?ooo`030000
003oool000000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`050?ooo`800000
00D0oooo00000000000000000?ooo`06000000X0oooo2@0000000`3oool000000?ooo`0300000003
0?ooo`000000000000L0oooo000C0?ooo`8000008P3oool00`000000oooo0000000:0?ooo`030000
003oool0oooo03P0oooo0`0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000030?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool01`3oool00`000000oooo000000020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000050?ooo`0000000000
0000003oool01P00000:0?ooo`T0000000<0oooo0000003oool00`0000000`3oool0000000000007
0?ooo`004`3oool200000280oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`0n0?oo
o`040000003oool0oooo0?ooo`800000103oool2000003L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2
000000050?ooo`00000000000000003oool01P00000:0?ooo`T0000000<0oooo0000003oool00`00
00000`3oool00000000000070?ooo`004`3oool200000280oooo00<000000?ooo`0000002P3oool0
0`000000oooo0?ooo`0n0?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00D0oooo0P0000001@3oool00000000000000000oooo00H00000
2P3oool9000000030?ooo`000000oooo00<0000000<0oooo0000000000001`3oool001<0oooo0P00
000R0?ooo`030000003oool0000000X0oooo00<000000?ooo`3oool0?@3oool2000000@0oooo0P00
00030?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool2000000050?ooo`00
000000000000003oool01P00000:0?ooo`T0000000<0oooo0000003oool00`0000000`3oool00000
000000070?ooo`004`3oool200000280oooo00<000000?ooo`0000002P3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool200000080oooo0P00
00000`3oool0000000000004000000X0oooo0P0000000`3oool0000000000006000000050?ooo`00
000000000000003oool00P0000070?ooo`00A03oool00`000000oooo0?ooo`180?ooo`800000GP3o
ool200000080oooo00<000000?ooo`3oool0103oool2000000X0oooo00<000000?ooo`3oool00P00
00000`3oool000000?ooo`03000000050?ooo`00000000000000003oool00P0000070?ooo`00A03o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05d0oooo0P0000020?ooo`030000003o
ool0oooo00@0oooo0P00000:0?ooo`030000003oool0oooo0080000000<0oooo0000003oool00`00
00001@3oool00000000000000000oooo008000001`3oool004@0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`1M0?ooo`8000000P3oool00`000000oooo0?ooo`040?ooo`8000002P3o
ool00`000000oooo0?ooo`02000000030?ooo`000000oooo00<0000000D0oooo0000000000000000
0?ooo`02000000L0oooo00140?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0G@3o
ool200000080oooo00<000000?ooo`3oool0103oool2000000X0oooo00<000000?ooo`3oool00P00
00000`3oool000000?ooo`03000000050?ooo`00000000000000003oool00P0000070?ooo`00A03o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05d0oooo0P0000020?ooo`030000003o
ool0oooo00@0oooo0P00000:0?ooo`030000003oool0oooo0080000000<0oooo0000003oool00`00
00001@3oool00000000000000000oooo008000001`3oool004@0oooo00<000000?ooo`3oool0B03o
ool2000005h0oooo0P0000020?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`030000003o
ool0oooo0080000000<0oooo0000003oool00`0000001@3oool00000000000000000oooo00800000
1`3oool004@0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1M0?ooo`8000000P3o
ool00`000000oooo0?ooo`040?ooo`8000002P3oool00`000000oooo0?ooo`02000000030?ooo`00
0000oooo00<0000000D0oooo00000000000000000?ooo`02000000L0oooo00140?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0G@3oool200000080oooo00<000000?ooo`3oool0103o
ool2000000X0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`03000000050?ooo`00
000000000000003oool00P0000070?ooo`00A03oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo05d0oooo0P0000020?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`030000003o
ool0oooo0080000000<0oooo0000003oool00`0000001@3oool00000000000000000oooo00800000
1`3oool004@0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1M0?ooo`8000000P3o
ool00`000000oooo0?ooo`040?ooo`8000002P3oool00`000000oooo0?ooo`02000000030?ooo`00
0000oooo00<0000000D0oooo00000000000000000?ooo`02000000L0oooo001O0?ooo`@000000`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo1@0000030?ooo`@00000503oool2000006X0oooo
00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo0`0000000`3oool0
00000000000;0?ooo`00GP3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0203oool01@00
0000oooo0?ooo`3oool0000000<0oooo0`0000000`3oool000000000000;0?ooo`00H`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000`3oool3000000030?ooo`000000
000000/0oooo001S0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000<0oooo
0`0000000`3oool000000000000;0?ooo`00G`3oool4000000<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0203oool01@000000oooo
0?ooo`3oool0000000<0oooo0`0000000`3oool000000000000;0?ooo`00G`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0A0?ooo`<00000J@3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`00
00000`3oool3000000030?ooo`000000000000/0oooo001O0?ooo`030000003oool0oooo00d0oooo
0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1Y0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000030?ooo`<0
000000<0oooo0000000000002`3oool005l0oooo1@00000=0?ooo`030000003oool0oooo00<0oooo
100000070?ooo`D0000000<0oooo0000000000001@3oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000030?ooo`<0000000<0oooo00000000
00002`3oool008@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000000`3oool3
000000030?ooo`000000000000/0oooo001n0?ooo`<000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000103oool2000006X0oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool0000000<0oooo0`0000000`3oool000000000000;0?ooo`00Q03oool010000000oooo0?oo
o`3oool2000000D0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`080?ooo`050000
003oool0oooo0?ooo`0000000`3oool3000000030?ooo`000000000000/0oooo00240?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`1h0?ooo`040000003oool0oooo0?oo
o`<0000000<0oooo0000000000002`3oool008<0oooo0P0000040?ooo`800000103oool00`000000
oooo0?ooo`1h0?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000000000002`3oool008l0
oooo00<000000?ooo`3oool0N03oool010000000oooo0?ooo`3oool3000000030?ooo`0000000000
00/0oooo002?0?ooo`800000N@3oool010000000oooo0?ooo`3oool3000000030?ooo`0000000000
00/0oooo002?0?ooo`030000003oool0oooo07P0oooo00@000000?ooo`3oool0oooo0`0000000`3o
ool000000000000;0?ooo`00S`3oool00`000000oooo0?ooo`1h0?ooo`040000003oool0oooo0?oo
o`<0000000<0oooo0000000000002`3oool008l0oooo00<000000?ooo`3oool0N03oool010000000
oooo0?ooo`3oool3000000030?ooo`000000000000/0oooo002?0?ooo`030000003oool0oooo07P0
oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000000000;0?ooo`00S`3oool2000007T0
oooo00@000000?ooo`3oool0oooo0`0000000`3oool000000000000;0?ooo`00S`3oool00`000000
oooo0?ooo`1h0?ooo`040000003oool0oooo0?ooo`<0000000<0oooo0000000000002`3oool008l0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`090?ooo`00S`3oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo00T0oooo002?0?ooo`800000PP3oool00`000000oooo0?oo
o`090?ooo`00DP3oool00`000000oooo0?ooo`040?ooo`8000001@3oool4000000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`D000000`3oool4000001<0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`090?ooo`00DP3oool00`000000oooo0?ooo`040?ooo`800000103oool0
0`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool02@3oool00580oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`090?ooo`00D`3oool00`000000oooo0?ooo`0>0?ooo`070000003oool0
oooo0?ooo`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
2@3oool005<0oooo00<000000?ooo`3oool02P3oool4000000<0oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0@0?ooo`<00000P@3oool00`000000oooo0?ooo`090?ooo`00E03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`090?ooo`00C`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool03@3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`D0000000<0oooo000000000000103oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo00T0oooo001?0?ooo`H000002`3oool5000000d0oooo00<000000?ooo`3oool00`3oool40000
00T0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`090?ooo`00O`3oool3000000<0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`090?ooo`00Q@3o
ool010000000oooo0?ooo`3oool2000000@0oooo0P0000220?ooo`030000003oool0oooo00T0oooo
00250?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo00T0oooo00240?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`090?ooo`00S`3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo00T0oooo002?0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool02@3oool008l0
oooo0P0000220?ooo`030000003oool0oooo00T0oooo002?0?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool02@3oool008l0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`090?ooo`00S`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00T0oooo002?0?oo
o`800000SP3oool008l0oooo00<000000?ooo`3oool0S@3oool008l0oooo00<000000?ooo`3oool0
S@3oool008l0oooo00<000000?ooo`3oool0S@3oool00001\
\>"],
  ImageRangeCache->{{{0, 286.313}, {176.563, 0}} -> {-1.05515, -9.32836*^-16, \
0.00919084, 1.32082*^-17}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      FormBox[GridBox[{
            {
              
              StyleBox[\(\("option name"\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\),
                FontSlant->"Italic"], 
              StyleBox[\(default\ value\),
                FontSlant->"Italic"], 
              RowBox[{"                                         ", 
                StyleBox["discription",
                  FontSlant->"Italic"], 
                
                StyleBox[
                  "                                                           \
                         ",
                  FontSlant->"Italic"]}]}
            }], TraditionalForm]],
    CellFrame->{{0, 0}, {0.5, 0}},
    GridBoxOptions->{ColumnWidths->Automatic}],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{GridBox[{
              {"Exact"},
              {"Eigenvalue"},
              {"Method"}
              }], " "}], TraditionalForm]],
    FontFamily->"Courier New",
    GridBoxOptions->{ColumnWidths->Automatic}],
  "                         ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              StyleBox["False",
                FontFamily->"Courier New"]},
            {
              StyleBox["Null",
                FontFamily->"Courier New"]},
            {
              StyleBox[\(Modified[0]\),
                FontFamily->"Courier New"]}
            }], TraditionalForm]],
    GridBoxOptions->{ColumnWidths->Automatic}],
  "                      ",
  Cell[BoxData[
      FormBox[GridBox[{
            {\(specifies\ the\ mode\ of\ calculation\ \((homogeneous\ BVP\ \
only)\)\)},
            {\(specifies\ name\ for\ eigenvalue\ variable\ \((homogeneous\ \
BVP\ only)\)\)},
            {
              RowBox[{
              "specifies", " ", "the", " ", "method", " ", "of", " ", 
                "approximation", " ", 
                RowBox[{"(", 
                  RowBox[{"see", " ", 
                    ButtonBox[\(modified\ a - method\ examples\),
                      ButtonData:>{"modified.nb", None},
                      ButtonStyle->"Hyperlink"]}], ")"}]}]}
            }], TraditionalForm]],
    GridBoxOptions->{ColumnWidths->Automatic}]
}], "DefinitionBox"],

Cell["Options for polynomial approximations. ", "Caption"],

Cell[TextData[{
  "Exact mode of calculation gives the result with no real numbers involved. \
Moreover any intermediate calculations are performed using exact arithmetic. \
This mode is available only if the LDE, boundary or initial conditions and \
boundary points of the interval has no real numbers involved. It should be \
pointed out that this mode (as a rule) leads to time and resources consuming \
computation and gives more bulky results. Nevertheless in some cases the \
Exact mode of calculation is absolutely necessary to get right results.\nIn a \
case of homogeneous LDE and BVP the appropriate eigenvalue variable must be \
specified by option ",
  StyleBox["Eigenvalue\[Rule]variable",
    FontFamily->"Courier New"],
  " (e.g. ",
  StyleBox["Eigenvalue\[Rule]\[Lambda]",
    FontFamily->"Courier New"],
  ") to get solutions for different eigen values. Nevertheless in some simple \
cases the eigen value variable can be determined automatically by the \
algorithm (see example below).\n",
  StyleBox["The approximation problem can be treated as initial value problem \
(IVP) or boundary value problem (BVP) with regular singular points (RSP) or \
without them. The treatment is as follows.\nIf no condition (Cond) presented \
the problem treated as IVP and the initial point of the approximation is the \
middle point of the giving interval: x0=(a+b)/2.\nIf condition (Cond) is one \
point condition (for instance cond is y[x0]=0, y'[x0]=1, ... with one point \
x0) then  the problem treated as IVP and x0 must be the middle point or the \
left point of the approximation interval, thus  x0 = (a+b)/2 or x0 = a.\nIf \
condition (Cond) is two points condition (for instance cond is y[x0]=0, \
y'[x1]=1, ... with two points x0 and x1) then the problem is treated as BVP \
(see ",
    FontWeight->"Bold"],
  StyleBox[ButtonBox["BVP examples",
    ButtonData:>{"bvp.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox[") and it must be x0 = a and x1 = b or x0 = b and x1 = a.\nIf an \
LDE has an RSP then it must be the left point of the interval of \
approximation (see ",
    FontWeight->"Bold"],
  StyleBox[ButtonBox["RSP examples",
    ButtonData:>{"rsp.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox["). ",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "In some cases (especially in a case of homogeneous LDE and BVP) it is \
convenient to get \"normalized\" approximate solution of a BVP or IVP. For \
this reason the package function ",
  StyleBox["Normalize",
    FontFamily->"Courier New"],
  " is provided. ",
  StyleBox["Normalize",
    FontFamily->"Courier New"],
  " performs normalization of a function f[x] on a given interval [a,b]. It \
means that for any f[x] one gets ",
  StyleBox["Normalize",
    FontFamily->"Courier New"],
  ": ",
  Cell[BoxData[
      \(f[x] \[Rule] 
        f[x]\/\@\(\[Integral]\_a\%b\( f[x]\^2\) \[DifferentialD]x\)\)]],
  ".Thus functions are normalized to 1 on a given interval. "
}], "Text"],

Cell[TextData[{
  "                                  ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{
                StyleBox[
                  FormBox[\(Normalize[expr, {x, a, b}]\),
                    "TraditionalForm"],
                  FontFamily->"Courier New"], "     "}], 
              RowBox[{
              "gives", " ", "normalized", " ", "form", " ", "of", " ", 
                StyleBox["expr",
                  FontFamily->"Courier New"], " ", "over", " ", 
                RowBox[{"interval", " ", 
                  StyleBox["[",
                    FontFamily->"Courier New"], 
                  StyleBox[\(a, b\),
                    FontFamily->"Courier New"], 
                  StyleBox["]",
                    FontFamily->"Courier New"]}]}]}
            }], TraditionalForm]],
    GridBoxOptions->{ColumnWidths->Automatic}],
  StyleBox[" ",
    GridBoxOptions->{ColumnWidths->Automatic}]
}], "DefinitionBox"],

Cell[TextData[{
  StyleBox["Normalize",
    FontFamily->"Courier New"],
  " function. "
}], "Caption"],

Cell[TextData[{
  StyleBox["Normalize",
    FontFamily->"Courier New"],
  " makes effect only on such parts of expression ",
  StyleBox["expr",
    FontFamily->"Courier New"],
  " which depend on ",
  StyleBox["x",
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell["\<\
This declares LDE with parameter \[Lambda].\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lde = \(y''\)[x] + \[Lambda]*y[x] \[Equal] 0\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[Lambda]\ y[x]\), "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "==", 
      "0"}]], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell[TextData[{
  "Now one can use ",
  StyleBox["ApproxSol",
    FontFamily->"Courier New"],
  " function to find polynomial approximation of solutions of the following \
homogeneous BVP: {",
  Cell[BoxData[
      RowBox[{
        RowBox[{\(\[Lambda]\ y[x]\), "+", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}]]],
  ",",
  StyleBox["y[0]\[Equal]0,y[\[Pi]]\[Equal]0}.",
    FontFamily->"Courier New"],
  StyleBox[" As corresponding eigen value variable is not specified then it \
is determined automatically. Only 6 values of eigen value variable are \
available for 5-degree approximation. ",
    FontFamily->"Times New Roman"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = 
      ApproxSol[{lde, y[0] \[Equal] 0, y[Pi] \[Equal] 0}, y[x], {x, 0, Pi}, 
        5, Exact \[Rule] False]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(LdeApprox::"noegvar" \(\(:\)\(\ \)\) 
      "no eigenvalue variable specified. Trying to determine ..."\)], \
"Message",
  CellLabel->"From In[54]:="],

Cell[BoxData[
    \(LdeApprox::"fxegvar" \(\(:\)\(\ \)\) 
      "\!\(\[Lambda]\) - is the eigenvalue variable."\)], "Message",
  CellLabel->"From In[54]:="],

Cell[BoxData[
    \({{\[Lambda] \[Rule] 0.9999976759187339`, 
        y[x] \[Rule] \((\(\(0.00040359655924775107`\)\(\[InvisibleSpace]\)\) \
+ 0.6924624699797575`\ x + 0.0341482223110128`\ x\^2 - 
                0.16206166768687508`\ x\^3 + 0.025792915498073162`\ x\^4 + 
                2.2851515841397134`*^-15\ x\^5)\)\ C[1]}, {\[Lambda] \[Rule] 
          4.00040129870332`, 
        y[x] \[Rule] \((\(-0.0013820081814021603`\) - 
                0.4110087282233684`\ x - 0.21679757937636915`\ x\^2 + 
                0.6933655972630808`\ x\^3 - 0.3090914991696416`\ x\^4 + 
                0.03935475196842599`\ x\^5)\)\ C[1]}, {\[Lambda] \[Rule] 
          9.609572658043371`, 
        y[x] \[Rule] \((\(\(0.009577738149983587`\)\(\[InvisibleSpace]\)\) - 
                0.44135576952796063`\ x + 0.7691403380912885`\ x\^2 - 
                0.40021256900251173`\ x\^3 + 0.06369580864425888`\ x\^4 - 
                5.555157895503139`*^-16\ x\^5)\)\ C[1]}, {\[Lambda] \[Rule] 
          18.15967213037614`, 
        y[x] \[Rule] \((\(-0.004621489670276869`\) + 
                0.25721084462272625`\ x - 0.6922611634347898`\ x\^2 + 
                0.6237862190060088`\ x\^3 - 0.2276952600933921`\ x\^4 + 
                0.028991060929966082`\ x\^5)\)\ C[1]}, {\[Lambda] \[Rule] 
          159.61001818516874`, 
        y[x] \[Rule] \((\(-0.04980239479297379`\) + 0.21169130953126947`\ x - 
                0.26419100517791555`\ x\^2 + 0.12529158948092703`\ x\^3 - 
                0.019940775793734978`\ x\^4 + 
                1.1267244740555863`*^-15\ x\^5)\)\ C[1]}, {\[Lambda] \[Rule] 
          295.5831584732923`, 
        y[x] \[Rule] \((\(-0.0336903093368247`\) + 0.2015595115886658`\ x - 
                0.3732898643762236`\ x\^2 + 0.29279621752011653`\ x\^3 - 
                0.10197772511052194`\ x\^4 + 
                0.012984207229284804`\ x\^5)\)\ C[1]}}\)], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell["\<\
One has to normalize the result to compare it with the exact solution.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr1 = Normalize[apr, {x, 0, Pi}]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \({{\[Lambda] \[Rule] 0.9999976759187339`, 
        y[x] \[Rule] 
          1.1370254828571014`\ \((\(\(0.00040359655924775107`\)\(\
\[InvisibleSpace]\)\) + 0.6924624699797575`\ x + 0.0341482223110128`\ x\^2 - 
                0.16206166768687508`\ x\^3 + 0.025792915498073162`\ x\^4 + 
                2.2851515841397134`*^-15\ x\^5)\)}, {\[Lambda] \[Rule] 
          4.00040129870332`, 
        y[x] \[Rule] 
          3.5143298232181763`\ \((\(-0.0013820081814021603`\) - 
                0.4110087282233684`\ x - 0.21679757937636915`\ x\^2 + 
                0.6933655972630808`\ x\^3 - 0.3090914991696416`\ x\^4 + 
                0.03935475196842599`\ x\^5)\)}, {\[Lambda] \[Rule] 
          9.609572658043371`, 
        y[x] \[Rule] 
          12.884453536932547`\ \((\(\(0.009577738149983587`\)\(\
\[InvisibleSpace]\)\) - 0.44135576952796063`\ x + 0.7691403380912885`\ x\^2 - 
                0.40021256900251173`\ x\^3 + 0.06369580864425888`\ x\^4 - 
                5.555157895503139`*^-16\ x\^5)\)}, {\[Lambda] \[Rule] 
          18.15967213037614`, 
        y[x] \[Rule] 
          38.958482289651265`\ \((\(-0.004621489670276869`\) + 
                0.25721084462272625`\ x - 0.6922611634347898`\ x\^2 + 
                0.6237862190060088`\ x\^3 - 0.2276952600933921`\ x\^4 + 
                0.028991060929966082`\ x\^5)\)}, {\[Lambda] \[Rule] 
          159.61001818516874`, 
        y[x] \[Rule] 
          43.70850265376224`\ \((\(-0.04980239479297379`\) + 
                0.21169130953126947`\ x - 0.26419100517791555`\ x\^2 + 
                0.12529158948092703`\ x\^3 - 0.019940775793734978`\ x\^4 + 
                1.1267244740555863`*^-15\ x\^5)\)}, {\[Lambda] \[Rule] 
          295.5831584732923`, 
        y[x] \[Rule] 
          76.26283005825574`\ \((\(-0.0336903093368247`\) + 
                0.2015595115886658`\ x - 0.3732898643762236`\ x\^2 + 
                0.29279621752011653`\ x\^3 - 0.10197772511052194`\ x\^4 + 
                0.012984207229284804`\ x\^5)\)}}\)], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell["The exact solution is as follows.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[{lde, y[0] \[Equal] 0}, y[x], x]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({{y[x] \[Rule] C[2]\ Sin[x\ \@\[Lambda]]}}\)], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell["This is the normalized form of the exact solution.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1 = Normalize[sol, {x, 0, Pi}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \({{y[x] \[Rule] 
          Sin[x\ \@\[Lambda]]\/\@\(\[Pi]\/2 - Sin[2\ \[Pi]\ \@\[Lambda]]\/\(4\
\ \@\[Lambda]\)\)}}\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["Now one can compare the results.", "MathCaption"],

Cell["For \[Lambda] = 1", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\(y[x] /. sol1[\([1]\)]\) /. \[Lambda] \[Rule] 1)\) - \((y[x] /. 
            apr1[\([1]\)])\), {x, 0, Pi}]\)], "Input",
  CellLabel->"In[58]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.303152 0.305737 597.085 [
[.17539 .29324 -9 -9 ]
[.17539 .29324 9 0 ]
[.32696 .29324 -3 -9 ]
[.32696 .29324 3 0 ]
[.47854 .29324 -9 -9 ]
[.47854 .29324 9 0 ]
[.63011 .29324 -3 -9 ]
[.63011 .29324 3 0 ]
[.78169 .29324 -9 -9 ]
[.78169 .29324 9 0 ]
[.93327 .29324 -3 -9 ]
[.93327 .29324 3 0 ]
[.01131 .0669 -42 -4.5 ]
[.01131 .0669 0 4.5 ]
[.01131 .18632 -42 -4.5 ]
[.01131 .18632 0 4.5 ]
[.01131 .42515 -36 -4.5 ]
[.01131 .42515 0 4.5 ]
[.01131 .54457 -36 -4.5 ]
[.01131 .54457 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30574 m
.17539 .31199 L
s
[(0.5)] .17539 .29324 0 1 Mshowa
.32696 .30574 m
.32696 .31199 L
s
[(1)] .32696 .29324 0 1 Mshowa
.47854 .30574 m
.47854 .31199 L
s
[(1.5)] .47854 .29324 0 1 Mshowa
.63011 .30574 m
.63011 .31199 L
s
[(2)] .63011 .29324 0 1 Mshowa
.78169 .30574 m
.78169 .31199 L
s
[(2.5)] .78169 .29324 0 1 Mshowa
.93327 .30574 m
.93327 .31199 L
s
[(3)] .93327 .29324 0 1 Mshowa
.125 Mabswid
.05412 .30574 m
.05412 .30949 L
s
.08444 .30574 m
.08444 .30949 L
s
.11476 .30574 m
.11476 .30949 L
s
.14507 .30574 m
.14507 .30949 L
s
.2057 .30574 m
.2057 .30949 L
s
.23602 .30574 m
.23602 .30949 L
s
.26633 .30574 m
.26633 .30949 L
s
.29665 .30574 m
.29665 .30949 L
s
.35728 .30574 m
.35728 .30949 L
s
.38759 .30574 m
.38759 .30949 L
s
.41791 .30574 m
.41791 .30949 L
s
.44822 .30574 m
.44822 .30949 L
s
.50885 .30574 m
.50885 .30949 L
s
.53917 .30574 m
.53917 .30949 L
s
.56948 .30574 m
.56948 .30949 L
s
.5998 .30574 m
.5998 .30949 L
s
.66043 .30574 m
.66043 .30949 L
s
.69074 .30574 m
.69074 .30949 L
s
.72106 .30574 m
.72106 .30949 L
s
.75138 .30574 m
.75138 .30949 L
s
.81201 .30574 m
.81201 .30949 L
s
.84232 .30574 m
.84232 .30949 L
s
.87264 .30574 m
.87264 .30949 L
s
.90295 .30574 m
.90295 .30949 L
s
.96358 .30574 m
.96358 .30949 L
s
.9939 .30574 m
.9939 .30949 L
s
.25 Mabswid
0 .30574 m
1 .30574 L
s
.02381 .0669 m
.03006 .0669 L
s
[(-0.0004)] .01131 .0669 1 0 Mshowa
.02381 .18632 m
.03006 .18632 L
s
[(-0.0002)] .01131 .18632 1 0 Mshowa
.02381 .42515 m
.03006 .42515 L
s
[(0.0002)] .01131 .42515 1 0 Mshowa
.02381 .54457 m
.03006 .54457 L
s
[(0.0004)] .01131 .54457 1 0 Mshowa
.125 Mabswid
.02381 .09676 m
.02756 .09676 L
s
.02381 .12661 m
.02756 .12661 L
s
.02381 .15647 m
.02756 .15647 L
s
.02381 .21617 m
.02756 .21617 L
s
.02381 .24603 m
.02756 .24603 L
s
.02381 .27588 m
.02756 .27588 L
s
.02381 .33559 m
.02756 .33559 L
s
.02381 .36545 m
.02756 .36545 L
s
.02381 .3953 m
.02756 .3953 L
s
.02381 .45501 m
.02756 .45501 L
s
.02381 .48486 m
.02756 .48486 L
s
.02381 .51472 m
.02756 .51472 L
s
.02381 .03705 m
.02756 .03705 L
s
.02381 .00719 m
.02756 .00719 L
s
.02381 .57443 m
.02756 .57443 L
s
.02381 .60428 m
.02756 .60428 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03174 m
.03279 .19848 L
.04262 .33989 L
.04758 .3966 L
.05288 .44744 L
.05785 .48656 L
.06244 .51592 L
.06788 .54295 L
.07069 .55386 L
.07379 .56362 L
.07647 .57029 L
.07899 .57508 L
.08035 .57711 L
.08165 .57868 L
.08236 .57941 L
.08314 .58008 L
.0838 .58056 L
.08451 .58098 L
.08522 .58131 L
.08587 .58153 L
.08715 .58174 L
.08831 .58167 L
.08955 .58134 L
.09018 .58106 L
.09087 .58069 L
.09211 .57983 L
.09358 .57849 L
.09492 .57698 L
.09988 .56908 L
.10458 .55857 L
.11423 .52916 L
.12449 .48889 L
.14291 .40201 L
.18066 .21369 L
.20163 .12637 L
.21082 .09506 L
.22086 .06637 L
.23063 .04441 L
.23971 .02939 L
.24474 .02333 L
.2493 .01923 L
.25183 .01753 L
.25316 .01679 L
.25457 .01614 L
.25581 .01567 L
.25716 .01526 L
.2584 .01498 L
.25955 .01482 L
.2608 .01472 L
.2615 .01472 L
Mistroke
.26213 .01473 L
.26337 .01484 L
.26453 .01502 L
.26519 .01516 L
.26589 .01534 L
.26714 .01573 L
.26996 .01695 L
.2724 .01839 L
.27467 .02004 L
.27984 .02488 L
.28879 .03674 L
.29837 .05398 L
.31965 .10691 L
.33979 .17147 L
.37817 .31461 L
.419 .46165 L
.4393 .5209 L
.44923 .54489 L
.45832 .56355 L
.46702 .57823 L
.47653 .59053 L
.48148 .59534 L
.48608 .5988 L
.48858 .60028 L
.49094 .6014 L
.49225 .60192 L
.49366 .60238 L
.49495 .60272 L
.49613 .60297 L
.49734 .60316 L
.49849 .60327 L
.49971 .60332 L
.50039 .60332 L
.50103 .6033 L
.50209 .60322 L
.50325 .60307 L
.50447 .60285 L
.50562 .60258 L
.50823 .60174 L
.51063 .60068 L
.51604 .59733 L
.52093 .59313 L
.52629 .58729 L
.5371 .57168 L
.54735 .55229 L
.55668 .53105 L
.57763 .47234 L
.61757 .33087 L
.65601 .18624 L
.67547 .12145 L
Mistroke
.68579 .09164 L
.6969 .06411 L
.70752 .04285 L
.71723 .02829 L
.7219 .02309 L
.72436 .02083 L
.72699 .0188 L
.72951 .01723 L
.7318 .01613 L
.73291 .01571 L
.7341 .01534 L
.73523 .01507 L
.73627 .01489 L
.73753 .01475 L
.73873 .01472 L
.7398 .01476 L
.74097 .01488 L
.74224 .01511 L
.74288 .01527 L
.74359 .01547 L
.74601 .01639 L
.74827 .01759 L
.7507 .01923 L
.75511 .02317 L
.76036 .02948 L
.76589 .03803 L
.77577 .05814 L
.78533 .08334 L
.79553 .1162 L
.8139 .18919 L
.85542 .3936 L
.87624 .49198 L
.88537 .52778 L
.89022 .54391 L
.89542 .55857 L
.90047 .56975 L
.90287 .57388 L
.90508 .57698 L
.9073 .57933 L
.90847 .58027 L
.90972 .58102 L
.91091 .58149 L
.91203 .58171 L
.91304 .58172 L
.91412 .58153 L
.91536 .58105 L
.91652 .58034 L
.91778 .57927 L
.91914 .57776 L
.92191 .57352 L
Mistroke
.92444 .56822 L
.9293 .55387 L
.93391 .53493 L
.93852 .51028 L
.9436 .47596 L
.95387 .38099 L
.96339 .25831 L
.97231 .10855 L
.97619 .03174 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{213.5, 131.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004:0000Y2000`400?l00000o`00003oo`3oool;
0?ooo`00o`3oool;0?ooo`00o`3oool;0?ooo`00o`3oool;0?ooo`00o`3oool;0?ooo`00o`3oool;
0?ooo`00o`3oool;0?ooo`00o`3oool;0?ooo`00o`3oool;0?ooo`00o`3oool;0?ooo`00o`3oool;
0?ooo`00o`3oool;0?ooo`00o`3oool;0?ooo`00o`3oool;0?ooo`00o`3oool;0?ooo`00=`3oool0
0`000000oooo0?ooo`3@0?ooo`00=`3oool200000=40oooo000g0?ooo`030000003oool0oooo0=00
oooo000g0?ooo`030000003oool0oooo02l0oooo0`00001S0?ooo`D00000=P3oool003L0oooo00<0
00000?ooo`3oool0;@3oool2000000<0oooo0P00001P0?ooo`8000000`3oool2000003D0oooo000g
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1L
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<P3oool003L0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0a0?ooo`00=`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool00`3oool003L0oooo0P00000[0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool003L0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00<0oooo000g0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`001P3oool40000
00D0oooo0P0000050?ooo`@00000103oool4000000@0oooo100000060?ooo`<00000103oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool00`3oool000D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo00050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00<0oooo000300000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo00H00000103oool2000002P0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`030?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00@0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0103oool000D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000001@3oool2000002L0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`040?ooo`001P3oool4000000`0oooo100000040?ooo`@00000103oool4000000H0oooo0P00
00050?ooo`8000009`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo000g
0?ooo`8000009P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo000g0?oo
o`8000009P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo000g0?ooo`80
00009P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo000g0?ooo`800000
9@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo000g0?ooo`8000009@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo000g0?ooo`8000009@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo000g0?ooo`8000009@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo000g0?ooo`800000903oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo000g0?ooo`800000903oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00@0oooo000g0?ooo`800000903oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00@0oooo000g0?ooo`800000903oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00@0oooo000g0?ooo`8000008`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00@0oooo000g0?ooo`8000008`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00@0oooo000g0?ooo`8000008`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00D0oooo000g0?ooo`8000008`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00D0oooo000g0?ooo`8000008`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00D0oooo000g0?ooo`030000003oool000000240oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`050?ooo`00=`3oool00`000000oooo0000000Q0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool01@3oool000H0oooo100000050?ooo`8000001@3oool4000000@0oooo
100000040?ooo`@000000`3oool5000000D0oooo00<000000?ooo`0000008@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00D0oooo00050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool000000240oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`050?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool000000200oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`000`0000020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00D0oooo0`00000P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1@3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0000000P0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0000000P0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool01@3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000
000P0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool000H0oooo1000000<
0?ooo`@00000103oool4000000@0oooo100000040?ooo`<000001P3oool00`000000oooo0000000O
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01@3oool003L0oooo00<000000?oo
o`0000007`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo000g0?ooo`03
0000003oool0000001l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`00
=`3oool3000001l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`050?ooo`00=`3o
ool00`000000oooo0000000O0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3o
ool003L0oooo00<000000?ooo`0000007P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00H0oooo000g0?ooo`030000003oool0000001h0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`00=`3oool010000000oooo0?ooo`00000M0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01P3oool003L0oooo00@000000?ooo`3oool000004P3oool40000
00D0oooo0`0000040?ooo`@000005@3oool5000000@0oooo00<000000?ooo`3oool03@3oool50000
00@0oooo0P0000050?ooo`@00000503oool600000180oooo1@0000050?ooo`8000001@3oool40000
01D0oooo0`0000050?ooo`030000003oool0oooo00H0oooo000g0?ooo`80000000<0oooo0000003o
ool0403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool2000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo0?ooo`8000004P3oool01@00
0000oooo0?ooo`3oool0000000D0oooo0P0000040?ooo`040000003oool0oooo0?ooo`8000004`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool01P3oool003L0oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo
00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`00=`3oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0000000E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo000g0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo1000000G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0;0?ooo`@000005`3oool2000001H0oooo00<000000?ooo`3oool02`3oool5000001D0
oooo0P0000050?ooo`030000003oool0oooo00H0oooo000g0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000001L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`060?ooo`00=`3oool010000000oooo0?ooo`00000A0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01H0oooo0`0000070?ooo`030000003oool0oooo00`0oooo0`00000=0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool00P00000C0?ooo`050000003oool0oooo
0?ooo`000000303oool01@000000oooo0?ooo`3oool0000001<0oooo00D000000?ooo`3oool0oooo
000000040?ooo`030000003oool0oooo00H0oooo000g0?ooo`80000000<0oooo0000003oool04@3o
ool4000000D0oooo00<000000?ooo`3oool0103oool5000001H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00/0oooo1@00000D0?ooo`<000005@3o
ool3000000d0oooo1P00000C0?ooo`<000001@3oool00`000000oooo0?ooo`060?ooo`00=`3oool0
10000000oooo0?ooo`00000K0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3o
ool003L0oooo00@000000?ooo`3oool000006`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00H0oooo000g0?ooo`040000003oool0oooo000001X0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`060?ooo`00=`3oool010000000oooo0?ooo`00000J0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01`3oool003L0oooo00@000000?ooo`3oool000006P3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo000g0?ooo`040000003oool0
oooo000001X0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`00<P3ooooH
00000000=`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01`000000oooo
0?ooo`3oool000000?ooo`0000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo0P0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000D0oooo0@0000010?ooo`00=`3oool01@000000
oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?oo
o`00=`3oool01@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`070?ooo`00=`3oool01@000000oooo0?ooo`3oool0000001P0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`070?ooo`00=`3oool01@000000oooo0?ooo`3oool00000
01P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`00=`3oool200000080
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0
oooo000g0?ooo`050000003oool0oooo0?ooo`0000005`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00L0oooo000g0?ooo`050000003oool0oooo0?ooo`0000005`3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo000g0?ooo`050000003oool0oooo0?ooo`00
00005`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo000g0?ooo`050000
003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0
oooo000g0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00P0oooo000g0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00P0oooo000g0?ooo`8000000P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool003L0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0203oool003L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0203oool003L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0203oool003L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0203oool003L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
203oool003L0oooo0P0000030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`080?ooo`00=`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`00=`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`080?ooo`00=`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`001P3oool4000000D0oooo
0P0000050?ooo`@00000103oool4000000@0oooo100000030?ooo`D000001@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`090?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P00
00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`090?ooo`001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo0005
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00T0oooo00050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool02@3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`090?ooo`001P3oool4000000`0oooo100000040?ooo`@00000103oool4
000000@0oooo0`0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00T0oooo000g0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00T0oooo000g0?ooo`800000103oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool02P3oool003L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02P3oool003L0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02P3oool003L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool003L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool02P3oool003L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool02P3oool003L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool003L0oooo0P0000050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0:0?ooo`00=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`00=`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0;0?ooo`00=`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`00=`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0;0?ooo`00=`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`00=`3oool2000000H0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00/0oooo000g0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00/0oooo000g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00060?ooo`@00000
1@3oool2000000D0oooo100000040?ooo`@00000103oool4000000H0oooo0`0000040?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00`0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool2000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00`0oooo00050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0303oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00H00000103oool2000000L0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?ooo`001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool000D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`001P3oool4000000`0oooo100000040?oo
o`@00000103oool4000000H0oooo0P0000050?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo000g0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00h0oooo000g0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo000g0?ooo`8000002P3o
ool010000000oooo0?ooo`00001>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
C@3oool2000000<0oooo00<000000?ooo`3oool03P3oool003L0oooo00<000000?ooo`3oool02@3o
ool4000004l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1>0?ooo`@000004@3o
ool003L0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo06@0oooo000g0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1T0?ooo`00=`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0I@3oool003L0oooo00<000000?ooo`3oool0H03oool2000000D0oooo
00<000000?ooo`3oool0IP3oool003L0oooo0P00001S0?ooo`D00000J@3oool003L0oooo00<00000
0?ooo`3oool0d03oool003L0oooo00<000000?ooo`3oool0d03oool003L0oooo00<000000?ooo`3o
ool0d03oool00?l0oooo2`3oool00?l0oooo2`3oool00?l0oooo2`3oool00?l0oooo2`3oool00?l0
oooo2`3oool00?l0oooo2`3oool00?l0oooo2`3oool00?l0oooo2`3oool00?l0oooo2`3oool00?l0
oooo2`3oool00?l0oooo2`3oool00?l0oooo2`3oool00?l0oooo2`3oool00?l0oooo2`3oool00?l0
oooo2`3oool00001\
\>"],
  ImageRangeCache->{{{0, 265.875}, {163.813, 0}} -> {-0.843701, -0.000630136, \
0.019106, 9.70051*^-06}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[58]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subscript[\[Delta], \[Lambda] \[Rule] 
          1] -> \((\[Lambda] /. apr1[\([1]\)])\) - 1\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(\[Delta]\_\(\[Lambda] \[Rule] 1\) \[Rule] \
\(-2.324081266102951`*^-6\)\)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell["For \[Lambda] = 4", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\(y[x] /. sol1[\([1]\)]\) /. \[Lambda] \[Rule] 4)\) + \((y[x] /. 
            apr1[\([2]\)])\), {x, 0, Pi}]\)], "Input",
  CellLabel->"In[60]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.303152 0.30902 48.8684 [
[.17539 .29652 -9 -9 ]
[.17539 .29652 9 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -9 -9 ]
[.47854 .29652 9 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -9 -9 ]
[.78169 .29652 9 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .01581 -36 -4.5 ]
[.01131 .01581 0 4.5 ]
[.01131 .11355 -36 -4.5 ]
[.01131 .11355 0 4.5 ]
[.01131 .21128 -36 -4.5 ]
[.01131 .21128 0 4.5 ]
[.01131 .40676 -30 -4.5 ]
[.01131 .40676 0 4.5 ]
[.01131 .50449 -30 -4.5 ]
[.01131 .50449 0 4.5 ]
[.01131 .60223 -30 -4.5 ]
[.01131 .60223 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .30902 m
.17539 .31527 L
s
[(0.5)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(1)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(1.5)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(2)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(2.5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(3)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75138 .30902 m
.75138 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01581 m
.03006 .01581 L
s
[(-0.006)] .01131 .01581 1 0 Mshowa
.02381 .11355 m
.03006 .11355 L
s
[(-0.004)] .01131 .11355 1 0 Mshowa
.02381 .21128 m
.03006 .21128 L
s
[(-0.002)] .01131 .21128 1 0 Mshowa
.02381 .40676 m
.03006 .40676 L
s
[(0.002)] .01131 .40676 1 0 Mshowa
.02381 .50449 m
.03006 .50449 L
s
[(0.004)] .01131 .50449 1 0 Mshowa
.02381 .60223 m
.03006 .60223 L
s
[(0.006)] .01131 .60223 1 0 Mshowa
.125 Mabswid
.02381 .04024 m
.02756 .04024 L
s
.02381 .06468 m
.02756 .06468 L
s
.02381 .08911 m
.02756 .08911 L
s
.02381 .13798 m
.02756 .13798 L
s
.02381 .16241 m
.02756 .16241 L
s
.02381 .18685 m
.02756 .18685 L
s
.02381 .23572 m
.02756 .23572 L
s
.02381 .26015 m
.02756 .26015 L
s
.02381 .28459 m
.02756 .28459 L
s
.02381 .33345 m
.02756 .33345 L
s
.02381 .35789 m
.02756 .35789 L
s
.02381 .38232 m
.02756 .38232 L
s
.02381 .43119 m
.02756 .43119 L
s
.02381 .45562 m
.02756 .45562 L
s
.02381 .48006 m
.02756 .48006 L
s
.02381 .52893 m
.02756 .52893 L
s
.02381 .55336 m
.02756 .55336 L
s
.02381 .5778 m
.02756 .5778 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07167 m
.02846 .17654 L
.03279 .25973 L
.03793 .34198 L
.04262 .40248 L
.04754 .45275 L
.0522 .48891 L
.05711 .51633 L
.05988 .52739 L
.06122 .53166 L
.06244 .53498 L
.0636 .53764 L
.06487 .54001 L
.0662 .54194 L
.06747 .54324 L
.06865 .54399 L
.06991 .54433 L
.0711 .54423 L
.07218 .54379 L
.07285 .54336 L
.07356 .54277 L
.07483 .54139 L
.0762 .53944 L
.0777 .5368 L
.0829 .52377 L
.08831 .5047 L
.09411 .47919 L
.10458 .42356 L
.12439 .30262 L
.14594 .17721 L
.15598 .12831 L
.16664 .08564 L
.17574 .05769 L
.18092 .04545 L
.18579 .03643 L
.19048 .03 L
.19314 .02735 L
.19562 .02553 L
.19697 .02479 L
.19824 .02426 L
.19938 .02392 L
.20062 .02369 L
.20127 .02364 L
.20197 .02362 L
.20271 .02366 L
.2034 .02374 L
.20464 .024 L
.20533 .02421 L
.20597 .02444 L
.20833 .02563 L
Mistroke
.21051 .0272 L
.21291 .02943 L
.21546 .03237 L
.22019 .03932 L
.22447 .04723 L
.23452 .07141 L
.24376 .0998 L
.26459 .18063 L
.30413 .36283 L
.32403 .44935 L
.34216 .51571 L
.35153 .5437 L
.3617 .56843 L
.36729 .57933 L
.37246 .58763 L
.37739 .59395 L
.37995 .59658 L
.38263 .59889 L
.38498 .60051 L
.38622 .60122 L
.38754 .60186 L
.38876 .60235 L
.38986 .60271 L
.39098 .60299 L
.39203 .60317 L
.39326 .6033 L
.39456 .60332 L
.39567 .60325 L
.39688 .60308 L
.3982 .60278 L
.3996 .60234 L
.40214 .60121 L
.40449 .59978 L
.40705 .59783 L
.41171 .59318 L
.42044 .58082 L
.42982 .56245 L
.44019 .5365 L
.46119 .46848 L
.50136 .30314 L
.54001 .14522 L
.56003 .08095 L
.5701 .05578 L
.57576 .04404 L
.58112 .03467 L
.58604 .0276 L
.59138 .02162 L
.59373 .01957 L
.59623 .01778 L
.59836 .01657 L
Mistroke
.60071 .01559 L
.60137 .01538 L
.6021 .01518 L
.60274 .01503 L
.60343 .01491 L
.60472 .01476 L
.60592 .01472 L
.60664 .01474 L
.60743 .0148 L
.60817 .0149 L
.60886 .01502 L
.61015 .01533 L
.61152 .01579 L
.61402 .01695 L
.61635 .0184 L
.62165 .02305 L
.62666 .02916 L
.63211 .03766 L
.64201 .05793 L
.66058 .11136 L
.68037 .18681 L
.70138 .2807 L
.73915 .45329 L
.75851 .52571 L
.7694 .55695 L
.77422 .5681 L
.77937 .57798 L
.78451 .58564 L
.78694 .58845 L
.78918 .59058 L
.79144 .59226 L
.7926 .59294 L
.79388 .59354 L
.79499 .59394 L
.79603 .5942 L
.79713 .59437 L
.79831 .59442 L
.79898 .59438 L
.79969 .5943 L
.80097 .59403 L
.80175 .59378 L
.80249 .5935 L
.80386 .59282 L
.8064 .59107 L
.80913 .58846 L
.81428 .5815 L
.81902 .57272 L
.82879 .54746 L
.83789 .51552 L
.85858 .41646 L
Mistroke
.89756 .18236 L
.90777 .13009 L
.91315 .10772 L
.91609 .09743 L
.91885 .08926 L
.92145 .08298 L
.92383 .07855 L
.92519 .07663 L
.92648 .07524 L
.92718 .07466 L
.92784 .07424 L
.92855 .07392 L
.92932 .07373 L
.93057 .07378 L
.93128 .07402 L
.93193 .07437 L
.93313 .07535 L
.93439 .07688 L
.93552 .0787 L
.93658 .08079 L
.93899 .08701 L
.94147 .09569 L
.94377 .10588 L
.94898 .13729 L
.95357 .1755 L
.95845 .22816 L
.96688 .35241 L
.97619 .54636 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[60]:=",
  ImageSize->{232.313, 143.563},
  ImageMargins->{{2.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004R0000/b000`400?l00000o`00003oo`3ooolS
0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS
0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS
0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00<03oool00`000000oooo0?ooo`3_0?ooo`001`3o
ool4000000D0oooo0P0000050?ooo`@00000103oool4000000D0oooo0`0000050?ooo`030000003o
ool0oooo0>l0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2
000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0>l0oooo
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0k`3oool000@000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?oo
o`800000R`3oool6000005l0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool0oooo100000050?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`1M0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0
oooo0?ooo`000000203oool00`000000oooo0?ooo`0W0?ooo`@00000G@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo05`0oooo00060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00H0oooo0P00
001L0?ooo`001`3oool4000000`0oooo100000040?ooo`@000001P3oool3000000@0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo05L0oooo0P00000:
0?ooo`030000003oool0oooo05X0oooo000`0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0F@3oool00300oooo0P00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo05T0oooo000`0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0F03oool00300oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1H0?ooo`00<03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo05L0oooo000`0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0E`3oool00300
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1G0?ooo`00<03oool200000280oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0EP3oool00300oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`1F0?ooo`00<03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0480oooo0P00000A
0?ooo`00<03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0440oooo00@000000?oo
o`0000000000403oool00300oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`100?oo
o`050000003oool0oooo0?ooo`000000403oool00300oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00300
oooo0P00000Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0=0?ooo`00<03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`00<03oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0=0?ooo`001`3oool4000000D0oooo0P0000050?ooo`@00000103oool4000000H0oooo0`000004
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00d0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool2000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<
0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`00100000020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool01P0000040?ooo`8000007`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool000H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0<0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000050?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00/0oooo00070?ooo`@00000303oool4000000@0oooo1000
00060?ooo`8000001@3oool2000001h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00/0oooo000`0?ooo`8000007P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02`3oool00300oooo0P00000N0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?oo
o`00<03oool2000001d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00/0oooo000`0?ooo`8000007@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00300oooo0P00000M0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`00<03oool2
000001d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00/0oooo000`0?ooo`8000007@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool02P3oool00300oooo0P00000M0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`00<03oool2000001`0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo
000`0?ooo`800000703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00300oooo0P00000L0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`00<03oool2000001`0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo000`0?ooo`80
0000703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool02P3oool00300oooo0P00000L0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`00<03oool2000001/0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo000`0?ooo`8000006`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool0
00L0oooo100000050?ooo`8000001@3oool4000000@0oooo100000030?ooo`D000001@3oool20000
01/0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00T0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000@0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool00`3oool2000001/0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000@0oooo00D000000?ooo`3oool0oooo000000080?ooo`8000006`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool000@000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool2000001X0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00T0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`8000006P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0203oool000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo0P00000J0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0000000I0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`080?ooo`001`3oool4000000`0oooo100000040?ooo`@00000103o
ool3000000H0oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0203oool00300oooo00<000000?ooo`000000603oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool0
0300oooo0`00000H0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`080?ooo`00<03oool00`000000oooo0000000H0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`00<03oool00`000000oooo
0000000H0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`00<03oool00`000000oooo0000000H0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`080?ooo`00<03oool00`000000oooo0000000H
0?ooo`@000001@3oool2000000D0oooo1000000@0?ooo`030000003oool0oooo00L0oooo1@00000H
0?ooo`D00000103oool2000000D0oooo1000000H0?ooo`D000003P3oool00`000000oooo0?ooo`08
0?ooo`D000001@3oool2000000D0oooo1000000@0?ooo`030000003oool0oooo00H0oooo0`000006
0?ooo`030000003oool0oooo00P0oooo000`0?ooo`030000003oool0000001L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00@0oooo0P0000040?ooo`040000003oool0oooo0?ooo`8000005`3oool0
1@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?oo
o`3oool0000000D0oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000
oooo0?ooo`080?ooo`00<03oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00h0oooo0P00000H0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00L0oooo
000`0?ooo`030000003oool0000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`0000006@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`070?ooo`00<03oool00`000000oooo0000000G0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool400000140oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00/0oooo1000000K0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`@000003`3oool00`000000oooo0?ooo`08
0?ooo`8000001`3oool00`000000oooo0?ooo`070?ooo`00<03oool00`000000oooo0000000G0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0000001d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool00300oooo00<000000?ooo`00
00005P3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00H0oooo0`00000J0?ooo`<000003@3oool00`000000oooo0000000I0?ooo`05
0000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`000000303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00L0oooo000`0?ooo`030000003oool0
000001H0oooo00<000000?ooo`0000000`00000<0?ooo`D00000403oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool02`3oool5000001P0oooo0`00000A
0?ooo`030000003oool0oooo00L0oooo0`00000=0?ooo`D000003P3oool00`000000oooo0?ooo`07
0?ooo`<000001`3oool00`000000oooo0?ooo`070?ooo`00<03oool3000001H0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo000`0?ooo`03
0000003oool0000001H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00L0oooo000`0?ooo`030000003oool0000001H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo000`0?ooo`030000003o
ool0000001D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00L0oooo000`0?ooo`030000003oool0000001D0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo000`0?ooo`040000003oool0oooo
000001@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00L0oooo000Z0?ooooP00000000`0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`8000001`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool2000000L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`8000001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool100000040oooo0@3oool0
0300oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00300oooo00@000000?ooo`3oool000004`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool0
0300oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01P3oool00300oooo00@000000?ooo`3oool000004`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool0
0300oooo0P0000000`3oool000000?ooo`0B0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`060?ooo`00<03oool010000000oooo0?ooo`00000C0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?oo
o`00<03oool010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`060?ooo`00<03oool010000000oooo0?ooo`00000C0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?oo
o`00<03oool010000000oooo0?ooo`00000C0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`060?ooo`00<03oool010000000oooo0?ooo`00000B0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?oo
o`00<03oool2000000030?ooo`000000oooo0140oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo000`0?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00H0
oooo000`0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00H0oooo000`0?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00H0
oooo000`0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool00300oooo00D000000?ooo`3oool0
oooo0000000A0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`060?ooo`00<03oool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool00300oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`060?ooo`00<03oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo
00070?ooo`@000001@3oool2000000D0oooo100000040?ooo`@000000`3oool5000000D0oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`060?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo0P0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo0000000@0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`060?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo
0?ooo`000000203oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00H0oooo00060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`8000000P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000100oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0oooo
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`050?ooo`001`3oool4000000`0oooo100000040?ooo`@00000103oool30000
00H0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`00<03oool01@000000oooo0?ooo`3oool0
000000l0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`050?ooo`00<03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo000`0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool01@3oool00300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`050?ooo`00<03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool00300oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`050?ooo`00<03oool2000000<0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
1@3oool00300oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`050?ooo`00<03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo000`0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool01@3oool00300oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`050?ooo`00<03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00D0oooo
000`0?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`050?ooo`00<03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00D0oooo000`0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool01@3oool000L0oooo100000050?ooo`8000001@3oool4000000@0oooo100000060?ooo`<0
0000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo00060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0103oool000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`06000000@0oooo0P0000060?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00@0
oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`040?oo
o`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0103oool0
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`040?ooo`001`3oool40000
00`0oooo100000040?ooo`@000001P3oool2000000D0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`040?ooo`00<03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0
oooo000`0?ooo`8000001`3oool01@000000oooo0?ooo`3oool000000480oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`040?ooo`00<03oool00`000000oooo0?ooo`060?ooo`050000
003oool0oooo0?ooo`000000@P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00@0
oooo000`0?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`040?ooo`00<03oool00`000000oooo0?oo
o`070?ooo`<00000A03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo000`
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`04
0?ooo`00<03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02T0oooo000`0?ooo`80
0000D03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0Y0?ooo`00<03oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02X0oooo000`0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:P3o
ool00300oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0[0?ooo`00<03oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo02/0oooo000`0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0:`3oool00300oooo0P00001B0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02`0oooo
000`0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool00300oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`001`3oool4000000D0oooo0P0000050?oo
o`@00000103oool4000000D0oooo0`0000050?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1J0?ooo`80000000<0oooo000000000000<03oool000H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0E03oool2000000H0oooo00<00000
0?ooo`3oool0G03oool300000340oooo00060?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0E@3o
ool2000000<0oooo0P00002C0?ooo`001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`800000E`3oool4000009D0oooo
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo100000050?ooo`03
0000003oool0oooo0>l0oooo00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo0>l0oooo00060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0>l0oooo00070?ooo`@00000303oool4000000@0oooo100000060?ooo`<00000103oool00`000000
oooo0?ooo`3_0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?oo
o`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?oo
o`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00o`3ooolS0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 289.375}, {178.438, 0}} -> {-0.641813, -0.00738645, \
0.0166824, 0.000103488}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[60]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subscript[\[Delta], \[Lambda] \[Rule] 
          4] -> \((\[Lambda] /. apr1[\([2]\)])\) - 4\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(\[Delta]\_\(\[Lambda] \[Rule] 4\) \[Rule] 
      0.0004012987033199522`\)], "Output",
  CellLabel->"Out[61]="]
}, Open  ]],

Cell[TextData[{
  "If the given LDE has non-polynomial coefficients one can use the package \
function ",
  StyleBox["ToRatCoeffs",
    FontFamily->"Courier New"],
  " which gives a rational interpolation of the coefficients. This function \
applies ",
  StyleBox["RationalInterpolation",
    FontFamily->"Courier New"],
  " function to each non-polynomial coefficient of the LDE. Thus ",
  StyleBox["ToRatCoeffs",
    FontFamily->"Courier New"],
  " function inherits all options from the ",
  StyleBox["RationalInterpolation",
    FontFamily->"Courier New"],
  " function of the ",
  StyleBox["NumericalMath`Approximations`",
    FontFamily->"Courier New"],
  " package."
}], "Text"],

Cell[TextData[{
  "            ",
  Cell[BoxData[
      FormBox[GridBox[{
            {
              RowBox[{
                StyleBox[
                  FormBox[\(ToRatCoeffs[lde, y[x], {x, a, b}, m, k]\),
                    "TraditionalForm"],
                  FontFamily->"Courier New"], "   "}], 
              RowBox[{"gives", 
                StyleBox[" ",
                  FontFamily->"Times New Roman"], 
                StyleBox[
                  RowBox[{
                    StyleBox["rat",
                      FontFamily->"Times New Roman"], "ional"}]], " ", 
                "interpolation", " ", "for", " ", 
                StyleBox["lde",
                  FontFamily->"Courier New"], " ", "coefficients", " ", "of", 
                " ", "degree", " ", \((m, k)\), " ", "on", " ", 
                RowBox[{"interval", " ", 
                  StyleBox["[",
                    FontFamily->"Courier New"], 
                  StyleBox[\(a, b\),
                    FontFamily->"Courier New"], 
                  StyleBox["]",
                    FontFamily->"Courier New"]}]}]}
            }], TraditionalForm]],
    GridBoxOptions->{ColumnWidths->Automatic}],
  StyleBox[" ",
    GridBoxOptions->{ColumnWidths->Automatic}]
}], "DefinitionBox"],

Cell["Rational interpolation for an LDE coefficients. ", "Caption"],

Cell[TextData[{
  "One can use any other available function from ",
  StyleBox["NumericalMath`Approximations`",
    FontFamily->"Courier New"],
  " package to get appropriate approximation of the coefficients. \
Nevertheless it should be pointed out that in such a case the coefficients \
can not involve indeterminate variables except independent one. This is a \
restriction of ",
  StyleBox["NumericalMath`Approximations`",
    FontFamily->"Courier New"],
  " package methods as pure numerical ones."
}], "Text"],

Cell["This LDE has non-polynomial coefficient.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lde = \(y'\)[x] + Erf[x]*y[x] \[Equal] 0\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Erf[x]\ y[x]\), "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "==", 
      "0"}]], "Output",
  CellLabel->"Out[62]="]
}, Open  ]],

Cell["Trying to find approximate solution.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = 
      ApproxSol[{lde, y[0] \[Equal] 1}, y[x], {x, \(-1\), 1}, 3]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(LdeApprox::"nopoly" \(\(:\)\(\ \)\) 
      "\!\(Erf[x]\) is not a polynomial on \!\(x\)"\)], "Message",
  CellLabel->"From In[63]:="],

Cell[BoxData[
    \($Aborted\)], "Output",
  CellLabel->"Out[63]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["ToRatCoeffs",
    FontFamily->"Courier New"],
  " to convert the LDE into one with polynomial coefficients on the given \
interval. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(lde1 = ToRatCoeffs[lde, y[x], {x, \(-1\), 1}, 9, 0]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\((1.81497657991008640822367588`15.9546*^-17 + 
              1.128377983372431148170755796553285`15.9546\ x - 
              5.997801536612255958710852906`15.9546*^-16\ x\^2 - 
              0.3760670288119831635650898736`15.9546\ x\^3 + 
              3.7216188219632981394936545351`15.9546*^-15\ x\^4 + 
              0.1123557019192992240143565478`15.9546\ x\^5 - 
              6.1140811719480848468672625782`15.9546*^-15\ x\^6 - 
              0.0254696585309700951380678968`15.9546\ x\^7 + 
              3.0180128289355964655245284688`15.9546*^-15\ x\^8 + 
              0.003504824639588756223405067077621`15.9546\ x\^9)\)\ y[x]\), 
        "+", 
        RowBox[{
          SuperscriptBox["y", "\[Prime]",
            MultilineFunction->None], "[", "x", "]"}]}], "==", 
      "0"}]], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell["Trying ApproxSol for the new LDE.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = 
      ApproxSol[{lde1, y[0] \[Equal] 1}, y[x], {x, \(-1\), 1}, 9]\)], "Input",\

  CellLabel->"In[65]:="],

Cell[BoxData[
    \({{y[x] \[Rule] 
          0.9999890336474119991649294901`15.6536 - 
            1.64464917619020715114807261`15.6536*^-17\ x - 
            0.5636214286567698350727586709`15.6536\ x\^2 + 
            1.740884398886896908265210033`15.6536*^-16\ x\^3 + 
            0.2483565788536577187275334667`15.6536\ x\^4 - 
            6.426828758812279957858134921`15.6536*^-16\ x\^5 - 
            0.0869293751159975466375069911`15.6536\ x\^6 + 
            7.754412070761744167454393647`15.6536*^-16\ x\^7 + 
            0.0172569503576412369494869046`15.6536\ x\^8 - 
            3.055642945785932579778211524`15.6536*^-16\ x\^9}}\)], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get the exact solution."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[{lde, y[0] \[Equal] 1}, y[x], x]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \[ExponentialE]\^\(1\/\@\[Pi] - \
\[ExponentialE]\^\(-x\^2\)\/\@\[Pi] - x\ Erf[x]\)}}\)], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell["Comparing the results.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
            apr[\([1]\)])\), {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[67]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.304323 27264.8 [
[.02381 .29182 -6 -9 ]
[.02381 .29182 6 0 ]
[.2619 .29182 -12 -9 ]
[.2619 .29182 12 0 ]
[.7381 .29182 -9 -9 ]
[.7381 .29182 9 0 ]
[.97619 .29182 -3 -9 ]
[.97619 .29182 3 0 ]
[.4875 .03168 -48 -4.5 ]
[.4875 .03168 0 4.5 ]
[.4875 .168 -39 -6.25 ]
[.4875 .168 0 6.25 ]
[.4875 .44065 -33 -6.25 ]
[.4875 .44065 0 6.25 ]
[.4875 .57697 -42 -4.5 ]
[.4875 .57697 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30432 m
.02381 .31057 L
s
[(-1)] .02381 .29182 0 1 Mshowa
.2619 .30432 m
.2619 .31057 L
s
[(-0.5)] .2619 .29182 0 1 Mshowa
.7381 .30432 m
.7381 .31057 L
s
[(0.5)] .7381 .29182 0 1 Mshowa
.97619 .30432 m
.97619 .31057 L
s
[(1)] .97619 .29182 0 1 Mshowa
.125 Mabswid
.07143 .30432 m
.07143 .30807 L
s
.11905 .30432 m
.11905 .30807 L
s
.16667 .30432 m
.16667 .30807 L
s
.21429 .30432 m
.21429 .30807 L
s
.30952 .30432 m
.30952 .30807 L
s
.35714 .30432 m
.35714 .30807 L
s
.40476 .30432 m
.40476 .30807 L
s
.45238 .30432 m
.45238 .30807 L
s
.54762 .30432 m
.54762 .30807 L
s
.59524 .30432 m
.59524 .30807 L
s
.64286 .30432 m
.64286 .30807 L
s
.69048 .30432 m
.69048 .30807 L
s
.78571 .30432 m
.78571 .30807 L
s
.83333 .30432 m
.83333 .30807 L
s
.88095 .30432 m
.88095 .30807 L
s
.92857 .30432 m
.92857 .30807 L
s
.25 Mabswid
0 .30432 m
1 .30432 L
s
.5 .03168 m
.50625 .03168 L
s
[(-0.00001)] .4875 .03168 1 0 Mshowa
.5 .168 m
.50625 .168 L
s
gsave
.4875 .168 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.5 .44065 m
.50625 .44065 L
s
gsave
.4875 .44065 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.5 .57697 m
.50625 .57697 L
s
[(0.00001)] .4875 .57697 1 0 Mshowa
.125 Mabswid
.5 .05894 m
.50375 .05894 L
s
.5 .0862 m
.50375 .0862 L
s
.5 .11347 m
.50375 .11347 L
s
.5 .14073 m
.50375 .14073 L
s
.5 .19526 m
.50375 .19526 L
s
.5 .22253 m
.50375 .22253 L
s
.5 .24979 m
.50375 .24979 L
s
.5 .27706 m
.50375 .27706 L
s
.5 .33159 m
.50375 .33159 L
s
.5 .35885 m
.50375 .35885 L
s
.5 .38612 m
.50375 .38612 L
s
.5 .41338 m
.50375 .41338 L
s
.5 .46791 m
.50375 .46791 L
s
.5 .49518 m
.50375 .49518 L
s
.5 .52244 m
.50375 .52244 L
s
.5 .54971 m
.50375 .54971 L
s
.5 .00441 m
.50375 .00441 L
s
.5 .60424 m
.50375 .60424 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03427 m
.02846 .2526 L
.03279 .39698 L
.03527 .45794 L
.03754 .5012 L
.03879 .52057 L
.04015 .53819 L
.04142 .55168 L
.04262 .56181 L
.04376 .56941 L
.045 .57539 L
.0457 .57782 L
.04637 .57952 L
.04762 .58116 L
.04894 .58084 L
.05016 .57881 L
.05086 .57693 L
.0515 .57481 L
.05293 .56866 L
.05528 .55476 L
.05783 .53519 L
.06244 .49042 L
.08293 .24126 L
.09325 .13491 L
.09911 .08922 L
.10173 .07272 L
.10458 .05763 L
.10734 .04587 L
.1099 .03751 L
.11234 .03176 L
.11357 .02968 L
.11423 .02879 L
.11493 .02802 L
.11615 .02708 L
.11727 .02668 L
.11848 .02674 L
.1198 .02736 L
.12094 .02837 L
.12217 .02992 L
.12332 .03182 L
.12437 .03391 L
.12709 .04089 L
.12961 .04923 L
.13528 .0742 L
.14558 .13736 L
.16594 .2994 L
.18499 .44872 L
.19436 .50802 L
.20325 .55138 L
.20816 .56919 L
Mistroke
.21075 .57675 L
.2135 .58337 L
.21606 .58817 L
.21837 .59142 L
.21948 .59261 L
.22069 .59362 L
.22183 .59432 L
.22287 .59474 L
.22414 .59496 L
.22534 .59489 L
.22642 .59458 L
.22759 .594 L
.22886 .59308 L
.23021 .59177 L
.23263 .58856 L
.23487 .58467 L
.23696 .58021 L
.24174 .56725 L
.24693 .54898 L
.25169 .52877 L
.26241 .4729 L
.28298 .33981 L
.30209 .21042 L
.32055 .10473 L
.32587 .08056 L
.33088 .06091 L
.33572 .04503 L
.34025 .03311 L
.34489 .0239 L
.34736 .0203 L
.35 .01742 L
.35132 .01636 L
.35202 .01591 L
.35276 .01551 L
.35341 .01523 L
.35413 .01499 L
.35539 .01475 L
.35661 .01474 L
.35792 .01497 L
.35916 .01543 L
.3603 .01605 L
.36138 .0168 L
.36253 .0178 L
.3646 .02007 L
.36706 .02357 L
.36929 .02749 L
.37417 .03839 L
.37877 .05158 L
.38847 .08782 L
.39876 .137 L
Mistroke
.4172 .24462 L
.45506 .4755 L
.46502 .52349 L
.47448 .55991 L
.4797 .5756 L
.48245 .58253 L
.48539 .58885 L
.4881 .5937 L
.49056 .59726 L
.49304 .60001 L
.49425 .60107 L
.49537 .60185 L
.49653 .6025 L
.49778 .60298 L
.49893 .60324 L
.50003 .60332 L
.5013 .6032 L
.50248 .6029 L
.50377 .60235 L
.50442 .60199 L
.50514 .60152 L
.5077 .59928 L
.51046 .59587 L
.51546 .58714 L
.52016 .57599 L
.5251 .56129 L
.53394 .52799 L
.55369 .42685 L
.57206 .3129 L
.59081 .19557 L
.61113 .08953 L
.61653 .06777 L
.62225 .04844 L
.62713 .03519 L
.62993 .02901 L
.63249 .0243 L
.63489 .02072 L
.63751 .01776 L
.63895 .01656 L
.63965 .01608 L
.64028 .01571 L
.64155 .01514 L
.64225 .01493 L
.64291 .01479 L
.6441 .01472 L
.64535 .01486 L
.64642 .01516 L
.64759 .01569 L
.64885 .01649 L
.65021 .01761 L
Mistroke
.65265 .0203 L
.65522 .0241 L
.65795 .02918 L
.66286 .04098 L
.66813 .05741 L
.67394 .07976 L
.69408 .18623 L
.71511 .32664 L
.73436 .45375 L
.74385 .50715 L
.74887 .53133 L
.75422 .5534 L
.75936 .57056 L
.76402 .58239 L
.76627 .58676 L
.7687 .59046 L
.76982 .5918 L
.771 .59296 L
.77201 .59374 L
.77312 .59438 L
.77442 .59484 L
.77562 .59497 L
.77625 .59493 L
.77695 .59479 L
.77767 .59455 L
.77835 .59423 L
.7796 .59341 L
.78074 .59239 L
.78331 .58916 L
.78548 .58544 L
.78784 .58032 L
.79262 .56669 L
.79785 .54676 L
.80345 .52 L
.81353 .45895 L
.83343 .30466 L
.84391 .2177 L
.85501 .1332 L
.86491 .07322 L
.86762 .06041 L
.87054 .0487 L
.87306 .04044 L
.87439 .03682 L
.87581 .03354 L
.8772 .0309 L
.87847 .02905 L
.87975 .02771 L
.88094 .02694 L
.88217 .02665 L
.88329 .02683 L
Mistroke
.88452 .02754 L
.88582 .02886 L
.88692 .03044 L
.88808 .0326 L
.89019 .03776 L
.8927 .04602 L
.89498 .05557 L
.8998 .08206 L
.90492 .11936 L
.9141 .20775 L
.9241 .32688 L
.93487 .46033 L
.93983 .51374 L
.94253 .53821 L
.94505 .55694 L
.9472 .56928 L
.94841 .57445 L
.9495 .57796 L
.9507 .58041 L
.95201 .58128 L
.95324 .58025 L
.95437 .57761 L
.95542 .57359 L
.95656 .56749 L
.95763 .55993 L
.9586 .55143 L
.96099 .52366 L
.96326 .48729 L
.96559 .43839 L
.96776 .38166 L
.97266 .20667 L
.97619 .03427 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[67]:=",
  ImageSize->{226, 139.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[R000`400?l00000o`00003oS@3oool0
0`000000oooo0?ooo`2:0?ooo`00S@3oool2000008/0oooo002=0?ooo`030000003oool0oooo08X0
oooo002=0?ooo`030000003oool0oooo08X0oooo001S0?ooo`<000009`3oool00`000000oooo0?oo
o`0T0?ooo`<00000H`3oool006<0oooo00@000000?ooo`00000000009P3oool00`000000oooo0?oo
o`0S0?ooo`80000000<0oooo000000000000HP3oool005<0oooo100000050?ooo`800000103oool6
000000<0oooo100000040?ooo`@00000103oool4000000@0oooo1@0000050?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1O0?ooo`00DP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000030?ooo`800000103oool01000
0000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
7`3oool00200oooo1000000^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3o
ool00`000000oooo000000040?ooo`80000000<0oooo0000003oool00`3oool010000000oooo0?oo
o`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0k0?ooo`<00000803oool00200oooo00@000000?ooo`3oool000009P3oool600000080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`060?ooo`030000003oool0000000@0
oooo0P0000000`3oool000000?ooo`030?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0P00000Q
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>P3oool2000000030?ooo`000000
000001l0oooo00070?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3oool0oooo0000000^
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo00000004
0?ooo`040000003oool00000000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0>P3oool01@000000
oooo0?ooo`3oool0000001L0oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000@0oooo00@000000?oo
o`0000000000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000103oool010000000oooo
0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool0
10000000oooo0?ooo`3oool3000000L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`@00000203oool010000000oooo0?ooo`3o
ool4000000<0oooo1@0000040?ooo`@00000103oool4000000H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3o
ool000L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`001`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0N0?ooo`8000007`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo
00070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool000L0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool01@3oool000L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`001`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool07@3oool2000001d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00D0oooo00070?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3oool000L0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01@3oool000L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?oo
o`001`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool06`3oool2000001`0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00D0oooo00070?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool0
00L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`001`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00070?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool01P3oool000L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`060?ooo`001`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00070?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool2000001X0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1P3oool000P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool01`3oool4000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`H000000`3oool4000000l0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool000P0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00H0oooo00080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0000000D000001`3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0203oool4000000<0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`8000006@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00H0oooo00080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3o
ool000P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`<00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000050?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`00203oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`D000002`3oool00`000000oooo000000050?ooo`@00000203oool00`00
0000oooo000000040?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0
oooo0`0000020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool04@3oool2000000D0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0140oooo0P0000040?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01L0oooo0P00000G0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool01P3oool000P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`00
203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00H0oooo00080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool000P0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0F0?ooo`8000005P3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`06
0?ooo`00203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00080?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool000P0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00H0oooo00080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01P3oool0
00P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0E0?ooo`8000005@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00080?ooo`H000002P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01@0oooo100000050?ooo`800000103oool5000001d0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01h0
oooo100000050?ooo`8000001@3oool4000001<0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0;0?ooo`D000001@3oool000P0oooo00@000000?ooo`3oool00000303oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0<0?ooo`8000001`3oool000P0oooo00@000000?ooo`3oool00000303oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07P3oool00`000000
oooo000000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00`0oooo0P0000070?ooo`001P0000020?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`H0
00000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0303oool2000000L0oooo00080?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool5000001h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`@0
00004P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00`0oooo0P0000070?ooo`00
203oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo0P00000Q0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0N0?ooo`06
0000003oool0oooo0000003oool000002`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool02`3oool2000000L0oooo00080?ooo`@000002`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool000000240oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0oooo00H000000?ooo`3oool000000?ooo`00
000;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0:0?ooo`<000001`3oool000P0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01<0oooo1000000:0?ooo`030000003oool0000000@000007P3o
ool00`000000oooo0?ooo`0C0?ooo`800000503oool00`000000oooo0?ooo`0O0?ooo`@00000303o
ool500000140oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?ooo`8000001`3o
ool000P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`00203oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00080?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool01P3oool000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`060?ooo`002@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool00?l000006`00000000L0
oooo00<000000?ooo`0000002P3oool00`000000oooo0000000;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000X0
oooo00<000000?ooo`0000001`3oool000L0oooo00<000000?ooo`000000303oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`0000001`3oool000T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01`3oool000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`00
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool04@3oool200000140oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00L0oooo00090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool000T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00L0oooo00090?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool01`3oool000T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`07
0?ooo`002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool0403oool200000100oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool000X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`002P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00h0oooo0P00
000?0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool000X0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool000X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`002P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00d0
oooo0P00000>0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool000X0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo10000003
0?ooo`050000003oool0oooo0?ooo`000000103oool5000000<0oooo1@00000>0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`002P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000
003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0G0?ooo`070000003oool0
oooo0?ooo`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`@000000`3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool2000000`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`080?ooo`002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo0`000004
0?ooo`030000003oool0oooo0080oooo0P00000=0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0D0?oo
o`D000003@3oool00`000000oooo0?ooo`030?ooo`@0000000<0oooo0000003oool01@3oool20000
00D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00P0oooo000:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0103oool00`000000
oooo000000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0a0?ooo`030000003oool0000000800000
0P3oool00`000000oooo000000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00@0oooo0P0000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`040?ooo`800000103oool2000000/0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0
oooo000:0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool000X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0203oool000/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`00
2`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool02@3oool2000000T0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00P0oooo000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool000/0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`09
0?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo000;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool01`3oool2000000L0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00T0oooo000<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00303oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool01@00
0000oooo0?ooo`3oool0000000`0oooo000<0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo0?ooo`000000303oool0
00`0oooo00D000000?ooo`3oool0oooo0000000X0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`00303oool01@000000oooo0?ooo`3oool0000002P0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00H0oooo0P00
00060?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0W0?ooo`040000003oool0oooo000000`0oooo000<0?ooo`050000003oool0oooo0?ooo`000000
:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0W0?ooo`040000003oool0oooo000000`0oooo000<0?ooo`050000
003oool0oooo0?ooo`000000:03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?ooo`040000003oool0oooo0000
00`0oooo000<0?ooo`050000003oool0oooo0?ooo`000000:@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?oo
o`040000003oool0oooo000000`0oooo000<0?ooo`040000003oool0oooo000002X0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0:03oool010000000oooo0?ooo`00000<0?ooo`00303oool010000000oooo0?ooo`00
000[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool4000000D0oooo0P00
00050?ooo`@00000103oool4000000@0oooo100000040?ooo`@00000103oool5000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0:03oool010000000oooo0?ooo`00000<0?ooo`003@3oool00`000000oooo0000
000[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0000000=0?ooo`003@3oool00`000000oooo0000000[0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo
000000@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0:P3oool2000000d0oooo000=0?ooo`<00000:`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000050?ooo`8000000`3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool2000000d0oooo000=0?ooo`800000
;03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo0P00000=
0?ooo`00?03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?oo
o`000000A@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo000m0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?oo
o`040000003oool0oooo000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`3oool3000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0k0?ooo`00?P3oool010000000oooo
0?ooo`00000A0?ooo`@00000303oool4000000@0oooo100000040?ooo`@00000103oool4000000H0
oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000004L0oooo0P000000
0`3oool000000?ooo`0m0?ooo`00?P3oool3000004P0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo04H0oooo0`00000n0?ooo`00RP3oool2000000040?ooo`000000oooo
000008X0oooo002;0?ooo`@00000R`3oool008d0oooo0P00002;0?ooo`00S@3oool00`000000oooo
0?ooo`2:0?ooo`00S@3oool00`000000oooo0?ooo`2:0?ooo`00S@3oool00`000000oooo0?ooo`2:
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 281.5}, {173.5, 0}} -> {-1.05612, -1.11638*^-05, \
0.00935227, 1.63341*^-07}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[67]="]
}, Open  ]],

Cell["\<\
The following example shows some of the package capabilities of getting \
symbolical results.\
\>", "Text"],

Cell["\<\
This is a simple IVP with parameter \[Xi].\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\(y''\)[x] + \[Xi]*y[x] \[Equal] 0, 
        y[0] \[Equal] 0, \(y'\)[0] \[Equal] 1}\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\[Xi]\ y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
        ",", \(y[0] == 0\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", "1"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[68]="]
}, Open  ]],

Cell[TextData[{
  "Finding polynomial approximation of the IVP solution on interval ",
  StyleBox["[-h,h]",
    FontFamily->"Courier New"],
  StyleBox[".",
    FontFamily->"Times New Roman"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[ivp, y[x], {x, \(-h\), h}, 7]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(\(2048\ x\^7\ \[Xi]\^3\)\/\(10321920 + 
                    322560\ h\^2\ \[Xi] + 5760\ h\^4\ \[Xi]\^2 + 
                    80\ h\^6\ \[Xi]\^3 + 
                    h\^8\ \[Xi]\^4\)\)\) + \(2688\ x\^5\ \[Xi]\^2\ \((32 + \
h\^2\ \[Xi])\)\)\/\(10321920 + 322560\ h\^2\ \[Xi] + 5760\ h\^4\ \[Xi]\^2 + \
80\ h\^6\ \[Xi]\^3 + h\^8\ \[Xi]\^4\) - \(960\ x\^3\ \[Xi]\ \((1792 + 56\ \
h\^2\ \[Xi] + h\^4\ \[Xi]\^2)\)\)\/\(10321920 + 322560\ h\^2\ \[Xi] + 5760\ h\
\^4\ \[Xi]\^2 + 80\ h\^6\ \[Xi]\^3 + h\^8\ \[Xi]\^4\) + 
            x\ \((1 - \(h\^8\ \[Xi]\^4\)\/\(10321920 + 322560\ h\^2\ \[Xi] + \
5760\ h\^4\ \[Xi]\^2 + 80\ h\^6\ \[Xi]\^3 + h\^8\ \[Xi]\^4\))\)}}\)], "Output",\

  CellLabel->"Out[69]="]
}, Open  ]],

Cell[TextData[{
  "Finding exact solution of the IVP using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \({{y[x] \[Rule] Sin[x\ \@\[Xi]]\/\@\[Xi]}}\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(h = \[Pi]\/2\)]],
  " and ",
  Cell[BoxData[
      \(\[Xi] = 1\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {h \[Rule] Pi/2, \[Xi] \[Rule] 
            1}, {x, \(-Pi\)/2, Pi/2}]\)], "Input",
  CellLabel->"In[71]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.303152 0.30903 428305 [
[.04527 .29653 -12 -9 ]
[.04527 .29653 12 0 ]
[.19685 .29653 -6 -9 ]
[.19685 .29653 6 0 ]
[.34842 .29653 -12 -9 ]
[.34842 .29653 12 0 ]
[.65158 .29653 -9 -9 ]
[.65158 .29653 9 0 ]
[.80315 .29653 -3 -9 ]
[.80315 .29653 3 0 ]
[.95473 .29653 -9 -9 ]
[.95473 .29653 9 0 ]
[.4875 .05205 -39 -6.25 ]
[.4875 .05205 0 6.25 ]
[.4875 .13771 -39 -6.25 ]
[.4875 .13771 0 6.25 ]
[.4875 .22337 -39 -6.25 ]
[.4875 .22337 0 6.25 ]
[.4875 .39469 -33 -6.25 ]
[.4875 .39469 0 6.25 ]
[.4875 .48035 -33 -6.25 ]
[.4875 .48035 0 6.25 ]
[.4875 .56601 -33 -6.25 ]
[.4875 .56601 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .30903 m
.04527 .31528 L
s
[(-1.5)] .04527 .29653 0 1 Mshowa
.19685 .30903 m
.19685 .31528 L
s
[(-1)] .19685 .29653 0 1 Mshowa
.34842 .30903 m
.34842 .31528 L
s
[(-0.5)] .34842 .29653 0 1 Mshowa
.65158 .30903 m
.65158 .31528 L
s
[(0.5)] .65158 .29653 0 1 Mshowa
.80315 .30903 m
.80315 .31528 L
s
[(1)] .80315 .29653 0 1 Mshowa
.95473 .30903 m
.95473 .31528 L
s
[(1.5)] .95473 .29653 0 1 Mshowa
.125 Mabswid
.07559 .30903 m
.07559 .31278 L
s
.1059 .30903 m
.1059 .31278 L
s
.13622 .30903 m
.13622 .31278 L
s
.16653 .30903 m
.16653 .31278 L
s
.22716 .30903 m
.22716 .31278 L
s
.25748 .30903 m
.25748 .31278 L
s
.28779 .30903 m
.28779 .31278 L
s
.31811 .30903 m
.31811 .31278 L
s
.37874 .30903 m
.37874 .31278 L
s
.40905 .30903 m
.40905 .31278 L
s
.43937 .30903 m
.43937 .31278 L
s
.46968 .30903 m
.46968 .31278 L
s
.53032 .30903 m
.53032 .31278 L
s
.56063 .30903 m
.56063 .31278 L
s
.59095 .30903 m
.59095 .31278 L
s
.62126 .30903 m
.62126 .31278 L
s
.68189 .30903 m
.68189 .31278 L
s
.71221 .30903 m
.71221 .31278 L
s
.74252 .30903 m
.74252 .31278 L
s
.77284 .30903 m
.77284 .31278 L
s
.83347 .30903 m
.83347 .31278 L
s
.86378 .30903 m
.86378 .31278 L
s
.8941 .30903 m
.8941 .31278 L
s
.92441 .30903 m
.92441 .31278 L
s
.01496 .30903 m
.01496 .31278 L
s
.98504 .30903 m
.98504 .31278 L
s
.25 Mabswid
0 .30903 m
1 .30903 L
s
.5 .05205 m
.50625 .05205 L
s
gsave
.4875 .05205 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.5 .13771 m
.50625 .13771 L
s
gsave
.4875 .13771 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.5 .22337 m
.50625 .22337 L
s
gsave
.4875 .22337 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.5 .39469 m
.50625 .39469 L
s
gsave
.4875 .39469 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.5 .48035 m
.50625 .48035 L
s
gsave
.4875 .48035 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.5 .56601 m
.50625 .56601 L
s
gsave
.4875 .56601 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.125 Mabswid
.5 .07346 m
.50375 .07346 L
s
.5 .09488 m
.50375 .09488 L
s
.5 .11629 m
.50375 .11629 L
s
.5 .15912 m
.50375 .15912 L
s
.5 .18054 m
.50375 .18054 L
s
.5 .20195 m
.50375 .20195 L
s
.5 .24478 m
.50375 .24478 L
s
.5 .2662 m
.50375 .2662 L
s
.5 .28761 m
.50375 .28761 L
s
.5 .33045 m
.50375 .33045 L
s
.5 .35186 m
.50375 .35186 L
s
.5 .37328 m
.50375 .37328 L
s
.5 .41611 m
.50375 .41611 L
s
.5 .43752 m
.50375 .43752 L
s
.5 .45894 m
.50375 .45894 L
s
.5 .50177 m
.50375 .50177 L
s
.5 .52318 m
.50375 .52318 L
s
.5 .5446 m
.50375 .5446 L
s
.5 .03063 m
.50375 .03063 L
s
.5 .00922 m
.50375 .00922 L
s
.5 .58743 m
.50375 .58743 L
s
.5 .60884 m
.50375 .60884 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .1064 m
.02846 .27854 L
.03279 .39931 L
.03754 .49437 L
.0402 .53278 L
.04262 .55959 L
.04385 .57051 L
.04516 .58021 L
.04629 .5871 L
.0475 .59306 L
.04881 .59786 L
.05003 .60095 L
.05077 .6022 L
.05148 .60296 L
.05212 .6033 L
.05281 .60332 L
.05408 .60242 L
.05523 .60062 L
.05587 .59925 L
.05656 .59747 L
.05781 .5935 L
.06022 .58335 L
.06244 .57144 L
.07221 .49798 L
.08293 .39721 L
.09426 .29123 L
.10458 .20895 L
.10938 .17767 L
.1146 .14942 L
.11953 .12853 L
.12409 .11432 L
.12658 .10863 L
.12891 .10461 L
.13025 .10288 L
.13147 .10164 L
.13217 .10109 L
.13281 .10067 L
.13349 .10034 L
.13423 .10009 L
.1349 .09997 L
.13563 .09995 L
.13632 .10003 L
.13696 .1002 L
.13816 .10076 L
.13944 .10167 L
.14081 .10303 L
.14209 .10464 L
.145 .1095 L
.14759 .11514 L
.14998 .12143 L
Mistroke
.15541 .13918 L
.16529 .18209 L
.18383 .28673 L
.20266 .40192 L
.22301 .50874 L
.22845 .53132 L
.23419 .55176 L
.23951 .56738 L
.24446 .57892 L
.24911 .58704 L
.25172 .59043 L
.25409 .59278 L
.25544 .59381 L
.25669 .59456 L
.25806 .59516 L
.25875 .59537 L
.25951 .59554 L
.26079 .59567 L
.26151 .59565 L
.26216 .59558 L
.26337 .59531 L
.26464 .59484 L
.26588 .5942 L
.26723 .59329 L
.26966 .59111 L
.27203 .58833 L
.27421 .5852 L
.27918 .57611 L
.28443 .56368 L
.29318 .537 L
.30281 .50027 L
.3432 .29955 L
.36181 .20748 L
.38207 .12689 L
.38741 .11051 L
.39309 .09567 L
.39835 .08441 L
.40329 .0761 L
.40789 .07039 L
.41047 .06804 L
.41284 .06644 L
.41412 .06581 L
.4153 .06535 L
.4166 .065 L
.41732 .06487 L
.41799 .0648 L
.41868 .06477 L
.41932 .06478 L
.42003 .06484 L
.42077 .06495 L
Mistroke
.42202 .06525 L
.42274 .06549 L
.4234 .06576 L
.42598 .06717 L
.42837 .06903 L
.431 .07167 L
.43379 .07516 L
.43897 .08344 L
.44366 .0929 L
.45321 .1175 L
.46219 .14657 L
.50076 .31262 L
.52033 .40208 L
.53069 .445 L
.54179 .48502 L
.55248 .51606 L
.56222 .53674 L
.56692 .54385 L
.56939 .54682 L
.57202 .54937 L
.57431 .55108 L
.57562 .55184 L
.57684 .5524 L
.57796 .5528 L
.57898 .55306 L
.58011 .55324 L
.5813 .55329 L
.58253 .55321 L
.58323 .5531 L
.58387 .55295 L
.58505 .55259 L
.5863 .55206 L
.58847 .5508 L
.59085 .5489 L
.59339 .54628 L
.59612 .5428 L
.60105 .53478 L
.61065 .51291 L
.61942 .48617 L
.63846 .40933 L
.6592 .30597 L
.68058 .1948 L
.69992 .10667 L
.70964 .0717 L
.71474 .0566 L
.72013 .04343 L
.72485 .03437 L
.72735 .03056 L
.73003 .02727 L
.7313 .02601 L
Mistroke
.73249 .02498 L
.73366 .02414 L
.73474 .02351 L
.73576 .02305 L
.73684 .02269 L
.73793 .02247 L
.73912 .02239 L
.74041 .0225 L
.74161 .02279 L
.74292 .02331 L
.74365 .02369 L
.74432 .02409 L
.74686 .02614 L
.74925 .0288 L
.75371 .03562 L
.75852 .04574 L
.76381 .06003 L
.76939 .07864 L
.7794 .12025 L
.81736 .33857 L
.82821 .40194 L
.83849 .45384 L
.84773 .4897 L
.85025 .49729 L
.85294 .50417 L
.85546 .50944 L
.85777 .51322 L
.86 .51588 L
.86113 .51684 L
.86236 .51758 L
.8636 .51801 L
.86429 .51811 L
.86492 .51811 L
.86615 .51786 L
.8673 .51732 L
.86839 .51654 L
.86954 .51543 L
.8716 .51268 L
.87382 .50863 L
.87626 .50284 L
.88134 .48627 L
.8868 .46169 L
.89667 .40021 L
.91641 .22723 L
.92683 .12857 L
.93255 .08072 L
.93535 .0605 L
.93793 .04445 L
.94032 .03217 L
.94158 .02683 L
Mistroke
.94294 .02209 L
.94365 .02003 L
.9443 .01843 L
.94557 .0161 L
.94625 .01529 L
.947 .0148 L
.9477 .01472 L
.94835 .01497 L
.94947 .01621 L
.95052 .01834 L
.95168 .02181 L
.95292 .02693 L
.95416 .03353 L
.95546 .04219 L
.95778 .06237 L
.95999 .0876 L
.96234 .12168 L
.96658 .20386 L
.97162 .34187 L
.97619 .51166 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[71]:=",
  ImageSize->{225.125, 139.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[B000`400?l00000o`00003oS@3oool0
0`000000oooo0?ooo`290?ooo`00S@3oool00`000000oooo0?ooo`290?ooo`00S@3oool00`000000
oooo0?ooo`290?ooo`00S@3oool2000008X0oooo002=0?ooo`030000003oool0oooo07T0oooo0P00
000>0?ooo`00S@3oool00`000000oooo0?ooo`1h0?ooo`<000003P3oool008d0oooo00<000000?oo
o`3oool0?`3oool2000003L0oooo00<000000?ooo`0000003P3oool008d0oooo00<000000?ooo`3o
ool0?@3oool2000000040?ooo`0000000000000003D0oooo00<000000?ooo`0000003P3oool008d0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03<0
oooo00@000000?ooo`3oool000003@3oool008d0oooo0P00000m0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0<P3oool01@000000oooo0?ooo`3oool0000000d0oooo001T0?ooo`<0
00000`3oool01@000000oooo0?ooo`3oool0000000@0oooo1@0000030?ooo`@000003P3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<@3oool01@00
0000oooo0?ooo`3oool0000000d0oooo001S0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0`0?ooo`050000003oool0oooo0?ooo`0000003@3oool006<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0300oooo00D000000?ooo`3oool0oooo
0000000=0?ooo`00FP3oool6000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02l0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`00H`3oool4000000<0oooo
00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`0000003@3oool006<0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02`3oool3000003T0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool006@0oooo
00<000000?ooo`3oool0303oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool006D0oooo0`00
000=0?ooo`030000003oool0oooo00<0oooo100000090?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`00M@3oool4000000l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo001d0?oo
o`8000000P3oool2000000P0oooo0`0000030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`00L`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00`0oooo00D000000?ooo`3oool0oooo0000000i0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00X0oooo001b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000
oooo000000030?ooo`800000>03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`00LP3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo00T0oooo0`0000030?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool00740oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00740oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool02@3oool00700oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00700oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02@3oool006l0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`800000
=P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`090?ooo`009P3oool4000004D0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3o
ool002H0oooo00@000000?ooo`3oool00000A03oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`002@3oool0
0`000000oooo0?ooo`0I0?ooo`050000003oool0oooo0?ooo`000000A03oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`002@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00X0oooo0P00000e0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00090?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00T0oooo00090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0f0?ooo`<000000P3oool01@000000oooo0000003oool0000000@0
oooo1@0000030?ooo`@0000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00T0oooo00090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0080oooo0`0000070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000`0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000/0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`002@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:P3oool6
00000080oooo1P0000030?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0<`3oool010000000oooo0?ooo`0000030?ooo`8000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0000000;0?ooo`<00000<P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`002@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0<`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`002@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0=03oool00`000000oooo000000040?ooo`030000003oool0oooo
00D0oooo0`0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0e0?ooo`8000000`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo100000030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00P0oooo00090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool000T0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool05@3oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00090?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`3oool200000380oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool000T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool05`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00090?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo01L0oooo00@000000?ooo`3oool0oooo0`0000030?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool000T0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0203oool000T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool000T0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`800000<@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`002@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`080?ooo`002@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`002@3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`070?ooo`002@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`070?ooo`002P3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0
oooo0P00000`0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
000:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0^0?ooo`D000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo1@0000030?ooo`@00000
1`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1`3oool000X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo02h0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0000000L0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo
000:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0^0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool000X0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02D0oooo1P00
00040?ooo`8000001@3oool00`000000oooo000000070?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`02
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`<00000;@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0<03oool2000000h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00800000303oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`070?oo
o`002P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0;P3oool3000000l0oooo00<000000?ooo`3oool00`3oool4000000T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0oooo0`0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`002P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0Q0?ooo`8000000`3oool2000002d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool0
00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0803oool00`000000oooo000000030?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0803oool3000000<0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0S0?ooo`050000003oool0oooo0?ooo`000000;P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`00
2@3oool5000000@0oooo0P0000050?ooo`D000005P3oool00`000000oooo0?ooo`040?ooo`D00000
7@3oool400000080oooo00<000000?ooo`3oool00P0000050?ooo`@00000603oool01@000000oooo
0?ooo`3oool0000001l0oooo100000050?ooo`800000103oool5000001h0oooo1@00000L0?ooo`H0
0000103oool2000000<0oooo00<000000?ooo`0000000`0000040?ooo`002P3oool2000000H0oooo
0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000020?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo
00@000000?ooo`3oool000007P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo0P0000030?ooo`800000103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0
oooo00@000000?ooo`3oool000001P3oool2000000<0oooo0P0000040?ooo`030000003oool0oooo
0040oooo000:0?ooo`8000004@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`030000003oool0000000d0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`02000001d0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool07@3oool2000001d0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0040oooo0006000000@0oooo0P00000A0?ooo`030000003oool0oooo0180
oooo1P0000050?ooo`030000003oool0oooo01@0oooo1P0000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000003@3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo0000
01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool07@3oool2000001`0oooo00D000000?ooo`3oool0oooo0000000;
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool000X0oooo0P00000=0?oo
o`D000005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool00P3oool2000000X0oooo1000000I0?ooo`040000003oool0oooo000001h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000<00000803oool2
000001`0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003oool0000000<00000103o
ool000X0oooo0P00000=0?ooo`050000003oool0oooo0?ooo`0000005P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00P3oool2000000X0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0000000N0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0000000S0?ooo`800000703oool01@000000oooo0?oo
o`3oool0000000`0oooo0P0000070?ooo`002@3oool3000000d0oooo00@000000?ooo`3oool00000
603oool00`000000oooo0?ooo`030?ooo`<000007P3oool00`000000oooo0?ooo`020?ooo`800000
2P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0000001h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000240oooo1000000L0?ooo`03
0000003oool0000000800000303oool2000000L0oooo000:0?ooo`8000003@3oool5000001L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0M0?ooo`@0000000<0oooo0000003oool0
2@3oool5000001T0oooo00<000000?ooo`0000007`3oool4000000T0oooo00<000000?ooo`3oool0
1@00000O0?ooo`800000703oool01@000000oooo0?ooo`3oool0000000`0oooo1P0000030?ooo`00
2P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0V0?ooo`040000003oool00000000002/0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool01P3oool000X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0:03oool2000002`0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1P3oool000X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool0:03oool2000002`0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3o
ool000X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool0:03oool2000002/0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool0
00X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool0:03oool2000002/0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool000X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0
oooo00020?ooool000006000000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
000000D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103oool000X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo01P0oooo00@000000?ooo`3oool000009P3oool010000000oooo0?ooo`00000Y0?oo
o`030000003oool0oooo02L0oooo0P00000X0?ooo`040000003oool0oooo000001T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00H0oooo000:0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?oo
o`002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0Z0?ooo`800000:@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`00
2P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0[0?ooo`800000:@3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`002P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0[0?ooo`800000:@3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`002P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0[0?ooo`800000:03oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`002P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0000002L0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool000/0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0000000W0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0
oooo000;0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`0000009`3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`060?ooo`002`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0000002L0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool01P3oool000/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;03oool2000000030?ooo`000000
oooo02@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool01P3oool000/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;03oool01000
0000oooo0?ooo`00000U0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo000;0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
02`0oooo00@000000?ooo`3oool000009@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`002`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0]0?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01P3oool0
00/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?ooo`3oool0000002<0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01P3oool000/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?ooo`3oool0
000002<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool01P3oool000/0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0;@3oool20000
0080oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`002`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0]0?ooo`050000003oool0oooo0?ooo`0000008`3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?oo
o`002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`020?ooo`D000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo1@0000030?ooo`@000003`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool01P3oool000/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool000/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo000;0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo000000070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`002`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0<0?ooo`<000000`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00H0oooo
000;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01P3oool000/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000`0oooo0`0000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`060?ooo`002`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`040?ooo`<000003`3oool00`000000oooo0?ooo`030?ooo`@000002@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`060?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0S0?ooo`<000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`060?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00H0
oooo000;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`000000103oool2000000D0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`060?ooo`002`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0Y0?ooo`<00000103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool01P3oool000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01P3oool000/0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool000/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
1@3oool000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool0<@3oool2000000H0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`050?ooo`002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`002`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`00303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00303oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`050?ooo`00303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00303oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0b
0?ooo`8000001`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000<0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00T0oooo0`0000020?ooo`050000003oool0oooo0?ooo`000000103oool5
000000<0oooo1000000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`00303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool01@3oool000`0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000<0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo
1P0000030?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000<0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00P0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000<0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0303oool3000000T0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`050?ooo`00303oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0000000`0oooo0`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool02P3oool2000000h0oooo00<000000?ooo`3oool00`3o
ool4000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool01@3oool000`0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`050?ooo`00303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0X0?ooo`<000000`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`050?ooo`00303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00D0
oooo000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`000000103oool2000000/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`00303oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0^0?ooo`<00000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01@3oool000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01@3oool000`0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0@@3oool01@000000oooo0?ooo`3oool0000002@0oooo000=0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
04<0oooo0`00000U0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1[0?ooo`003@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0f0?ooo`8000003@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo06`0oooo
000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo06`0oooo000=0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo06d0oooo000=0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo06d0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo06h0oooo000=0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo06h0oooo000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03P0oooo0P00000A0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0K`3oool000h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool3
000000<0oooo00D000000?ooo`3oool0oooo000000040?ooo`D000000`3oool4000000l0oooo00<0
00000?ooo`3oool04@3oool200000080oooo0P00001b0?ooo`003P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0180oooo1000001c0?ooo`003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0>0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08T0oooo000>
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0R@3oool000h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool4
000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`<00000R@3oool000h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08T0oooo000>0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool3000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08T0oooo000>0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0140oooo0`00000=0?ooo`030000003oool0oooo00<0oooo100000090?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0R@3oool000h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08T0oooo000>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo02l0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0R@3o
ool000l0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`020?ooo`800000RP3oool000l0oooo00@00000
0?ooo`3oool00000=@3oool00`000000oooo0?ooo`020?ooo`800000=`3oool00`000000oooo0000
00040?ooo`030000003oool0oooo08T0oooo000?0?ooo`040000003oool0oooo000003H0oooo00@0
00000?ooo`3oool00000>@3oool3000000@0oooo00<000000?ooo`3oool0R@3oool000l0oooo00@0
00000?ooo`3oool00000=`3oool200000440oooo00<000000?ooo`3oool0R@3oool00100oooo0P00
001k0?ooo`030000003oool0oooo08T0oooo000@0?ooo`800000N`3oool00`000000oooo0?ooo`29
0?ooo`00S@3oool2000008X0oooo002=0?ooo`030000003oool0oooo08T0oooo002=0?ooo`030000
003oool0oooo08T0oooo002=0?ooo`030000003oool0oooo08T0oooo0000\
\>"],
  ImageRangeCache->{{{0, 280.375}, {172.875, 0}} -> {-1.67804, -7.26097*^-07, \
0.0148346, 1.04998*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[71]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(h = \[Pi]\/8\)]],
  " and ",
  Cell[BoxData[
      \(\[Xi] = 1\/4\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {h \[Rule] Pi/8, \[Xi] \[Rule] 
            1/4}, {x, \(-Pi\)/8, Pi/8}]\)], "Input",
  CellLabel->"In[72]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 1.21261 0.309453 3.14173e+013 [
[.01496 .29695 -12 -9 ]
[.01496 .29695 12 0 ]
[.25748 .29695 -12 -9 ]
[.25748 .29695 12 0 ]
[.74252 .29695 -9 -9 ]
[.74252 .29695 9 0 ]
[.98504 .29695 -9 -9 ]
[.98504 .29695 9 0 ]
[.4875 .07382 -55.5 -6.25 ]
[.4875 .07382 0 6.25 ]
[.4875 .15237 -43.5 -6.25 ]
[.4875 .15237 0 6.25 ]
[.4875 .23091 -55.5 -6.25 ]
[.4875 .23091 0 6.25 ]
[.4875 .388 -49.5 -6.25 ]
[.4875 .388 0 6.25 ]
[.4875 .46654 -37.5 -6.25 ]
[.4875 .46654 0 6.25 ]
[.4875 .54508 -49.5 -6.25 ]
[.4875 .54508 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01496 .30945 m
.01496 .3157 L
s
[(-0.4)] .01496 .29695 0 1 Mshowa
.25748 .30945 m
.25748 .3157 L
s
[(-0.2)] .25748 .29695 0 1 Mshowa
.74252 .30945 m
.74252 .3157 L
s
[(0.2)] .74252 .29695 0 1 Mshowa
.98504 .30945 m
.98504 .3157 L
s
[(0.4)] .98504 .29695 0 1 Mshowa
.125 Mabswid
.07559 .30945 m
.07559 .3132 L
s
.13622 .30945 m
.13622 .3132 L
s
.19685 .30945 m
.19685 .3132 L
s
.31811 .30945 m
.31811 .3132 L
s
.37874 .30945 m
.37874 .3132 L
s
.43937 .30945 m
.43937 .3132 L
s
.56063 .30945 m
.56063 .3132 L
s
.62126 .30945 m
.62126 .3132 L
s
.68189 .30945 m
.68189 .3132 L
s
.80315 .30945 m
.80315 .3132 L
s
.86378 .30945 m
.86378 .3132 L
s
.92441 .30945 m
.92441 .3132 L
s
.25 Mabswid
0 .30945 m
1 .30945 L
s
.5 .07382 m
.50625 .07382 L
s
gsave
.4875 .07382 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.5 .15237 m
.50625 .15237 L
s
gsave
.4875 .15237 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.5 .23091 m
.50625 .23091 L
s
gsave
.4875 .23091 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.5 .388 m
.50625 .388 L
s
gsave
.4875 .388 -49.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.5 .46654 m
.50625 .46654 L
s
gsave
.4875 .46654 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.5 .54508 m
.50625 .54508 L
s
gsave
.4875 .54508 -49.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.125 Mabswid
.5 .08953 m
.50375 .08953 L
s
.5 .10524 m
.50375 .10524 L
s
.5 .12095 m
.50375 .12095 L
s
.5 .13666 m
.50375 .13666 L
s
.5 .16808 m
.50375 .16808 L
s
.5 .18378 m
.50375 .18378 L
s
.5 .19949 m
.50375 .19949 L
s
.5 .2152 m
.50375 .2152 L
s
.5 .24662 m
.50375 .24662 L
s
.5 .26233 m
.50375 .26233 L
s
.5 .27804 m
.50375 .27804 L
s
.5 .29374 m
.50375 .29374 L
s
.5 .32516 m
.50375 .32516 L
s
.5 .34087 m
.50375 .34087 L
s
.5 .35658 m
.50375 .35658 L
s
.5 .37229 m
.50375 .37229 L
s
.5 .4037 m
.50375 .4037 L
s
.5 .41941 m
.50375 .41941 L
s
.5 .43512 m
.50375 .43512 L
s
.5 .45083 m
.50375 .45083 L
s
.5 .48225 m
.50375 .48225 L
s
.5 .49796 m
.50375 .49796 L
s
.5 .51367 m
.50375 .51367 L
s
.5 .52937 m
.50375 .52937 L
s
.5 .05811 m
.50375 .05811 L
s
.5 .04241 m
.50375 .04241 L
s
.5 .0267 m
.50375 .0267 L
s
.5 .01099 m
.50375 .01099 L
s
.5 .56079 m
.50375 .56079 L
s
.5 .5765 m
.50375 .5765 L
s
.5 .59221 m
.50375 .59221 L
s
.5 .60792 m
.50375 .60792 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01646 m
.02846 .22051 L
.03279 .36352 L
.03527 .42805 L
.03754 .47339 L
.04018 .51873 L
.04134 .53443 L
.04262 .55187 L
.04384 .56408 L
.04499 .57454 L
.0462 .58152 L
.0475 .59024 L
.04818 .59373 L
.04892 .59721 L
.04963 .59896 L
.05028 .6007 L
.0515 .60245 L
.05281 .60245 L
.05406 .6007 L
.05476 .60245 L
.05541 .6007 L
.0566 .59547 L
.05786 .59024 L
.06022 .57977 L
.06244 .56582 L
.06507 .54489 L
.06746 .52571 L
.07283 .47339 L
.08253 .36875 L
.09322 .25016 L
.10458 .14203 L
.11404 .0775 L
.11943 .05134 L
.1219 .04088 L
.12324 .03564 L
.12449 .03041 L
.12556 .03041 L
.1267 .02518 L
.12796 .02344 L
.12911 .02169 L
.13019 .01995 L
.13132 .01995 L
.13229 .0182 L
.13335 .01646 L
.13457 .01646 L
.13571 .0182 L
.13694 .01646 L
.13764 .01646 L
.13827 .0182 L
.13941 .01995 L
Mistroke
.14065 .01995 L
.14182 .02169 L
.14291 .02344 L
.1442 .02692 L
.14556 .03041 L
.14674 .0339 L
.148 .03564 L
.14871 .03913 L
.14936 .04088 L
.15063 .04436 L
.1535 .05483 L
.16347 .1054 L
.18209 .224 L
.20283 .37311 L
.21194 .43328 L
.22199 .49345 L
.2316 .53879 L
.24061 .57018 L
.24303 .57803 L
.24558 .58413 L
.25013 .59198 L
.25135 .59547 L
.2525 .59721 L
.25313 .59809 L
.25382 .59809 L
.25502 .59983 L
.25572 .6007 L
.25647 .60157 L
.2571 .60157 L
.25779 .60157 L
.25844 .60157 L
.25913 .60245 L
.26037 .60332 L
.26159 .60245 L
.26228 .60332 L
.26293 .60332 L
.26423 .60245 L
.26564 .60157 L
.26688 .60157 L
.26819 .59983 L
.27053 .59721 L
.27308 .59373 L
.27448 .59198 L
.27517 .59111 L
.27581 .59024 L
.27656 .58762 L
.27737 .58675 L
.27807 .58501 L
.2788 .58413 L
.27948 .58239 L
Mistroke
.28013 .58065 L
.28159 .57629 L
.3017 .50391 L
.31209 .45246 L
.32196 .39753 L
.34049 .29027 L
.36054 .17778 L
.3787 .0945 L
.38884 .06006 L
.39349 .04698 L
.39839 .03564 L
.40364 .02692 L
.40484 .02474 L
.40597 .023 L
.40728 .02169 L
.40847 .02082 L
.41116 .01864 L
.41238 .01777 L
.41367 .0169 L
.41434 .0169 L
.41509 .01646 L
.4164 .01646 L
.41714 .01602 L
.41794 .01602 L
.41869 .01646 L
.41937 .01646 L
.42058 .0169 L
.42172 .01733 L
.42296 .0182 L
.42429 .01908 L
.42699 .02147 L
.42947 .02431 L
.43397 .03107 L
.43873 .04044 L
.44867 .06725 L
.45959 .10649 L
.49995 .30919 L
.51854 .41012 L
.5388 .50587 L
.54979 .54664 L
.55514 .56299 L
.55999 .5752 L
.56467 .58522 L
.56973 .59373 L
.57108 .59525 L
.57182 .59612 L
.57251 .59721 L
.57373 .5983 L
.57507 .59939 L
.57751 .60114 L
Mistroke
.57815 .60157 L
.57884 .60201 L
.58009 .60245 L
.58134 .60288 L
.58205 .60245 L
.58271 .60245 L
.58396 .60245 L
.58512 .60245 L
.58577 .60245 L
.58646 .60201 L
.58792 .60114 L
.59058 .59896 L
.59326 .59634 L
.59578 .59329 L
.6005 .58544 L
.60942 .56451 L
.61907 .53269 L
.639 .44374 L
.66006 .32602 L
.67992 .21004 L
.69802 .11587 L
.70736 .0775 L
.71752 .04436 L
.72023 .03739 L
.7231 .03041 L
.72555 .02605 L
.72624 .02518 L
.72697 .02431 L
.72826 .02169 L
.72947 .02082 L
.73079 .01908 L
.73147 .01995 L
.7322 .0182 L
.73351 .01733 L
.73415 .01733 L
.73484 .01733 L
.73609 .01646 L
.73731 .01559 L
.73844 .01646 L
.73958 .01646 L
.74083 .01646 L
.74201 .01733 L
.74311 .0182 L
.74438 .01995 L
.74508 .01908 L
.74573 .01995 L
.74698 .02082 L
.74812 .02256 L
.75037 .02692 L
.75279 .03128 L
Mistroke
.75719 .04175 L
.76198 .05657 L
.76723 .07576 L
.77783 .12546 L
.79737 .24754 L
.81829 .3984 L
.82848 .46641 L
.83386 .50129 L
.83956 .53269 L
.84454 .55536 L
.85002 .57629 L
.85242 .58326 L
.85369 .58675 L
.85432 .58849 L
.85501 .59198 L
.85628 .59373 L
.85745 .59373 L
.85854 .59721 L
.85969 .59896 L
.86093 .6007 L
.86163 .60245 L
.86229 .6007 L
.86298 .60245 L
.86361 .60245 L
.86435 .6007 L
.86503 .60245 L
.86624 .6007 L
.86756 .6007 L
.86872 .6007 L
.86995 .59896 L
.87249 .59373 L
.87318 .59198 L
.87383 .59198 L
.8745 .59024 L
.87523 .58849 L
.8768 .58326 L
.87756 .58152 L
.87824 .57977 L
.87894 .57629 L
.87961 .5728 L
.88031 .57105 L
.88107 .56757 L
.88616 .54315 L
.89155 .50653 L
.90123 .42456 L
.91946 .22923 L
.92952 .11936 L
.93447 .07576 L
.93907 .04436 L
.94018 .03739 L
Mistroke
.94138 .03041 L
.94252 .02692 L
.94356 .02169 L
.94478 .0182 L
.94607 .0182 L
.94715 .01472 L
.94834 .01472 L
.94966 .01646 L
.95087 .01995 L
.95153 .02344 L
.95226 .02692 L
.95357 .0339 L
.9548 .04262 L
.95611 .05308 L
.95734 .06704 L
.95846 .07924 L
.95948 .09494 L
.96055 .11238 L
.96281 .15075 L
.96689 .24841 L
.97133 .38968 L
.97619 .60245 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[72]:=",
  ImageSize->{223.125, 137.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004F0000[2000`400?l00000o`00003oo`3ooolG
0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG
0?ooo`00S03oool00`000000oooo0?ooo`270?ooo`00S03oool00`000000oooo0?ooo`270?ooo`00
S03oool00`000000oooo0?ooo`270?ooo`00S03oool2000008P0oooo000A0?ooo`030000003oool0
oooo01T0oooo0P0000170?ooo`<000004`3oool00`000000oooo0?ooo`0j0?ooo`<00000=03oool2
000001@0oooo000A0?ooo`030000003oool0oooo01P0oooo0P0000000`3oool000000?ooo`130?oo
o`8000000`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03T0oooo00D000000?oo
o`3oool0oooo0000000b0?ooo`030000003oool0000001@0oooo000A0?ooo`030000003oool0oooo
01L0oooo0P0000030?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0000001@0oooo000A0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03`3oool2000003P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0_0?ooo`040000003oool0oooo000001<0oooo000A0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0;P3oool010000000oooo0?ooo`00000C0?ooo`004@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo02d0oooo00D000000?ooo`3oool0oooo0000000C0?oo
o`004@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02`0oooo00D000000?ooo`3o
ool0oooo0000000C0?ooo`004@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0
oooo0P00000g0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0;03oool01@000000
oooo0?ooo`3oool0000001<0oooo000A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0;03oool01@000000oooo0?ooo`3oool0000001<0oooo000A0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo000A0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo000A0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00@0oooo0P00
00050?ooo`@000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo1@0000030?ooo`@00000
103oool00`000000oooo0?ooo`0;0?ooo`800000=P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`004@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`020?ooo`070000003o
ool0oooo0?ooo`000000oooo000000060?ooo`800000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0100oooo000A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`050?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0100oooo000A0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0?0?ooo`H000001P3oool00`000000oooo0?ooo`0>0?ooo`070000003o
ool0oooo0?ooo`000000oooo000000050?ooo`030000003oool0000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0:0?ooo`@00000
0`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`000000103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3oool3000003<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool03@3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`H000000P3oool01@000000oooo0?ooo`3oool0000003D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
403oool00140oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01H0oooo1P00000;0?ooo`D000002P3oool010000000oooo0?ooo`0000050?ooo`@00000
1P3oool010000000oooo0?ooo`0000030?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0@0?ooo`004@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0=0?ooo`<00000
00@0oooo0000003oool000001@3oool00`000000oooo0?ooo`02000003<0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0403oool00140oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool04@3oool00`000000oooo000000030?ooo`800000
0`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo000A0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool04P3oool2
000000<0oooo0`0000020?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool0
0140oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`800000<`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0?0?ooo`004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`004@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0?0?ooo`004@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`004P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00H0oooo0P00000b0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo000B0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00l0oooo000B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo000B0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00l0oooo000B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0T0?ooo`@000000`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool5000000<0oooo1000000;0?ooo`030000003oool0oooo00D0oooo0P00000a0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00l0oooo000B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool00180oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo000B0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`H000001`3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`004P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08`3oool40000
00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool3000002l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03`3oool00180oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0?0?ooo`004P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo
0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo1P000000
0`3oool000000?ooo`030?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool0
0180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
02<0oooo1@0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool40000
00T0oooo00<000000?ooo`3oool00P0000000`3oool000000?ooo`020?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool03`3oool00180oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0403oool3000000<0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`3oool2000002l0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03`3oool00180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`030000
00@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`004P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo008000001@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00l0oooo000B0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01H0oooo0P0000030?ooo`<00000
0`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00l0oooo000B0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool00`3oool2000002h0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3o
ool00180oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03`3oool00180oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00180
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool03`3oool00180oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`020?ooo`800000;P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`004P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0>0?ooo`004P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`004P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?oo
o`004P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0403oool5000000D0oooo0P0000050?ooo`@000000`3oool200000080oooo00<000000?ooo`3o
ool00P3oool5000000<0oooo1000000=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0>0?ooo`004P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0403oool01@000000oooo0?ooo`3oool0000000D0
oooo0P0000040?ooo`030000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0
000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool2000002d0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool0
0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`3oool2000000P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00D00000
0?ooo`3oool0oooo0000000]0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo000B0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?ooo`H00000103oool0
0`000000oooo0?ooo`0@0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`050000
003oool0oooo0?ooo`000000;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`004P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0;0?ooo`@000000`3oool200000080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01@000000oooo
0?ooo`3oool0000002d0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03P3oool00180oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0
oooo0`00000[0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo000B0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0@0?ooo`050000003oool0oooo0?ooo`00
0000303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo0`0000040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool01@000000oooo0?ooo`3oool00000
02d0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03P3oool00180oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0100oooo0`00000=0?ooo`D000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo100000070?ooo`D000000P3oool200000080
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`004P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0K0?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool03P3oool00180oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool05@3oool3000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02000002/0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03P3oool00180oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`3oool300000080
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`002@3oool4000000D0oooo
0P0000070?ooo`<000001@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo
100000050?ooo`800000103oool5000000X0oooo00<000000?ooo`3oool06`3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00D0oooo100000050?ooo`800000103oool5000000@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`050?ooo`@0000000<0oooo0000003oool00P3oool2000000L0oooo0`0000010?oo
o`00203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000@0oooo00D000000?ooo`3o
ool0oooo000000090?ooo`030000003oool0oooo01/0oooo0P0000030?ooo`@0000000<0oooo0000
003oool0:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool2000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000000`3oool2
000000P0oooo0@0000010?ooo`40oooo00080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00@000000?oo
o`0000000000:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000003@3oool100000040oooo0@3oool0
00H000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool6000000D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0000000[0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo0P0000090?ooo`H000000@3oool000P0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0000000[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`040000003oool0oooo
00000080oooo00080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`000000:`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`8000002P3oool010000000oooo0?ooo`0000020?ooo`00203oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo000000050?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
00090?ooo`030000003oool0oooo02<0oooo00@000000?ooo`0000000000:P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0080oooo0P00000;0?ooo`030000003oool000000080oooo00090?ooo`@00000
1@3oool00`000000oooo0?ooo`060?ooo`8000001@3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00P0oooo1000000<0?ooo`<000002@3oool00`000000oooo0?ooo`0U0?ooo`800000
:`3oool00`000000oooo0?ooo`060?ooo`@00000303oool3000000H0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`050?ooo`@0000000<0oooo0000003oool02`3oool200000080oooo
000B0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo02D0oooo0P00000[0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo000B
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02D0oooo0P00000Z0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo000C0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo02D0oooo0`00000Y0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo000C0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02D0oooo0P00000Z0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo000C0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`004`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3o
ool000/0ooooo`000005000000L0oooo000?0?ooo`050000003oool0oooo0?ooo`0000002P3oool0
10000000oooo0?ooo`00000<0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool2000000h0oooo00<000000?ooo`3oool02@3o
ool010000000oooo0?ooo`00000;0?ooo`050000003oool0oooo0?ooo`0000002`3oool000l0oooo
00D000000?ooo`3oool0oooo0000000=0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`0000002`3oool001<0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool09`3oool2000002P0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool001<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0:03oool2000002P0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool001<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0:03oool2000002P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool001<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0:03oool2000002P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool001<0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0:03oool2000002L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool001<0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0:03oool3000002H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool001<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo000C0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`004`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool0
01<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0:@3oool3000002D0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool001<0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0000000U0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00`0
oooo000C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo02T0oooo00@000000?ooo`3oool00000903oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0<0?ooo`004`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo000002@0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0303oool001<0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00X0oooo1@0000050?ooo`8000001@3oool4000000<0oooo
00D000000?ooo`3oool0oooo000000040?ooo`D000000`3oool4000001<0oooo0P0000000`3oool0
00000?ooo`0S0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo000C0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`00
00001@3oool2000000@0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0100oooo00@000000?ooo`3oool000008`3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`004`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool0
10000000oooo0?ooo`00000S0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00`0oooo000C0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`0000000`3oool00`000000oooo000000070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`050000003oool0
oooo0?ooo`0000008P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`004`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`@000000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo0`0000000`3oool000000?oo
o`0Q0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00`0oooo000C0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00X0oooo0P00000@
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`050000003oool0oooo0?ooo`0000008P3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?ooo`004`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02@3oool0
1@000000oooo0?ooo`3oool0000000`0oooo0P00000>0?ooo`<00000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00D000000?ooo`3oool0oooo0000000R0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00`0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0:0?ooo`<000003@3oool5000000d0oooo00<000000?ooo`3oool00`3o
ool4000000L0oooo1@0000020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
0000000Q0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00`0oooo000D0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo0P0000030?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0303oool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool3000000<0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0<0?ooo`00503oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Q0?ooo`040000
003oool0oooo0?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0303oool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08P3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00`0oooo000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0240oooo0P0000030?ooo`<00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
303oool001@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0;03oool2000000@0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0<0?ooo`00503oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`00503oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0<0?ooo`00503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`00503oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0/0?ooo`800000103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo
000D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00`0oooo000D0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00`0oooo000D0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0G0?oo
o`@000000`3oool01@000000oooo0?ooo`3oool0000000@0oooo1@0000030?ooo`@00000503oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool0
01@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
01D0oooo0P0000030?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`8000001@3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo000D0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`00503oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0303oool001@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01D0oooo1@0000030?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0303oool001@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo01D0oooo0P00000A0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`<000001@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00`0oooo000D0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`0E0?ooo`8000003`3oool3000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`00503oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool05@3oool6000000d0oooo00<000000?ooo`3o
ool00`3oool4000000L0oooo1@0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo000D0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo02@0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo000D0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01h0oooo0`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool2000000L0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`00
503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0T0?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0303oool001@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0903oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo000D0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo02@0oooo0P0000030?ooo`<00000103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0303oool001D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0<03o
ool2000000P0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`005@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0;0?ooo`005@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`005@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0;0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0a0?ooo`8000002@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00/0oooo000E0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo000E
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00/0oooo000E0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0380oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo000E0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00@0oooo0P0000050?ooo`@000000`3oool01@000000oooo0?ooo`3oool00000
00@0oooo1@0000030?ooo`@000004`3oool2000000X0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0;0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`005@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0;0?ooo`005@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00L000000?ooo`3oool0oooo0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo000F0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool4000000<0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`<000002P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo000F0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0;0?oo
o`005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02T0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0=0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo1@0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo000F0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0:P3oool010000000oooo0?ooo`3oool6000000<0oooo00<000000?oo
o`3oool01@3oool5000000d0oooo00<000000?ooo`3oool00`3oool4000000T0oooo00L000000?oo
o`3oool0oooo0000003oool0000000<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00/0oooo000F0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0oooo0`000003
0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo0P00000<0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool02`3oool001H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool0
10000000oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00/0oooo000F0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02X0oooo00D00000
0?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0;0?ooo`005P3oool01@000000oooo0?ooo`3oool0000002h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?ooo`8000000`3oool3000000<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00/0oooo000F
0?ooo`050000003oool0oooo0?ooo`000000;P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo03D0oooo0P00000>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3o
ool001H0oooo00D000000?ooo`3oool0oooo0000000_0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool02`3oool001L0oooo00@000000?ooo`3oool00000;`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00/0oooo000G0?ooo`040000003oool0oooo00000300oooo00<0
00000?ooo`3oool0103oool2000003P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00/0oooo000G0?ooo`040000003oool0oooo00000340oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0g0?ooo`8000003`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00/0oooo000G0?ooo`030000003oool000000380oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00l0oooo0P000005
0?ooo`030000003oool0oooo0440oooo00D000000?ooo`3oool0oooo0000000J0?ooo`030000003o
ool0oooo00/0oooo000G0?ooo`030000003oool000000380oooo0P0000020?ooo`800000>P3oool0
0`000000oooo0?ooo`0@0?ooo`8000000`3oool00`000000oooo0?ooo`120?ooo`80000000<0oooo
0000003oool06P3oool00`000000oooo0?ooo`0;0?ooo`00603oool2000003<0oooo1000000k0?oo
o`030000003oool0oooo0140oooo100000160?ooo`<000006`3oool00`000000oooo0?ooo`0;0?oo
o`00S03oool2000008P0oooo002<0?ooo`030000003oool0oooo08L0oooo002<0?ooo`030000003o
ool0oooo08L0oooo002<0?ooo`030000003oool0oooo08L0oooo003o0?oooaL0oooo003o0?oooaL0
oooo003o0?oooaL0oooo003o0?oooaL0oooo003o0?oooaL0oooo0000\
\>"],
  ImageRangeCache->{{{0, 277.875}, {171.25, 0}} -> {-0.447691, -1.05212*^-14, \
0.00397418, 1.53391*^-16}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[72]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(\[Xi] = 1\/4\)]],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {\[Xi] \[Rule] 1/4}, {x, \(-Pi\)/8, 
        Pi/8}, {h, \(-Pi\)/4, Pi/4}]\)], "Input",
  CellLabel->"In[73]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1984e-017 1.04977 -0.0679587 1.04977 [
[.17361 .1887 -23.621 -9 ]
[.17361 .1887 .37898 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50576 .05808 -15.8045 -9 ]
[.50576 .05808 2.19555 0 ]
[.76162 .0881 0 -6.17057 ]
[.76162 .0881 24 2.82943 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.93925 .36012 0 -5.91342 ]
[.93925 .36012 18 3.08658 ]
[.01802 .30329 -43.5 -3.85359 ]
[.01802 .30329 0 8.64641 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00461 .44514 -37.5 -4.02105 ]
[-0.00461 .44514 0 8.47895 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.18274 .19813 m
.18731 .20284 L
s
[(-0.2)] .17361 .1887 .96842 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51367 .06855 m
.51763 .07378 L
s
[(0.2)] .50576 .05808 .75605 1 Mshowa
.125 Mabswid
.06871 .24278 m
.07155 .2455 L
s
.10615 .22812 m
.10897 .23088 L
s
.14416 .21324 m
.14694 .21603 L
s
.22191 .18279 m
.22461 .18566 L
s
.26168 .16722 m
.26434 .17013 L
s
.30206 .15141 m
.30467 .15435 L
s
.38471 .11905 m
.38724 .12207 L
s
.42702 .10248 m
.4295 .10554 L
s
.47 .08565 m
.47243 .08875 L
s
.55805 .05117 m
.56037 .05435 L
s
.60315 .03351 m
.60541 .03673 L
s
.64899 .01556 m
.65119 .01882 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.74932 .09266 m
.74316 .09495 L
s
[(-0.5)] .76162 .0881 -1 .37124 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.92673 .36405 m
.92047 .36602 L
s
[(0.5)] .93925 .36012 -1 .31409 Mshowa
.125 Mabswid
.76936 .12333 m
.76566 .12468 L
s
.78884 .15312 m
.78513 .15445 L
s
.80777 .18207 m
.80405 .18338 L
s
.82617 .21023 m
.82245 .21152 L
s
.8615 .26426 m
.85776 .26551 L
s
.87846 .2902 m
.87472 .29144 L
s
.89497 .31547 m
.89122 .31668 L
s
.91106 .34007 m
.90731 .34127 L
s
.72867 .06109 m
.72499 .06248 L
s
.70741 .02856 m
.70374 .02998 L
s
.94201 .38743 m
.93825 .38859 L
s
.95691 .41022 m
.95315 .41137 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03027 .29859 m
.0364 .29624 L
s
gsave
.01802 .30329 -43.5 -1.85359 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00775 .44073 m
.01393 .43853 L
s
gsave
-0.00461 .44514 -37.5 -2.02105 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.125 Mabswid
.02811 .31225 m
.03179 .31085 L
s
.02593 .32602 m
.02961 .32463 L
s
.02372 .33992 m
.02741 .33853 L
s
.0215 .35394 m
.02519 .35256 L
s
.017 .38235 m
.0207 .38099 L
s
.01472 .39675 m
.01842 .3954 L
s
.01242 .41128 m
.01612 .40994 L
s
.01009 .42594 m
.0138 .42461 L
s
.03242 .28506 m
.03609 .28364 L
s
.03455 .27164 m
.03821 .27021 L
s
.03665 .25834 m
.04032 .2569 L
s
.00538 .45566 m
.00909 .45435 L
s
.003 .47073 m
.00671 .46942 L
s
.00059 .48593 m
.0043 .48464 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.557 .651 .898 r
.37482 .78281 .39787 .81114 .43683 .80094 .41374 .78172 Metetra
.683 .772 .918 r
.41374 .78172 .43683 .80094 .47655 .77606 .45371 .76737 Metetra
.938 .774 .652 r
.45371 .76737 .47655 .77606 .51696 .56535 .49518 .63649 Metetra
.49518 .63649 .51696 .56535 .55522 .55384 .53459 .53216 Metetra
.664 .741 .907 r
.53459 .53216 .55522 .55384 .59402 .54217 .57375 .52018 Metetra
.649 .736 .913 r
.57375 .52018 .59402 .54217 .63336 .53033 .61351 .50958 Metetra
.866 .431 .021 r
.61351 .50958 .63336 .53033 .67796 .62396 .6579 .60207 Metetra
.859 .424 0 r
.6579 .60207 .67796 .62396 .72618 .72519 .70588 .70206 Metetra
.63 .741 .927 r
.70588 .70206 .72618 .72519 .77006 .7137 .75033 .69202 Metetra
.645 .763 .934 r
.75033 .69202 .77006 .7137 .81462 .70203 .79539 .68001 Metetra
.945 .784 .651 r
.79539 .68001 .81462 .70203 .85988 .69018 .83186 .56526 Metetra
.783 .577 .62 r
.83186 .56526 .85988 .69018 .88309 .46905 .86463 .4347 Metetra
.681 .675 .838 r
.86463 .4347 .88309 .46905 .92516 .44253 .90828 .41783 Metetra
.579 .703 .927 r
.90828 .41783 .92516 .44253 .96935 .42924 .95412 .41293 Metetra
.514 .386 .643 r
.35666 .64273 .37482 .78281 .41374 .78172 .39366 .66502 Metetra
.561 .434 .664 r
.39366 .66502 .41374 .78172 .45371 .76737 .43243 .66992 Metetra
.651 .51 .678 r
.43243 .66992 .45371 .76737 .49518 .63649 .47261 .644 Metetra
.828 .999 .827 r
.47261 .644 .49518 .63649 .53459 .53216 .51309 .60403 Metetra
.373 .071 .318 r
.51309 .60403 .53459 .53216 .57375 .52018 .55359 .57435 Metetra
.481 .138 .307 r
.55359 .57435 .57375 .52018 .61351 .50958 .59475 .56781 Metetra
.578 .238 .357 r
.59475 .56781 .61351 .50958 .6579 .60207 .63727 .57956 Metetra
.284 .577 .939 r
.63727 .57956 .6579 .60207 .70588 .70206 .68106 .59167 Metetra
.594 .466 .675 r
.68106 .59167 .70588 .70206 .75033 .69202 .72505 .58502 Metetra
.655 .508 .671 r
.72505 .58502 .75033 .69202 .79539 .68001 .76812 .55378 Metetra
.664 .501 .653 r
.76812 .55378 .79539 .68001 .83186 .56526 .81048 .51178 Metetra
.701 .613 .756 r
.81048 .51178 .83186 .56526 .86463 .4347 .85416 .48389 Metetra
.525 .161 .291 r
.85416 .48389 .86463 .4347 .90828 .41783 .90167 .48681 Metetra
.603 .266 .372 r
.90167 .48681 .90828 .41783 .95412 .41293 .95282 .50853 Metetra
.607 .932 .961 r
.33179 .64156 .35666 .64273 .39366 .66502 .37083 .62537 Metetra
.615 .611 .824 r
.37083 .62537 .39366 .66502 .43243 .66992 .41002 .6185 Metetra
.62 .569 .776 r
.41002 .6185 .43243 .66992 .47261 .644 .44994 .6099 Metetra
.671 .667 .837 r
.44994 .6099 .47261 .644 .51309 .60403 .49059 .595 Metetra
.673 .891 .977 r
.49059 .595 .51309 .60403 .55359 .57435 .53179 .57829 Metetra
.311 .801 .785 r
.53179 .57829 .55359 .57435 .59475 .56781 .57356 .56527 Metetra
.375 .831 .922 r
.57356 .56527 .59475 .56781 .63727 .57956 .61607 .55642 Metetra
.617 .738 .932 r
.61607 .55642 .63727 .57956 .68106 .59167 .65933 .54742 Metetra
.649 .619 .806 r
.65933 .54742 .68106 .59167 .72505 .58502 .70313 .53382 Metetra
.662 .602 .777 r
.70313 .53382 .72505 .58502 .76812 .55378 .74733 .51605 Metetra
.67 .663 .834 r
.74733 .51605 .76812 .55378 .81048 .51178 .79225 .4997 Metetra
.556 .845 .998 r
.79225 .4997 .81048 .51178 .85416 .48389 .83839 .48944 Metetra
.83839 .48944 .85416 .48389 .90167 .48681 .88555 .48065 Metetra
.602 .929 .963 r
.88555 .48065 .90167 .48681 .95282 .50853 .93238 .46168 Metetra
.43 .479 .809 r
.30891 .59366 .33179 .64156 .37083 .62537 .34646 .60729 Metetra
.65 .785 .946 r
.34646 .60729 .37083 .62537 .41002 .6185 .38621 .5954 Metetra
.656 .742 .914 r
.38621 .5954 .41002 .6185 .44994 .6099 .42656 .58327 Metetra
.653 .715 .894 r
.42656 .58327 .44994 .6099 .49059 .595 .46752 .57127 Metetra
.659 .744 .912 r
.46752 .57127 .49059 .595 .53179 .57829 .50912 .55835 Metetra
.656 .781 .94 r
.50912 .55835 .53179 .57829 .57356 .56527 .55136 .54528 Metetra
.649 .781 .945 r
.55136 .54528 .57356 .56527 .61607 .55642 .59425 .53262 Metetra
.653 .75 .921 r
.59425 .53262 .61607 .55642 .65933 .54742 .63782 .51975 Metetra
.659 .724 .897 r
.63782 .51975 .65933 .54742 .70313 .53382 .68206 .50608 Metetra
.659 .726 .899 r
.68206 .50608 .70313 .53382 .74733 .51605 .72699 .49212 Metetra
.651 .759 .928 r
.72699 .49212 .74733 .51605 .79225 .4997 .77269 .47872 Metetra
.65 .79 .949 r
.77269 .47872 .79225 .4997 .83839 .48944 .81911 .46475 Metetra
.654 .76 .928 r
.81911 .46475 .83839 .48944 .88555 .48065 .86629 .45064 Metetra
.367 .569 .916 r
.86629 .45064 .88555 .48065 .93238 .46168 .9175 .46347 Metetra
.105 .125 .597 r
.28961 .49091 .30891 .59366 .34646 .60729 .32296 .56194 Metetra
.468 .518 .826 r
.32296 .56194 .34646 .60729 .38621 .5954 .3618 .5708 Metetra
.636 .729 .915 r
.3618 .5708 .38621 .5954 .42656 .58327 .40244 .56031 Metetra
.656 .752 .921 r
.40244 .56031 .42656 .58327 .46752 .57127 .4438 .54757 Metetra
.656 .749 .918 r
.4438 .54757 .46752 .57127 .50912 .55835 .48581 .53463 Metetra
.656 .752 .92 r
.48581 .53463 .50912 .55835 .55136 .54528 .52847 .52147 Metetra
.656 .754 .922 r
.52847 .52147 .55136 .54528 .59425 .53262 .5718 .50812 Metetra
.656 .751 .92 r
.5718 .50812 .59425 .53262 .63782 .51975 .61582 .49456 Metetra
.656 .749 .918 r
.61582 .49456 .63782 .51975 .68206 .50608 .66055 .48076 Metetra
.656 .751 .92 r
.66055 .48076 .68206 .50608 .72699 .49212 .706 .46677 Metetra
.656 .754 .922 r
.706 .46677 .72699 .49212 .77269 .47872 .75219 .45253 Metetra
.636 .743 .926 r
.75219 .45253 .77269 .47872 .81911 .46475 .79931 .44022 Metetra
.369 .628 .953 r
.79931 .44022 .81911 .46475 .86629 .45064 .8493 .4481 Metetra
.785 .285 0 r
.8493 .4481 .86629 .45064 .9175 .46347 .90916 .52869 Metetra
.498 0 0 r
.26459 .46755 .28961 .49091 .32296 .56194 .30011 .50137 Metetra
.165 .27 .727 r
.30011 .50137 .32296 .56194 .3618 .5708 .33709 .53891 Metetra
.565 .652 .894 r
.33709 .53891 .3618 .5708 .40244 .56031 .37767 .5355 Metetra
.646 .739 .917 r
.37767 .5355 .40244 .56031 .4438 .54757 .41939 .52347 Metetra
.655 .751 .92 r
.41939 .52347 .4438 .54757 .48581 .53463 .46181 .51019 Metetra
.656 .751 .92 r
.46181 .51019 .48581 .53463 .52847 .52147 .50491 .49665 Metetra
.656 .751 .92 r
.50491 .49665 .52847 .52147 .5718 .50812 .54869 .4829 Metetra
.656 .751 .92 r
.54869 .4829 .5718 .50812 .61582 .49456 .59318 .46893 Metetra
.656 .751 .92 r
.59318 .46893 .61582 .49456 .66055 .48076 .63839 .45473 Metetra
.655 .751 .92 r
.63839 .45473 .66055 .48076 .706 .46677 .68435 .44034 Metetra
.646 .748 .924 r
.68435 .44034 .706 .46677 .75219 .45253 .73113 .42679 Metetra
.549 .716 .95 r
.73113 .42679 .75219 .45253 .79931 .44022 .77942 .42183 Metetra
0 .165 .642 r
.77942 .42183 .79931 .44022 .8493 .4481 .83305 .46178 Metetra
.658 .134 0 r
.83305 .46178 .8493 .4481 .90916 .52869 .88922 .50131 Metetra
.063 .453 .881 r
.23889 .44355 .26459 .46755 .30011 .50137 .2757 .45944 Metetra
0 0 .517 r
.2757 .45944 .30011 .50137 .33709 .53891 .31157 .50984 Metetra
.501 .652 .926 r
.31157 .50984 .33709 .53891 .37767 .5355 .35219 .51013 Metetra
.637 .737 .921 r
.35219 .51013 .37767 .5355 .41939 .52347 .39426 .49859 Metetra
.654 .75 .92 r
.39426 .49859 .41939 .52347 .46181 .51019 .43711 .48503 Metetra
.656 .751 .92 r
.43711 .48503 .46181 .51019 .50491 .49665 .48064 .47109 Metetra
.656 .751 .92 r
.48064 .47109 .50491 .49665 .54869 .4829 .52489 .45693 Metetra
.656 .751 .92 r
.52489 .45693 .54869 .4829 .59318 .46893 .56985 .44253 Metetra
.656 .751 .92 r
.56985 .44253 .59318 .46893 .63839 .45473 .61556 .4279 Metetra
.654 .751 .921 r
.61556 .4279 .63839 .45473 .68435 .44034 .66204 .41318 Metetra
.637 .745 .927 r
.66204 .41318 .68435 .44034 .73113 .42679 .7094 .40009 Metetra
.496 .689 .954 r
.7094 .40009 .73113 .42679 .77942 .42183 .75852 .39898 Metetra
0 .025 .538 r
.75852 .39898 .77942 .42183 .83305 .46178 .81388 .45401 Metetra
0 .374 .698 r
.81388 .45401 .83305 .46178 .88922 .50131 .86863 .47301 Metetra
.498 0 0 r
.21248 .41888 .23889 .44355 .2757 .45944 .24784 .45257 Metetra
.725 .199 0 r
.24784 .45257 .2757 .45944 .31157 .50984 .28466 .49006 Metetra
.51 .748 .981 r
.28466 .49006 .31157 .50984 .35219 .51013 .32586 .48601 Metetra
.644 .756 .93 r
.32586 .48601 .35219 .51013 .39426 .49859 .36839 .47321 Metetra
.655 .752 .921 r
.36839 .47321 .39426 .49859 .43711 .48503 .41166 .45912 Metetra
.656 .751 .92 r
.41166 .45912 .43711 .48503 .48064 .47109 .45565 .44476 Metetra
.656 .751 .92 r
.45565 .44476 .48064 .47109 .52489 .45693 .50036 .43016 Metetra
.656 .751 .92 r
.50036 .43016 .52489 .45693 .56985 .44253 .54581 .41533 Metetra
.656 .751 .92 r
.54581 .41533 .56985 .44253 .61556 .4279 .59203 .40024 Metetra
.655 .751 .92 r
.59203 .40024 .61556 .4279 .66204 .41318 .63902 .38494 Metetra
.646 .747 .923 r
.63902 .38494 .66204 .41318 .7094 .40009 .68688 .37047 Metetra
.557 .701 .936 r
.68688 .37047 .7094 .40009 .75852 .39898 .73618 .36469 Metetra
0 .286 .787 r
.73618 .36469 .75852 .39898 .81388 .45401 .79041 .40443 Metetra
.167 .349 .801 r
.79041 .40443 .81388 .45401 .86863 .47301 .84734 .44377 Metetra
.878 .441 .081 r
.18532 .39351 .21248 .41888 .24784 .45257 .217 .46531 Metetra
.426 0 0 r
.217 .46531 .24784 .45257 .28466 .49006 .25658 .47326 Metetra
.615 .818 .978 r
.25658 .47326 .28466 .49006 .32586 .48601 .29872 .4613 Metetra
.655 .761 .927 r
.29872 .4613 .32586 .48601 .36839 .47321 .34173 .44698 Metetra
.656 .752 .921 r
.34173 .44698 .36839 .47321 .41166 .45912 .38545 .43243 Metetra
.656 .751 .92 r
.38545 .43243 .41166 .45912 .45565 .44476 .42989 .41762 Metetra
.656 .751 .92 r
.42989 .41762 .45565 .44476 .50036 .43016 .47508 .40258 Metetra
.656 .751 .92 r
.47508 .40258 .50036 .43016 .54581 .41533 .52102 .38728 Metetra
.656 .751 .92 r
.52102 .38728 .54581 .41533 .59203 .40024 .56775 .3717 Metetra
.656 .751 .92 r
.56775 .3717 .59203 .40024 .63902 .38494 .61528 .35589 Metetra
.656 .751 .92 r
.61528 .35589 .63902 .38494 .68688 .37047 .66363 .33979 Metetra
.637 .735 .919 r
.66363 .33979 .68688 .37047 .73618 .36469 .71296 .32561 Metetra
.443 .582 .897 r
.71296 .32561 .73618 .36469 .79041 .40443 .76482 .33214 Metetra
0 .126 .654 r
.76482 .33214 .79041 .40443 .84734 .44377 .82533 .41353 Metetra
.545 .167 .275 r
.14779 .45065 .18532 .39351 .217 .46531 .18609 .46317 Metetra
.517 .899 .956 r
.18609 .46317 .217 .46531 .25658 .47326 .22811 .44904 Metetra
.654 .767 .932 r
.22811 .44904 .25658 .47326 .29872 .4613 .27083 .43459 Metetra
.652 .75 .921 r
.27083 .43459 .29872 .4613 .34173 .44698 .31424 .42024 Metetra
.659 .755 .921 r
.31424 .42024 .34173 .44698 .38545 .43243 .35843 .40488 Metetra
.659 .752 .919 r
.35843 .40488 .38545 .43243 .42989 .41762 .40334 .38931 Metetra
.653 .748 .92 r
.40334 .38931 .42989 .41762 .47508 .40258 .449 .37412 Metetra
.653 .75 .921 r
.449 .37412 .47508 .40258 .52102 .38728 .49545 .35866 Metetra
.658 .755 .921 r
.49545 .35866 .52102 .38728 .56775 .3717 .5427 .3423 Metetra
.659 .753 .919 r
.5427 .3423 .56775 .3717 .61528 .35589 .59077 .3256 Metetra
.652 .747 .92 r
.59077 .3256 .61528 .35589 .66363 .33979 .6397 .3094 Metetra
.655 .752 .921 r
.6397 .3094 .66363 .33979 .71296 .32561 .6895 .29255 Metetra
.654 .736 .909 r
.6895 .29255 .71296 .32561 .76482 .33214 .74019 .27549 Metetra
.447 .501 .821 r
.74019 .27549 .76482 .33214 .82533 .41353 .79426 .2864 Metetra
.592 .939 .937 r
.11466 .45215 .14779 .45065 .18609 .46317 .15697 .43273 Metetra
.605 .706 .916 r
.15697 .43273 .18609 .46317 .22811 .44904 .19884 .42312 Metetra
.619 .75 .94 r
.19884 .42312 .22811 .44904 .27083 .43459 .24169 .41162 Metetra
.684 .794 .933 r
.24169 .41162 .27083 .43459 .31424 .42024 .28584 .39339 Metetra
.697 .77 .908 r
.28584 .39339 .31424 .42024 .35843 .40488 .33076 .37318 Metetra
.661 .728 .9 r
.33076 .37318 .35843 .40488 .40334 .38931 .37612 .3568 Metetra
.619 .712 .912 r
.37612 .3568 .40334 .38931 .449 .37412 .42209 .34476 Metetra
.617 .738 .932 r
.42209 .34476 .449 .37412 .49545 .35866 .46898 .33248 Metetra
.66 .782 .939 r
.46898 .33248 .49545 .35866 .5427 .3423 .51683 .31528 Metetra
.697 .791 .923 r
.51683 .31528 .5427 .3423 .59077 .3256 .56546 .29359 Metetra
.681 .752 .905 r
.56546 .29359 .59077 .3256 .6397 .3094 .61485 .27332 Metetra
.626 .706 .903 r
.61485 .27332 .6397 .3094 .6895 .29255 .66533 .25939 Metetra
.608 .723 .926 r
.66533 .25939 .6895 .29255 .74019 .27549 .71696 .24693 Metetra
.699 .799 .927 r
.71696 .24693 .74019 .27549 .79426 .2864 .76888 .22363 Metetra
.18 .375 .82 r
.08666 .40408 .11466 .45215 .15697 .43273 .1241 .42515 Metetra
.086 .627 .848 r
.1241 .42515 .15697 .43273 .19884 .42312 .16519 .42748 Metetra
.726 .983 .905 r
.16519 .42748 .19884 .42312 .24169 .41162 .2107 .39658 Metetra
.852 .859 .847 r
.2107 .39658 .24169 .41162 .28584 .39339 .25779 .35058 Metetra
.747 .695 .801 r
.25779 .35058 .28584 .39339 .33076 .37318 .30403 .31559 Metetra
.596 .573 .798 r
.30403 .31559 .33076 .37318 .37612 .3568 .3491 .30527 Metetra
.417 .505 .841 r
.3491 .30527 .37612 .3568 .42209 .34476 .39431 .31445 Metetra
.284 .577 .939 r
.39431 .31445 .42209 .34476 .46898 .33248 .4411 .32395 Metetra
.443 .846 .973 r
.4411 .32395 .46898 .33248 .51683 .31528 .48976 .31324 Metetra
.77 .986 .899 r
.48976 .31324 .51683 .31528 .56546 .29359 .53939 .27606 Metetra
.862 .895 .857 r
.53939 .27606 .56546 .29359 .61485 .27332 .58905 .22734 Metetra
.735 .7 .818 r
.58905 .22734 .61485 .27332 .66533 .25939 .63917 .19366 Metetra
.528 .521 .792 r
.63917 .19366 .66533 .25939 .71696 .24693 .69151 .1927 Metetra
.342 .459 .835 r
.69151 .1927 .71696 .24693 .76888 .22363 .74691 .21172 Metetra
.443 .099 .285 r
.03587 .50705 .08666 .40408 .1241 .42515 .07833 .50246 Metetra
.304 0 .15 r
.07833 .50246 .1241 .42515 .16519 .42748 .12357 .48318 Metetra
.977 .912 .589 r
.12357 .48318 .16519 .42748 .2107 .39658 .18327 .33637 Metetra
.855 .677 .661 r
.18327 .33637 .2107 .39658 .25779 .35058 .23733 .21978 Metetra
.58 .434 .648 r
.23733 .21978 .25779 .35058 .30403 .31559 .2813 .20292 Metetra
.583 .454 .67 r
.2813 .20292 .30403 .31559 .3491 .30527 .32591 .18745 Metetra
0 0 .504 r
.32591 .18745 .3491 .30527 .39431 .31445 .36562 .28314 Metetra
.859 .424 0 r
.36562 .28314 .39431 .31445 .4411 .32395 .40922 .38821 Metetra
.32 0 .116 r
.40922 .38821 .4411 .32395 .48976 .31324 .45998 .37292 Metetra
.289 0 .082 r
.45998 .37292 .48976 .31324 .53939 .27606 .51178 .35533 Metetra
.51178 .35533 .53939 .27606 .58905 .22734 .56317 .22548 Metetra
.994 .853 .591 r
.56317 .22548 .58905 .22734 .63917 .19366 .61129 .08011 Metetra
.604 .472 .675 r
.61129 .08011 .63917 .19366 .69151 .1927 .66171 .0571 Metetra
.553 .419 .653 r
.66171 .0571 .69151 .1927 .74691 .21172 .71379 .04673 Metetra
.63 .839 .98 r
0 .48963 .03587 .50705 .07833 .50246 .04439 .47421 Metetra
.761 .782 .87 r
.04439 .47421 .07833 .50246 .12357 .48318 .09173 .44227 Metetra
.919 .711 .606 r
.09173 .44227 .12357 .48318 .18327 .33637 .16384 .20553 Metetra
.577 .431 .647 r
.16384 .20553 .18327 .33637 .23733 .21978 .20751 .18843 Metetra
.664 .741 .907 r
.20751 .18843 .23733 .21978 .2813 .20292 .25192 .17104 Metetra
.664 .741 .907 r
.25192 .17104 .2813 .20292 .32591 .18745 .2971 .15335 Metetra
.859 .428 0 r
.2971 .15335 .32591 .18745 .36562 .28314 .33597 .25079 Metetra
.863 .431 .009 r
.33597 .25079 .36562 .28314 .40922 .38821 .37877 .35806 Metetra
.644 .777 .944 r
.37877 .35806 .40922 .38821 .45998 .37292 .43021 .34019 Metetra
.645 .763 .934 r
.43021 .34019 .45998 .37292 .51178 .35533 .48265 .32198 Metetra
.645 .763 .934 r
.48265 .32198 .51178 .35533 .56317 .22548 .53611 .30341 Metetra
.92 .808 .339 r
.53611 .30341 .56317 .22548 .61129 .08011 .58578 .05493 Metetra
.78 .857 .908 r
.58578 .05493 .61129 .08011 .66171 .0571 .63663 .0204 Metetra
.664 .741 .907 r
.63663 .0204 .66171 .0571 .71379 .04673 .68874 0 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.18274 .19813 m
.18731 .20284 L
s
[(-0.2)] .17361 .1887 .96842 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51367 .06855 m
.51763 .07378 L
s
[(0.2)] .50576 .05808 .75605 1 Mshowa
.125 Mabswid
.06871 .24278 m
.07155 .2455 L
s
.10615 .22812 m
.10897 .23088 L
s
.14416 .21324 m
.14694 .21603 L
s
.22191 .18279 m
.22461 .18566 L
s
.26168 .16722 m
.26434 .17013 L
s
.30206 .15141 m
.30467 .15435 L
s
.38471 .11905 m
.38724 .12207 L
s
.42702 .10248 m
.4295 .10554 L
s
.47 .08565 m
.47243 .08875 L
s
.55805 .05117 m
.56037 .05435 L
s
.60315 .03351 m
.60541 .03673 L
s
.64899 .01556 m
.65119 .01882 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[73]:=",
  ImageSize->{237.313, 192.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004X0000l2000`400?l00000o`00003oo`3ooolY
0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY
0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY
0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY
0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00o`3ooolY
0?ooo`00o`3ooolY0?ooo`00o`3ooolY0?ooo`00e03oool200000580oooo003B0?ooo`80000000<0
ZKgX000000000000D@3oool00<l0oooo0`0000030:Vmj0800000D@3oool009L0oooo100000050?oo
o`800000103oool500000280oooo0`0000050:Vmj0030000002Y_NP000000500oooo002F0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000@0oooo00D000000?ooo`3o
ool0oooo0000000O0?ooo`<00000202Y_NP010000000ZKgX00000000001?0?ooo`00UP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool07P3oool30000
00030:Vmj0000000ZKgX00L0ZKgX00@000000:Vmj02Y_NP00000C`3oool009H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01X0oooo100000000`37
fnP000000:Vmj0090:Vmj0030000002Y_NP0ZKgX00800000CP3oool009H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01H0oooo0`0000000`3oool0
00000<OKj0020<OKj0030000002Y_NP0ZKgX00P0ZKgX00@000000:Vmj02Y_NP0ZKgX0P00001=0?oo
o`00UP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool04`3oool200000080oooo0P0000050<OKj0030000002Y_NP0ZKgX00P0ZKgX00<000000:Vmj02Y
_NP00P00001=0?ooo`00UP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
00D000000?ooo`3oool0oooo0000000B0?ooo`<0000000@0oooo0000003oool000002037fnP00`00
0000ZKgX0:Vmj0070:Vmj0040000002Y_NP0ZKgX0:Vmj0800000C03oool009L0oooo1000000<0?oo
o`<000004@3oool2000000@0oooo0P0000090<OKj0030000002Y_NP0ZKgX00L0ZKgX00L000000:Vm
j02Y_NP0ZKgX0000003oool0000004/0oooo002h0?ooo`<000001@3oool00`000000am_X0<OKj00:
0<OKj0030000002Y_NP0ZKgX00H0ZKgX00@000000:Vmj02Y_NP0ZKgX0`00001;0?ooo`00]P3oool2
000000H0oooo0P00000>0<OKj0030000002Y_NP0ZKgX00D0ZKgX10000000102=JjL000000?ooo`00
001:0?ooo`00/`3oool5000000D0oooo00<000000<OKj037fnP03P37fnP010000000ZKgX0:Vmj02Y
_NP5000000@0SF^W00@000000?ooo`3oool00000B@3oool00;40oooo0P00000:0?ooo`8000003`37
fnP4000000@0SF^W00<0000008e[Y`2=JjL00`2=JjL00`000000oooo000000190?ooo`00[P3oool3
000000`0oooo00<000000>_>EP0000003037fnP20000000309Yh[0000000SF^W00D0SF^W00<00000
08e[Y`2=JjL00`2=JjL010000000oooo00000000000@0?ooo`@000001@3oool2000000D0oooo1000
000T0?ooo`00[03oool2000000h0oooo00D000000>_>EP3[cUH0jliF000000090<OKj08000000`2J
N:`00`000000SF^W08e[Y`0408e[Y`030000002=JjL0SF^W00<0SF^W00D000000?ooo`3oool0oooo
0000000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`00Z@3oool4000000l0oooo00<0
00000>_>EP3[cUH00P3[cUH00`000000am_X0<OKj0030<OKj0<000001P2JN:`00`000000SF^W08e[
Y`0308e[Y`030000002=JjL0SF^W00<0SF^W00D000000?ooo`3oool0oooo0000000>0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q0?ooo`00YP3o
ool3000000@0oooo00<000000?ooo`3oool0303oool00`000000jliF0>_>EP030>_>EP0300000037
fnP0am_X008000002@2JN:`00`000000SF^W08e[Y`0308e[Y`030000002=JjL0SF^W00<0SF^W00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`H000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08@3oool007`0oooo1000000T
0?ooo`8000005P3oool00`000000jliF0>_>EP040>_>EP8000002`2JN:`00`000000SF^W08e[Y`03
08e[Y`030000002=JjL0SF^W00@0SF^W00D000000?ooo`3oool0oooo0000000=0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool02@3oool4000002@0oooo001k0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool07P3oool3000001P0oooo00<000000>_>EP3[cUH0103[cUH0
0`000000VWR/09Yh[00:09Yh[0030000002=JjL0SF^W00<0SF^W00<0000008e[Y`2=JjL0102=JjL0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo001k0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0703oool4000001P0oooo00<000000>_>EP3[cUH0103[cUH20000
00d0VWR/00<0000008e[Y`2=JjL00P2=JjL00`000000SF^W08e[Y`0408e[Y`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool09@3oool007/0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0I0?ooo`<00000703oool00`000000jliF0>_>EP040>_>EP030000003nfYL0000000`0
VWR/00<0000008e[Y`2=JjL00P2=JjL00`000000SF^W08e[Y`0408e[Y`030000003oool0oooo00<0
oooo0P00000;0?ooo`@00000303oool5000002<0oooo001k0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool05`3oool2000001l0oooo00<000000>_>EP3[cUH0103[cUH00`000000o]ZG
0000000<09Yh[0030000002=JjL0SF^W00<0SF^W00<0000008e[Y`2=JjL00`2=JjL00`000000oooo
0?ooo`020?ooo`<00000@`3oool007/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0D0?ooo`<000008@3oool00`000000jliF0>_>EP030>_>EP040000003nfYL0o]ZG000000`0VWR/
00<0000008e[Y`2=JjL00`2=JjL00`000000SF^W08e[Y`0408e[Y`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0@03oool007/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0B0?ooo`@000008P3oool00`000000jliF0>_>EP030>_>EP040000003nfYL0o]ZG000000`0VWR/
00<0000008e[Y`2=JjL00`2=JjL00`000000SF^W08e[Y`0408e[Y`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0@03oool007`0oooo1000000B0?ooo`<000009@3oool00`000000jliF0>_>
EP040>_>EP050000003nfYL0o]ZG0?kJU`000000302JN:`00`000000SF^W08e[Y`0208e[Y`030000
002=JjL0SF^W00@0SF^W00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0o0?ooo`00T03o
ool2000002P0oooo00<000000>_>EP3[cUH00`3[cUH00`000000o]ZG0?kJU`020?kJU`030000002J
N:`0VWR/00X0VWR/00<0000008e[Y`2=JjL00P2=JjL00`000000SF^W08e[Y`0408e[Y`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0?P3oool008d0oooo0`00000Z0?ooo`030000003[cUH0
jliF00<0jliF00<000000?kJU`3nfYL00P3nfYL00`000000VWR/09Yh[00:09Yh[0030000002=JjL0
SF^W0080SF^W00<0000008e[Y`2=JjL0102=JjL00`000000oooo0?ooo`060?ooo`030000003oool0
oooo03h0oooo002;0?ooo`@00000:`3oool00`000000jliF0>_>EP030>_>EP030000003nfYL0o]ZG
0080o]ZG00<0000009Yh[02JN:`02P2JN:`00`000000SF^W08e[Y`0208e[Y`030000002=JjL0SF^W
00D0SF^W00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0m0?ooo`00R03oool3000002l0
oooo00<000000>_>EP3[cUH00P3[cUH00`000000o]ZG0?kJU`030?kJU`030000002JN:`0VWR/00X0
VWR/00<0000008e[Y`2=JjL00P2=JjL00`000000SF^W08e[Y`0508e[Y`030000003oool0oooo00D0
oooo0`00000n0?ooo`00Q@3oool300000340oooo00<000000>_>EP3[cUH00`3[cUH00`000000o]ZG
0?kJU`040?kJU`030000002JN:`0VWR/00X0VWR/00D0000008e[Y`2=JjL0SF^W0000000708e[Y`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0?03oool008<0oooo0P00000d0?ooo`030000
003[cUH0jliF00<0jliF00<000000?kJU`3nfYL0103nfYL00`000000VWR/09Yh[00:09Yh[0050000
002=JjL0SF^W08e[Y`0000001`2=JjL00`000000oooo0?ooo`080?ooo`030000003oool0oooo03/0
oooo00200?ooo`@00000=@3oool00`000000jliF0>_>EP020>_>EP030000003nfYL0o]ZG00D0o]ZG
00<0000009Yh[02JN:`02P2JN:`01@000000SF^W08e[Y`2=JjL0000000L0SF^W00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0j0?ooo`00A@3oool4000000D0oooo0P0000040?ooo`D00000
9@3oool2000000@0oooo00<000000?ooo`3oool0<P3oool00`000000jliF0>_>EP020>_>EP030000
003nfYL0o]ZG00D0o]ZG00<0000009Yh[02JN:`02P2JN:`01@000000SF^W08e[Y`2=JjL0000000P0
SF^W00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0j0?ooo`00A03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`050000003oool0oooo0?ooo`00
00008P3oool3000003/0oooo00<000000>_>EP3[cUH00P3[cUH00`000000o]ZG0?kJU`060?kJU`03
0000002JN:`0VWR/00X0VWR/00@0000008e[Y`2=JjL00000202=JjL00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03T0oooo00140?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0Q0?ooo`800000?@3oool00`000000jliF0>_>EP020>_>EP03
0000003nfYL0o]ZG00L0o]ZG00<0000009Yh[02JN:`02P2JN:`010000000SF^W08e[Y`00000808e[
Y`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>03oool003`0oooo1P0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0M0?ooo`<0
000000<0oooo0000003oool0?03oool00`000000jliF0>_>EP020>_>EP030000003nfYL0o]ZG00L0
o]ZG00<0000009Yh[02JN:`02P2JN:`01@000000SF^W08e[Y`2=JjL0000000L0SF^W00<000000?oo
o`3oool02@3oool2000003X0oooo00140?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0J0?ooo`<0000000<0ZKgX000000000000?P3oool01@000000
jliF0>_>EP3[cUH0000000X0o]ZG00<0000009Yh[02JN:`02P2JN:`01@000000SF^W08e[Y`2=JjL0
000000L0SF^W00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0g0?ooo`00A03oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool30000
00D0ZKgX0P00000m0?ooo`050000003[cUH0jliF0>_>EP0000002P3nfYL00`000000VWR/09Yh[00:
09Yh[0050000002=JjL0SF^W08e[Y`000000202=JjL00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo03H0oooo00140?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool0
1@000000oooo0?ooo`3oool0000001H0oooo0`0000070:Vmj0030000003KK@00000003`0oooo00D0
00000>_>EP3[cUH0jliF0000000;0?kJU`030000002JN:`0VWR/00X0VWR/00@0000008e[Y`2=JjL0
0000202=JjL00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03H0oooo00150?ooo`@00000
303oool3000001@0oooo0`0000000`2Y_NP000000:Vmj0080:Vmj0800000>`3oool01@000000jliF
0>_>EP3[cUH0000000`0o]ZG00<0000009Yh[02JN:`02P2JN:`010000000SF^W08e[Y`00000808e[
Y`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=@3oool006X0oooo0P0000020:Vmj003
0000002Y_NP0ZKgX00T0ZKgX00<000000=]]00000000>P3oool01@000000jliF0>_>EP3[cUH00000
00`0o]ZG00<0000009Yh[02JN:`02P2JN:`010000000SF^W08e[Y`00000808e[Y`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0=03oool006L0oooo0`0000050:Vmj0030000002Y_NP0ZKgX
00P0ZKgX00@000000=]]003KK@000000>@3oool01@000000jliF0>_>EP3[cUH0000000`0o]ZG00<0
000009Yh[02JN:`02P2JN:`010000000SF^W08e[Y`00000808e[Y`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0=03oool006@0oooo100000080:Vmj0030000002Y_NP0ZKgX00P0ZKgX00@0
00000=]]003KK@000000>03oool010000000jliF0>_>EP00000>0?kJU`030000002JN:`0VWR/00X0
VWR/00<0000008e[Y`0000002@2=JjL00`000000oooo0?ooo`0<0?ooo`800000=@3oool00680oooo
0`00000;0:Vmj0030000002Y_NP0ZKgX00P0ZKgX00D000000=]]003KK@00ffd00000000f0?ooo`05
0000003[cUH0jliF0>_>EP0000003P3nfYL00`000000VWR/09Yh[00:09Yh[0030000002=JjL00000
00T0SF^W00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0b0?ooo`00G`3oool300000080
TfjU00<000000:Vmj02Y_NP02P2Y_NP00`000000ZKgX0:Vmj0070:Vmj08000000P3KK@000`000000
oooo0?ooo`0d0?ooo`050000003[cUH0jliF0>_>EP0000003P3nfYL@000000T0SF^W00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0b0?ooo`00G@3oool3000000D0TfjU00<000000:Vmj02Y
_NP02P2Y_NP00`000000ZKgX0:Vmj0040:Vmj080000000<0UGB[0000003KK@000P3KK@000`000000
oooo0?ooo`0c0?ooo`040000003[cUH0jliF000000d0o]ZG0`00000<08N5bP040000001GMMD00000
000000P0SF^W00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0a0?ooo`00FP3oool40000
00P0TfjU00<000000:Vmj02Y_NP02P2Y_NP00`000000ZKgX0:Vmj003000000<0UGB[00D000000=]]
003KK@00ffd00000000e0?ooo`040000003[cUH0jliF000000`0o]ZG00D000000;bcd@2l/m40_;?A
0000000<08N5bP80000000@0EgGE00000000000000001@2=JjL00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0300oooo001H0?ooo`<000000`2CKZD00`000000TfjU09=^Y@0509=^Y@030000
002Y_NP0ZKgX00X0ZKgX0`00000709EdZ`050000003KK@00ffd00=]]00000000=03oool010000000
jliF0>_>EP00000:0?kJU`800000102l/m400`000000QhG:08N5bP0:08N5bP800000101GMMD30000
00<0SF^W00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0`0?ooo`00E@3oool300000003
0?ooo`000000TfjU00`0TfjU00<000000:Vmj02Y_NP01`2Y_NP20000000309A_Y@000000UGB[00L0
UGB[00D000000=]]003KK@00ffd00000000c0?ooo`040000003[cUH0jliF000000X0o]ZG00<00000
0;bcd@2l/m401@2l/m400`000000QhG:08N5bP0:08N5bP030000001GMMD0EgGE00D0EgGE0P000000
0`2=JjL000000?ooo`0A0?ooo`030000003oool0oooo00H0oooo1000000U0?ooo`00D`3oool20000
00<0oooo0P00000>09=^Y@030000002Y_NP0ZKgX00<0ZKgX0`00000309A_Y@030000002EM:/0UGB[
00H0UGB[00D000000=]]003KK@00ffd00000000c0?ooo`040000003[cUH0jliF000000P0o]ZG0P00
00080;bcd@0300000027QLX0QhG:00X0QhG:00<0000005Mee@1GMMD01`1GMMD300000100oooo0P00
00070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool00500oooo0`000000
0`3oool000000?ooo`020?ooo`8000003`2CKZD00`000000ZKgX0:Vmj002000000L0U6nU00<00000
09EdZ`2EM:/01P2EM:/01@000000ffd00=]]003KK@0000000380oooo00@000000>_>EP3[cUH00000
1`3nfYL00`000000_;?A0;bcd@090;bcd@0300000027QLX0QhG:00X0QhG:00<0000005Mee@1GMMD0
2@1GMMD200000100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0280oooo001>0?ooo`800000203oool00`000000jkJK0000000?09=^Y@8000002@2D
KjD00`000000UGB[09EdZ`0609EdZ`050000003KK@00ffd00=]]00000000<P3oool00`000000jliF
000000060?kJU`800000302l/m400`000000QhG:08N5bP0:08N5bP030000001GMMD0EgGE00/0EgGE
0P00000?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0R0?ooo`00B`3oool3000000T0oooo00@000000>^fV`3[]Y/000003`2CKZD00`000000U6nU
09A_Y@0809A_Y@030000002EM:/0UGB[00L0UGB[00D000000=]]003KK@00ffd00000000a0?ooo`03
0000003[cUH0000000H000003P2l/m400`000000QhG:08N5bP0:08N5bP8000002`1GMMD3000000l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0280
oooo00180?ooo`@000002`3oool010000000jkJK0>^fV`00000>09=^Y@8000002P2DKjD00`000000
UGB[09EdZ`0709EdZ`050000003KK@00ffd00=]]00000000<03oool00`000000jliF0>_>EP060000
00030=cUf`000000_;?A00d0_;?A00<0000008N5bP27QLX02@27QLX2000000T0EgGE0P0000030;;<
k@030000003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0280oooo00160?ooo`8000003`3oool010000000jkJK0>^fV`00000>09=^
Y@8000002`2DKjD00`000000UGB[09EdZ`0609EdZ`050000003KK@00ffd00=]]00000000<03oool0
0`000000jliF0000000500000080g>GK00<000000;bcd@2l/m40302l/m400`000000QhG:08N5bP09
08N5bP0300000027QLX0000000H0EgGE0P0000050;;<k@030000003oool0oooo00h0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0280oooo00130?ooo`<00000403oool0
1@000000jkJK0>^fV`3[]Y/0000000d0TfjU00@000000=Z]Z@3J[JT000002P2DKjD00`000000UGB[
09EdZ`0709EdZ`050000003KK@00ffd00=]]00000000;`3oool00`000000jliF00000004000000@0
g>GK00<000000;bcd@2l/m40302l/m400`000000QhG:08N5bP0808N5bP0300000027QLX0000000@0
EgGE0P0000080;;<k@030000003oool0oooo00`0oooo0P0000040?ooo`@000009@3oool00440oooo
0P00000C0?ooo`050000003[]Y/0jkJK0>^fV`0000003@2CKZD010000000fZfY0=Z]Z@00000:09A_
Y@030000002EM:/0UGB[00L0UGB[00D000000=]]003KK@00ffd00000000_0?ooo`030000003[cUH0
000000<000001P3LiM/00`000000_;?A0;bcd@0;0;bcd@0300000027QLX0QhG:00P0QhG:00D00000
08N5bP27QLX0000005Mee@02000000X0//c]00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0Z0?ooo`00?P3oool300000080oooo00<000000?ooo`3oool0403oool01@000000jkJK0>^fV`3[
]Y/0000000`0TfjU00D000000=Z]Z@3J[JT0fZfY0000000:09A_Y@030000002EM:/0UGB[00P0UGB[
00@000000=]]003KK@000000;`3oool5000000L0g>GK00<000000;bcd@2l/m40302l/m400`000000
QhG:08N5bP0608N5bP80000000@0QhG:0000000000000000302bc>d00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo02T0oooo000l0?ooo`8000005`3oool00`000000jkJK0>^fV`020>^fV`03
0000002CKZD0TfjU00X0TfjU00D000000=Z]Z@3J[JT0fZfY0000000;09A_Y@030000002EM:/0UGB[
00L0UGB[00D000000=]]003KK@00ffd00000000]0?ooo`030000003[cUH00000008000002@3LiM/0
0`000000_;?A0;bcd@0;0;bcd@0300000027QLX0QhG:00<0QhG:1P00000209^ik@030000002bc>d0
//c]00/0//c]00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Y0?ooo`00>P3oool20000
01T0oooo00<000000>^fV`3[]Y/00`3[]Y/00`000000TfjU09=^Y@0809=^Y@030000003J[JT0fZfY
0080fZfY00<0000009A_Y@2DKjD02@2DKjD00`000000UGB[09EdZ`0709EdZ`8000000P3KK@000`00
0000oooo0?ooo`0[0?ooo`030000003[cUH00000008000002@3LiM/00`000000_;?A0;bcd@0<0;bc
d@0300000027QLX0000000@000000`2K^Nd010000000VkW]09^ik@00000=0;;<k@030000003oool0
oooo00l0oooo00<000000?ooo`3oool0:03oool003X0oooo0P00000I0?ooo`030000003[]Y/0jkJK
00<0jkJK00<0000009=^Y@2CKZD0202CKZD00`000000fZfY0=Z]Z@020=Z]Z@030000002DKjD0U6nU
00T0U6nU00<0000009EdZ`2EM:/0202EM:/200000080ffd000<000000?ooo`3oool0:P3oool40000
00/0g>GK00<000000;bcd@2l/m402P2l/m44000000P0VkW]00@0000009^ik@2K^Nd000003@2bc>d0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02L0oooo000j0?ooo`030000003oool00000
01L0oooo00<000000>^fV`3[]Y/0103[]Y/00`000000TfjU09=^Y@0709=^Y@030000003J[JT0fZfY
00@0fZfY00<0000009A_Y@2DKjD0202DKjD00`000000UGB[09EdZ`0809EdZ`050000003LKP800000
0=]]00000000;03oool3000000d0g>GK00<000000;bcd@2l/m401@2l/m4400000080X;CW00<00000
09^ik@2K^Nd0202K^Nd010000000VkW]09^ik@00000<0;;<k@030000003oool0oooo00h0oooo0P00
000Y0?ooo`00>P3oool010000000oooo0?ooo`00000F0?ooo`030000003[]Y/0jkJK00@0jkJK00<0
000009=^Y@2CKZD01`2CKZD00`000000fZfY0=Z]Z@040=Z]Z@030000002DKjD0U6nU00P0U6nU00<0
000009EdZ`2EM:/0202EM:/3000000030=]]00000000oooo02/0oooo0P00000>0=cUf`040000002l
/m40_;?A0;bcd@H00000102P]>L00`000000VkW]09^ik@0909^ik@040000002K^Nd0VkW]000000/0
//c]00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0V0?ooo`00>@3oool300000080oooo
00<000000?ooo`3oool04`3oool00`000000jkJK0>^fV`040>^fV`030000002CKZD0TfjU00H0TfjU
00<000000=Z]Z@3J[JT01@3J[JT00`000000U6nU09A_Y@0909A_Y@030000002EM:/0UGB[00P0UGB[
00D000000=a^0P000000ffd00000000Z0?ooo`8000003`3LiM/7000000P0X;CW00<0000009^ik@2K
^Nd0202K^Nd010000000VkW]09^ik@00000<0;;<k@030000003oool0oooo0100oooo00<000000?oo
o`3oool09@3oool003T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003[]Y/0jkJK00@0jkJK00<0000009=^Y@2CKZD01P2CKZD00`000000fZfY0=Z]Z@050=Z]Z@03
0000002DKjD0U6nU00T0U6nU00<0000009EdZ`2EM:/0202EM:/2000000030=a^0P000000000002X0
oooo0P00000=0=cUf`80000000@0[/3W00000000000000002`2P]>L00`000000VkW]09^ik@0909^i
k@030000002K^Nd0000000@00000202bc>d00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
02D0oooo000i0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool00`000000
jkJK0>^fV`050>^fV`030000002CKZD0TfjU00D0TfjU00<000000=Z]Z@3J[JT01P3J[JT00`000000
U6nU09A_Y@0909A_Y@030000002EM:/0UGB[00P0UGB[0P0000020=a^0P800000:03oool4000000X0
g>GK1@0000000`2^`>L000000:2di`0<0:2di`030000002K^Nd0VkW]00L0VkW]0`0000000`2W_>P0
000007:0dP0207:0dPH000000`2bc>d00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0
oooo000i0?ooo`8000001P3oool200000100oooo00<000000>^fV`3[]Y/01@3[]Y/00`000000TfjU
09=^Y@0509=^Y@030000003J[JT0fZfY00H0fZfY00<0000009A_Y@2DKjD02@2DKjD00`000000UGB[
09EdZ`0809EdZ`0300000000084000000080g6h200<000000?ooo`3oool0903oool400000080aOcV
00<000000=cUf`3LiM/0103LiM/5000000D0[/3W00<000000:2di`2P]>L02`2P]>L00`000000VkW]
09^ik@0309^ik@<000000P2W_>P010000000YkcX0:Nlj000000807:0dP@000004`3oool00`000000
oooo0?ooo`0S0?ooo`00>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo
00<000000>^fV`3[]Y/01P3[]Y/00`000000TfjU09=^Y@0309=^Y@030000003J[JT0fZfY00P0fZfY
00<0000009A_Y@2DKjD02@2DKjD00`000000UGB[09EdZ`0709EdZ`0300000000084000000080g6h2
0P00000T0?ooo`030000001901@0B@0D008000000`35o>H200000080g>GK100000080:k0i`030000
002P]>L0X;CW00/0X;CW00<0000009^ik@2K^Nd00`0000060:Nlj0030000002W_>P0000000/0LX3B
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0S0?ooo`00>@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00/0oooo00<000000>^fV`3[]Y/01`3[]Y/00`000000TfjU09=^
Y@0309=^Y@030000003J[JT0fZfY00P0fZfY00<0000009A_Y@2DKjD02@2DKjD00`000000UGB[09Ed
Z`0709EdZ`03000000000840000000<0g6h20P00000R0?ooo`040000001901@0B@0D04T050800000
1035o>H4000000`0[/3W00<000000:2di`2P]>L02P2P]>L3000000X0YkcX00<000000:Nlj0000000
2`1bP=800`000000oooo0?ooo`0?0?ooo`030000003oool0000002@0oooo000:0?ooo`@000000`3o
ool01@000000oooo0?ooo`3oool0000000@0oooo1@0000030?ooo`@000004`3oool2000000X0oooo
00<000000?ooo`3oool02P3oool00`000000jkJK0>^fV`070>^fV`030000002CKZD0TfjU0080TfjU
00<000000=Z]Z@3J[JT02@3J[JT00`000000U6nU09A_Y@0909A_Y@030000002EM:/0UGB[00P0UGB[
00<000000000P@0000000P3LKP800`000000ff`00000000O0?ooo`8000000`1901@2000000<0aOcV
0`0000000`2bb^`000000:k0i`0<0:k0i`030000002P]>L0X;CW00L0X;CW0`0000020:O0j`030000
002W_>P0YkcX00T0YkcX0P00000;07:0dP030000003oool0oooo0180oooo00<000000?ooo`3oool0
8@3oool000T0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000>^fV`3[
]Y/01`3[]Y/00`000000TfjU09=^Y@0209=^Y@030000003J[JT0fZfY00T0fZfY00<0000009A_Y@2D
KjD02@2DKjD00`000000UGB[09EdZ`0809EdZ`03000000000840000000<0g6h200<000000=]/0000
00007@3oool00`000000B@0D04T0500304T05080000000@0aOcV00000000000000000`2bb^`00`00
0000[/3W0:k0i`0<0:k0i`030000002P]>L0X;CW00<0X;CW0`0000050:O0j`030000002W_>P0YkcX
00T0YkcX00<000000:Nlj00000002P1bP=800`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0240oooo000>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000>^fV`3[]Y/0203[]Y/01@000000
TfjU09=^Y@2CKZD0000000`0fZfY00<0000009A_Y@2DKjD02P2DKjD00`000000UGB[09EdZ`0509Ed
Z`H000000P3LKP8010000000ff`00=]/0000000K0?ooo`030000001901@0B@0D0080B@0D1@000007
0;;:k0030000002^`>L0[/3W00/0[/3W00<000000:2di`2P]>L00`0000090:O0j`030000002W_>P0
YkcX00T0YkcX0P00000:07:0dP030000003oool0oooo01<0oooo00<000000?ooo`3oool0803oool0
00030?ooo`000000000000@000001`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3o
ool2000000h0oooo00<000000?ooo`3oool01P3oool00`000000jkJK0>^fV`080>^fV`050000002C
KZD0TfjU09=^Y@000000303J[JT00`000000U6nU09A_Y@0:09A_Y@030000002EM:/0UGB[00D00000
0`2HT/`00`000000JX7G000000030=a^0P040000003KK000ff`0000001P0oooo0P00000204T050D0
00002`2bb^`00`000000[/3W0:k0i`0:0:k0i`<000003@2W`>/00`000000YkcX0:Nlj0090:Nlj080
00002P1bP=800`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01l0oooo000:0?ooo`@00000
0`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`050?ooo`030000003[]Y/0jkJK00P0jkJK00@0000009=^Y@2CKZD000003P3J[JT00`00
0000U6nU09A_Y@0909A_Y@<00000202HT/`010000000JX7G06Z1e`0000020=a^0P040000003KK000
ff`00=]/00<000004P3oool30000000304T050000000000000<000000P2U`nl00`000000//[/0;;:
k00:0;;:k0030000002^`>L0[/3W00H0[/3W0`0000020:Joj`030000002W`>/0Yl3[00`0Yl3[00<0
00000:Nlj02W_>P02@2W_>P00`000000LX3B07:0dP0807:0dP030000003oool0oooo01<0oooo00<0
00000?ooo`3oool07`3oool000X0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00<0oooo00<000000>^fV`3[]Y/02@3[]Y/010000000TfjU09=^Y@00
000>0=Z]Z@030000002DKjD0U6nU00P0U6nU0P00000;09RBc0030000001ZPML0000000<0g6h200<0
00000=]/003KK0000`3KK006000000H0oooo1P0000000`1A01d0000000000003000000@0YL?_00<0
00000;;:k02bb^`02`2bb^`00`000000[/3W0:k0i`040:k0i`8000001P2V_n/00`000000Yl3[0:O0
j`0;0:O0j`030000002W_>P0YkcX00T0YkcX0P00000907:0dP030000003oool0oooo0180oooo00<0
00000?ooo`000000803oool000X0oooo00<000000?ooo`3oool03@3oool3000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0?0?ooo`8000004@3oool00`000000oooo0?ooo`02
0?ooo`030000003[]Y/0jkJK00X0jkJK0P00000?0=Z]Z@030000002DKjD0U6nU00H0U6nU0P000002
0;nac@030000002HT/`0V9;<00P0V9;<00<0000006Z1e`0000000`3LKP800`000000ff`00=]/0009
0=]/00H000001@1A01d4000000L0YL?_00<000000;;:k02bb^`0302bb^`00`000000[/3W0:k0i`03
000000T0Y[o[00<000000:O0j`2W`>/02`2W`>/00`000000YkcX0:Nlj0090:Nlj0030000001bP=80
LX3B00L0LX3B00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0M0?ooo`002P3oool50000
00d0oooo00<000000?ooo`3oool00`3oool4000000L0oooo1@0000000`3oool00000000000030?oo
o`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000<0>^fV`8000003`3J[JT0
0`000000U6nU09A_Y@0509A_Y@030000002o/Ld0_k7=0080_k7=00<0000009RBc02HT/`02@2HT/`0
0`000000JX7G000000020=a^0P030000003KK000ff`000/0ff`000<0000005407@1A01d00`1A01d4
000000030:G3k`000000YL?_00L0YL?_0P00000=0;;:k0<00000302V_n/00`000000Yl3[0:O0j`0;
0:O0j`L000001P2W_>P00`000000LX3B07:0dP0707:0dP030000003oool0oooo01@0oooo00<00000
0?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000E0?oo
o`030000003oool0000000d0jkJK00<000000=Z]Z@3J[JT03P3J[JT00`000000U6nU09A_Y@0409A_
Y@030000002o/Ld0_k7=00@0_k7=00<0000009RBc02HT/`0202HT/`00`000000JX7G000000030=a^
0P030000003KK000ff`000T0ff`000@0000005407@1A01d0D@0M100000050:G3k`030000002U`nl0
YL?_00@0YL?_00<000000:S8l00000002P2bb^`300000080Z<3[00<000000:Joj`2V_n/02`2V_n/0
0`000000Yl3[0:O0j`060:O0j`@000000P2S_>/00`000000LICU076Di@02076Di@L000002@1bP=80
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01`0oooo000Y0?ooo`<000000`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000001H0oooo0P00000=0>^fV`030000003J[JT0
fZfY00h0fZfY00<0000009A_Y@2DKjD00`2DKjD00`000000_k7=0;nac@050;nac@030000002HT/`0
V9;<00T0V9;<00<0000006Z1e`0000000P3LKP800`000000ff`00=]/00090=]/00D000002@2U`nl0
0`000000YL?_0:G3k`030:G3k`040000002Xb?00Z<S`000000H0//[/0`0000060:S0j`030000002V
_n/0Y[o[00/0Y[o[00@000000:O0j`2W`>/0Yl3[100000060:>lj`030000001aU>D0LICU00P0LICU
0P00000807:0dP030000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool4000000D0oooo
0P0000050?ooo`@000000@3oool002l0oooo00<000000?ooo`3oool00`3oool010000000oooo0000
0000000F0?ooo`030000003[]Y/0jkJK00/0jkJK00<000000=Z]Z@3J[JT03`3J[JT01@000000U6nU
09A_Y@2DKjD0000000T0_k7=00<0000009RBc02HT/`02@2HT/`2000000<0g6h200<000000=]/003K
K0001P3KK005000000/0YL?_00<000000:G3k`2U`nl00`2U`nl01@000000Z<S`0:S8l02Xb?000000
0080//[/0`00000:0:S0j`030000002V_n/0Y[o[00X0Y[o[1000000;0:>lj`030000001aU>D0LICU
00P0LICU0P00000707:0dP030000003oool0oooo01D0oooo0P0000070?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool00P3oool10000
0000;`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000000F0?ooo`030000003[
]Y/0jkJK00/0jkJK00<000000?[YUP000000403J[JT010000000U6nU00000000000:0;nac@030000
002HT/`0V9;<00T0V9;<00<0000006Z1e`0000000P3LKP800`000000ff`00=]/00030=]/00H00000
3P2U`nl01@000000YL?_0:G3k`2U`nl0000000@0Z<S`0`00000=0:S0j`030000002V_n/0Y[o[00L0
Y[o[0`0000020:O0j`030000002S_>/0Xkc[00X0Xkc[00<00000076Di@1aU>D0201aU>D3000000L0
LX3B00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03@3oool100000000;P3oool2000000@0oooo00@000000?ooo`3oool0
00005P3oool00`000000jkJK0>^fV`0;0>^fV`030000003jjIH000000100fZfY0P00000<0;nac@03
0000002HT/`0V9;<00X0V9;<0P0000030=a^0P030000003KK000000000@00000102Ta_400`000000
YL?_0:G3k`0<0:G3k`050000002U`nl0YL?_0000002Xb?000`0000020:S1j`030000002X`>/0Z<3[
00`0Z<3[00<000000:Joj`2V_n/0102V_n/2000000H0Yl3[00<000000:>lj`2S_>/02P2S_>/00`00
0000LICU076Di@07076Di@03000000008:L0000000L0LX3B00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool10000
0000=`3oool2000001D0oooo00<000000>^fV`3[]Y/02P3[]Y/01@000000n^VF0?[YUP3jjIH00000
00l0fZfY00<000000;nac@2o/Ld0302o/Ld00`000000V9;<09RBc00909RBc0040000001ZPML00000
0=a^0PD00000202Ta_400`000000YL?_0:G3k`0<0:G3k`@000001P2X`N/00`000000Z<3[0:S0j`0<
0:S0j`030000002V_n/0Y[o[00<000002@2W`>/00`000000Xkc[0:>lj`090:>lj`030000001aU>D0
LICU00P0LICU00<00000000PY`0000001P1bP=800`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`@000000@3oool0
03L0oooo00<000000?ooo`3oool04`3oool00`000000jkJK0>^fV`0;0>^fV`050000003jjIH0n^VF
0?[YUP0000003P3J[JT00`000000f]_H0000000=0;nac@030000002HT/`0V9;<00T0V9;<1P00000;
0:C6l@030000002U`nl0YL?_00`0YL?_0P0000090:S1j`030000002X`>/0Z<3[00/0Z<3[0`00000<
0:O0j`030000002S_>/0Xkc[00X0Xkc[00<00000076Di@1aU>D01`1aU>D010000000022W00000000
000507:0dP030000003oool0oooo01P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool003H0oooo00<00000
0?ooo`3oool0503oool00`000000jkJK0>^fV`0;0>^fV`030000003jjIH0n^VF0080n^VF00<00000
0=Z]Z@3J[JT02P3J[JT010000000f]_H0=[Kf000000>0;nac@030000002HT/`0V9;<00D0V9;<1`00
000>0:C6l@030000002U`nl0YL?_00P0YL?_0`00000;0:S1j`030000002X`>/0Z<3[00P0Z<3[0`00
00020:O0j`030000002W`>/0Yl3[00/0Yl3[00<000000:>lj`2S_>/02@2S_>/00`000000LICU076D
i@07076Di@04000000008:L0022W000000H0LX3B00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`00=P3oool00`000000oooo0000000D0?ooo`030000003[]Y/0jkJK00X0jkJK00<0
00000?[YUP3jjIH00`3jjIH00`000000fZfY0=Z]Z@090=Z]Z@030000003JfmP0f]_H0080f]_H00<0
00000;nac@2o/Ld02`2o/Ld00`000000V9;<09RBc00309RBc0D000000P2Y^^H00`000000W[KY0000
000>0:C6l@030000002U`nl0YL?_00@0YL?_0`0000000`2W_n/000000:S1j`0<0:S1j`030000002X
`>/0Z<3[00@0Z<3[0`0000050:O0j`030000002W`>/0Yl3[00`0Yl3[00<000000:>lj`2S_>/0102S
_>/6000000T0LICU00@00000000PY`008:L000001@1bP=800`000000oooo0?ooo`0F0?ooo`<00000
103oool4000000`0oooo1@00000003H0oooo0P00000D0?ooo`030000003[]Y/0jkJK00/0jkJK00<0
00000?[YUP3jjIH0103jjIH00`000000fZfY0=Z]Z@070=Z]Z@030000003JfmP0f]_H00<0f]_H00<0
00000;nac@2o/Ld0302o/Ld00`000000V9;<00000004000000H0ZK[V00<0000009jfj@0000003P2T
a_400`000000YL?_0:G3k`03000000D0Yko[00<000000:S1j`2X`N/02`2X`N/00`000000Z<3[0:S0
j`03000000T0Yl3[00<000000:O0j`2W`>/02`2W`>/7000000H0S[?_0P000007076Di@0500000000
8:L0022W000PY`000000101bP=800`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01H0oooo
000]0?ooo`@000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003[]Y/0jkJK00X0jkJK00<0
00000?[YUP3jjIH01@3jjIH00`000000fZfY0=Z]Z@060=Z]Z@030000003JfmP0f]_H00D0f]_H00<0
00000;nac@2o/Ld02P2o/Ld6000000T0ZK[V0P00000>0:C6l@<000002@2W_n/00`000000Z<7[0:S1
j`0:0:S1j`<000003@2W`>/00`000000Yl3[0:O0j`070:O0j`<000000P2U_n`00`000000S[?_08jc
k`0808jck`0300000000BLT0000000L0LICU00<00000000PY`008:L00P00000307:0dP030000003o
ool0oooo01T0oooo00<000000?ooo`3oool05P3oool002`0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000>^fV`3[]Y/02P3[]Y/0
0`000000n^VF0?[YUP060?[YUP030000003J[JT0fZfY00@0fZfY00<000000=[Kf03JfmP01`3JfmP0
0`000000_k7=0;nac@070;nac@D000003@2Y^^H2000000X0Y<Ka0`00000=0:Noj`030000002X`N/0
Z<7[00D0Z<7[100000020:O0j`030000002W`>/0Yl3[00`0Yl3[00<000000:O0j`2W`>/00`2W`>/3
000000D0YKo/00<0000008jck`2>/nl02@2>/nl01000000004W9000000000005076Di@0500000000
8:L0022W000PY`000000101bP=800`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01D0oooo
000/0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000001<0oooo00<0
00000>^fV`3[]Y/02`3[]Y/00`000000n^VF0?[YUP060?[YUP030000003J[JT0fZfY00<0fZfY00<0
00000=[Kf03JfmP0203JfmP00`000000_k7=0;nac@050;nac@@000000`2baNP00`000000ZK[V0:Vj
iP0:0:VjiP030000002N]^T0000000H0Y<Ka0`0000030:Noj`030000002W_n/0Yko[00/0Yko[00<0
00000:S1j`2X`N/0100000070:O0j`030000002W`>/0Yl3[00/0Yl3[00<000000:O0j`2W`>/00`00
00090:Fok0030000002>/nl0S[?_00T0S[?_00@000000019b@00BLT00000101aU>D00`000000022W
000PY`02000PY`050000001bP=80LX3B07:0dP000000703oool00`000000oooo0?ooo`0D0?ooo`00
;03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
4P3oool00`000000jkJK0>^fV`0:0>^fV`030000003jjIH0n^VF00P0n^VF00D000000=Z]Z@3J[JT0
fZfY0000000<0=[Kf0030000002o/Ld0_k7=0080_k7=0`0000070;;5j0030000002Y^^H0ZK[V00X0
ZK[V00<0000009jfj@0000000P2Ta_43000000L0Yko[00<000000:Noj`2W_n/02P2W_n/3000000`0
Yl3[00<000000:O0j`2W`>/02P2W`>/3000000d0YKo/00<0000008jck`2>/nl02@2>/nl010000000
04W90019b@000004076Di@03000000008:L0022W0080022W00@0000007:0dP1bP=800000703oool0
0`000000oooo0?ooo`0D0?ooo`00;03oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000005@3oool00`000000jkJK0>^fV`0:0>^fV`030000003jjIH0n^VF00P0n^VF00@00000
0=Z]Z@3J[JT000003@3JfmP00`000000_k7=00000002000000X0//GX00<000000:VjiP2Y^^H02P2Y
^^H5000000X0Yko[00<000000:Noj`2W_n/01`2W_n/300000080Yl3[00<000000:O0j`2W`>/02`2W
`>/00`000000Yl3[0:O0j`050:O0j`@000000P2W`>/00`000000YKo/0:Fok00<0:Fok0030000002>
/nl0S[?_00P0S[?_00@000000019b@00BLT004W90P000002076Di@03000000008:L0022W0080022W
0P0000000`1bP=8000000?ooo`0J0?ooo`030000003oool0000001D0oooo000/0?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool0oooo0P00000D0?ooo`030000003[]Y/0jkJK00T0jkJK
00<000000?[YUP3jjIH02P3jjIH2000000d0f]_H1000000=0;;5j0030000002Y^^H0ZK[V00L0ZK[V
0P0000020:S0j`030000002W_n/0Yko[00/0Yko[00<000000:Noj`2W_n/0102W_n/2000000H0Yl3[
00<000000:O0j`2W`>/02`2W`>/00`000000Yl3[0:O0j`04000000L0Yl3[00<000000:Fok02U_n`0
2`2U_n`00`000000S[?_08jck`0908jck`0300000000BLT004W9008004W900<00000076Di@000000
1@008:L010000000LX3B07:0dP00000M0?ooo`030000003oool0oooo0180oooo000/0?ooo`030000
003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000D0?ooo`030000003[]Y/0jkJK00X0
jkJK00<000000?[YUP3jjIH02P3jjIH2000000X0f]_H100000020:o;kP030000002baNP0//GX00`0
//GX00<000000:VjiP2Y^^H00`2Y^^H3000000D0Z<3[00<000000:Noj`2W_n/02`2W_n/00`000000
Yko[0:Noj`03000000T0Yl3[00<000000:O0j`2W`>/02P2W`>/3000000`0Yl3[00<000000:Fok02U
_n`02P2U_n`>000000@004W90`000005000PY`030000001bP=80000001d0oooo00<000000?ooo`3o
ool04P3oool002d0oooo100000040?ooo`030000003oool0oooo00h0oooo00D000000?ooo`3oool0
oooo0000000<0>^fV`030000003jjIH0n^VF00P0n^VF0P0000020;Wki`8000001P3JfmP4000000D0
[l_^00<000000;;5j02baNP0302baNP00`000000ZK[V0:VjiP02000000T0Z<3[00<000000:Noj`2W
_n/02P2W_n/3000000`0Yl3[00<000000:O0j`2W`>/01`2W`>/300000080Yl3[00<000000:O0j`2W
`>/02`2W`>/00`000000YKo/0:Fok0050:Fok0@000000P2S_^d00`000000O[3d07j`m00907j`m003
00000000BLT004W900<004W900<00000000PY`008:L010008:L2000001h0oooo00<000000?ooo`3o
ool04@3oool003D0oooo00<000000?ooo`3oool03P3oool3000000030?ooo`000000jkJK00X0jkJK
00<000000?[YUP3jjIH0203jjIH00`000000^O_W0;Wki`040;Wki`80000000<0f]_H000000000000
0P0000090:o;kP800000302baNP3000000`0Z<3[00<000000:Noj`2W_n/01`2W_n/200000080Yl3[
00<000000:O0j`2W`>/02`2W`>/00`000000Yl3[0:O0j`040:O0j`8000001P2W`>/00`000000Yl3[
0:O0j`0;0:O0j`030000002U_n`0YKo/00@000001P2S_^d00`000000O[3d07j`m00:07j`m0030000
0000BLT004W9008004W90`000004000PY`8000007`3oool00`000000oooo0?ooo`0@0?ooo`00=@3o
ool00`000000oooo0?ooo`0=0?ooo`050000001a6DP0LAU8074IB0000000303[]Y/00`000000n^VF
0?[YUP060?[YUP8000001`2innL5000000d0[l_^00<000000;;5j02baNP01@2baNP400000080Z<7[
00<000000:S0j`2X`>/02`2X`>/00`000000Yko[0:Noj`030:Noj`<000001@2W`>/00`000000Yl3[
0:O0j`0;0:O0j`030000002W`>/0Yl3[00<000002@2W`>/00`000000Yl3[0:O0j`0:0:O0j`<00000
2`2S_^d00`000000O[3d07j`m00907j`m08000001000BLT00`000000:UW=00000004000PY`800000
6`3oool400000180oooo000e0?ooo`030000003oool0oooo00d0oooo00D00000074IB01a6DP0LAU8
0000000;0>^fV`030000003jjIH0n^VF00D0n^VF0P0000060;Wki`D000000P2N_o000`000000[l_^
0:o;kP0<0:o;kP030000002baNP0//GX00@000001`2X`N/00`000000Z<3[0:S0j`0;0:S0j`030000
002W_n/0Yko[008000002@2W`>/00`000000Yl3[0:O0j`0:0:O0j`<00000302W`>/00`000000Yl3[
0:O0j`070:O0j`<000000P2W`>/00`000000Xkk]0:>nk@0:0:>nk@030000001n/?@0O[3d00T0O[3d
0P0000030019b@040000000ZFLd0:UW=000000@0022W00<000000?ooo`3oool04`3oool600000080
VTAO0`00000A0?ooo`00=03oool00`000000oooo0?ooo`0=0?ooo`030000001a6DP0LAU80080LAU8
00<000000>^fV`3[]Y/02@3[]Y/00`000000n^VF0?[YUP040?[YUP030000002innL0^O_W00<0^O_W
1@00000609jol0030000002_bnh0[l_^00/0[l_^0`00000<0:S1j`030000002X`>/0Z<3[00X0Z<3[
0`00000;0:O0j`030000002W`>/0Yl3[00L0Yl3[0`0000020:O0j`030000002W`>/0Yl3[00/0Yl3[
00<000000:O0j`2W`>/0102W`>/2000000D0Yl3[00<000000:>nk@2S_^d02`2S_^d00`000000O[3d
07j`m00907j`m08000000`00BLT00`000000:UW=02YIc@02000000<0022W00<000000?ooo`3oool0
3P3oool4000000P0VTAO00@0000009Bck@0000000000403oool003@0oooo0P00000>0?ooo`050000
001a6DP0LAU8074IB0000000303[]Y/00`000000n^VF0?[YUP020?[YUP8000000P2innL5000000/0
W[o`0P0000090:o;kP8000000P2V_n/00`000000Z<7[0:S1j`0;0:S1j`030000002X`>/0Z<3[00D0
Z<3[100000020:O0j`030000002W`>/0Yl3[00X0Yl3[00<000000:O0j`2W`>/0102W`>/2000000H0
Yl3[00<000000:O0j`2W`>/02`2W`>/00`000000Yl3[0:O0j`03000000P0Yl3[00<000000:>nk@2S
_^d02P2S_^d00`000000O[3d07j`m00507j`m0L000000P00BLT00`000000:UW=02YIc@0202YIc@04
000000008:L0022W000000h0oooo0P0000000`26:DX0000009Y4G`0909Y4G`040000002D/nd0U;?]
00000100oooo000d0?ooo`030000003oool0oooo00`0oooo00<00000074IB01a6DP00P1a6DP00`00
0000jkJK0>^fV`090>^fV`030000003jjIH0n^VF0080n^VF1P00000309ZdjP030000002N_o00W[o`
00/0W[o`00<000000:o;kP2_bnh00`2_bnh3000000D0Y[o[00<000000:S1j`2X`N/02`2X`N/00`00
0000Z<3[0:S0j`04000000L0Yl3[00<000000:O0j`2W`>/02P2W`>/00`000000Yl3[0:O0j`030000
00T0Yl3[00<000000:O0j`2W`>/02P2W`>/3000000`0Yl3[00<000000:>nk@2S_^d02@2S_^d80000
00H0S;Oc0P0000020019b@030000000ZFLd0:UW=0080:UW=0P0000000`008:L000000?ooo`090?oo
o`<000000`26:DX00`000000VTAO09Y4G`0809Y4G`030000002D/nd0U;?]008000003`3oool003@0
oooo00<000000?ooo`3oool0303oool00`000000LAU8074IB002074IB0030000003[]Y/0jkJK00T0
jkJK00@000000?[YUP3jjIH0n^VF1000000709ZdjP030000002N_o00W[o`00/0W[o`00<000000:o;
kP2_bnh00P0000090:Joj`030000002X`N/0Z<7[00X0Z<7[0`00000<0:O0j`030000002W`>/0Yl3[
00T0Yl3[0`00000=0:O0j`030000002W`>/0Yl3[00D0Yl3[100000020:O0j`030000002W`>/0Yl3[
00/0Yl3[00<000000:>nk@2S_^d0102S_^d400000080YKo/00<0000008bgl`2<]o<02P2<]o<20000
00030019b@000000:UW=00D0:UW=00<00000000PY`0000001`3oool2000000H0QRU:00<0000009Y4
G`2JA5l0202JA5l3000000030?ooo`000000oooo00h0oooo000d0?ooo`030000003oool0oooo00/0
oooo00<00000074IB01a6DP00P1a6DP00`000000jkJK0>^fV`090>^fV`030000003jjIH0n^VF00<0
00002`2J]>X2000000/0W[o`0`00000<0:Joj`030000002X`N/0Z<7[00L0Z<7[0P0000020:O0j`03
0000002W`>/0Yl3[00/0Yl3[00<000000:O0j`2W`>/01@2W`>/300000080Yl3[00<000000:O0j`2W
`>/0302W`>/00`000000Yl3[0:O0j`04000000L0Yl3[00<000000:O0j`2W`>/02P2W`>/00`000000
Xkk]0:>nk@04000000L0YKo/00<0000008bgl`2<]o<02P2<]o<2000000030019b@000000:UW=00D0
:UW=0`0000040?ooo`8000002026:DX00`000000VTAO09Y4G`0809Y4G`050000003oool0oooo0?oo
o`0000003`3oool000@0oooo100000030?ooo`050000003oool0oooo0?ooo`000000103oool50000
00<0oooo1000000C0?ooo`<00000303oool00`000000LAU8074IB002074IB0030000003[]Y/0jkJK
00T0jkJK0`000000103jjIH0000009O`k`00000<09ZdjP030000002N_o00W[o`00D0W[o`0`000002
0:O4kP030000002V_n/0Y[o[00/0Y[o[00<000000:S1j`2X`N/00`2X`N/3000000D0Yl3[00<00000
0:O0j`2W`>/02`2W`>/00`000000Yl3[0:O0j`04000000H0Yl3[00<000000:O0j`2W`>/02`2W`>/3
000000/0Yl3[00<000000:O0j`2W`>/02P2W`>/3000000/0YKo/00<0000008bgl`2<]o<02P2<]o<4
000000L0:UW=0P0000040?ooo`0300000026:DX0QRU:00L0QRU:00<0000009Y4G`2JA5l0202JA5l0
1@000000oooo0?ooo`3oool0000000l0oooo00030?ooo`030000003oool0oooo0080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool010000000LAU8
074IB01a6DP2000000030<;8gP000000jkJK00L0jkJK0`0000020?[YUP050000002Gl>l0Uo3_09O`
k`000000302J]>X00`000000W[o`09jol004000000H0YlC^00<000000:Joj`2V_n/02`2V_n/00`00
0000Z<7[0:S1j`02000000T0Yl3[00<000000:O0j`2W`>/02P2W`>/3000000/0Yl3[00<000000:O0
j`2W`>/01`2W`>/300000080Yl3[00<000000:O0j`2W`>/02P2W`>/00`000000Yl3[0:O0j`050:O0
j`@000000P2W`>/00`000000YKo/0:Fok00:0:Fok0030000002<]o<0S;Oc00D0S;Oc100000020::n
k@<00000200ZFLd010000000oooo0?ooo`00000:08HYBP030000002JA5l0VTAO00P0VTAO00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`00203oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool02`3oool010000000LAU8074IB0000004
0<;8gP030000003[]Y/0jkJK0080jkJK0`000000103[]Y/000000?[YUP3jjIH2000000@0Uo3_00<0
000009ZdjP2J]>X02@2J]>X3000000/0YlC^0P00000;0:Joj`<00000302W`>/00`000000Yl3[0:O0
j`050:O0j`@000000P2W`>/00`000000Yl3[0:O0j`0:0:O0j`030000002W`>/0Yl3[00@0Yl3[0P00
00050:O0j`030000002W`>/0Yl3[00/0Yl3[00<000000:O0j`2W`>/0100000070:O0j`030000002U
_n`0YKo/00X0YKo/00<0000008bgl`2<]o<0100000070::nk@8000002@0ZFLd5000000P0QRU:00<0
000009Y4G`2JA5l0202JA5l00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo0008
0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`8000002`3oool010000000LAU8
074IB00000050<;8gP030000003[]Y/0000000800000103[]Y/00`000000n^VF000000020?ooo`<0
00000P2Gl>l00`000000V[CZ09ZdjP0509ZdjP<000000P24i_@00`000000YlC^0:O4kP0;0:O4kP03
0000002V_n/0Y[o[00D0Y[o[0`0000020:O2k@030000002W`>/0Yl3[00/0Yl3[00<000000:O0j`2W
`>/0100000070:O0j`030000002W`>/0Yl3[00X0Yl3[00<000000:O0j`2W`>/00`0000080:O0j`03
0000002W`>/0Yl3[00X0Yl3[0`00000;0:O0j`030000002U_n`0YKo/00X0YKo/0`00000;0::nk@04
0000001NX?<00000000000L0:UW=00<000000<Q80038B0000P38B004000000<0QRU:00<0000009Y4
G`2JA5l02@2JA5l00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00040?ooo`@0
00000`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool30000
00D0`/SN0`0000060>^fV`040000003jjIH0n^VF000000D0oooo1000000209ZdjP@000001P24i_@0
0`000000YlC^0:O4kP0;0:O4kP030000002V_n/0Y[o[00@000001P2W`^d00`000000Yl3[0:O0j`0:
0:O0j`<00000302W`>/00`000000Yl3[0:O0j`090:O0j`<00000302W`>/00`000000Yl3[0:O0j`06
0:O0j`<000000P2W`>/00`000000Yl3[0:O0j`0:0:O0j`030000002U_n`0YKo/00D0YKo/10000002
0:O1k0030000002R_^d0X[k]00X0X[k]00<0000005jPl`0000000P00000602YIc@0300000038B000
b4P000D0b4P01000000;09Y4G`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool0
00@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`090?ooo`8000001032b=h30000
00<0`/SN00<000000>^fV`3[]Y/00`3[]Y/00`000000n^VF000000090?ooo`D000002@24i_@20000
00/0YlC^0`00000;0:O2k@030000002W`>/0Yl3[00L0Yl3[0P0000020:O0j`030000002W`>/0Yl3[
00/0Yl3[00<000000:O0j`2W`>/01@2W`>/300000080Yl3[00<000000:O0j`2W`>/02`2W`>/00`00
0000Yl3[0:O0j`030:O0j`8000001@2W`>/00`000000Yl3[0:O0j`0;0:O0j`030000002U_n`0YKo/
00@000001`2W`N`00`000000X[k]0::nk@0:0::nk@030000001NX?<0GZ3c00@00000100ZFLd00`00
0000b4P00<Q800080<Q800L00000102JA5l00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00`0oooo00040?ooo`030000003oool0oooo00d0oooo0`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool5000000030?ooo`000000000000@0oooo00<000000?ooo`3o
ool02@3oool00`000000`/SN0<;8gP03000000L0`/SN00<000000>^fV`3[]Y/00P3[]Y/2000000l0
oooo1P00000508CVm0030000002Wa>h0YlC^00D0YlC^0`00000209gAnP030000002W`^d0Yl;]00X0
Yl;]00<000000:O0j`2W`>/00`2W`>/3000000D0Yl3[00<000000:O0j`2W`>/02`2W`>/00`000000
Yl3[0:O0j`04000000H0Yl3[00<000000:O0j`2W`>/02P2W`>/00`000000Yl3[0:O0j`03000000P0
Yl3[00<000000:O0j`2W`>/02P2W`>/3000000/0Yl7/00<000000::nk@2R_^d02P2R_^d300000080
Yl;]1@00000202YIc@0300000038B000b4P000T0b4P00`0000000`2JkOH0000009Y4G`0309Y4G`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0303oool000@0oooo1@00000=0?ooo`030000
003oool0oooo00<0oooo100000090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P0000090?ooo`D000002`32b=h00`000000jkJK0>^fV`02000001H0oooo1@0000001024i_@00000
0:O4kP2Wa>h4000000H0WM7j00<000000:O2k@2W`^d02P2W`^d00`000000Yl3[0:O0j`02000000T0
Yl3[00<000000:O0j`2W`>/02P2W`>/3000000/0Yl3[00<000000:O0j`2W`>/02@2W`>/3000000`0
Yl3[00<000000:O0j`2W`>/01P2W`>/300000080Yl3[00<000000:O1k02W`N`02P2W`N`00`000000
X[k]0::nk@050::nk@@000000P2Vb_800`000000Yl;]0:O2k@020:O2k@0300000000Gk8005nb00<0
00002`38B0000`000000V^gf09[]mP0209[]mP050000002JA5l0VTAO09Y4G`000000103oool00`00
0000oooo0?ooo`0<0?ooo`008`3oool3000000<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo1000000>0<;8gP030000003[]Y/0jkJK0080
00006`3oool4000000/0WM7j00<000000:O2k@2W`^d02@2W`^d3000000/0Yl3[00<000000:O0j`2W
`>/01`2W`>/300000080Yl3[00<000000:O0j`2W`>/02P2W`>/00`000000Yl3[0:O0j`050:O0j`<0
00000P2W`>/00`000000Yl3[0:O0j`0;0:O0j`030000002W`>/0Yl3[00<0Yl3[0P0000060:O0j`03
0000002W`N`0Yl7/00X0Yl7/00<000000::nk@2R_^d0100000070:K:lP030000002W`^d0Yl;]0080
Yl;]0P000002001O/P8000002P38B0000`000000V^gf09[]mP0209[]mP050000002JA5l0VTAO09Y4
G`000000103oool00`000000oooo0?ooo`0<0?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`04
0000003oool0oooo000000H0oooo1@00000@0<;8gP<000007`3oool2000000/0WM7j00<000000:O2
k@2W`^d01@2W`^d300000080Y<7^00<000000:O0j`2W`>/02P2W`>/00`000000Yl3[0:O0j`040:O0
j`8000001P2W`>/00`000000Yl3[0:O0j`0:0:O0j`030000002W`>/0Yl3[00@000001P2W`>/00`00
0000Yl3[0:O0j`0:0:O0j`030000002W`>/0Yl3[00<00000202W`>/00`000000Yl7/0:O1k00:0:O1
k0<000002`2Vb_800`000000Yl;]0:O2k@040:O2k@0500000000Gk8005nb001O/P0000002038B000
0`000000V^gf09[]mP0409[]mP040000002JA5l0VTAO000000D0oooo00<000000?ooo`3oool02`3o
ool002T0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo0P0000020?ooo`@00000
102Qe_X00`000000`/SN0<;8gP0=0<;8gP8000008P3oool00`000000WM7j09gAnP0909gAnP030000
002W`^d0Yl;]00@000001P2T`Nh00`000000Yl3[0:O0j`0:0:O0j`030000002W`>/0Yl3[00<00000
202W`>/00`000000Yl3[0:O0j`0:0:O0j`<000002`2W`>/00`000000Yl3[0:O0j`090:O0j`<00000
302W`>/00`000000Yl7/0:O1k0050:O1k0@000000P2V`^d00`000000Y/[b0:K:lP0:0:K:lP030000
002W`^d0Yl;]00@0Yl;]0P0000000`00Gk800000000000070<Q800030000002JkOH0V^gf00@0V^gf
00@0000009Y4G`2JA5l000001@3oool00`000000oooo0?ooo`0;0?ooo`00:03oool2000000@0oooo
00H000000?ooo`3oool0oooo0000003oool3000000P0XMKj00<000000<;8gP32b=h02P32b=h20000
02D0oooo0P00000609gAnPH000002`2T`Nh00`000000Yl3[0:O0j`090:O0j`<00000302W`>/00`00
0000Yl3[0:O0j`050:O0j`@000000P2W`>/00`000000Yl3[0:O0j`0:0:O0j`030000002W`>/0Yl3[
00D0Yl3[0`0000020:Noj`030000002W`>/0Yl3[00/0Yl3[00<000000:O1k02W`N`0100000070:K2
k@030000002Vb_80Y/[b00X0Y/[b00@000000:O2k@2W`^d0Yl;]1`0000070<Q800030000002JkOH0
V^gf00D0V^gf00<0000009Y4G`0000001@3oool00`000000oooo0?ooo`0;0?ooo`00<P3oool20000
00`0XMKj0P0000080<;8gP800000:@3oool6000000D0P[ok00<000000:C1kP2T`Nh02P2T`Nh00`00
0000Yl3[0:O0j`050:O0j`<000000P2W_n/00`000000Yl3[0:O0j`0;0:O0j`030000002W`>/0Yl3[
00@000001`2W`>/00`000000Yl3[0:O0j`0:0:O0j`030000002W`>/0Yl3[00@000001P2W_n/00`00
0000Yl3[0:O0j`0:0:O0j`<00000302V`^d00`000000Y/[b0:K:lP080:K:lPH000001@38Tih20000
00H0b4P00P00000609[]mP030000002JA5l0000000D0oooo00<000000?ooo`3oool02`3oool003<0
oooo0P00000=0:7FnP0300000032b=h0`/SN00<0`/SN0P00000/0?ooo`8000002@22_o/00`000000
Y<7^0:C1kP0:0:C1kP030000002W`>/0Yl3[00@000001P2W_n/00`000000Yl3[0:O0j`0:0:O0j`<0
00002`2W`>/00`000000Yl3[0:O0j`0:0:O0j`<000002`2W_n/00`000000Yl3[0:O0j`070:O0j`80
00000P2X^NH00`000000Y/;]0:K2k@0;0:K2k@040000002Vb_80Y/[b0:K:lPH0000000D0S]So0000
002cW<40/ic1000000060<RCWP<000001@38B00010000000oooo00000000000509[]mP8000001@3o
ool00`000000oooo0?ooo`0;0?ooo`00=03oool3000000`0XMKj00<000000<;8gP32b=h00P00000^
0?ooo`@000002022_o/00`000000Y<7^0:C1kP090:C1kP<000002`2W_n/00`000000Yl3[0:O0j`07
0:O0j`8000000P2W`>/00`000000Yl3[0:O0j`0:0:O0j`030000002W`>/0Yl3[00D0Yl3[10000002
0:O0j`030000002W_n/0Yko[00X0Yko[00<000000:O0j`2W`>/00`2W`>/3000000D0Z;WV00<00000
0:K2k@2V`^d02P2V`^d4000000D0S]So0P0000030;>L`@0300000038Tih0b9>N00@0b9>N00@00000
0?ooo`00000000001038B00010000000oooo0?ooo`3oool300000080V^gf0P0000050?ooo`030000
003oool0oooo00/0oooo000f0?ooo`<000001`2Qe_X600000340oooo00<0000007l0000000000P00
000708:on`030000002T`Nh0Y<7^00D0Y<7^0`0000020:>lj`030000002W_n/0Yko[00X0Yko[00<0
00000:O0j`2W`>/00`2W`>/3000000D0Yl3[00<000000:O0j`2W`>/02P2W`>/00`000000Yl3[0:O0
j`04000000L0Yl3[00<000000:Noj`2W_n/02P2W_n/00`000000Yl3[0:O0j`02000000P0Z;WV00<0
00000:K2k@2V`^d01`2V`^d300000080ZjWE00<0000008kHo`2>f?l00`2>f?l00`000000/ic10;>L
`@030;>L`@0300000038Tih0b9>N00@0b9>N00<000000?ooo`3oool00P0000030<Q800030000003o
ool0oooo00@0oooo0P0000000`2JkOH000000?ooo`040?ooo`030000003oool0oooo00/0oooo000g
0?ooo`030000003oool0000000H00000=`3oool20000000307l000000000000000D000000`22_o/0
0`000000Y<7^0:C1kP04000000H0Xkc[00<000000:Noj`2W_n/02P2W_n/00`000000Yl3[0:O0j`02
000000T0Yl3[00<000000:O0j`2W`>/02@2W`>/3000000/0Yl3[00<000000:Noj`2W_n/02P2W_n/3
000000/0Z;WV00<000000:K2k@2V`^d0102V`^d2000000H0ZjWE0P0000000`2>f?l0000000000006
0;>L`@0300000038Tih0b9>N00@0b9>N00<000000?ooo`3oool00P0000030<Q800030000003oool0
oooo00H0oooo0P0000050?ooo`030000003oool0oooo00/0oooo000h0?ooo`030000003oool0oooo
03`0oooo0P0000000`1o0000000002Y5^P02000000<0P:K]1P00000;0:>lj`030000002W_n/0Yko[
00T0Yko[0`00000<0:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000020:O1k0030000002W`>/0Yl3[
00X0Yl3[00<000000:Noj`2W_n/01@2W_n/400000080Z;WU00<000000:RiiP2X^NH02P2X^NH00`00
0000Y/;]0:K2k@03000000X0ZjWE00<000000;>L`@2cW<401@2cW<400`000000b9>N0<RCWP050<RC
WP040000003oool0oooo0?ooo`80000000<0b4P00000003oool0403oool00`000000oooo0?ooo`0:
0?ooo`00>@3oool2000003`0oooo00@0000001XOV000000000000P0ZAKX2000000L0P:K]00<00000
0:>lj`2S_>/02P2S_>/00`000000Yko[0:Noj`050:Noj`<000000P2W`>/00`000000Yl3[0:O0j`0;
0:O0j`030000002W`>/0Yl3[00@000001P2W`N`00`000000Yl3[0:O0j`0:0:O0j`030000002W_n/0
Yko[00@000001`2X^ND00`000000Z;WV0:RiiP090:RiiP<00000302[ZMD2000000L0/ic100<00000
0<RCWP38Tih01@38Tih00`000000oooo0?ooo`020?ooo`0300000038B00000000140oooo00<00000
0?ooo`3oool02P3oool003/0oooo00<000000?ooo`3oool0>@3oool01@0000006QnH0000001o0000
00000080:TFj0P000007082Vk@030000002S_>/0Xkc[00X0Xkc[00<000000:Noj`2W_n/010000006
0:O0j`030000002W`>/0Yl3[00X0Yl3[0`00000;0:O1k0030000002W`>/0Yl3[00T0Yl3[0`00000;
0:Rii@030000002X^NH0Z;WV00L0Z;WV0P0000020:VJaP030000002[ZMD0ZjWE00T0ZjWE00@00000
0:V0Y`2YP:L000001P2cW<400`000000b9>N0<RCWP050<RCWP030000003oool0oooo00<0oooo0P00
000A0?ooo`030000003oool0oooo00X0oooo000l0?ooo`030000003oool0oooo03T0oooo00@00000
01XOV000000000000`0ZAKX00`000000P:K]082Vk@06082Vk@030000002S_>/0Xkc[00T0Xkc[0`00
000;0:O0j`8000001`2W`>/300000080Yl3[00<000000:O1k02W`N`02P2W`N`00`000000Yl3[0:O0
j`050:O0j`<000000P2W_n/00`000000Z;WU0:Rii@0:0:Rii@030000002X^NH0Z;WV00<0Z;WV0`00
00040:VJaP030000002[ZMD0ZjWE00P0ZjWE00D000000:V0Y`2YP:L0ZH2W000000060;>L`@030000
0038Tih0b9>N00D0b9>N00<000000?ooo`3oool00`3oool200000140oooo00<000000?ooo`3oool0
2P3oool003d0oooo00<000000?ooo`3oool0>03oool0100000006QnH00000000000402Y5^P030000
0020Y^d0P:K]00H0P:K]00<000000:>lj`2S_>/01@2S_>/300000080YKgZ00<000000:O0j`2W`>/0
2`2W`>/00`000000Yl3[0:O0j`04000000H0Yl3[00<000000:O1k02W`N`02P2W`N`00`000000Yl3[
0:O0j`04000000H0Yko[00<000000:Rii@2X^ND02P2X^ND00`000000Z;WV0:RiiP02000000P0ZI[6
00<000000:^Ye@2[ZMD01P2[ZMD00`000000ZH2W0:V0Y`030:V0Y`030000002cW<40/ic10080/ic1
00<000000<RCWP38Tih01P38Tih00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool02P3oool003h0oooo00<000000?ooo`3oool0=`3oool00`0000006QnH01XO
V002000000@0:TFj00<00000082Vk@20Y^d01P20Y^d00`000000Xkc[0:>lj`04000000H0YKgZ00<0
00000:O0j`2W`>/02P2W`>/3000000/0Yl3[00<000000:O1k02W`N`02@2W`N`3000000X0Yko[00<0
00000:Rii@2X^ND02P2X^ND3000000X0ZI[600<000000:^Ye@2[ZMD01@2[ZMD00`000000ZH2W0:V0
Y`040:V0Y`030000002cW<40/ic10080/ic100<000000<RCWP38Tih01P38Tih00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool003l0oooo0P00000g
0?ooo`030000000J7iP06QnH008000001@0ZAKX;000000/0YKgZ0P0000070:O0j`<000000P2W_n/0
0`000000Yl3[0:O0j`0:0:O0j`030000002W`N`0Yl7/00D0Yl7/0`0000020:K7l@030000002W_n/0
Yko[00T0Yko[00<000000:Rii@2X^ND01@2X^ND4000000030:JNcP000000ZI[600/0ZI[600<00000
0:^Ye@2[ZMD00`2[ZMD00`000000ZH2W0:V0Y`050:V0Y`030000002cW<40/ic10080/ic100<00000
0<RCWP38Tih01@38Tih00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02P3oool00440oooo00<000000?ooo`3oool0=03oool01@0000006QnH01XOV00J7iP0
000000H0:TFj00<00000092Vi02@Y^@01P2@Y^@00`000000YKgZ0:FmjP0;0:FmjP030000002W`>/0
Yl3[00@000001P2W_n/00`000000Yl3[0:O0j`0:0:O0j`030000002W`N`0Yl7/00@000001P2Vao40
0`000000Yko[0:Noj`090:Noj`030000002X^ND0Z;WU00@000001P2VW/h00`000000ZI[60:VJaP09
0:VJaP030000002[ZMD0ZjWE0080ZjWE00<000000:V0Y`2YP:L01`2YP:L01@000000/ic10;>L`@2c
W<40000000L0b9>N00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00X0oooo00120?ooo`030000003oool0oooo03@0oooo00<0000001XOV00J7iP00P000005
02Y5^P030000002@Y^@0T:KT00L0T:KT00<000000:FmjP2U_NX02P2U_NX3000000X0Yko[00<00000
0:O0j`2W`>/02P2W`>/3000000X0Y/Oa00<000000:Noj`2W_n/02@2W_n/3000000X0YYk>00<00000
0:VJaP2YV/H02P2YV/H010000000ZjWE0:^Ye@00000:0:V0Y`040000002cW<40/ic1000000P0b9>N
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo
00130?ooo`030000003oool0oooo03<0oooo00D0000001XOV00J7iP06QnH0000000602Y5^P030000
002@Y^@0T:KT00L0T:KT0P0000070:FmjP<000000P2W`>/00`000000Yko[0:Noj`090:Noj`030000
002W`>/0Yl3[00D0Yl3[100000020:O7l0030000002Vao40Y/Oa00T0Y/Oa00<000000:Noj`2W_n/0
1@2W_n/30000000309flkP000000YYk>00/0YYk>00<000000:VJaP2YV/H02@2YV/H00`000000ZjWE
0000000;0:V0Y`040000002cW<40/ic1000000P0b9>N00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00140?ooo`800000<`3oool01@0000006QnH
01XOV00J7iP0000000L0:TFj00<00000092Vi02@Y^@0202@Y^@00`000000YKgZ0:FmjP04000000H0
Yl3[00<000000:Noj`2W_n/02@2W_n/00`000000Yl3[0:O0j`04000000L0YlO`00<000000:K7l@2V
ao402@2Vao400`000000Yko[0:Noj`04000000D0WKc^00<000000:JNcP2VW/h02@2VW/h00`000000
ZI[60:VJaP0:0:VJaP030000002YP:L0ZH2W00/0ZH2W00<000000;>L`@0000002038Tih00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02@3oool004H0oooo
00<000000?ooo`3oool0<03oool00`0000006QnH01XOV00201XOV0030000000ZAKX0:TFj00D0:TFj
00<00000092Vi02@Y^@01`2@Y^@3000000/0Yl3[00<000000:Noj`2W_n/0202W_n/3000000`0YlO`
00<000000:K7l@2Vao401`2Vao44000000T0WKc^00<000000:JNcP2VW/h02@2VW/h00`000000ZI[6
0:VJaP080:VJaP<000003@2YP:L00`000000/ic1000000080<RCWP030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`00A`3oool00`000000oooo0?oo
o`0`0?ooo`040000000J7iP06QnH01XOV0<000001@0ZAKX00`000000T:KT092Vi004092Vi0<00000
0P2R^^X00`000000Yl3[0:O0j`0:0:O0j`030000002W_n/0Yko[00@0Yko[0`0000020:Rnj@030000
002Wao00YlO`00/0YlO`00@000000:K7l@2Vao40Y/Oa1@00000305oDk0030000002M_>h0WKc^00P0
WKc^00<000000:JNcP2VW/h02@2VW/h00`000000ZI[60:VJaP060:VJaP040000002WPZ/0Yh:[0000
00h0ZH2W00<000000<RCWP38Tih01`38Tih00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool02@3oool004P0oooo00<000000?ooo`3oool0;`3oool00`000000
6QnH01XOV00201XOV0030000001gQ=<0000000@0000000@0:TFj0000002@Y^@0T:KT0`0000060::j
jP030000002W`>/0Yl3[00X0Yl3[00<000000:Noj`2W_n/00`0000060:Rnj@030000002Wao00YlO`
00X0YlO`2000000505oDk0030000002M_>h0WKc^00L0WKc^00<000000:JNcP2VW/h02@2VW/h00`00
0000ZI[60:VJaP050:VJaP030000002WPZ/0Yh:[0080Yh:[00<000000:V0Y`2YP:L02`2YP:L00`00
0000b9>N0<RCWP070<RCWP030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`090?ooo`00B@3oool2000002l0oooo00<0000001XOV00J7iP00P0J7iP00`000000
MhCC07N4d`0407N4d`@000002P2R^^X00`000000Yl3[0:O0j`090:O0j`<000002P2X_^T2000000L0
YlO`1`0000040?ooo`<000000`1Oe>`00`000000WKc^09flkP0709flkP030000002VW/h0YYk>00T0
YYk>00<000000:VJaP2YV/H00P2YV/H2000000D0Yh:[00<000000:V0Y`2YP:L02`2YP:L00`000000
b9>N0<RCWP070<RCWP030000003oool0oooo00d0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`090?ooo`00B`3oool00`000000oooo0?ooo`0/0?ooo`030000000J7iP06QnH00<06QnH
00<0000007N4d`1gQ=<01P1gQ=<00`000000X[[Z0::jjP090::jjP030000002W`>/0Yl3[00D0Yl3[
0`0000020:Ngi0030000002X_^T0Z;kY00X0Z;kY00<000000:O7l02Wao001P00000<0?ooo`D00000
202M_>h00`000000YYk>0:JNcP090:JNcP050000002YV/H0ZI[60:VJaP0000001`2WPZ/00`000000
ZH2W0:V0Y`0:0:V0Y`8000002@38Tih00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool004`0oooo00<000000?ooo`3oool0:`3oool00`0000006QnH
01XOV00301XOV0030000001gQ=<0MhCC00L0MhCC00<000000::jjP2R^^X02@2R^^X00`000000Yl3[
0:O0j`04000000H0YkOT00<000000:Rnj@2X_^T02@2X_^T6000001<0oooo0`00000709flkP030000
002VW/h0YYk>00T0YYk>0`0000080:N2Z`030000002YP:L0ZH2W00X0ZH2W00<000000?78YP000000
1`38Tih00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool004d0oooo00<000000?ooo`3oool0:`3oool00`0000006QnH01XOV00301XOV0030000001g
Q=<0MhCC00H0MhCC00<000000::jjP2R^^X02@2R^^X3000000X0YkOT00<000000:Rnj@2X_^T01`2X
_^T2000000<0[>Cj00<000000?ooo`3oool05@3oool4000000@0WKc^00<000000:JNcP2VW/h01`2V
W/h3000000X0Yh:[00<000000:V0Y`2YP:L02P2YP:L00`000000lLRV000000070<RCWP030000003o
ool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`00CP3oool2
000002/0oooo00<0000001XOV00J7iP00`0J7iP00`000000MhCC07N4d`0707N4d`030000002R^^X0
X[[Z00D0X[[Z0`0000020:Nmj@030000002W]n@0YkOT00T0YkOT00<000000:Rnj@2X_^T00`2X_^T3
000000@0[>Cj00<000000?ooo`3oool05`3oool00`000000B9?`04RCl0040000000409flkP000000
YYk>0:JNcPH000000P2HMj`00`000000Yh:[0:N2Z`090:N2Z`030000002YP:L0ZH2W00P0ZH2W00@0
00000?78YP3ab:H000001`38Tih00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool00500oooo00<000000?ooo`3oool0:03oool2000000D06QnH00<0
000007N4d`1gQ=<01`1gQ=<00`000000X[[Z0::jjP04000000H0YkgY00<000000:Ngi02W]n@02@2W
]n@00`000000Z;kY0:Rnj@02000000D0[>Cj0P00000K0?ooo`0300000018To00B9?`00<0B9?`1000
000809Qg[0030000002WPZ/0Yh:[00T0Yh:[00<000000:V0Y`2YP:L0202YP:L010000000lLRV0?78
YP0000070<RCWP030000003oool0oooo0140oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`080?ooo`00D@3oool00`000000oooo0?ooo`0W0?ooo`040000001^N/l00000000000<06QnH
00<0000007N4d`1gQ=<01`1gQ=<3000000X0YkgY00<000000:Ngi02W]n@02@2W]n@3000000H0[>Cj
00<000000?ooo`3oool0703oool00`000000B9?`04RCl00304RCl0030000002HMj`0V7N/00T0V7N/
00<000000:N2Z`2WPZ/0202WPZ/00`000000ZH2W0:V0Y`080:V0Y`050000003ab:H0lLRV0?78YP00
00001P38Tih00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00580oooo00<000000?ooo`3oool09`3oool00`000000KW[?06ijc`02000000806QnH
00<0000007N4d`1gQ=<00`1gQ=<300000080Y/Sb00<000000:Nmj@2W_NT02@2W_NT00`000000YkOT
0:Ngi0050:Ngi0<000000`2[Z]H200000080[>Cj0P00000P0?ooo`0300000018To00B9?`0080B9?`
00<0000009Qg[02HMj`02@2HMj`00`000000Yh:[0:N2Z`080:N2Z`030000002YP:L0ZH2W00L0ZH2W
00<000000?78YP3ab:H00P3ab:H00`000000b9>N0<RCWP040<RCWP030000003oool0oooo01<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`080?ooo`00D`3oool2000002L0oooo00<0
000006ijc`1^N/l00P1^N/l300000080MhCC0`0000060:K8lP030000002W_NT0YkgY00T0YkgY00<0
00000:Ngi02W]n@0100000080:^ZeP8000008P3oool00`000000B9?`04RCl00304RCl0030000002H
Mj`0V7N/00P0V7N/00<000000:N2Z`2WPZ/0202WPZ/00`000000ZH2W0:V0Y`070:V0Y`030000003a
b:H0lLRV0080lLRV00<000000<RCWP38Tih01038Tih00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0203oool005D0oooo00<000000?ooo`3oool09@3oool0
0`000000KW[?06ijc`0306ijc`<000002P2Vb?82000000P0YkgY1000000<0:^ZeP030000003oool0
oooo0280oooo00<0000004RCl018To000P18To000`000000V7N/09Qg[00809Qg[0030000002WPZ/0
Yh:[00T0Yh:[00<000000:V0Y`2YP:L01P2YP:L00`000000lLRV0?78YP020?78YP0300000038Tih0
b9>N00@0b9>N00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo001F0?ooo`030000003oool0oooo02@0oooo00<0000006ijc`1^N/l01@1^N/l20000
00/0Y/Sb00@000000:Nmj@2W_NT0YkgY1000000309jAaP030000002[Z]H0Zj[F00T0Zj[F0P00000T
0?ooo`0300000018To00B9?`0080B9?`00<0000009Qg[02HMj`02@2HMj`00`000000Yh:[0:N2Z`08
0:N2Z`030000002YP:L0ZH2W00D0ZH2W00<000000?78YP3ab:H0103ab:H00`000000b9>N0<RCWP03
0<RCWP030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`07
0?ooo`00E`3oool00`000000oooo0?ooo`0S0?ooo`030000001^N/l0KW[?00L0KW[?00<000000:K8
lP2Vb?801`2Vb?85000000L0WY7600<000000:^ZeP2[Z]H0202[Z]H3000002D0oooo00D0000004RC
l018To00B9?`0000000;09Qg[0030000002WPZ/0Yh:[00P0Yh:[00<000000:V0Y`2YP:L01@2YP:L0
0`000000lLRV0?78YP040?78YP0300000038Tih0b9>N00<0b9>N00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo001H0?ooo`030000003oool0oooo
02<0oooo00<0000006ijc`1^N/l01`1^N/l2000000<0Y/Sb1000000209fLdP030000002NTLH0WY76
00P0WY7600<000000:^ZeP2[Z]H01P2[Z]H010000000dooC00000000000U0?ooo`0300000018To00
B9?`0080B9?`00<0000009Qg[02HMj`0202HMj`00`000000Yh:[0:N2Z`080:N2Z`030000002YP:L0
ZH2W00D0ZH2W00<000000?78YP3ab:H0103ab:H00`000000b9>N0<RCWP030<RCWP030000003oool0
oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`00F@3oool20000
02<0oooo00<0000006ijc`1^N/l0201^N/l4000000L0WIcB00<0000009jAaP2NTLH0202NTLH00`00
0000Zj[F0:^ZeP040:^ZeP040000003Com<00000000002L0oooo00D0000004RCl018To00B9?`0000
000:09Qg[0030000002WPZ/0Yh:[00P0Yh:[00<000000:V0Y`2YP:L0102YP:L00`000000lLRV0?78
YP050?78YP0300000038Tih0b9>N0080b9>N00<000000?ooo`3oool0603oool01@000000oooo0?oo
o`3oool0000000T0oooo001K0?ooo`030000003oool0oooo0240oooo00<0000006ijc`1^N/l01@1^
N/l200000080Vnkf00<0000009fLdP2MW=801P2MW=800`000000WY7609jAaP0909jAaP030000002[
Z]H0Zj[F0080Zj[F00<000000=?od`3Com<00P00000W0?ooo`0500000018To00B9?`04RCl0000000
2`2HMj`00`000000Yh:[0:N2Z`080:N2Z`030000002YP:L0ZH2W00<0ZH2W00<000000?78YP3ab:H0
1P3ab:H01@000000b9>N0<RCWP38Tih0000001/0oooo00@000000?ooo`3oool000002@3oool005`0
oooo00<000000?ooo`3oool0803oool00`000000KW[?06ijc`0206ijc`<00000102Kk_H00`000000
WIcB09fLdP0709fLdP030000002NTLH0WY7600P0WY7600D000000:^ZeP2[Z]H0Zj[F000000020=?o
d`030000003`aZH0000002P0oooo00@0000004RCl018To0000002`2HMj`00`000000Yh:[0:N2Z`08
0:N2Z`030000002YP:L0ZH2W00<0ZH2W00<000000?78YP3ab:H01P3ab:H01@000000b9>N0<RCWP38
Tih0000001/0oooo00@000000?ooo`3oool000002@3oool005d0oooo00<000000?ooo`3oool0803o
ool010000000KW[?00000000000809_^mP030000002MW=80WIcB00H0WIcB00<0000009jAaP2NTLH0
2@2NTLH010000000Zj[F0000003Com<3000000030?36YP000000oooo02L0oooo00D0000004RCl018
To00B9?`0000000:09Qg[0030000002WPZ/0Yh:[00P0Yh:[00<000000:V0Y`2YP:L00P2YP:L00`00
0000lLRV0?78YP070?78YP0500000038Tih0b9>N0<RCWP000000703oool00`000000oooo00000009
0?ooo`00GP3oool200000200oooo1`00000509_^mP030000002MW=80WIcB00H0WIcB00<0000009jA
aP2NTLH02P2NTLH300000080YX:]00<000000?36YP000000:@3oool010000000B9?`04RCl000000:
09Qg[0030000002WPZ/0Yh:[00P0Yh:[00<000000:V0Y`2YP:L00P2YP:L00`000000lLRV0?78YP07
0?78YP0500000038Tih0b9>N0<RCWP0000007@3oool00`000000oooo000000080?ooo`00H03oool0
0`000000oooo0?ooo`0S0?ooo`<00000102Kk_H00`000000WIcB09fLdP0609fLdP030000002NTLH0
WY7600L0WY760P0000040:J2[@040000003`aZH0l<JV000002T0oooo00@0000004RCl018To000000
2P2HMj`00`000000Yh:[0:N2Z`080:N2Z`030000002YP:L0ZH2W0080ZH2W00<000000?78YP3ab:H0
203ab:H010000000b9>N0<RCWP00000N0?ooo`800000203oool00640oooo00<000000?ooo`3oool0
8P3oool00`000000Pf:T08=RY00200000080Vnkf00<0000009fLdP2MW=801P2MW=800`000000WY76
09jAaP0509jAaP8000001P2VPZd00`000000l<JV0000000Z0?ooo`0400000018To00B9?`000000/0
V7N/00<000000:N2Z`2WPZ/0202WPZ/010000000ZH2W0:V0Y`00000;0?78YP0400000038Tih0b9>N
000001h0oooo0P0000080?ooo`00HP3oool00`000000oooo0?ooo`0Q0?ooo`0300000023HZ@0Pf:T
0080Pf:T0P0000000`2Kk_H0000009fLdP0709fLdP030000002NTLH0WY7600<0WY7600<000000:J2
[@2VPZd01P2VPZd00`000000l<JV0000000[0?ooo`0300000018To00000000/0V7N/00<000000:N2
Z`2WPZ/0202WPZ/010000000ZH2W0:V0Y`00000;0?78YP0400000038Tih0b9>N000001h0oooo0P00
00080?ooo`00H`3oool200000280oooo00<0000008=RY023HZ@00`23HZ@2000000P0WIcB00@00000
09jAaP2NTLH0WY760P0000080:J2[@040000003`aZH0l<JV000002/0oooo00@0000004RCl018To00
00002P2HMj`00`000000Yh:[0:N2Z`080:N2Z`040000002YP:L0ZH2W000000/0lLRV00@000000<RC
WP38Tih000006P3oool4000000X0oooo001U0?ooo`030000003oool0oooo01l0oooo00<0000008=R
Y023HZ@01@23HZ@5000000@0WIcB0`00000:0:J2[@040000003`aZH0l<JV000002`0oooo00<00000
04RCl00000002P2HMj`00`000000Yh:[0:N2Z`080:N2Z`030000002YP:L0000000d0lLRV00<00000
0<RCWP0000005P3oool4000000h0oooo001V0?ooo`030000003oool0oooo01h0oooo00<0000008=R
Y023HZ@01@23HZ@00`000000SfnY08m_Z@0208m_Z@D00000302VPZd010000000l<JV0?36YP00000/
0?ooo`0300000018To00000000/0V7N/00<000000:N2Z`2WPZ/01`2WPZ/00`000000ZH2W0000000=
0?78YP8000004`3oool400000180oooo001W0?ooo`030000003oool0oooo01d0oooo00<0000008=R
Y023HZ@01@23HZ@00`000000SfnY08m_Z@0608m_Z@030000002VPZd0YX:]00T0YX:]00@000000?36
YP3`aZH00000;P3oool2000000/0V7N/00<000000:N2Z`2WPZ/0202WPZ/2000000d0lLRV0P00000?
0?ooo`@000005P3oool006P0oooo0P00000M0?ooo`0300000023HZ@0Pf:T00H0Pf:T00<0000008m_
Z@2?KjT01@2?KjT00`000000YX:]0:J2[@090:J2[@040000003`aZH0l<JV000002h0oooo00<00000
04RCl00000002P2HMj`00`000000Yh:[0:N2Z`080:N2Z`030000003ab:H0lLRV00`0lLRV0P00000;
0?ooo`@000006P3oool006X0oooo00<000000?ooo`3oool06P3oool00`000000Pf:T08=RY00608=R
Y0030000002?KjT0SfnY00H0SfnY00<000000:J2[@2VPZd0202VPZd010000000l<JV0?36YP00000_
0?ooo`8000002P2HMj`00`000000Yh:[0:N2Z`070:N2Z`8000003`3ab:H00`000000oooo0?ooo`05
0?ooo`@000007P3oool006/0oooo00<000000?ooo`3oool06P3oool00`000000Pf:T08=RY00508=R
Y0030000002?KjT0SfnY00H0SfnY00<000000:J2[@2VPZd01`2VPZd01@000000l<JV0?36YP3`aZH0
000002l0oooo0P00000;09Qg[0030000002WPZ/0Yh:[00<0Yh:[0`0000020:G3k`030000003ab:H0
lLRV00`0lLRV00<000000?ooo`3oool00P3oool300000280oooo001/0?ooo`030000003oool0oooo
01T0oooo00<0000008=RY023HZ@01@23HZ@00`000000SfnY08m_Z@0608m_Z@030000002VPZd0YX:]
00L0YX:]00D000000?36YP3`aZH0l<JV0000000`0?ooo`030000002HMj`0V7N/00T0V7N/00<00000
0:N2Z`0000000`0000060:G3k`030000003ab:H0lLRV00X0lLRV1P00000U0?ooo`00K@3oool00`00
0000oooo0?ooo`0H0?ooo`0300000023HZ@0Pf:T00D0Pf:T00<0000008m_Z@2?KjT01P2?KjT00`00
0000YX:]0:J2[@070:J2[@050000003`aZH0l<JV0?36YP000000<03oool2000000P0V7N/1000000;
0:G3k`030000003ab:H0lLRV00D0lLRV1P00000Y0?ooo`00KP3oool2000001P0oooo00<0000008=R
Y023HZ@01@23HZ@00`000000SfnY08m_Z@0608m_Z@030000002VPZd0YX:]00H0YX:]00D000000?36
YP3`aZH0l<JV0000000b0?ooo`030000002HMj`0V7N/00H000000`2Q_Nd00`000000YL?_0:G3k`0:
0:G3k`030000003ab:H0lLRV00H00000;@3oool00700oooo00<000000?ooo`3oool05@3oool00`00
0000Pf:T08=RY00608=RY0030000002?KjT0SfnY00H0SfnY00<000000:J2[@2VPZd01@2VPZd01@00
0000l<JV0?36YP3`aZH000000380oooo0`00000:0:6mk@030000002U`nl0YL?_00T0YL?_1@00000a
0?ooo`00L@3oool00`000000oooo0?ooo`0D0?ooo`0300000023HZ@0Pf:T00H0Pf:T00<0000008m_
Z@2?KjT01P2?KjT00`000000YX:]0:J2[@050:J2[@050000003`aZH0l<JV0?36YP000000<`3oool0
0`000000XKg]0:6mk@090:6mk@030000002U`nl0YL?_00D0YL?_1@00000e0?ooo`00LP3oool00`00
0000oooo0?ooo`0C0?ooo`0300000023HZ@0Pf:T00H0Pf:T00<0000008m_Z@2?KjT01P2?KjT00`00
0000YX:]0:J2[@050:J2[@050000003`aZH0l<JV0?36YP000000=03oool00`000000XKg]0:6mk@09
0:6mk@030000002U`nl0YL?_00D00000>@3oool007<0oooo0P00000D0?ooo`0300000023HZ@0Pf:T
00D0Pf:T00<0000008m_Z@2?KjT01P2?KjT00`000000YX:]0:J2[@040:J2[@030000003`aZH0l<JV
0080l<JV00<000000?ooo`3oool0<P3oool00`000000XKg]0:6mk@090:6mk@@00000?@3oool007D0
oooo00<000000?ooo`3oool04@3oool00`000000Pf:T08=RY00508=RY0030000002?KjT0SfnY00H0
SfnY00<000000:J2[@2VPZd0102VPZd00`000000l<JV0?36YP020?36YP030000003oool0oooo03<0
oooo00<000000:6mk@2Q_Nd01@2Q_Nd300000440oooo001f0?ooo`030000003oool0oooo0100oooo
00<0000008=RY023HZ@01@23HZ@00`000000SfnY08m_Z@0708m_Z@030000002VPZd0YX:]00<0YX:]
00D000000?36YP3`aZH0l<JV0000000g0?ooo`030000002Q_Nd0XKg]00@00000A03oool007L0oooo
00<000000?ooo`3oool03`3oool00`000000Pf:T08=RY00608=RY0030000002?KjT0SfnY00H0SfnY
00<000000:J2[@2VPZd00P2VPZd00`000000l<JV0?36YP020?36YP030000003oool0oooo03@0oooo
100000180?ooo`00N03oool2000000l0oooo00<0000008=RY023HZ@01P23HZ@00`000000SfnY08m_
Z@0608m_Z@030000002VPZd0YX:]0080YX:]00<000000?36YP3`aZH00P3`aZH00`000000oooo0?oo
o`0`0?ooo`@00000C03oool007X0oooo00<000000?ooo`3oool0303oool00`000000Pf:T08=RY006
08=RY0030000002?KjT0SfnY00H0SfnY00<000000:J2[@2VPZd00P2VPZd00`000000l<JV0?36YP02
0?36YP030000003oool0oooo02`0oooo1000001@0?ooo`00N`3oool00`000000oooo0?ooo`0;0?oo
o`0300000023HZ@0Pf:T00H0Pf:T00<0000008m_Z@2?KjT01`2?KjT010000000YX:]0:J2[@000005
0?36YP030000003oool0oooo02P0oooo1000001D0?ooo`00O03oool00`000000oooo0?ooo`0;0?oo
o`0300000023HZ@0Pf:T00D0Pf:T00<0000008m_Z@2?KjT01`2?KjT010000000YX:]0:J2[@000004
0?36YP030000003oool0oooo02D0oooo1000001H0?ooo`00O@3oool2000000/0oooo00<0000008=R
Y023HZ@01P23HZ@00`000000SfnY08m_Z@0608m_Z@040000002VPZd0YX:]000000@0l<JV00<00000
0?ooo`3oool08P3oool3000005`0oooo001o0?ooo`030000003oool0oooo00P0oooo00<0000008=R
Y023HZ@01P23HZ@00`000000SfnY08m_Z@0608m_Z@030000002VPZd0000000D0l<JV00<000000?oo
o`3oool07P3oool4000005l0oooo00200?ooo`030000003oool0oooo00L0oooo00<0000008=RY023
HZ@01P23HZ@00`000000SfnY08m_Z@0608m_Z@030000002VPZd0000000D0l<JV00<000000?ooo`3o
ool06P3oool4000006<0oooo00210?ooo`030000003oool0oooo00H0oooo00<0000008=RY023HZ@0
1P23HZ@00`000000SfnY08m_Z@0708m_Z@8000001@3`aZH00`000000oooo0?ooo`0F0?ooo`@00000
I`3oool00880oooo0P0000060?ooo`0300000023HZ@0Pf:T00H0Pf:T00<0000008m_Z@2?KjT01`2?
KjT00`000000l<JV0?36YP040?36YP030000003oool0oooo0180oooo1000001[0?ooo`00Q03oool0
0`000000oooo0?ooo`040?ooo`0300000023HZ@0Pf:T00D0Pf:T00<0000008m_Z@2?KjT01P2?KjT3
000000@0l<JV00<000000?ooo`3oool03`3oool4000006l0oooo00250?ooo`030000003oool0oooo
00<0oooo00<0000008=RY023HZ@01P23HZ@00`000000SfnY08m_Z@0208m_Z@<000000`2^aN/30000
00030?36YP000000oooo00`0oooo1000001c0?ooo`00QP3oool00`000000oooo0?ooo`020?ooo`03
00000023HZ@0Pf:T00H0Pf:T00<0000008m_Z@0000000P0000090:k5j`8000002@3oool4000007L0
oooo00270?ooo`040000003oool0oooo0?ooo`/000002`2^aN/2000000L0oooo0`00001k0?ooo`00
R03oool200000080oooo00<0000008jVi@2>Y^D01P2>Y^D00`000000[/G[0:k5j`070:k5j`800000
1@3oool4000007h0oooo002:0?ooo`030000003oool0000000T0SZKU00<000000:k5j`2^aN/01@2^
aN/010000000oooo0?ooo`3oool400000880oooo002;0?ooo`030000003oool0000000T0SZKU00<0
00000:k5j`2^aN/00P2^aN/6000008H0oooo002<0?ooo`030000003oool0000000T0SZKU00<00000
0:k5j`0000000`00002:0?ooo`00S@3oool3000000L0SZKU0`00002>0?ooo`00S`3oool010000000
SZKU08jVi@2>Y^D400000940oooo002@0?ooo`<00000U@3oool00?l0oooo:@3oool00?l0oooo:@3o
ool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3o
ool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3o
ool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3o
ool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3oool00?l0oooo:@3o
ool00?l0oooo:@3oool00001\
\>"],
  ImageRangeCache->{{{0, 295.625}, {239.625, 0}} -> {-0.200976, -0.0295752, \
0.00501465, 0.00501465}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[73]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results in point ",
  Cell[BoxData[
      \(x = \[Pi]\/16\)]],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {x \[Rule] Pi/16}, {\[Xi], 1/10, 
        1}, {h, \(-Pi\)/8, Pi/8}]\)], "Input",
  CellLabel->"In[74]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.21268e-016 1.04977 -0.0679587 1.04977 [
[.09267 .22056 -18 -8.89284 ]
[.09267 .22056 0 .10716 ]
[.22808 .16727 -17.3856 -9 ]
[.22808 .16727 .61442 0 ]
[.37094 .11108 -16.5516 -9 ]
[.37094 .11108 1.44839 0 ]
[.52186 .05175 -15.7176 -9 ]
[.52186 .05175 2.28236 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.78169 .11883 0 -6.14072 ]
[.78169 .11883 24 2.85928 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.92356 .33608 0 -5.93551 ]
[.92356 .33608 18 3.06449 ]
[.01844 .30069 -43.5 -3.85053 ]
[.01844 .30069 0 8.64947 ]
[.00945 .35699 -6 -2.8201 ]
[.00945 .35699 0 6.1799 ]
[.00014 .41537 -37.5 -3.98578 ]
[.00014 .41537 0 8.51422 ]
[-0.00952 .47594 -37.5 -4.05761 ]
[-0.00952 .47594 0 8.44239 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10206 .22973 m
.10675 .23431 L
s
[(0.2)] .09267 .22056 1 .97619 Mshowa
.23703 .17687 m
.2415 .18167 L
s
[(0.4)] .22808 .16727 .93173 1 Mshowa
.37937 .12114 m
.38359 .12616 L
s
[(0.6)] .37094 .11108 .83907 1 Mshowa
.52971 .06227 m
.53364 .06753 L
s
[(0.8)] .52186 .05175 .7464 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.13514 .21677 m
.13793 .21955 L
s
.16866 .20365 m
.17141 .20646 L
s
.20262 .19035 m
.20534 .1932 L
s
.2719 .16322 m
.27455 .16613 L
s
.30724 .14938 m
.30985 .15233 L
s
.34306 .13535 m
.34564 .13834 L
s
.41618 .10672 m
.41867 .10977 L
s
.4535 .09211 m
.45595 .0952 L
s
.49134 .07729 m
.49374 .08041 L
s
.56863 .04703 m
.57093 .05022 L
s
.60809 .03158 m
.61035 .0348 L
s
.64813 .0159 m
.65033 .01916 L
s
.0694 .24251 m
.07225 .24523 L
s
.03716 .25514 m
.04004 .25782 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.76936 .12333 m
.7632 .12558 L
s
[(-0.2)] .78169 .11883 -1 .3646 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.91106 .34007 m
.90481 .34207 L
s
[(0.2)] .92356 .33608 -1 .319 Mshowa
.125 Mabswid
.70741 .02856 m
.70374 .02998 L
s
.72867 .06109 m
.72499 .06248 L
s
.74932 .09266 m
.74563 .09403 L
s
.78884 .15312 m
.78513 .15445 L
s
.80777 .18207 m
.80405 .18338 L
s
.82617 .21023 m
.82245 .21152 L
s
.8615 .26426 m
.85776 .26551 L
s
.87846 .2902 m
.87472 .29144 L
s
.89497 .31547 m
.89122 .31668 L
s
.92673 .36405 m
.92298 .36523 L
s
.94201 .38743 m
.93825 .38859 L
s
.95691 .41022 m
.95315 .41137 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03069 .29598 m
.03681 .29363 L
s
gsave
.01844 .30069 -43.5 -1.85053 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.02175 .3524 m
.02789 .35011 L
s
[(0)] .00945 .35699 1 -0.37331 Mshowa
.01248 .4109 m
.01864 .40867 L
s
gsave
.00014 .41537 -37.5 -1.98578 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.00286 .4716 m
.00905 .46942 L
s
gsave
-0.00952 .47594 -37.5 -2.05761 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.125 Mabswid
.02892 .30711 m
.0326 .3057 L
s
.02715 .31831 m
.03083 .31691 L
s
.02536 .32959 m
.02904 .3282 L
s
.02356 .34096 m
.02725 .33957 L
s
.01992 .36393 m
.02361 .36256 L
s
.01808 .37555 m
.02177 .37418 L
s
.01622 .38725 m
.01992 .38589 L
s
.01436 .39903 m
.01806 .39768 L
s
.01058 .42286 m
.01428 .42153 L
s
.00867 .43491 m
.01238 .43358 L
s
.00675 .44705 m
.01046 .44573 L
s
.00481 .45927 m
.00852 .45796 L
s
.03244 .28494 m
.03611 .28352 L
s
.03417 .27397 m
.03785 .27255 L
s
.0359 .26309 m
.03957 .26165 L
s
.00089 .48401 m
.00461 .48271 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.658 .751 .919 r
.37961 .66772 .40219 .6875 .43986 .67602 .4176 .65659 Metetra
.661 .758 .922 r
.4176 .65659 .43986 .67602 .47807 .66263 .45613 .64504 Metetra
.664 .78 .936 r
.45613 .64504 .47807 .66263 .51677 .6458 .49522 .63283 Metetra
.662 .834 .966 r
.49522 .63283 .51677 .6458 .55585 .62336 .53484 .61954 Metetra
.595 .917 .974 r
.53484 .61954 .55585 .62336 .59506 .59283 .57499 .60484 Metetra
.57499 .60484 .59506 .59283 .63404 .55133 .6156 .58816 Metetra
.305 0 .138 r
.6156 .58816 .63404 .55133 .67327 .51832 .65661 .56887 Metetra
.366 .03 .256 r
.65661 .56887 .67327 .51832 .71375 .50614 .69789 .54639 Metetra
.265 0 .155 r
.69789 .54639 .71375 .50614 .75481 .49379 .7393 .51999 Metetra
.7393 .51999 .75481 .49379 .79647 .48125 .78062 .48882 Metetra
.67 .956 .723 r
.78062 .48882 .79647 .48125 .83874 .46853 .82161 .45213 Metetra
.73 .839 .932 r
.82161 .45213 .83874 .46853 .88163 .45563 .86428 .4313 Metetra
.664 .741 .907 r
.86428 .4313 .88163 .45563 .92516 .44253 .90828 .41783 Metetra
.664 .741 .907 r
.90828 .41783 .92516 .44253 .96935 .42924 .95296 .40417 Metetra
.657 .75 .919 r
.35643 .64731 .37961 .66772 .4176 .65659 .39475 .63605 Metetra
.656 .751 .92 r
.39475 .63605 .4176 .65659 .45613 .64504 .43363 .62468 Metetra
.654 .755 .924 r
.43363 .62468 .45613 .64504 .49522 .63283 .47307 .61327 Metetra
.652 .765 .932 r
.47307 .61327 .49522 .63283 .53484 .61954 .5131 .6018 Metetra
.644 .785 .949 r
.5131 .6018 .53484 .61954 .57499 .60484 .55373 .59049 Metetra
.627 .82 .975 r
.55373 .59049 .57499 .60484 .6156 .58816 .59499 .57931 Metetra
.569 .867 .996 r
.59499 .57931 .6156 .58816 .65661 .56887 .6369 .5684 Metetra
.355 .827 .88 r
.6369 .5684 .65661 .56887 .69789 .54639 .67952 .55797 Metetra
.08 0 0 r
.67952 .55797 .69789 .54639 .7393 .51999 .72289 .54811 Metetra
.356 0 .068 r
.72289 .54811 .7393 .51999 .78062 .48882 .76706 .53899 Metetra
.464 .11 .279 r
.76706 .53899 .78062 .48882 .82161 .45213 .81211 .53082 Metetra
.511 .203 .381 r
.81211 .53082 .82161 .45213 .86428 .4313 .85814 .52382 Metetra
.525 .23 .408 r
.85814 .52382 .86428 .4313 .90828 .41783 .90525 .51825 Metetra
.533 .243 .42 r
.90525 .51825 .90828 .41783 .95296 .40417 .95357 .51436 Metetra
.657 .75 .919 r
.33264 .62636 .35643 .64731 .39475 .63605 .3713 .61477 Metetra
.657 .75 .918 r
.3713 .61477 .39475 .63605 .43363 .62468 .41054 .60299 Metetra
.657 .749 .918 r
.41054 .60299 .43363 .62468 .47307 .61327 .45035 .59105 Metetra
.657 .747 .916 r
.45035 .59105 .47307 .61327 .5131 .6018 .49075 .57891 Metetra
.657 .744 .914 r
.49075 .57891 .5131 .6018 .55373 .59049 .53176 .56661 Metetra
.658 .738 .909 r
.53176 .56661 .55373 .59049 .59499 .57931 .5734 .55411 Metetra
.658 .73 .903 r
.5734 .55411 .59499 .57931 .6369 .5684 .61566 .54136 Metetra
.658 .718 .893 r
.61566 .54136 .6369 .5684 .67952 .55797 .65857 .52845 Metetra
.658 .703 .88 r
.65857 .52845 .67952 .55797 .72289 .54811 .70214 .51526 Metetra
.657 .682 .862 r
.70214 .51526 .72289 .54811 .76706 .53899 .74639 .50187 Metetra
.654 .658 .842 r
.74639 .50187 .76706 .53899 .81211 .53082 .79132 .4882 Metetra
.65 .631 .818 r
.79132 .4882 .81211 .53082 .85814 .52382 .83696 .47429 Metetra
.645 .603 .792 r
.83696 .47429 .85814 .52382 .90525 .51825 .88331 .46011 Metetra
.639 .574 .766 r
.88331 .46011 .90525 .51825 .95357 .51436 .93039 .4456 Metetra
.657 .75 .919 r
.3082 .60482 .33264 .62636 .3713 .61477 .34721 .59294 Metetra
.656 .75 .919 r
.34721 .59294 .3713 .61477 .41054 .60299 .3868 .58098 Metetra
.654 .751 .921 r
.3868 .58098 .41054 .60299 .45035 .59105 .42698 .56897 Metetra
.652 .752 .923 r
.42698 .56897 .45035 .59105 .49075 .57891 .46777 .55697 Metetra
.648 .755 .928 r
.46777 .55697 .49075 .57891 .53176 .56661 .50919 .54516 Metetra
.642 .761 .935 r
.50919 .54516 .53176 .56661 .5734 .55411 .55127 .53364 Metetra
.633 .771 .946 r
.55127 .53364 .5734 .55411 .61566 .54136 .59404 .52254 Metetra
.617 .786 .962 r
.59404 .52254 .61566 .54136 .65857 .52845 .63756 .51209 Metetra
.59 .806 .982 r
.63756 .51209 .65857 .52845 .70214 .51526 .68189 .50248 Metetra
.535 .827 .999 r
.68189 .50248 .70214 .51526 .74639 .50187 .72711 .49398 Metetra
.421 .825 .979 r
.72711 .49398 .74639 .50187 .79132 .4882 .7733 .48683 Metetra
.192 .722 .825 r
.7733 .48683 .79132 .4882 .83696 .47429 .82059 .48133 Metetra
.116 0 0 r
.82059 .48133 .83696 .47429 .88331 .46011 .86913 .47787 Metetra
.341 0 0 r
.86913 .47787 .88331 .46011 .93039 .4456 .9191 .47681 Metetra
.655 .75 .919 r
.28309 .58273 .3082 .60482 .34721 .59294 .32244 .57065 Metetra
.651 .75 .922 r
.32244 .57065 .34721 .59294 .3868 .58098 .36237 .55879 Metetra
.643 .752 .928 r
.36237 .55879 .3868 .58098 .42698 .56897 .4029 .54748 Metetra
.628 .757 .939 r
.4029 .54748 .42698 .56897 .46777 .55697 .44405 .53719 Metetra
.6 .767 .96 r
.44405 .53719 .46777 .55697 .50919 .54516 .48588 .52856 Metetra
.542 .783 .987 r
.48588 .52856 .50919 .54516 .55127 .53364 .52847 .52227 Metetra
.403 .78 .992 r
.52847 .52227 .55127 .53364 .59404 .52254 .57196 .51923 Metetra
.061 .62 .8 r
.57196 .51923 .59404 .52254 .63756 .51209 .61654 .52052 Metetra
.356 0 0 r
.61654 .52052 .63756 .51209 .68189 .50248 .66247 .52745 Metetra
.542 .072 .089 r
.66247 .52745 .68189 .50248 .72711 .49398 .71011 .54148 Metetra
.603 .211 .273 r
.71011 .54148 .72711 .49398 .7733 .48683 .75996 .56451 Metetra
.487 .159 .336 r
.75996 .56451 .7733 .48683 .82059 .48133 .80917 .5574 Metetra
.455 .129 .323 r
.80917 .5574 .82059 .48133 .86913 .47787 .85873 .54317 Metetra
.437 .095 .286 r
.85873 .54317 .86913 .47787 .9191 .47681 .90916 .52869 Metetra
.654 .749 .92 r
.25728 .56 .28309 .58273 .32244 .57065 .29698 .54775 Metetra
.646 .749 .924 r
.29698 .54775 .32244 .57065 .36237 .55879 .33725 .53606 Metetra
.629 .749 .933 r
.33725 .53606 .36237 .55879 .4029 .54748 .3781 .52563 Metetra
.599 .75 .95 r
.3781 .52563 .4029 .54748 .44405 .53719 .41958 .51735 Metetra
.537 .751 .975 r
.41958 .51735 .44405 .53719 .48588 .52856 .46177 .51243 Metetra
.4 .732 .991 r
.46177 .51243 .48588 .52856 .52847 .52227 .50481 .5124 Metetra
.077 .597 .879 r
.50481 .5124 .52847 .52227 .57196 .51923 .54895 .51897 Metetra
.389 0 0 r
.54895 .51897 .57196 .51923 .61654 .52052 .59454 .53449 Metetra
.621 .111 .014 r
.59454 .53449 .61654 .52052 .66247 .52745 .6421 .56175 Metetra
.419 0 .094 r
.6421 .56175 .66247 .52745 .71011 .54148 .69018 .55956 Metetra
.096 0 0 r
.69018 .55956 .71011 .54148 .75996 .56451 .73866 .54537 Metetra
.63 .821 .974 r
.73866 .54537 .75996 .56451 .80917 .5574 .78798 .53094 Metetra
.645 .763 .934 r
.78798 .53094 .80917 .5574 .85873 .54317 .83816 .51625 Metetra
.645 .763 .934 r
.83816 .51625 .85873 .54317 .90916 .52869 .88922 .50131 Metetra
.653 .749 .92 r
.23074 .53664 .25728 .56 .29698 .54775 .27079 .52409 Metetra
.643 .747 .924 r
.27079 .52409 .29698 .54775 .33725 .53606 .31141 .51227 Metetra
.624 .743 .933 r
.31141 .51227 .33725 .53606 .3781 .52563 .35261 .50204 Metetra
.589 .737 .946 r
.35261 .50204 .3781 .52563 .41958 .51735 .39443 .49443 Metetra
.523 .721 .963 r
.39443 .49443 .41958 .51735 .46177 .51243 .43695 .49099 Metetra
.4 .682 .975 r
.43695 .49099 .46177 .51243 .50481 .5124 .48034 .49352 Metetra
.164 .576 .934 r
.48034 .49352 .50481 .5124 .54895 .51897 .52489 .50424 Metetra
0 .324 .722 r
.52489 .50424 .54895 .51897 .59454 .53449 .57101 .52609 Metetra
.336 0 0 r
.57101 .52609 .59454 .53449 .6421 .56175 .6189 .54757 Metetra
.605 .859 .991 r
.6189 .54757 .6421 .56175 .69018 .55956 .66712 .53318 Metetra
.645 .763 .934 r
.66712 .53318 .69018 .55956 .73866 .54537 .71619 .51853 Metetra
.645 .763 .934 r
.71619 .51853 .73866 .54537 .78798 .53094 .76611 .50362 Metetra
.645 .763 .934 r
.76611 .50362 .78798 .53094 .83816 .51625 .81691 .48845 Metetra
.645 .763 .934 r
.81691 .48845 .83816 .51625 .88922 .50131 .86863 .47301 Metetra
.654 .749 .92 r
.20345 .51257 .23074 .53664 .27079 .52409 .24386 .49959 Metetra
.646 .746 .922 r
.24386 .49959 .27079 .52409 .31141 .51227 .28487 .48716 Metetra
.631 .74 .927 r
.28487 .48716 .31141 .51227 .35261 .50204 .32647 .476 Metetra
.605 .727 .931 r
.32647 .476 .35261 .50204 .39443 .49443 .36868 .467 Metetra
.564 .704 .935 r
.36868 .467 .39443 .49443 .43695 .49099 .41158 .4614 Metetra
.504 .663 .933 r
.41158 .4614 .43695 .49099 .48034 .49352 .45531 .46073 Metetra
.422 .6 .92 r
.45531 .46073 .48034 .49352 .52489 .50424 .50008 .46675 Metetra
.319 .511 .888 r
.50008 .46675 .52489 .50424 .57101 .52609 .54624 .48184 Metetra
.208 .403 .835 r
.54624 .48184 .57101 .52609 .6189 .54757 .59429 .50884 Metetra
.547 .634 .889 r
.59429 .50884 .6189 .54757 .66712 .53318 .64333 .50593 Metetra
.645 .763 .934 r
.64333 .50593 .66712 .53318 .71619 .51853 .69298 .4908 Metetra
.645 .763 .934 r
.69298 .4908 .71619 .51853 .76611 .50362 .74352 .47541 Metetra
.645 .763 .934 r
.74352 .47541 .76611 .50362 .81691 .48845 .79496 .45973 Metetra
.645 .763 .934 r
.79496 .45973 .81691 .48845 .86863 .47301 .84734 .44377 Metetra
.655 .749 .919 r
.17536 .4878 .20345 .51257 .24386 .49959 .21616 .47427 Metetra
.651 .747 .92 r
.21616 .47427 .24386 .49959 .28487 .48716 .25758 .46091 Metetra
.644 .741 .919 r
.25758 .46091 .28487 .48716 .32647 .476 .29963 .44811 Metetra
.632 .727 .916 r
.29963 .44811 .32647 .476 .36868 .467 .34233 .4363 Metetra
.615 .703 .908 r
.34233 .4363 .36868 .467 .41158 .4614 .38572 .42618 Metetra
.592 .666 .89 r
.38572 .42618 .41158 .4614 .45531 .46073 .42987 .41844 Metetra
.565 .614 .86 r
.42987 .41844 .45531 .46073 .50008 .46675 .4749 .414 Metetra
.535 .552 .819 r
.4749 .414 .50008 .46675 .54624 .48184 .52099 .41398 Metetra
.506 .487 .769 r
.52099 .41398 .54624 .48184 .59429 .50884 .5684 .41973 Metetra
.483 .428 .72 r
.5684 .41973 .59429 .50884 .64333 .50593 .61747 .43276 Metetra
.404 .416 .759 r
.61747 .43276 .64333 .50593 .69298 .4908 .66869 .45507 Metetra
.587 .685 .909 r
.66869 .45507 .69298 .4908 .74352 .47541 .72017 .44625 Metetra
.645 .763 .934 r
.72017 .44625 .74352 .47541 .79496 .45973 .77227 .43004 Metetra
.645 .763 .934 r
.77227 .43004 .79496 .45973 .84734 .44377 .82533 .41353 Metetra
.657 .75 .918 r
.14645 .46229 .17536 .4878 .21616 .47427 .18764 .44821 Metetra
.656 .748 .918 r
.18764 .44821 .21616 .47427 .25758 .46091 .22948 .43399 Metetra
.654 .744 .916 r
.22948 .43399 .25758 .46091 .29963 .44811 .272 .41967 Metetra
.652 .736 .91 r
.272 .41967 .29963 .44811 .34233 .4363 .31521 .40533 Metetra
.648 .719 .9 r
.31521 .40533 .34233 .4363 .38572 .42618 .35914 .39113 Metetra
.643 .693 .881 r
.35914 .39113 .38572 .42618 .42987 .41844 .4038 .37719 Metetra
.635 .656 .853 r
.4038 .37719 .42987 .41844 .4749 .414 .44925 .36362 Metetra
.622 .61 .817 r
.44925 .36362 .4749 .414 .52099 .41398 .49552 .35068 Metetra
.608 .559 .774 r
.49552 .35068 .52099 .41398 .5684 .41973 .54268 .33856 Metetra
.591 .509 .73 r
.54268 .33856 .5684 .41973 .61747 .43276 .59081 .32753 Metetra
.576 .465 .69 r
.59081 .32753 .61747 .43276 .66869 .45507 .64001 .31784 Metetra
.563 .427 .654 r
.64001 .31784 .66869 .45507 .72017 .44625 .69041 .30981 Metetra
.557 .425 .657 r
.69041 .30981 .72017 .44625 .77227 .43004 .74216 .30384 Metetra
.551 .431 .669 r
.74216 .30384 .77227 .43004 .82533 .41353 .79546 .30031 Metetra
.657 .75 .918 r
.11667 .43605 .14645 .46229 .18764 .44821 .15824 .42151 Metetra
.657 .75 .918 r
.15824 .42151 .18764 .44821 .22948 .43399 .20049 .40671 Metetra
.657 .749 .917 r
.20049 .40671 .22948 .43399 .272 .41967 .24344 .39168 Metetra
.657 .747 .916 r
.24344 .39168 .272 .41967 .31521 .40533 .28711 .37637 Metetra
.657 .743 .913 r
.28711 .37637 .31521 .40533 .35914 .39113 .33151 .36083 Metetra
.657 .736 .908 r
.33151 .36083 .35914 .39113 .4038 .37719 .37667 .34501 Metetra
.657 .726 .9 r
.37667 .34501 .4038 .37719 .44925 .36362 .42261 .32886 Metetra
.655 .712 .889 r
.42261 .32886 .44925 .36362 .49552 .35068 .46934 .31246 Metetra
.654 .693 .874 r
.46934 .31246 .49552 .35068 .54268 .33856 .51688 .29569 Metetra
.65 .668 .854 r
.51688 .29569 .54268 .33856 .59081 .32753 .56526 .27863 Metetra
.645 .639 .83 r
.56526 .27863 .59081 .32753 .64001 .31784 .61449 .2612 Metetra
.638 .607 .802 r
.61449 .2612 .64001 .31784 .69041 .30981 .6646 .24343 Metetra
.629 .573 .772 r
.6646 .24343 .69041 .30981 .74216 .30384 .7156 .22529 Metetra
.619 .539 .742 r
.7156 .22529 .74216 .30384 .79546 .30031 .76752 .20671 Metetra
.657 .75 .918 r
.08599 .409 .11667 .43605 .15824 .42151 .12794 .39404 Metetra
.656 .75 .919 r
.12794 .39404 .15824 .42151 .20049 .40671 .17057 .37888 Metetra
.655 .75 .92 r
.17057 .37888 .20049 .40671 .24344 .39168 .21392 .3636 Metetra
.654 .752 .922 r
.21392 .3636 .24344 .39168 .28711 .37637 .25799 .3482 Metetra
.65 .753 .925 r
.25799 .3482 .28711 .37637 .33151 .36083 .30281 .33286 Metetra
.647 .758 .93 r
.30281 .33286 .33151 .36083 .37667 .34501 .34841 .31758 Metetra
.642 .764 .937 r
.34841 .31758 .37667 .34501 .42261 .32886 .39481 .3025 Metetra
.633 .774 .948 r
.39481 .3025 .42261 .32886 .46934 .31246 .44206 .28783 Metetra
.621 .788 .962 r
.44206 .28783 .46934 .31246 .51688 .29569 .4902 .27369 Metetra
.601 .808 .979 r
.4902 .27369 .51688 .29569 .56526 .27863 .53932 .26023 Metetra
.565 .829 .995 r
.53932 .26023 .56526 .27863 .61449 .2612 .58947 .24767 Metetra
.497 .844 .995 r
.58947 .24767 .61449 .2612 .6646 .24343 .64078 .23627 Metetra
.368 .819 .939 r
.64078 .23627 .6646 .24343 .7156 .22529 .69336 .22627 Metetra
.158 .699 .761 r
.69336 .22627 .7156 .22529 .76752 .20671 .74737 .21795 Metetra
.658 .75 .918 r
.05437 .38111 .08599 .409 .12794 .39404 .09672 .36551 Metetra
.661 .75 .916 r
.09672 .36551 .12794 .39404 .17057 .37888 .13982 .34936 Metetra
.666 .747 .911 r
.13982 .34936 .17057 .37888 .21392 .3636 .1837 .33239 Metetra
.673 .741 .901 r
.1837 .33239 .21392 .3636 .25799 .3482 .22841 .31417 Metetra
.681 .728 .885 r
.22841 .31417 .25799 .3482 .30281 .33286 .27394 .2943 Metetra
.689 .706 .861 r
.27394 .2943 .30281 .33286 .34841 .31758 .32031 .27219 Metetra
.695 .676 .828 r
.32031 .27219 .34841 .31758 .39481 .3025 .36747 .24717 Metetra
.694 .637 .788 r
.36747 .24717 .39481 .3025 .44206 .28783 .41533 .2186 Metetra
.689 .595 .746 r
.41533 .2186 .44206 .28783 .4902 .27369 .46379 .18571 Metetra
.679 .553 .704 r
.46379 .18571 .4902 .27369 .53932 .26023 .51264 .14763 Metetra
.667 .513 .667 r
.51264 .14763 .53932 .26023 .58947 .24767 .56164 .1036 Metetra
.598 .441 .64 r
.56164 .1036 .58947 .24767 .64078 .23627 .61118 .07647 Metetra
.571 .414 .629 r
.61118 .07647 .64078 .23627 .69336 .22627 .66171 .0571 Metetra
.569 .407 .623 r
.66171 .0571 .69336 .22627 .74737 .21795 .71317 .03738 Metetra
.665 .751 .914 r
.02177 .35224 .05437 .38111 .09672 .36551 .06461 .33545 Metetra
.681 .75 .903 r
.06461 .33545 .09672 .36551 .13982 .34936 .10843 .31645 Metetra
.705 .74 .879 r
.10843 .31645 .13982 .34936 .1837 .33239 .15335 .29355 Metetra
.729 .715 .837 r
.15335 .29355 .1837 .33239 .22841 .31417 .1995 .26439 Metetra
.745 .674 .782 r
.1995 .26439 .22841 .31417 .27394 .2943 .24688 .22629 Metetra
.746 .623 .723 r
.24688 .22629 .27394 .2943 .32031 .27219 .29535 .1762 Metetra
.678 .537 .686 r
.29535 .1762 .32031 .27219 .36747 .24717 .34306 .13535 Metetra
.588 .461 .674 r
.34306 .13535 .36747 .24717 .41533 .2186 .38984 .11704 Metetra
.596 .479 .691 r
.38984 .11704 .41533 .2186 .46379 .18571 .43745 .0984 Metetra
.607 .511 .719 r
.43745 .0984 .46379 .18571 .51264 .14763 .4859 .07942 Metetra
.627 .568 .769 r
.4859 .07942 .51264 .14763 .56164 .1036 .53524 .06011 Metetra
.657 .687 .867 r
.53524 .06011 .56164 .1036 .61118 .07647 .58547 .04044 Metetra
.664 .741 .907 r
.58547 .04044 .61118 .07647 .66171 .0571 .63663 .0204 Metetra
.664 .741 .907 r
.63663 .0204 .66171 .0571 .71317 .03738 .68874 0 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10206 .22973 m
.10675 .23431 L
s
[(0.2)] .09267 .22056 1 .97619 Mshowa
.23703 .17687 m
.2415 .18167 L
s
[(0.4)] .22808 .16727 .93173 1 Mshowa
.37937 .12114 m
.38359 .12616 L
s
[(0.6)] .37094 .11108 .83907 1 Mshowa
.52971 .06227 m
.53364 .06753 L
s
[(0.8)] .52186 .05175 .7464 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.13514 .21677 m
.13793 .21955 L
s
.16866 .20365 m
.17141 .20646 L
s
.20262 .19035 m
.20534 .1932 L
s
.2719 .16322 m
.27455 .16613 L
s
.30724 .14938 m
.30985 .15233 L
s
.34306 .13535 m
.34564 .13834 L
s
.41618 .10672 m
.41867 .10977 L
s
.4535 .09211 m
.45595 .0952 L
s
.49134 .07729 m
.49374 .08041 L
s
.56863 .04703 m
.57093 .05022 L
s
.60809 .03158 m
.61035 .0348 L
s
.64813 .0159 m
.65033 .01916 L
s
.0694 .24251 m
.07225 .24523 L
s
.03716 .25514 m
.04004 .25782 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[74]:=",
  ImageSize->{223.125, 181},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004F0000hR000`400?l00000o`00003oo`3ooolG
0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG
0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG
0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG
0?ooo`00a@3oool5000004`0oooo00370?ooo`030000003oool0oooo04`0oooo00370?ooo`030000
003oool0oooo04`0oooo00370?ooo`030000003oool0oooo04`0oooo00370?ooo`030000003oool0
oooo04`0oooo00370?ooo`030000003oool0oooo04`0oooo00350?ooo`<00000CP3oool00<L0oooo
00<000000?ooo`3oool0C03oool00?l0oooo5`3oool00?l0oooo5`3oool00?l0oooo5`3oool00?l0
oooo5`3oool00?l0oooo5`3oool00?l0oooo5`3oool009<0oooo100000050?ooo`8000001@3oool4
000002<0oooo0P00001:0?ooo`00TP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0080oooo0P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool30000
00030:Vmj0000000000004T0oooo002B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01X0oooo100000030:Vmj080
0000B@3oool00980oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05`3oool4000000H0ZKgX00<000000:Vmj0000000
B03oool00980oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`@000005`3o
ool5000000P0ZKgX00@000000:Vmj00000000000A`3oool00980oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04P3o
ool5000000X0ZKgX00@000000:Vmj02Y_NP00000A`3oool00980oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403o
ool3000000<0ZKgX00<000000:Vmj02Y_NP0202Y_NP01@000000ZKgX0:Vmj02Y_NP0000004H0oooo
002C0?ooo`@00000303oool400000140oooo0`0000060:Vmj0030000002Y_NP0ZKgX00L0ZKgX00@0
00000:Vmj02Y_NP0ZKgX0P0000150?ooo`00]@3oool3000000X0ZKgX00<000000:Vmj02Y_NP01P2Y
_NP010000000ZKgX0:Vmj02Y_NP2000004D0oooo002c0?ooo`<000003@2Y_NP00`000000ZKgX0:Vm
j0050:Vmj0@0000000<0TFRO000000000000A03oool00;00oooo0`0000020:R_g@030000002Y_NP0
ZKgX00/0ZKgX00<000000:Vmj02Y_NP0102Y_NP3000000<0TFRO00<000000?ooo`000000@`3oool0
0:h0oooo0P0000000`2X[md000000:R_g@020:R_g@030000002Y_NP0ZKgX00`0ZKgX00<000000:Vm
j02Y_NP00`000002095XW`030000002AJ9l0TFRO0080TFRO0P0000130?ooo`00Z`3oool3000000P0
Z:oM00<000000:Vmj02Y_NP02`2Y_NP3000000D0TFRO00<00000095XW`2AJ9l00P2AJ9l00`000000
oooo000000120?ooo`00L03oool4000000D0oooo0P0000060?ooo`<000008`3oool4000000`0Z:oM
00<000000:Vmj02Y_NP0202Y_NP200000003099YX@000000TFRO00D0TFRO00<00000095XW`2AJ9l0
0P2AJ9l010000000oooo0000000000110?ooo`00K`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`050000003oool0oooo0?ooo`000000803oool400000003
0:2Aa0000000Z:oM00`0Z:oM00<000000:Vmj02Y_NP01@2Y_NP2000000<0TVVQ00<00000095XW`2A
J9l0102AJ9l00`000000TFRO095XW`02095XW`040000003oool0000000000440oooo001_0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool00000
01h0oooo0`0000020:2Aa0030000002PTL@0000000d0Z:oM00<000000:Vmj02Y_NP00`2Y_NP20000
00H0TVVQ00<00000095XW`2AJ9l00`2AJ9l00`000000TFRO095XW`02095XW`050000003oool0oooo
0?ooo`000000@03oool006l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`050000003oool0oooo0?ooo`0000006`3oool3000000P0X97400<000000:R_g@2X[md02`2X[md0
0`000000ZKgX0:Vmj002000000P0TVVQ00<00000095XW`2AJ9l00`2AJ9l00`000000TFRO095XW`03
095XW`040000003oool0oooo00000400oooo001_0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02@3oool4000001T0oooo1000000:0:2Aa0030000002X[md0Z:oM00`0Z:oM0P00000:
099YX@030000002AJ9l0TFRO00<0TFRO00<00000095XW`2AJ9l00`2AJ9l01@000000oooo0?ooo`3o
ool0000003l0oooo001_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0H0?ooo`D00000302PTL@00`000000Z:oM0:R_g@090:R_g@<000002`2BJJ40
0`000000TFRO095XW`03095XW`030000002AJ9l0TFRO00<0TFRO00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0l0?ooo`00K`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool05@3oool3000000<0Vh:h00<000000:2Aa02PTL@02`2PTL@00`00
0000Z:oM0:R_g@060:R_g@8000000P2IL:<00`000000TVVQ099YX@09099YX@030000002AJ9l0TFRO
00<0TFRO00<00000095XW`2AJ9l00`2AJ9l00`000000oooo0?ooo`020?ooo`030000003oool0oooo
03`0oooo001`0?ooo`@000003P3oool300000140oooo0`00000609^2^0030000002PTL@0X97400/0
X97400<000000:R_g@2X[md0102X[md2000000D0VG2S00<00000099YX@2BJJ40202BJJ400`000000
TFRO095XW`03095XW`030000002AJ9l0TFRO00<0TFRO00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0>0?ooo`@000001@3oool2000000@0oooo1@00000I0?ooo`00U03oool4000000P0Vh:h
00<000000:2Aa02PTL@02`2PTL@010000000Z:oM0:R_g@2X[md2000000L0VG2S00<00000099YX@2B
JJ402@2BJJ400`000000TFRO095XW`02095XW`030000002AJ9l0TFRO00@0TFRO00L000000?ooo`3o
ool0oooo0000003oool0000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`800000103oool01@000000oooo0?ooo`3oool0000001T0oooo002A0?ooo`@000002`2KP[P0
0`000000X9740:2Aa00;0:2Aa0040000002X[md00000000000T0VG2S00<00000099YX@2BJJ402@2B
JJ400`000000TFRO095XW`02095XW`030000002AJ9l0TFRO00@0TFRO00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0J0?ooo`00SP3oool40000000309Qj/0000000Vh:h00/0Vh:h00<00000
0:2Aa02PTL@0302PTL@00`000000VG2S09U`X`0909U`X`030000002BJJ40TVVQ00T0TVVQ00<00000
095XW`2AJ9l00P2AJ9l00`000000TFRO095XW`04095XW`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00`3oool600000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01T0oooo002<0?ooo`@00000102HN[000`000000Vh:h09^2^00:09^2
^0030000002PTL@0X97400X0X9740P00000;09U`X`030000002BJJ40TVVQ00T0TVVQ00<00000095X
W`2AJ9l00P2AJ9l00`000000TFRO095XW`04095XW`030000003oool0oooo00D0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0603oool008T0oooo1000000709Qj/0030000002KP[P0Vh:h00X0Vh:h00<000000:2Aa02P
TL@0202PTL@2000000030:Z3ZP000000VG2S00X0VG2S00<00000099YX@2BJJ402@2BJJ400`000000
TFRO095XW`02095XW`030000002AJ9l0TFRO00@0TFRO00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0G0?ooo`00C`3oool4000000D0oooo0P0000070?ooo`<000008`3oool3000000X0V7Z`
00<0000009^2^02KP[P02`2KP[P00`000000X9740:2Aa0060:2Aa0030000002ZPjX0ZX>Z0080ZX>Z
00<0000009U`X`2IL:<02@2IL:<00`000000TVVQ099YX@09099YX@050000002AJ9l0TFRO095XW`00
00001`2AJ9l00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000006@3oool004h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000203oool00`000000
oooo0?ooo`0O0?ooo`<0000000<0UWJ/0000002HN[002`2HN[000`000000Vh:h09^2^00:09^2^003
0000002PTL@0X97400D0X97400<000000:Z3ZP2ZPjX00`2ZPjX00`000000VG2S09U`X`0909U`X`03
0000002BJJ40TVVQ00T0TVVQ00D00000095XW`2AJ9l0TFRO00000007095XW`030000003oool0oooo
00H0oooo00<000000?ooo`3oool02@3oool4000000`0oooo0`00000J0?ooo`00CP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07@3oool300000080
UWJ/00<0000009If[00000002`2HN[000`000000Vh:h09^2^00:09^2^0030000002PTL@0X97400@0
X97400<000000:Z3ZP2ZPjX0102ZPjX00`000000VG2S09U`X`0909U`X`030000002BJJ40TVVQ00T0
TVVQ00<00000095XW`2AJ9l00P2AJ9l00`000000TFRO095XW`04095XW`030000003oool0oooo00@0
oooo0`00000h0?ooo`00CP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00P0oooo
1P00000K0?ooo`<000001`2FMZ`00`000000V7Z`09Qj/00909Qj/0030000002KP[P0Vh:h00/0Vh:h
00<000000:2Aa02PTL@00P2PTL@00`000000ZX>Z0:Z3ZP050:Z3ZP030000002IL:<0VG2S00T0VG2S
00<00000099YX@2BJJ402@2BJJ400`000000TFRO095XW`02095XW`030000002AJ9l0TFRO00@0TFRO
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0e0?ooo`00CP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000006P3oool3000000T0UWJ/
00<0000009Qj/02HN[002P2HN[000`000000Vh:h09^2^00:09^2^0030000002PTL@0X97400800000
202ZPjX00`000000VG2S09U`X`0909U`X`030000002BJJ40TVVQ00T0TVVQ00<00000095XW`2AJ9l0
0P2AJ9l00`000000TFRO095XW`04095XW`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
=03oool004h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo000001L0oooo1@00000:09If[0030000002HN[00V7Z`00X0V7Z`00<0000009^2^02KP[P0
2`2KP[P2000000X0ZX>Z00<0000009U`X`2IL:<02@2IL:<00`000000TVVQ099YX@09099YX@030000
002AJ9l0TFRO0080TFRO00<00000095XW`2AJ9l01@2AJ9l00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03@0oooo001>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0000000D0?ooo`<0000000D0oooo000000000000[HV_0000000;09If[0030000
002HN[00V7Z`00T0V7Z`00<0000009^2^02KP[P02`2KP[P00`000000ZX>Z0:Z3ZP0:0:Z3ZP030000
002IL:<0VG2S00T0VG2S00<00000099YX@2BJJ402@2BJJ401@000000TFRO095XW`2AJ9l0000000L0
TFRO00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0c0?ooo`00C`3oool4000000h0oooo
0P00000B0?ooo`<000000P3oool00`000000[HV_0:f9[`020:f9[`030000002FMZ`0UWJ/00P0UWJ/
00<0000009Qj/02HN[002@2HN[000`000000Vh:h09^2^00:09^2^0800000302ZPjX00`000000VG2S
09U`X`0909U`X`030000002BJJ40TVVQ00T0TVVQ00D00000095XW`2AJ9l0TFRO00000007095XW`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0<P3oool00780oooo0`0000040?ooo`030000
002]RJl0[HV_00<0[HV_00<0000009If[02FMZ`0202FMZ`00`000000V7Z`09Qj/00:09Qj/0030000
002KP[P0Vh:h00L0Vh:h0P0000000`2]SK@000000:Z3ZP0;0:Z3ZP030000002IL:<0VG2S00T0VG2S
00<00000099YX@2BJJ402@2BJJ401@000000TFRO095XW`2AJ9l0000000L0TFRO00<000000?ooo`3o
ool0203oool2000003@0oooo001`0?ooo`8000001P3oool00`000000[HV_0:f9[`040:f9[`030000
002FMZ`0UWJ/00P0UWJ/00<0000009Qj/02HN[002P2HN[000`000000Vh:h09^2^00609^2^0030000
002]SK@0[Hfd0080[Hfd00<000000:Z3ZP2ZPjX02@2ZPjX00`000000VG2S09U`X`0909U`X`030000
002BJJ40TVVQ00T0TVVQ00D00000095XW`2AJ9l0TFRO00000007095XW`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0<@3oool006d0oooo0`0000070?ooo`030000002]RJl0[HV_00D0[HV_
00<0000009If[02FMZ`02@2FMZ`00`000000V7Z`09Qj/00909Qj/0030000002KP[P0Vh:h00D0Vh:h
00<000000:f=]02]SK@00`2]SK@00`000000ZX>Z0:Z3ZP090:Z3ZP030000002IL:<0VG2S00T0VG2S
00<00000099YX@2BJJ402@2BJJ401@000000TFRO095XW`2AJ9l0000000P0TFRO00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0a0?ooo`00JP3oool300000080oooo00<000000?ooo`3oool0
0`3oool2000000P0[HV_00<0000009If[02FMZ`02@2FMZ`00`000000V7Z`09Qj/00:09Qj/0030000
002KP[P0Vh:h00<0Vh:h00<000000:f=]02]SK@0102]SK@00`000000ZX>Z0:Z3ZP0:0:Z3ZP030000
002IL:<0VG2S00P0VG2S00<00000099YX@2BJJ402P2BJJ4010000000TFRO095XW`000008095XW`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0<03oool00300oooo100000050?ooo`800000
103oool5000002@0oooo0P00000:0?ooo`030000002]RJl0[HV_00T0[HV_00<0000009If[02FMZ`0
202FMZ`00`000000V7Z`09Qj/00:09Qj/0030000002KP[P0Vh:h0080Vh:h00<000000:f=]02]SK@0
1@2]SK@00`000000ZX>Z0:Z3ZP0:0:Z3ZP030000002IL:<0VG2S00T0VG2S00<00000099YX@2BJJ40
2@2BJJ4010000000TFRO095XW`000008095XW`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0;`3oool002l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000
103oool01@000000oooo0?ooo`3oool000000240oooo0`00000;0?ooo`030000002]RJl0[HV_00X0
[HV_00<0000009If[02FMZ`02@2FMZ`00`000000V7Z`09Qj/00909Qj/0030000002KP[P0Vh:h0080
00002@2]SK@00`000000ZX>Z0:Z3ZP090:Z3ZP030000002IL:<0VG2S00T0VG2S00<00000099YX@2B
JJ402@2BJJ4010000000TFRO095XW`000008095XW`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0;`3oool002l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0200oooo0P0000020?ooo`030000003oool0oooo00P0oooo0P00000<0:f9[`03
0000002FMZ`0UWJ/00T0UWJ/00<0000009Qj/02HN[002P2HN[02000000/0[Hfd00<000000:Z3ZP2Z
PjX02@2ZPjX00`000000VG2S09U`X`0909U`X`030000002BJJ40TVVQ00T0TVVQ00@00000095XW`2A
J9l00000202AJ9l00`000000oooo0?ooo`0;0?ooo`800000<03oool002l0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01`0oooo0`00000>0?ooo`04
0000002nWkT0_Yni000000/0[HV_00<0000009If[02FMZ`02@2FMZ`00`000000V7Z`09Qj/00:09Qj
/0030000002]SK@0[Hfd00X0[Hfd00<000000:Z3ZP2ZPjX02@2ZPjX00`000000VG2S09U`X`0909U`
X`030000002BJJ40TVVQ00T0TVVQ00@00000095XW`2AJ9l000002@2AJ9l00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo02d0oooo000_0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0H0?ooo`<00000403oool01@000000_Yni0;jO^@2nWkT0
000000/0[HV_00<0000009If[02FMZ`02@2FMZ`00`000000V7Z`09Qj/00809Qj/0<00000302]SK@0
0`000000ZX>Z0:Z3ZP0:0:Z3ZP030000002IL:<0VG2S00P0VG2S00<00000099YX@2BJJ402P2BJJ40
0`000000TFRO00000009095XW`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;@3oool0
02l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01D0oooo0P0000020?ooo`030000003oool0oooo00d0oooo00<000000;jO^@2nWkT00P2nWkT00`00
0000[HV_0:f9[`0:0:f9[`030000002FMZ`0UWJ/00T0UWJ/00<0000009Qj/02HN[001P2HN[001@00
0000/9Rn0;2H_P2`V;h0000000`0[Hfd00<000000:Z3ZP2ZPjX02@2ZPjX00`000000VG2S09U`X`08
09U`X`030000002BJJ40TVVQ00X0TVVQ00<00000095XW`0000002@2AJ9l00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02`0oooo000_0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0203oool01@000000oooo0?ooo`3oool0000001@0oooo0`00000C0?ooo`030000002nWkT0
_Yni00<0_Yni00<000000:f9[`2]RJl02P2]RJl00`000000UWJ/09If[00909If[0030000002HN[00
V7Z`00@0V7Z`0P0000040;2H_P030000002]SK@0[Hfd00X0[Hfd00<000000:Z3ZP2ZPjX02@2ZPjX0
0`000000VG2S09U`X`0909U`X`030000002BJJ40TVVQ00T0TVVQ00<00000095XW`0000002@2AJ9l0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02/0oooo000`0?ooo`@00000303oool30000
01<0oooo0P00000F0?ooo`030000002nWkT0_Yni00@0_Yni00<000000:f9[`2]RJl02@2]RJl00`00
0000UWJ/09If[00909If[0030000002HN[00V7Z`0080V7Z`0P0000060;2H_P030000002]SK@0[Hfd
00X0[Hfd00<000000:Z3ZP2ZPjX02@2ZPjX00`000000VG2S09U`X`0909U`X`030000002BJJ40TVVQ
00T0TVVQ00<00000095XW`0000002@2AJ9l00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02/0oooo001C0?ooo`<000000P3oool00`000000oooo0?ooo`0B0?ooo`030000002nWkT0_Yni00D0
_Yni00<000000:f9[`2]RJl02@2]RJl00`000000UWJ/09If[00909If[0050000002HN[00V7Z`09Qj
/00000002@2`V;h00`000000[Hfd0:f=]0090:f=]0030000002ZPjX0ZX>Z00T0ZX>Z00<0000009U`
X`2IL:<02@2IL:<00`000000TVVQ099YX@09099YX@040000002AJ9l0TFRO000000T0TFRO00<00000
0?ooo`3oool00P00000<0?ooo`030000003oool0oooo00H0oooo1000000P0?ooo`00D@3oool20000
01T0oooo00<000000;jO^@2nWkT01P2nWkT00`000000[HV_0:f9[`090:f9[`030000002FMZ`0UWJ/
00X0UWJ/0`00000:0;2H_P030000002]SK@0[Hfd00X0[Hfd00<000000:Z3ZP2ZPjX0202ZPjX00`00
0000VG2S09U`X`0909U`X`030000002BJJ40TVVQ00T0TVVQ00@00000095XW`2AJ9l000002@2AJ9l5
000000/0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01d0oooo001>0?ooo`<000006P3oool00`000000_Yni0;jO^@080;jO^@030000002]RJl0[HV_
00T0[HV_00<0000009If[02FMZ`02@2FMZ`00`000000/9Rn0;2H_P0:0;2H_P030000002]SK@0[Hfd
00X0[Hfd00<000000:Z3ZP2ZPjX02@2ZPjX00`000000VG2S09U`X`0809U`X`030000002BJJ40TVVQ
00X0TVVQ00<00000095XW`0000001`2AJ9l4000000<0WXVm00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool004/0
oooo0`00000L0?ooo`030000002nWkT0_Yni00T0_Yni00<000000:f9[`2]RJl02@2]RJl00`000000
UWJ/09If[00709If[0<000003@2`V;h00`000000[Hfd0:f=]0090:f=]0030000002ZPjX0ZX>Z00T0
ZX>Z00<0000009U`X`2IL:<0202IL:<00`000000TVVQ099YX@0:099YX@040000002AJ9l00000095X
W`H000001`2NRKd00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`00B@3oool2000001h0oooo00<000000;jO^@2n
WkT02P2nWkT00`000000[HV_0:f9[`090:f9[`030000002FMZ`0UWJ/00H0UWJ/00D000000;6Sb@2a
XlT0/J?90000000<0;2H_P030000002]SK@0[Hfd00T0[Hfd00<000000:Z3ZP2ZPjX02@2ZPjX00`00
0000VG2S09U`X`0909U`X`030000002BJJ40TVVQ00L0TVVQ2@00000:09j9_@030000003oool0oooo
00`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01d0oooo00160?ooo`<000007P3oool3000000`0_Yni00<000000:f9[`2]RJl02@2]RJl00`000000
UWJ/09If[00409If[0800000102aXlT00`000000/9Rn0;2H_P0:0;2H_P030000002]SK@0[Hfd00X0
[Hfd00<000000:Z3ZP2ZPjX0202ZPjX00`000000VG2S09U`X`0909U`X`040000002BJJ40TVVQ099Y
X@H000000`1NdO03000000030:6Ba@000000WXVm00X0WXVm00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool07@3oool004@0
oooo0P0000030?ooo`030000003oool0oooo01X0oooo00D000000;j/b02n[<P0_Zc80000000<0;jO
^@030000002]RJl0[HV_00P0[HV_00<0000009If[02FMZ`00P2FMZ`2000000H0/J?900<000000;2H
_P2`V;h02P2`V;h00`000000[Hfd0:f=]00:0:f=]0030000002ZPjX0ZX>Z00P0ZX>Z00<0000009U`
X`2IL:<0202IL:<5000000H0G]7`0`0000000`2QT/D000000:6Ba@020:6Ba@030000002NRKd0WXVm
00T0WXVm00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3oool0000000@0oooo00<00000
0?ooo`3oool07@3oool00440oooo0`00000Q0?ooo`030000002n[<P0_Zc80080_Zc800<000000;jO
^@2nWkT02P2nWkT00`000000[HV_0:f9[`090:f9[`040000002FMZ`0UWJ/000000T0/J?900<00000
0;2H_P2`V;h02P2`V;h00`000000[Hfd0:f=]0090:f=]0030000002ZPjX0ZX>Z00T0ZX>Z00<00000
09U`X`2IL:<00`2IL:<4000000<0OmSn0P00000305kAl0<00000102QT/D01@000000XI;50:6Ba@2Q
T/D0000000/0WXVm00<000000?ooo`3oool02`3oool00`000000oooo000000030?ooo`@00000803o
ool003h0oooo1@00000P0?ooo`8000001P2n[<P00`000000_Yni0;jO^@090;jO^@030000002]RJl0
[HV_00T0[HV_0`00000:0;6Sb@030000002`V;h0/9Rn00X0/9Rn00<000000:f=]02]SK@02@2]SK@0
0`000000ZX>Z0:Z3ZP090:Z3ZP030000002IL:<0000000<000002@1of?h3000000H0XI;50P000003
0:6Ba@030000002NRKd0WXVm00T0WXVm00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0U
0?ooo`00?03oool2000002@0oooo00<000000;j/b02n[<P01P2n[<P00`000000_Yni0;jO^@0:0;jO
^@030000002]RJl0[HV_00P0[HV_00<000000;6Sb@2aXlT02`2aXlT00`000000/9Rn0;2H_P090;2H
_P030000002]SK@0[Hfd00X0[Hfd00<000000:Z3ZP2ZPjX01P2ZPjX4000000X0OmSn0`0000000`2S
Vld000000:6Ba@030:6Ba@<000000P2QT/D01@000000XI;50:6Ba@2QT/D0000000/0WXVm00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`00>P3oool2000002D0oooo00<000000;j/
b02n[<P01`2n[<P00`000000_Yni0;jO^@0:0;jO^@030000002]RJl0[HV_00H0[HV_0`00000=0;6S
b@030000002`V;h0/9Rn00X0/9Rn00<000000:f=]02]SK@02@2]SK@00`000000ZX>Z0:Z3ZP060000
00<0T=Cn0P00000707oHoP8000001@2SVld4000000D0XI;500D000000:6Ba@2QT/D0XI;50000000;
09j9_@030000003oool0oooo00h0oooo00<000000?ooo`3oool08`3oool003X0oooo0P00000S0?oo
o`8000002`2n[<P00`000000_Yni0;jO^@090;jO^@030000002]RJl0[HV_00@0[HV_0P0000030;6]
d`030000002aXlT0/J?900X0/J?900<000000;2H_P2`V;h02P2`V;h00`000000[Hfd0:f=]0080:f=
]0@000002`2@e?h200000080OmSn0`0000050:>Kc@<000002@2QT/D010000000XI;50:6Ba@00000;
09j9_@030000003oool0oooo00h0oooo00<000000?ooo`3oool08`3oool003X0oooo0`00000Q0?oo
o`030000002n[<P0_Zc800/0_Zc800<000000;jO^@2nWkT02@2nWkT00`000000[HV_0:f9[`020:f9
[`8000001@2a[M<00`000000/J?90;6Sb@0;0;6Sb@030000002`V;h0/9Rn00T0/9Rn00<000000:f=
]02]SK@0102]SK@400000080VLkj00<00000093DoP2@e?h02`2@e?h3000000H0Xi_=0P0000030:>K
c@030000002QT/D0XI;500L0XI;500@000000:6Ba@2QT/D000002`2NRKd00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0280oooo000j0?ooo`040000003oool0oooo000001h0oooo0P000000
0`2j]mH000000;j/b00<0;j/b0030000002nWkT0_Yni00T0_Yni00@000000:f9[`0000000000202a
[M<00`000000/J?90;6Sb@0:0;6Sb@030000002`V;h0/9Rn00X0/9Rn00<000000:f=]00000000`00
000709W>nP030000002@e?h0T=Cn00L0T=Cn0`0000000`2UXm@000000:>Kc@030:>Kc@<000001@2S
Vld00`000000XI;50:6Ba@080:6Ba@030000002QT/D0000000/0WXVm00<000000?ooo`3oool03@3o
ool00`000000oooo0000000S0?ooo`00>@3oool2000000<0oooo00<000000?ooo`3oool06P3oool0
1@000000^[OF0;ZgeP2j]mH0000000d0_Zc800<000000;jO^@2nWkT02@2nWkT2000000X0/JgC00<0
00000;6Sb@2aXlT02P2aXlT00`000000/9Rn0;2H_P090;2H_P<00000302Ic_X00`000000T=Cn093D
oP04093DoP8000001@2UXm@4000000T0Xi_=00<000000:6Ba@2QT/D01`2QT/D010000000XI;50:6B
a@00000:09j9_@030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool003T0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000002j]mH0^[OF00<0^[OF00<0
00000;j/b02n[<P02P2n[<P00`000000_Yni0;jO^@070;jO^@80000000<0/;CL0000002a[M<02P2a
[M<00`000000/J?90;6Sb@0:0;6Sb@030000002`V;h0/9Rn00D0/9Rn0`00000209k9mP030000002I
c_X0VLkj00/0VLkj00<00000093DoP2@e?h00`0000050:FSe0<00000302SVld00`000000XI;50:6B
a@080:6Ba@030000002QT/D0000000X0WXVm00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0P0?ooo`00>@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo0P000007
0;ZgeP030000002n[<P0_Zc800X0_Zc800<000000;jO^@2nWkT0102nWkT2000000<0/;CL00<00000
0;6]d`2a[M<02@2a[M<00`000000/J?90;6Sb@0:0;6Sb@030000002`V;h0/9Rn00<0/9Rn0P000006
09k9mP030000002Ic_X0VLkj00X0VLkj0`0000050:FSe0<000000`2UXm@00`000000Xi_=0:>Kc@09
0:>Kc@030000002QT/D0XI;500T0XI;50P00000;09j9_@030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0803oool003T0oooo0P0000060?ooo`030000003oool0oooo01<0oooo00<000000;Zg
eP2j]mH01`2j]mH00`000000_Zc80;j/b00:0;j/b0030000002nWkT0_Yni0080_Yni0P0000060;2d
g0030000002a[M<0/JgC00T0/JgC00<000000;6Sb@2aXlT02P2aXlT00`000000/9Rn000000020000
00T0W/Wf0P00000709W>nP<000000P2VZmX00`000000YJ?D0:FSe003000000H0YJ?D00<000000:>K
c@2SVld02P2SVld00`000000XI;50:6Ba@090:6Ba@8000002P2NRKd00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01l0oooo000i0?ooo`030000003oool0oooo00H0oooo0P00000A0?ooo`80
00002`2j]mH00`000000_Zc80;j/b00:0;j/b0040000002nWkT00000000000P0/;CL00<000000;6]
d`2a[M<02@2a[M<00`000000/J?90;6Sb@090;6Sb@<000003P2NbOH00`000000VLkj09W>nP040000
00D0YZ_J0`00000:0:FSe0030000002SVld0Xi_=00T0Xi_=00<000000:6Ba@2QT/D02@2QT/D20000
00X0WXVm00<000000?ooo`3oool0403oool200000200oooo000:0?ooo`D000000P3oool01@000000
oooo0?ooo`3oool0000000@0oooo1@0000030?ooo`@000004`3oool2000000T0oooo00<000000?oo
o`3oool03@3oool00`000000^[OF0;ZgeP0;0;ZgeP030000002n[<P0_Zc800T0_Zc80`00000;0;2d
g0030000002a[M<0/JgC00T0/JgC00<000000;6Sb@2aXlT0102aXlT400000080X/Kb00<0000009k9
mP2NbOH0302NbOH3000000H0YZ_J0`0000000`2VZmX000000:FSe00:0:FSe0030000002SVld0Xi_=
00X0Xi_=00<000000:6Ba@2QT/D02@2QT/D00`000000WXVm09j9_@0909j9_@030000003oool0oooo
0100oooo00<000000?ooo`3oool07P3oool000`0oooo00<000000?ooo`3oool00`3oool00`000000
oooo000000070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool200000003
0;Bmh@000000^[OF00`0^[OF00<000000;j/b02n[<P01P2n[<P200000080[[[R00<000000;2dg02`
]=`02P2`]=`00`000000/JgC0;6]d`080;6]d`030000002aXlT0/J?900@000001`2Ra_800`000000
W/Wf09k9mP0809k9mP<0000000<0Yk7O0000002VZmX00`2VZmX3000000@0YZ_J00<000000:FSe02U
Xm@02P2UXm@00`000000Xi_=0:>Kc@090:>Kc@030000002QT/D0XI;500X0XI;500<0000009j9_@2N
RKd00`2NRKd6000001<0oooo00<000000?ooo`3oool07@3oool000`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
1`3oool2000000@0];gQ00<000000;ZgeP2j]mH02`2j]mH00`000000_Zc80;j/b0020;j/b0<00000
102^^^800`000000/;CL0;2dg00:0;2dg0030000002a[M<0/JgC00P0/JgC0`00000<0:;6lP800000
1P2NbOH2000000D0Yk7O00@000000:J[fP0000000000202VZmX00`000000YJ?D0:FSe0090:FSe003
0000002SVld0Xi_=00X0Xi_=00<000000:6Ba@2QT/D0102QT/D;000000D0SFj[00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0L0?ooo`0000<0oooo000000000000100000050?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool03`3oool2000000d0oooo00<000000?ooo`3oool0
103oool2000000L0];gQ00<000000;ZgeP2j]mH02P2j]mH00`000000_Zc80;j/b002000000P0[[[R
00<000000;2dg02`]=`02P2`]=`00`000000/JgC0;6]d`040;6]d`<000000P2T`nl00`000000X/Kb
0:;6lP0<0:;6lP030000002NbOH0W/Wf00<000001P2W/Ml3000000/0YZ_J00<000000:FSe02UXm@0
2@2UXm@00`000000Xi_=0:>Kc@070:>Kc@T000001@2>K:P2000000X0SFj[00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0L0?ooo`00303oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0?ooo`80
00002@2d_N400`000000^[OF0;ZgeP0:0;ZgeP<000002`2^^^800`000000/;CL0;2dg0090;2dg003
0000002a[M<0/JgC00@000001P2T`nl00`000000X/Kb0:;6lP0;0:;6lP<000001P2W/Ml300000080
Yk7O00<000000:J[fP2VZmX02@2VZmX00`000000YJ?D0:FSe0090:FSe0040000002SVld0Xi_=0:>K
c@H000000P2@KJL00`000000SVbX08i/Z00908i/Z0030000002=KZ/0000000T0SFj[00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`060?ooo`@000001@3oool2000000@0oooo1@0000010?oo
o`00303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0?0?ooo`8000003`3oool3000000`0];gQ00<000000;ZgeP2j
]mH01`2j]mH200000080[;gV00<000000:jjhP2^^^802@2^^^800`000000/;CL0;2dg0090;2dg0<0
00002`2T`nl2000000T0X/Kb0P0000020:Nfh`040000002W/Ml0Yk7O0:Nag`<000001@2W/Ml00`00
0000YZ_J0:J[fP0:0:J[fP030000002UXm@0YJ?D00L0YJ?D1@000008091]Y`030000002>K:P0SVbX
00X0SVbX00<0000008e^Z`000000202=KZ/00`000000oooo0?ooo`0B0?ooo`8000001P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`050000003oool0oooo
0?ooo`0000000@3oool000X0oooo0`00000=0?ooo`<00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0303oool200000080[[oW00<000000;Bm
h@2d_N402`2d_N400`000000^[OF0;ZgeP030;ZgeP<00000102/_NH00`000000[[[R0:jjhP0:0:jj
hP030000002`]=`0/;CL00H0/;CL0P0000020:G2kP030000002T`nl0Y<?_00/0Y<?_00<000000:;6
lP2Ra_800`2Ra_83000000@0YkKS100000090:Nag`030000002VZmX0YZ_J00T0YZ_J00@000000:FS
e02UXm@0YJ?D1P00000209=g/0030000002@KJL0T6fW00T0T6fW00<0000008i/Z02>K:P02@2>K:P0
0`000000SFj[0000000808e^Z`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool0
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`@000001`3oool50000
00030?ooo`000000000000<0oooo00<000000?ooo`3oool02@3oool3000000D0[[oW00<000000;Bm
h@2d_N402`2d_N400`000000^[OF0;ZgeP02000000P0[;gV00<000000:jjhP2^^^802P2^^^800`00
0000/;CL0;2dg0020;2dg0<000001@2U`^h00`000000Y<?_0:C3k`0;0:C3k`030000002Ra_80X/Kb
008000001@2W]^<4000000/0Yk7O00<000000:J[fP2VZmX02@2VZmX4000000P0TgN`00<00000091]
Y`2@KJL02@2@KJL00`000000SVbX08i/Z00908i/Z0040000002=KZ/0SFj[000000P0SFj[00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`010?ooo`00;`3oool00`000000oooo0?ooo`030?oo
o`040000003oool00000000000T0oooo0P0000090:joi`030000002d_N40];gQ00X0];gQ0`00000;
0:bmiP030000002^^^80[[[R00T0[[[R00<000000;2dg02`]=`00P0000090:G2kP030000002T`nl0
Y<?_00X0Y<?_0`0000040:Nfh`<00000102W]^<00`000000Yk7O0:Nag`090:Nag`030000002VZmX0
YZ_J00@0YZ_J100000000`2GP[X0000009=g/00:09=g/0030000002@KJL0T6fW00P0T6fW00<00000
08i/Z02>K:P02@2>K:P01@000000SFj[08e^Z`2=KZ/0000000L0SFj[00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3o
ool100000040oooo0@3oool002T0oooo0`0000030?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000001`3oool3000000`0[[oW00<000000;Bmh@2d_N401`2d_N4200000080Z[oY00<0
00000:bmiP2/_NH02P2/_NH00`000000[[[R0:jjhP080:jjhP<00000302U`^h00`000000Y<?_0:C3
k`050:C3k`@000000P2X^NH00`000000YkKS00000002000000L0YkKS00<000000:Nag`2W/Ml02@2W
/Ml00`000000YZ_J0:J[fP04000000D0Uh:j00<0000009=g/02CMk002@2CMk000`000000T6fW091]
Y`08091]Y`030000002>K:P0SVbX00T0SVbX00<0000008e^Z`2=KZ/00P2=KZ/00`000000SFj[08e^
Z`0408e^Z`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`00;`3oool00`000000oooo0?ooo`03
0?ooo`040000003oool00000000000@0oooo0P0000020:[0j@030000002^_nL0[[oW00/0[[oW00<0
00000;Bmh@2d_N400`2d_N43000000D0Z[oY00<000000:bmiP2/_NH02@2/_NH00`000000[[[R0:jj
hP050:jjhP<000000P2V`>`00`000000YL;^0:G2kP0;0:G2kP030000002T`nl0Y<?_00@000001@2X
^NH3000000/0YkKS00<000000:Nag`2W/Ml0202W/Ml3000000X0Uh:j00<0000009=g/02CMk00202C
Mk000`000000T6fW091]Y`09091]Y`030000002>K:P0SVbX00T0SVbX00D0000008e^Z`2=KZ/0SFj[
0000000708e^Z`030000003oool0oooo01@0oooo00D000000?ooo`3oool0oooo000000040?ooo`03
0000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo000000010?ooo`00;`3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000030?ooo`8000001@2Z`>T00`000000[[oW0:jo
i`0;0:joi`030000002d_N40];gQ008000002@2Z_nT00`000000[;gV0:bmiP090:bmiP030000002^
^^80[[[R00@000001P2V`>`00`000000YL;^0:G2kP0:0:G2kP<000001`2X^NH2000000<0Z;WV00<0
00000:Nfh`2W]^<02@2W]^<00`000000Yk7O0:Nag`040:Nag`<0000000<0Vho60000002GP[X02P2G
P[X00`000000TgN`09=g/00809=g/0030000002@KJL0T6fW00T0T6fW00<0000008i/Z02>K:P02@2>
K:P00`000000SFj[08e^Z`0208e^Z`030000002=KZ/0SFj[00@0SFj[00<000000?ooo`3oool04`3o
ool00`000000oooo000000030?ooo`@00000303oool300000080oooo000^0?ooo`800000103oool0
0`000000oooo0?ooo`04000000P0Z/3Y00<000000:joi`2^_nL02P2^_nL3000000/0Z[oY00<00000
0:bmiP2/_NH02@2/_NH3000000/0Y/3/00<000000:G2kP2U`^h01`2U`^h200000080Z;cX00<00000
0:RiiP2X^NH00P2X^NH3000000D0Z;WV00<000000:Nfh`2W]^<02@2W]^<00`000000Yk7O0:Nag`04
000000D0Vho600<0000009N2^P2GP[X0202GP[X00`000000TgN`09=g/00809=g/0030000002@KJL0
T6fW00T0T6fW00<0000008i/Z02>K:P02@2>K:P00`000000SFj[08e^Z`0308e^Z`030000002=KZ/0
SFj[00<0SFj[00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`00=`3oool20000
00/0Z/3Y00<000000:joi`2^_nL01`2^_nL200000080ZKoZ00<000000:Zoj@2Z_nT02P2Z_nT00`00
0000[;gV0:bmiP050:bmiP<000000P2W`>`00`000000Y/3/0:K0k00:0:K0k0030000002U`^h0YL;^
00<0YL;^0`0000050:Rlj0@000002@2X^NH00`000000YkKS0:Nfh`070:Nfh`@000002@2KSlH00`00
0000Uh:j09N2^P0809N2^P030000002CMk00TgN`00T0TgN`00<00000091]Y`2@KJL0202@KJL00`00
0000SVbX08i/Z00908i/Z0030000002=KZ/0SFj[00<0SFj[00<0000008e^Z`2=KZ/00`2=KZ/00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo000^0?ooo`@00000103oool00`000000
oooo0000000<0:[0j@030000002^_nL0[[oW00<0[[oW0`0000050:VojP030000002Z_nT0Z[oY00X0
Z[oY00<000000:bmiP2/_NH0100000060:O0k0030000002V`>`0Y/3/00X0Y/3/00<000000:G2kP2U
`^h00P0000060:Rlj0@00000302X^NH010000000YkKS0:Nfh`2W]^<500000080WicA00<0000009^?
aP2KSlH0202KSlH00`000000Uh:j09N2^P0909N2^P030000002CMk00TgN`00P0TgN`00<00000091]
Y`2@KJL0202@KJL00`000000SVbX08i/Z00:08i/Z0030000002=KZ/0SFj[00<0SFj[00<0000008e^
Z`2=KZ/00`2=KZ/00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01@0oooo000]0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000:[0j@0;0:[0
j@030000002^_nL0[[oW008000002@2Y_nX00`000000Z[oY0:Zoj@090:Zoj@<000002`2W`>`20000
00X0Y/3/0`0000050:Rlj0<000000`2X_>P00`000000Z;WV0:RiiP0:0:RiiP@00000202OW=400`00
0000Vho609^?aP0809^?aP030000002GP[X0Uh:j00P0Uh:j00<0000009=g/02CMk00202CMk000`00
0000T6fW091]Y`09091]Y`030000002>K:P0SVbX00T0SVbX00<0000008e^Z`2=KZ/0102=KZ/00`00
0000SFj[08e^Z`0208e^Z`030000003oool0oooo01H0oooo0P00000E0?ooo`00;@3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool2000000X0Z/3Y0`00000<0:Vo
jP030000002Z_nT0Z[oY00H0Z[oY0P0000020:Noj`030000002W`>`0Yl3/00/0Yl3/00<000000:K0
k02V`>`0102V`>`300000080Z;kY00<000000:Rlj02X_>P00`0000070:Rlj0030000002X^NH0Z;WV
00D0Z;WV100000000`2RYmX0000009nLd@0909nLd@030000002KSlH0Vho600P0Vho600<0000009N2
^P2GP[X0202GP[X00`000000TgN`09=g/00809=g/0030000002@KJL0T6fW00T0T6fW00<0000008i/
Z02>K:P02@2>K:P00`000000SFj[08e^Z`0508e^Z`050000002=KZ/0SFj[08e^Z`000000603oool2
000001D0oooo000]0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000002Z`>T0Z/3Y00@0Z/3Y0`0000020:Roj`030000002Y_nX0ZKoZ00/0ZKoZ00<00000
0:Zoj@2Z_nT00`2Z_nT2000000D0Yko[00<000000:O0k02W`>`02`2W`>`00`000000Y/3/0:K0k003
000000D0Z;kY0`00000;0:Rlj0030000002X^NH0Z;WV00@000001P2RYmX00`000000WicA09nLd@07
09nLd@030000002KSlH0Vho600P0Vho600<0000009N2^P2GP[X0202GP[X00`000000TgN`09=g/008
09=g/0030000002@KJL0T6fW00T0T6fW00<0000008i/Z02>K:P02@2>K:P00`000000SFj[08e^Z`05
08e^Z`050000002=KZ/0SFj[08e^Z`0000006P3oool00`000000oooo0?ooo`0B0?ooo`00;@3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`8000001@3oool00`000000Z/3Y0:[0
j@03000000H0Z;o[00<000000:VojP2Y_nX02`2Y_nX00`000000Z[oY0:Zoj@02000000P0Yko[00<0
00000:O0k02W`>`02P2W`>`3000000D0Z;kY0`0000020:Rnj@030000002X_>P0Z;cX00T0Z;cX0`00
000:0::WfP030000002OW=40WicA00P0WicA00<0000009^?aP2KSlH0202KSlH00`000000Uh:j09N2
^P0809N2^P030000002CMk00TgN`00P0TgN`00<00000091]Y`2@KJL0202@KJL00`000000SVbX08i/
Z00908i/Z0030000002=KZ/0SFj[00H0SFj[00D0000008e^Z`2=KZ/0SFj[0000000I0?ooo`030000
003oool0oooo0180oooo000]0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000070?ooo`8000002P2X_n/2000000/0ZKoZ0`00000;0:Noj`030000002W`>`0Yl3/00L0Yl3/
0P0000020:RojP030000002X_^T0Z;kY00<000001P2X_^T00`000000Z;cX0:Rlj0060:Rlj0800000
0P2T/N400`000000XZOJ0::WfP090::WfP030000002OW=40WicA00L0WicA00<0000009^?aP2KSlH0
202KSlH00`000000Uh:j09N2^P0809N2^P030000002CMk00TgN`00P0TgN`00<00000091]Y`2@KJL0
2@2@KJL00`000000SVbX08i/Z00908i/Z0030000002=KZ/0SFj[00H0SFj[00@0000008e^Z`2=KZ/0
00006P3oool00`000000oooo0?ooo`0A0?ooo`00;@3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000Z;o[0:Roj`0:0:Roj`030000002Y_nX0ZKoZ00D0
ZKoZ0`0000020:Noj`030000002W_n/0Yko[00X0Yko[00<000000:O0k02W`>`00`2W`>`3000000D0
Z;oZ0P00000:0:Rnj@030000002X_>P0Z;cX00<0Z;cX0P0000040:Bah@030000002RYmX0XZOJ00T0
XZOJ00<0000009nLd@2OW=401`2OW=400`000000Vho609^?aP0809^?aP030000002GP[X0Uh:j00P0
Uh:j00<0000009=g/02CMk00202CMk000`000000T6fW091]Y`09091]Y`030000002>K:P0SVbX00T0
SVbX00<0000008e^Z`2=KZ/01P2=KZ/010000000SFj[08e^Z`00000J0?ooo`030000003oool0oooo
0140oooo000^0?ooo`@000000`3oool00`000000oooo0?ooo`080?ooo`030000002X_n/0Z;o[00X0
Z;o[00<000000:VojP2Y_nX0100000060:Noj`030000002W_n/0Yko[00X0Yko[00<000000:O0k02W
`>`00P0000050:RojP<0000000<0Z;oZ0000002X_^T02P2X_^T00`000000Z;cX0:Rlj002000000L0
Y;7Q00<000000::WfP2RYmX0202RYmX00`000000WicA09nLd@0809nLd@030000002KSlH0Vho600P0
Vho600<0000009N2^P2GP[X01`2GP[X00`000000TgN`09=g/00809=g/0030000002@KJL0T6fW00T0
T6fW00<0000008i/Z02>K:P02@2>K:P00`000000SFj[08e^Z`0708e^Z`040000002=KZ/0SFj[0000
01T0oooo0P00000B0?ooo`00=@3oool00`000000oooo0?ooo`090?ooo`8000002P2X_n/3000000/0
Yko[00<000000:Noj`2W_n/02@2W_n/3000000@0Z;oZ0`0000040:RojP030000002X_^T0Z;kY00T0
Z;kY0`0000090:Bah@030000002RYmX0XZOJ00T0XZOJ00<0000009nLd@2OW=401`2OW=400`000000
Vho609^?aP0809^?aP030000002GP[X0Uh:j00P0Uh:j00<0000009=g/02CMk001`2CMk000`000000
T6fW091]Y`09091]Y`030000002>K:P0SVbX00T0SVbX00<0000008e^Z`2=KZ/0202=KZ/00`000000
SFj[0000000K0?ooo`030000003oool0oooo00l0oooo000e0?ooo`800000303oool00`000000Z;o[
0:Roj`040:Roj`<000000P2X_n/00`000000Yko[0:Noj`0:0:Noj`030000002W_n/0Yko[00D0Yko[
0`0000020:RojP030000002X_nX0000000800000202X_nX00`000000Z;kY0:Rnj@050:Rnj@<00000
0P2U^>H00`000000Y;7Q0:Bah@080:Bah@030000002RYmX0XZOJ00P0XZOJ00<0000009nLd@2OW=40
202OW=400`000000Vho609^?aP0709^?aP030000002GP[X0Uh:j00P0Uh:j00<0000009=g/02CMk00
1`2CMk000`000000T6fW091]Y`0:091]Y`030000002>K:P0SVbX00P0SVbX00<0000008e^Z`2=KZ/0
2@2=KZ/2000001/0oooo00<000000?ooo`3oool03`3oool003D0oooo00<000000?ooo`3oool0303o
ool00`000000Z;o[0:Roj`03000000H0Z;o[00<000000:Noj`2W_n/02P2W_n/00`000000Yko[0:No
j`04000000@0Z;oZ0`00000<0:RojP030000002X_^T0Z;kY00@000001@2U^>H00`000000Y;7Q0:Ba
h@090:Bah@030000002RYmX0XZOJ00P0XZOJ00<0000009nLd@2OW=401`2OW=400`000000Vho609^?
aP0809^?aP030000002GP[X0Uh:j00L0Uh:j00<0000009=g/02CMk00202CMk000`000000T6fW091]
Y`09091]Y`030000002>K:P0SVbX00T0SVbX00<0000008e^Z`2=KZ/0202=KZ/2000001/0oooo0P00
000@0?ooo`001@3oool500000080oooo00D000000?ooo`3oool0oooo000000040?ooo`D000000`3o
ool4000001@0oooo0P00000>0?ooo`8000002P2X_n/2000000X0Yko[0`0000050:RojP<000000`2X
_nX00`000000Z;oZ0:RojP090:RojP<000002P2U^>H00`000000Y;7Q0:Bah@080:Bah@030000002R
YmX0XZOJ00P0XZOJ00<0000009nLd@2OW=401`2OW=400`000000Vho609^?aP0809^?aP030000002G
P[X0Uh:j00L0Uh:j00<0000009=g/02CMk00202CMk000`000000T6fW091]Y`09091]Y`030000002>
K:P0SVbX00T0SVbX00<0000008e^Z`2=KZ/02@2=KZ/2000001L0oooo0`0000000`28?V/000000000
000?0?ooo`001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool03P3oool00`000000Z;o[0:Roj`0:0:Roj`030000002W_n/0Yko[00@0Yko[0`000002
0:Roj`030000002X_nX0Z;oZ00<000001`2X_nX00`000000Z;oZ0:RojP050:RojP<000000P2V_>P0
0`000000YKSV0:FhiP090:FhiP030000002T/N40Y;7Q00P0Y;7Q00<000000::WfP2RYmX0202RYmX0
0`000000WicA09nLd@0709nLd@030000002KSlH0Vho600L0Vho600<0000009N2^P2GP[X0202GP[X0
0`000000TgN`09=g/00709=g/0030000002@KJL0T6fW00T0T6fW00<0000008i/Z02>K:P02@2>K:P0
0`000000SFj[08e^Z`0908e^Z`8000004`3oool4000000@0R3i[0P00000?0?ooo`001`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool00`00
0000Z;o[0:Roj`0:0:Roj`030000002W_n/0Yko[00<000001@2X_n/3000000/0Z;oZ00<000000:Ro
jP2X_nX0100000060:Jlj0030000002U^>H0YKSV00T0YKSV00<000000:Bah@2T/N401`2T/N400`00
0000XZOJ0::WfP040::WfQ@000001@2KSlH00`000000Uh:j09N2^P0709N2^P030000002CMk00TgN`
00L0TgN`00<00000091]Y`2@KJL02@2@KJL00`000000SVbX08i/Z00908i/Z0030000002=KZ/0SFj[
00H0SFj[0`0000020:G3k`030000003oool0oooo00d0oooo0`00000808PnJ`030000002Y_NP00000
00h0oooo00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool200000180
oooo0P00000:0:Roj`<000001@2X_n/300000080Z;o[0P00000:0:RojP<000002`2V_>P00`000000
YKSV0:FhiP080:FhiP030000002T/N40Y;7Q00@0Y;7Q2P000005092Mg00300000028SM40R8gA00H0
R8gA00<00000085la021O<@00`21O<@7000000P0Uh:j00<0000009=g/02CMk001`2CMk000`000000
T6fW091]Y`0:091]Y`030000002>K:P0SVbX00T0SVbX00<0000008e^Z`2=KZ/00P2=KZ/3000000D0
YL?_00<000000?ooo`3oool02P3oool30000000308HjJ0000000R3i[00P0R3i[00@000000:Vmj02Y
_NP000003@3oool000L0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool04`3oool00`000000Z;o[0:Roj`040:Roj`<000000P2X_n/01000
0000Z;o[0:Roj`2X_n/2000000L0Z;o[00<000000:RojP2X_nX0102X_nX300000080YkkZ00<00000
0:Jlj02V_>P02@2V_>P00`000000YKSV0:FhiP080:FhiPL000001@2GZ^<00`000000T9gL092Mg007
092Mg00300000028SM40R8gA00L0R8gA00<00000085la021O<@01`21O<@00`000000Nffh00000003
000000@0Uh:j00<0000009=g/02CMk00202CMk000`000000T6fW091]Y`09091]Y`030000002>K:P0
SVbX00T0SVbX00<0000008e^Z`0000000P0000090:G3k`030000003oool0oooo00H0oooo0`000004
08HjJ00300000028?V/0R3i[00L0R3i[00@000000:Vmj02Y_NP000003@3oool000L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`030000002X_n/0Z;o[00<000001P2X_n/3
000000X0Z;o[00<000000:RojP2X_nX00`0000060:NnjP030000002V_>P0Y[cX00T0Y[cX00<00000
0:FhiP2U^>H0102U^>H300000080WK?X00<0000009NZh`2GZ^<01`2GZ^<00`000000T9gL092Mg008
092Mg00300000028SM40R8gA00H0R8gA00<00000085la021O<@02021O<@00`000000Nffh07]]^002
07]]^0@0000000<0Uh:j0000002CMk00202CMk000`000000T6fW091]Y`09091]Y`030000002>K:P0
SVbX00P0SVbX0`00000=0:G3k`030000003oool0oooo00<0oooo0P00000708HjJ00300000028?V/0
R3i[00L0R3i[00<000000:Vmj02Y_NP00P00000<0?ooo`001@3oool3000000d0oooo0`0000040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool2000001H0oooo0P0000060:Ro
j`<0000000<0Z;o[0000002X_n/02P2X_n/3000000X0YkkZ00<000000:Jlj02V_>P02@2V_>P00`00
0000YKSV0:FhiP03000000D0WK?X00<0000009NZh`2GZ^<0202GZ^<00`000000T9gL092Mg007092M
g00300000028SM40R8gA00L0R8gA00<00000085la021O<@01`21O<@00`000000Nffh07]]^00607]]
^0<00000202CMk000`000000T6fW091]Y`09091]Y`030000002>K:P0SVbX00D0SVbX0`0000020:G3
k`030000002U`nl0YL?_00/0YL?_0P0000020?ooo`<000002026>VP00`000000R3i[08PnJ`0708Pn
J`<0000000<0oooo0000003oool02`3oool000L0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`@000001`3oool5000000030?ooo`000000000000@0oooo00<000000?ooo`3o
ool05P3oool010000000Z;o[0:Roj`2X_n/3000000D0Z;o[00<000000:Roj`2X_n/01@2X_n/30000
0080Yko[00<000000:NnjP2W_^X02@2W_^X00`000000Y[cX0:Jlj0070:Jlj0@000002@2M/nP00`00
0000Uj[S09NZh`0809NZh`030000002@WM`0T9gL00L0T9gL00<0000008R=d@28SM401P28SM400`00
0000PGc4085la007085la0030000001kKKP0Nffh00L0Nffh00@0000006MZ`P00000000001P2CMk00
0`000000T6fW091]Y`0:091]Y`030000002>K:P0SVbX0080SVbX0P0000050:G3k`030000002U`nl0
YL?_00`0YL?_0`000002088cH@0300000026>VP0QSYX00H0QSYX00<0000008PnJ`28?V/01`28?V/0
1@000000oooo0?ooo`3oool0000000`0oooo000Z0?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo0000000I0?ooo`<000002@2X_n/00`000000Z;o[0:Roj`04000000H0Yko[00<0
00000:NnjP2W_^X02@2W_^X010000000Y[cX0:Jlj02V_>P5000000<0XK[Z00<0000009fcj02M/nP0
202M/nP00`000000Uj[S09NZh`0709NZh`030000002@WM`0T9gL00L0T9gL00<0000008R=d@28SM40
1P28SM400`000000PGc4085la007085la0030000001kKKP0Nffh00P0Nffh00<0000006MZ`P1WJ/80
0P00000409=g/0030000002@KJL0T6fW00X0T6fW00<0000008i/Z00000000P0000080:G3k`030000
002U`nl0YL?_00/0YL?_0P000003088cH@0300000026>VP0QSYX00H0QSYX00<0000008PnJ`28?V/0
1`28?V/01@000000oooo0?ooo`3oool0000000`0oooo000T0?ooo`<000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo0?ooo`8000005P3oool3000000030?ooo`000000Z;o[00T0
Z;o[0`00000;0:Noj`030000002W_^X0YkkZ00P0YkkZ100000090:6jjP030000002M/nP0WK?X00P0
WK?X00<0000009NZh`2GZ^<01`2GZ^<00`000000T9gL092Mg007092Mg00300000028SM40R8gA00H0
R8gA00<00000085la021O<@01`21O<@00`000000Nffh07]]^00707]]^0030000001WJ/80If[20080
If[20P00000309=g/0030000002@KJL0T6fW00L0T6fW1000000<0:G3k`030000002U`nl0YL?_00L0
YL?_0`0000020:G3k`0400000022<f40PS=Q000000P0QSYX00@0000008PnJ`28?V/0R3i[0P000004
08PnJ`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool002X0oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`00000D0?ooo`<000001@3oool00`000000Z;o[0:Roj`04
0:Roj`<000000P2X_n/00`000000Yko[0:Noj`0:0:Noj`030000002W_^X0YkkZ00@0YkkZ0`000002
0:Bmj`030000002Q^^X0XK[Z00T0XK[Z00<0000009fcj02M/nP01`2M/nP00`000000Uj[S09NZh`08
09NZh`030000002@WM`0T9gL00H0T9gL00<0000008R=d@28SM401P28SM400`000000PGc4085la007
085la0030000001kKKP0Nffh00L0Nffh00<0000006MZ`P1WJ/80101WJ/820000000309=g/0000000
T6fW0080T6fW1P00000309J_j0030000002U`nl0YL?_00/0YL?_00<000000:G3k`2U`nl00`2U`nl3
000000D0YL?_00@00000088cH@22<f4000002026>VP40000000305L000000000R3i[00<0R3i[00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`00:P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000000P3oool200000100oooo0`0000090?ooo`030000002X_n/0Z;o[00<00000
1P2X_n/00`000000Yko[0:Noj`0:0:Noj`030000002W_^X0YkkZ00<000001P2T_N/00`000000XK[Z
0:6jjP090:6jjP030000002M/nP0WK?X00L0WK?X00<0000009NZh`2GZ^<01`2GZ^<00`000000T9gL
092Mg007092Mg00300000028SM40R8gA00H0R8gA00<00000085la021O<@01P21O<@00`000000Nffh
07]]^00807]]^0030000001WJ/80If[200D0If[21@00000:09J_j0030000002U`nl0YL?_00X0YL?_
00<000000:G3k`2U`nl00`0000090:G3k`8000001P26>VP4000000<0E`0000<000000:>Ba0000000
0`28?V/00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo000Y0?ooo`800000103o
ool01@000000oooo0?ooo`3oool0000000h0oooo0`00000=0?ooo`8000002P2X_n/2000000X0Yko[
0`00000:0:Bmj`030000002Q^^X0XK[Z00T0XK[Z00<0000009fcj02M/nP00`2M/nPC000000@0T9gL
00<0000008R=d@28SM401P28SM400`000000PGc4085la007085la0030000001kKKP0Nffh00L0Nffh
00<0000006MZ`P1WJ/801`1WJ/800`000000UZoX09J_j00:09J_j0030000002U`nl0YL?_00X0YL?_
0`00000=0:G3k`0400000026>VP0QSYX08HjJ0<000001`1G00000`000000Xi;40000000408PnJ`05
0000003oool0oooo0?ooo`0000002`3oool003<0oooo00<000000?ooo`3oool02P3oool200000140
oooo00<000000:Roj`2X_n/02P2X_n/00`000000Yko[0:Noj`040:Noj`<000000P2V_n/00`000000
Y;g[0:Bmj`090:Bmj`030000002Q^^X0XK[Z00L0XK[Z1`000005092dk`0300000021ZNh0PJW^00L0
PJW^00@0000006bIj`1/VN/0K9W[1`00000608R=d@0300000021O<@0PGc400L0PGc400<0000007]]
^01kKKP0201kKKP00`000000If[206MZ`P0606MZ`P030000002F[nP0UZoX00/0UZoX00<000000:G3
k`2U`nl01@2U`nl400000080YL?_00<000000:G3k`2U`nl0302U`nl4000000T0E`0000@000000:>B
a02ST/@000000`28?V/01@000000oooo0?ooo`3oool0000000/0oooo00020?ooo`D000000`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo1@0000030?ooo`@000004`3oool3000000P0oooo0`00
000D0?ooo`030000002X_n/0Z;o[00X0Z;o[00<000000:Noj`2W_n/00`0000060:Joj`030000002T
_N/0Y;g[00T0Y;g[00@000000:6jjP2Q^^X0XK[Z1@00000309ZjkP030000002@]>l0T;C_00L0T;C_
00<00000086YkP21ZNh01P21ZNh00`000000K9W[06bIj`0706bIj`<000001@28SM400`000000PGc4
085la006085la0030000001kKKP0Nffh00P0Nffh00<0000006MZ`P1WJ/801`1WJ/800`000000UZoX
09J_j00;09J_j0030000002U`nl0YL?_00@000001`2U`nl00`000000YL?_0:G3k`0;0:G3k`030000
000M0000000000X0E`0000@000000:>Ba02ST/@000000`28?V/01@000000oooo0?ooo`3oool00000
00/0oooo00020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo000000070?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00D0oooo0`00000H0?ooo`8000002P2X_n/3000000X0Y[o[00<000000:Bm
j`2T_N/0202T_N/4000000T0V[[^00<00000092dk`2@]>l01`2@]>l00`000000PJW^086YkP06086Y
kP030000001/VN/0K9W[00H0K9W[00<000000562h`1AP^<00`00000208R=d@0300000021O<@0PGc4
00L0PGc400<0000007]]^01kKKP01`1kKKP00`000000If[206MZ`P0806MZ`P030000002F[nP0UZoX
00X0UZoX0`00000;0:G3k`030000002U`nl0YL?_00/0YL?_0`00000905L000050000002ST/@0Xi;4
0:>Ba00000000`28?V/01@000000oooo0?ooo`3oool0000000/0oooo00030?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`020?ooo`<000007@3oool0
0`000000Z;o[0:Roj`040:Roj`<000000P2W_n/00`000000Y[o[0:Joj`090:Joj`030000002T_N/0
Y;g[00@0Y;g[0`0000020:6mk@030000002J^^h0V[[^00P0V[[^00<00000092dk`2@]>l01`2@]>l0
0`000000PJW^086YkP07086YkP030000001/VN/0K9W[00H0K9W[00<000000562h`1AP^<00P1AP^<2
0000000308R=d@000000PGc400L0PGc400<0000007]]^01kKKP0201kKKP00`000000If[206MZ`P08
06MZ`P030000002F[nP0UZoX00H0UZoX0`0000020:G3k`030000002U`nl0YL?_00X0YL?_00<00000
0:G3k`2U`nl01P2U`nl400000080YL?_2`0000040:>Ba00400000028?V/0R3i[000000@0oooo00<0
00000?ooo`3oool0203oool000@0oooo00<000000?ooo`3oool0103oool00`000000oooo00000007
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@
0?ooo`D000008@3oool00`000000Z;o[0:Roj`03000000H0Yko[00<000000:Joj`2V_n/02@2V_n/0
0`000000Y;g[0:Bmj`03000000H0XKg]00<0000009ZjkP2J^^h0202J^^h00`000000T;C_092dk`07
092dk`0300000021ZNh0PJW^00L0PJW^00<0000006bIj`1/VN/01@1/VN/00`000000DH;S0562h`04
0562h`8000002021O<@00`000000Nffh07]]^00807]]^0030000001WJ/80If[200P0If[200<00000
09J_j02F[nP0102F[nP2000000H0YL?_00<000000:G3k`2U`nl02P2U`nl010000000YL?_0:G3k`2U
`nl4000000H0YL?_00<0000006lHB@1_64T01`1_64T00`000000Xi;40:>Ba0020:>Ba00400000028
?V/0R3i[000000@0oooo00<000000?ooo`3oool0203oool000D0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo0P00000U0?ooo`8000002P2W_n/00`000000Y[o[
0:Joj`080:Joj`<000002P2Q_Nd00`000000V[[^09ZjkP0809ZjkP030000002@]>l0T;C_00L0T;C_
00<00000086YkP21ZNh01P21ZNh00`000000K9W[06bIj`0606bIj`030000001AP^<0DH;S00D0DH;S
0P000006085la0030000001kKKP0Nffh00P0Nffh00<0000006MZ`P1WJ/802@1WJ/800`000000UZoX
09J_j003000000P0YL?_00<000000:G3k`2U`nl02P2U`nl4000000/0YL?_00<0000006lHB@1_64T0
1P1_64T00`000000Xi;40:>Ba0030:>Ba00300000028?V/0000000@0oooo00<000000?ooo`3oool0
203oool000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0T0?ooo`030000002W
_n/0Yko[00T0Yko[00<000000:Joj`2V_n/0102V_n/300000080YKk/00<000000:6mk@2Q_Nd02@2Q
_Nd00`000000V[[^09ZjkP0609ZjkQL000001P1/VN/00`000000DH;S0562h`050562h`040000000e
ImD00000000000D0PGc400<0000007]]^01kKKP0201kKKP00`000000If[206MZ`P0806MZ`P<00000
302U`nl00`000000YL?_0:G3k`050:G3k`@000000P2U`nl00`000000YL?_0:G3k`0;0:G3k`030000
001_64T0KaQ900@0KaQ900<000000:>Ba02ST/@0102ST/@00`000000R3i[000000040?ooo`030000
003oool0oooo00P0oooo00020?ooo`050000003oool0oooo0?ooo`000000303oool3000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`D0000000<0oooo000000000000
1P3oool2000002D0oooo00<000000:Noj`2W_n/02@2W_n/00`000000Y[o[0:Joj`03000000H0YKk/
00<000000:6mk@2Q_Nd02@2Q_Nd010000000V[[^09ZjkP2J^^h4000000<0U[cb00<0000008FhmP25
^?H01`25^?H00`000000IZki06J^n@0606J^n@@00000101/VN/00`000000DH;S0562h`050562h`03
0000000eImD0=FOE008000000`21O<@00`000000Nffh07]]^00807]]^0030000001WJ/80If[200@0
If[2100000020:G3k`030000002U`nl0YL?_00/0YL?_00<000000:G3k`2U`nl0100000070:G3k`03
0000002U`nl0YL?_00X0YL?_0P00000506lHB@030000002ST/@0Xi;400@0Xi;400<0000008PnJ`00
0000103oool00`000000oooo0?ooo`080?ooo`000`3oool3000000l0oooo00<000000?ooo`3oool0
0`3oool4000000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02<0oooo0P0000080:Noj`@000002P2U_^`2000000P0XKg]1@00000809JllP030000
0025^?H0QKSf00L0QKSf0P00000806J^n@030000000YTnl0000000@00000201AP^<010000000=FOE
03EWe@0eImD200000003085la0000000Nffh00X0Nffh00<0000006MZ`P0000000`0000070:G3k`03
0000002U`nl0YL?_00X0YL?_0`00000;0:G3k`030000002U`nl0YL?_00X0YL?_0P00000506lHB@03
0000002ST/@0Xi;400D0Xi;40P0000040?ooo`030000003oool0oooo00P0oooo000R0?ooo`<00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
903oool010000000Yko[0:Noj`2W_n/4000000<0Yko[00<000000:Fnk02U_^`02P2U_^`010000000
XKg]0:6mk@2Q_Nd4000000<0Wkk^00<0000009JllP2F_?80202F_?800`000000QKSf08FhmP0808Fh
mP030000001V[_T0IZki00H0IZki0P00000302VCk`<000001P1AP^<00`000000=FOE03EWe@0303EW
e@<000001@1kKKP7000000/0YL?_00<000000:G3k`2U`nl01`2U`nl300000080YL?_00<000000:G3
k`2U`nl02P2U`nl00`000000YL?_0:G3k`050:G3k`@000000P2U`nl00`000000KaQ906lHB@0206lH
B@030000002ST/@0Xi;400D0Xi;40P0000040?ooo`030000003oool0oooo00P0oooo000X0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0T0?ooo`<0
0000202W_n/00`000000YKk/0:Fnk0090:Fnk0@00000202O_^h00`000000U[cb09JllP0809JllP03
00000025^?H0QKSf00H0QKSf3`00000202VCk`@00000101AP^<00`000000=FOE03EWe@0403EWe@H0
00001P2<X^<00`000000YL?_0:G3k`0:0:G3k`030000002U`nl0YL?_00@0YL?_0P0000050:G3k`03
0000002U`nl0YL?_00/0YL?_00<000000:G3k`2U`nl0100000070:G3k`050000001_64T0KaQ906lH
B@000000202ST/@00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo000X0?ooo`07
0000003oool0oooo0?ooo`000000oooo0000000:0?ooo`030000003oool0oooo02@0oooo00<00000
0:Noj`2W_n/0202W_n/2000000H0YKk/0`0000020:Bok0030000002O_^h0Wkk^00P0Wkk^0P000009
09JllP0400000025^?H0QKSf08FhmP@000000`29`?T2000000P0I[_m2P0000030562h`030000000e
ImD0=FOE00@0=FOE00<0000008bRh`2<X^<02@2<X^<00`000000YL?_0:G3k`0:0:G3k`030000002U
`nl0YL?_00<00000202U`nl00`000000YL?_0:G3k`0:0:G3k`<000002`2U`nl200000080KaQ900@0
00000:>Ba02ST/@0Xi;41P0000050?ooo`030000003oool0oooo00L0oooo000W0?ooo`800000103o
ool00`000000oooo0?ooo`0:0?ooo`8000009@3oool00`000000Yko[0:Noj`090:Noj`030000002U
_^`0YKk/00<000001P2T_n`00`000000Wkk^09nnkP0909nnkP030000002F_?80U[cb00<0U[cb1`00
000908W0n@030000001V^od0I[_m00L0I[_m0P00000301>Hh@L000001P0eImD00`000000S:;S08bR
h`0908bRh`030000002U`nl0YL?_00X0YL?_0`00000<0:G3k`030000002U`nl0YL?_00H0YL?_0`00
00020:G3k`030000002U`nl0YL?_00X0YL?_00<0000006lHB@0000001000000;0?ooo`030000003o
ool0oooo00L0oooo000l0?ooo`030000003oool0oooo02<0oooo00<000000:Noj`2W_n/0202W_n/3
000000X0Y;o/00<0000009nnkP2O_^h0202O_^h6000000D0VKoc00<0000008W0n@29`?T02@29`?T2
000000D0I[_m2P0000000`1Waod0000000000002000000H0=FOE00<0000008bRh`2<X^<02@2<X^<0
0`000000YL?_0:G3k`050:G3k`@000000P2U`nl00`000000YL?_0:G3k`0;0:G3k`030000002U`nl0
YL?_00<0YL?_0P0000050:G3k`030000002U`nl0YL?_00/0YL?_0P00000?0?ooo`030000003oool0
oooo00L0oooo000m0?ooo`030000003oool0oooo02<0oooo00<000000:Noj`2W_n/0102W_n/30000
0080Yko[00<000000:Bok02T_n`02@2T_n`00`000000Wkk^09nnkP0409nnkP<000000P2Q_nh00`00
0000VKoc09Vol`0709Vol`8000002@29`?T7000000H0R/Sl0P00000406O7o@D00000100eImD00`00
0000S:;S08bRh`0:08bRh`030000002U`nl0YL?_00@000001`2U`nl00`000000YL?_0:G3k`0:0:G3
k`030000002U`nl0YL?_00<00000202U`nl00`000000YL?_0:G3k`0:0:G3k`8000003`3oool00`00
0000oooo0?ooo`070?ooo`00?P3oool00`000000oooo0?ooo`0S0?ooo`030000002W_n/0Yko[00<0
00001P2W_n/00`000000Y;o/0:Bok0090:Bok0030000002O_^h0Wkk^00<000001P2Q_nh00`000000
VKoc09Vol`0809Vol`0400000029`?T0RL3i08W0n@D000000`2Ia?D00`000000R/Sl08[8o00908[8
o0@000001@2RaO82000000<0=FOE00<0000008bRh`2<X^<02@2<X^<3000000/0YL?_00<000000:G3
k`2U`nl02P2U`nl3000000`0YL?_00<000000:G3k`2U`nl01@2U`nl4000000030?ooo`000000oooo
00h0oooo00<000000?ooo`3oool01`3oool003l0oooo0P00000T0?ooo`8000002P2W_n/2000000P0
Y;o/1000000:0:6okP030000002I_o<0VKoc00H0VKoc1@00000909W4m@8000001P2:b?`300000080
Y<;_00<000000:;5lP2RaO801P2RaO8200000080=FOE00<0000008bRh`2<X^<0102<X^<400000080
V]_m00<000000:G3k`2U`nl02P2U`nl00`000000YL?_0:G3k`050:G3k`@000000P2Qd_T00`000000
YL?_0:G3k`0:0:G3k`040000002U`nl0YL?_0:G3k`@000001P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00L0oooo00110?ooo`030000003oool0oooo0280oooo00<000000:Noj`2W
_n/02P2W_n/010000000Y;o/0:Bok02T_n`4000000<0YKo/00<000000:6okP2Q_nh02@2Q_nh01000
0000VKoc09Vol`2I_o<4000000<0X<7`0P00000;09W4m@030000002:b?`0R/Sl00<000001P2T`^l0
0`000000X/Gb0:;5lP070:;5lP<000000P2<X^<4000000L0V]_m00<000000:G3k`2U`nl02P2U`nl0
0`000000YL?_0:G3k`04000000L0XM;i00<000000:G3k`2U`nl02@2U`nl4000000/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`00@P3oool00`000000oooo0?ooo`0R0?oo
o`030000002W_n/0Yko[00T0Yko[100000080:Fok0030000002Q_nh0XKo^00P0XKo^100000090:31
l0030000002Ia?D0VLCe00L0VLCe1000000:0:C2k`030000002RaO80X/Gb00D0X/Gb1P00000;09[K
o@030000002U`nl0YL?_00X0YL?_0`00000;0:7Bn@030000002U`nl0YL?_00D0YL?_1000000@0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01P3oool004<0oooo00<000000?ooo`3o
ool08P3oool2000000H0Yko[0`0000020:Noj`030000002U_n`0YKo/00P0YKo/00<000000:6okP2Q
_nh0102Q_nh300000080Y<3]00<000000:31l02P`O002@2P`O02000000<0VLCe100000030:G1k@03
0000002T`^l0Y<;_00T0Y<;_00<000000:;5lP2RaO80100000050:Rji`8000002`2Jfod00`000000
YL?_0:G3k`050:G3k`@000000P0H00000`000000XM;i0:7Bn@0:0:7Bn@030000002U`nl0YL?_00@0
0000503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00140?ooo`030000
003oool0oooo02<0oooo00<000000:Noj`2W_n/00`0000060:Noj`030000002U_n`0YKo/00P0YKo/
00<000000:6okP2Q_nh00`0000060:C0k@030000002P`O00X<7`00T0X<7`100000080:G1k@800000
202T`^l4000000X0Z;[W0`00000:09[Ko@030000002U`nl0YL?_00@00000103oool5000000T0XM;i
1000000I0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool004D0oooo0P00
000T0?ooo`8000002P2W_n/00`000000YKo/0:Fok0060:Fok0@000002P2T`>d2000000H0X<7`0`00
00020:K0k0030000002U`Nd0YL7]00T0YL7]00@000000:C2k`2T`^l0Y<;_100000030:Rlj0030000
002X^^L0Z;[W00T0Z;[W00<000000:Rgi00000003000000;0?ooo`<000000`2Qd_T5000001h0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`00A`3oool00`000000oooo0?oo
o`0R0?ooo`030000002W_n/0Yko[00T0Yko[00@000000:Fok02U_n`0YKo/100000030:Jok0030000
002T`>d0Y<3]00X0Y<3]00<000000:31l02P`O000`0000060:K0k0030000002U`Nd0YL7]00P0YL7]
100000080:Rlj0030000002X^^L0Z;[W00P0Z;[W00@000000:Rgi02X]n@0Z;OT1@00000C0?ooo`@0
00008`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00180?ooo`030000
003oool0oooo0280oooo00<000000:Noj`2W_n/0202W_n/4000000P0Y[o/00<000000:C0k@2T`>d0
2@2T`>d3000000X0Y/3/00<000000:G1k@2U`Nd0102U`Nd300000080Z;kY00<000000:Rlj02X_>P0
202X_>P00`000000Z;[W0:Rji`060:Rji`P00000?@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00H0oooo00190?ooo`030000003oool0oooo0280oooo0P0000060:Noj`8000000P2W
_n/00`000000Y[o/0:Jok0080:Jok08000001P2T`>d300000080Yl3[00<000000:K0k02V`>`02@2V
`>`00`000000YL7]0:G1k@03000000H0Z;kY00<000000:Rlj02X_>P0202X_>P010000000Z;[W0:Rj
i`2X^^L4000000@0TMgn0P0000100?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1P3oool004X0oooo0P00000T0?ooo`030000002W_n/0Yko[00<000001@2W_n/00`000000Y[o/0:Jo
k0090:Jok0030000002T`>d0Y<3]00<000001P2W`>/00`000000Y/3/0:K0k0080:K0k0<000002@2X
_^T00`000000Z;cX0:Rlj0080:Rlj0@000001@2AgOh3000004<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`00C03oool00`000000oooo0?ooo`0R0?ooo`8000002@2W_n/2
000000P0Y[o/1000000:0:O0j`030000002V`>`0Y/3/00@0Y/3/0`0000020:RojP030000002X_^T0
Z;kY00P0Z;kY00<000000:Rlj02X_>P0102X_>P300000080X=7i0P000003097MoP800000AP3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo001=0?ooo`030000003oool0oooo
0280oooo00<000000:Noj`2W_n/02@2W_n/010000000Y[o/0:Jok02V_n`4000000<0Yko[00<00000
0:O0j`2W`>/02@2W`>/00`000000Y/3/0:K0k003000000H0Z;oZ00<000000:Rnj@2X_^T0202X_^T0
0`000000Z;cX0:Rlj003000000L0X=7i0`0000190?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01@3oool004h0oooo00<000000?ooo`3oool08P3oool00`000000Yko[0:Noj`080:No
j`@00000202W_n/00`000000Yl3[0:O0j`080:O0j`<000002P2X_nX00`000000Z;kY0:Rnj@060:Rn
j@@00000202PdOT2000004d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o`00C`3oool00`000000oooo0?ooo`0R0?ooo`030000002W_n/0Yko[00@0Yko[0`0000020:Roj`03
0000002W_n/0Yko[00P0Yko[00<000000:O0j`2W`>/0102W`>/300000080Z;o[00<000000:RojP2X
_nX02@2X_nX010000000Z;kY0:Rnj@2X_^T4000000<0Y<Sb00<000000:3An@2PdOT0102PdOT20000
0500oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`00D03oool2000002<0
oooo00<000000:Noj`2W_n/00`0000060:Roj`030000002W_n/0Yko[00P0Yko[00<000000:O0j`2W
`>/00`0000060:Roj`030000002X_nX0Z;oZ00P0Z;oZ100000080:C8lP8000000P2PdOT200000580
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`00DP3oool00`000000oooo
0?ooo`0Q0?ooo`8000002P2X_n/00`000000Yko[0:Noj`060:Noj`@000002P2X_n/00`000000Z;oZ
0:RojP040:RojP<000000P2V`nh00`000000Y<Sb0:C8lP080:C8lP<00000E@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00D0oooo001C0?ooo`030000003oool0oooo0240oooo00<0
00000:Roj`2X_n/02@2X_n/010000000Yko[0:Noj`2W_n/4000000<0Z;o[00<000000:Roj`2X_n/0
2@2X_n/00`000000Z;oZ0:RojP03000000H0Y/?^0P0000060:C8lP80000000<0V>[i0000003oool0
EP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo001D0?ooo`030000003o
ool0oooo0240oooo00<000000:Roj`2X_n/0202X_n/4000000P0Z;o[0P0000080:Roj`@000002`2V
`nh00`000000Y<Sb0:C8lP030000000309SZn@000000000005P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`040?ooo`00E@3oool200000280oooo0P0000060:Roj`8000000P2X_n/0
0`000000Z;o[0:Roj`090:Roj`040000002X_n/0Z;o[0:Roj`@000000`2W`N`00`000000Y/?^0:K3
kP090:K3kP<000000`2Hj_T00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool005L0oooo00<000000?ooo`3oool08@3oool00`000000Z;o[0:Roj`03
000000D0Z;o[00<000000:Roj`2X_n/0202X_n/4000000P0Yl7/0P0000060:K3kP<000000`2YeOL3
000005d0oooo00D000000?ooo`3oool0oooo000000060?ooo`00F03oool00`000000oooo0?ooo`0Q
0?ooo`8000002@2X_n/00`000000Z;o[0:Roj`040:Roj`<000000P2W`>/00`000000Yl7/0:O1k009
0:O1k0030000002V`nh0Y/?^00<000001P2YeOL2000005l0oooo00@000000?ooo`3oool000001P3o
ool005T0oooo00<000000?ooo`3oool08@3oool00`000000Z;o[0:Roj`080:Roj`030000002X_n/0
Z;o[00<000001P2W`>/00`000000Yl7/0:O1k0080:O1k0<00000202YeOL00`000000oooo0?ooo`1O
0?ooo`040000003oool0oooo000000H0oooo001J0?ooo`030000003oool0oooo0240oooo0P000008
0:Roj`<000002P2W`>/00`000000Yl7/0:O1k0040:O1k0<000000P2Yanl2000000D0ZMGg0P00001S
0?ooo`030000003oool0000000H0oooo001K0?ooo`8000008`3oool010000000Z;o[0:Roj`2X_n/4
00000080Z;o[0P00000:0:O0j`030000002W`N`0Yl7/00<000001`2Yanl2000000030:WEm`000000
000006H0oooo00<000000?ooo`0000001@3oool005d0oooo00<000000?ooo`3oool08@3oool30000
00P0Z;o[00<000000:O0j`2W`>/01`2W`>/3000000/0ZLO_0P00001Y0?ooo`8000001@3oool005h0
oooo00<000000?ooo`3oool08@3oool00`000000Z;o[0:Roj`080:Roj`8000000`2W`>/400000080
ZL;/00<000000:W7k`2Yanl01`2Yanl2000006/0oooo0P0000050?ooo`00G`3oool00`000000oooo
0?ooo`0Q0?ooo`030000002X_n/0Z;o[00P0Z;o[100000070:W2k08000001@2Yanl2000006d0oooo
0P0000050?ooo`00H03oool200000280oooo00<000000:Roj`2X_n/0102X_n/300000080Z<3[00<0
00000:W2k02Y`^`0202Y`^`00`000000ZLO_0:W7k`02000006/0oooo100000070?ooo`00HP3oool0
0`000000oooo0?ooo`0P0?ooo`030000002X_n/0Z;o[00<000001P2X`>/00`000000ZL;/0:W2k007
0:W2k0<00000J@3oool4000000/0oooo001S0?ooo`030000003oool0oooo0200oooo0P0000090:S0
j`030000002Y`^`0ZL;/00@0ZL;/0`00001X0?ooo`@000003`3oool006@0oooo00<000000?ooo`3o
ool0803oool00`000000Z<3[0:S0j`080:S0j`030000002Y`^`0ZL;/00<00000I`3oool4000001<0
oooo001U0?ooo`030000003oool0oooo0200oooo0P0000080:S0j`<00000IP3oool4000001L0oooo
001V0?ooo`8000008P3oool010000000Z<3[0:S0j`2X`>/4000006H0oooo0`00000K0?ooo`00J03o
ool00`000000oooo0?ooo`0P0?ooo`<00000IP3oool4000001h0oooo001Y0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0HP3oool400000280oooo001Z0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0GP3oool4000002H0oooo001[0?ooo`8000007P3oool00`000000
oooo0?ooo`1J0?ooo`@00000:P3oool006d0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`1F0?ooo`@00000;P3oool006h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`1C0?ooo`<00000<P3oool006l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1?
0?ooo`@00000=@3oool00700oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1;0?oo
o`@00000>@3oool00740oooo0P00000H0?ooo`030000003oool0oooo04L0oooo1000000m0?ooo`00
L`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04<0oooo100000110?ooo`00M03o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0400oooo0`0000150?ooo`00M@3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03`0oooo100000180?ooo`00MP3oool20000
01<0oooo00<000000?ooo`3oool0>03oool4000004`0oooo001h0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0=03oool400000500oooo001i0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0<03oool4000005@0oooo001j0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0;03oool4000005P0oooo001k0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0:@3oool3000005`0oooo001l0?ooo`800000303oool00`000000oooo0?ooo`0V0?oo
o`@00000G`3oool007h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0R0?ooo`@0
0000H`3oool007l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0N0?ooo`@00000
I`3oool00800oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000J`3o
ool00840oooo0P0000070?ooo`030000003oool0oooo01H0oooo1000001_0?ooo`00P`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo01<0oooo0`00001c0?ooo`00Q03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo1000001f0?ooo`00Q@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo1000001j0?ooo`00QP3oool01@000000oooo0?oo
o`3oool0000000T0oooo1000001n0?ooo`00Q`3oool2000000030?ooo`000000oooo00@0oooo1000
00220?ooo`00R@3oool2000000030?ooo`000000000000800000QP3oool008X0oooo0P00002:0?oo
o`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?oo
o`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?oo
o`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?ooo`00o`3ooolG0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 277.875}, {225.25, 0}} -> {-0.215687, -0.0614005, \
0.00536204, 0.00536204}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[74]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(h = \[Pi]\/8\)]],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {h \[Rule] Pi/8}, {\[Xi], 1/16, 
        2}, {x, \(-Pi\)/8, 
        Pi/8}, \[IndentingNewLine]ViewPoint -> {2.220, \ 1.779, \ 
          1.833}]\)], "Input",
  CellLabel->"In[75]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77122 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-4.99817e-017 1.01989 -0.0693598 1.01989 [
[.90539 .28416 0 -6.43539 ]
[.90539 .28416 18 2.56461 ]
[.80927 .1975 0 -6.58868 ]
[.80927 .1975 6 2.41132 ]
[.70254 .10129 0 -6.76834 ]
[.70254 .10129 18 2.23166 ]
[.58333 -0.00616 0 -6.98181 ]
[.58333 -0.00616 6 2.01819 ]
[.13814 .22647 -24 -7.47697 ]
[.13814 .22647 0 1.52303 ]
[.26946 .15376 -6 -7.76875 ]
[.26946 .15376 0 1.23125 ]
[.41243 .07463 -18 -8.12394 ]
[.41243 .07463 0 .87606 ]
[.01639 .32679 -43.5 -9.96821 ]
[.01639 .32679 0 2.53179 ]
[.00554 .40486 -6 -7.03754 ]
[.00554 .40486 0 1.96246 ]
[-0.0058 .48647 -37.5 -9.57335 ]
[-0.0058 .48647 0 2.92665 ]
[ 0 0 0 0 ]
[ 1 .77122 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.97016 .35799 m
.57217 0 L
s
.89367 .28919 m
.88782 .29171 L
s
[(0.5)] .90539 .28416 -1 .43009 Mshowa
.7977 .20287 m
.79192 .20555 L
s
[(1)] .80927 .1975 -1 .46415 Mshowa
.69115 .10702 m
.68546 .10989 L
s
[(1.5)] .70254 .10129 -1 .50408 Mshowa
.57217 0 m
.56659 .00308 L
s
[(2)] .58333 -0.00616 -1 .55151 Mshowa
.125 Mabswid
.87525 .27262 m
.87175 .27415 L
s
.85645 .25571 m
.85296 .25726 L
s
.83727 .23846 m
.83378 .24003 L
s
.81769 .22085 m
.81421 .22244 L
s
.77729 .18451 m
.77383 .18614 L
s
.75645 .16576 m
.753 .16741 L
s
.73515 .1466 m
.73171 .14828 L
s
.71339 .12703 m
.70997 .12873 L
s
.66842 .08657 m
.66501 .08832 L
s
.64517 .06566 m
.64178 .06743 L
s
.62139 .04427 m
.61801 .04607 L
s
.59706 .02239 m
.5937 .02421 L
s
.91174 .30544 m
.90822 .30693 L
s
.92945 .32137 m
.92592 .32284 L
s
.94682 .33699 m
.94328 .33845 L
s
.96385 .35232 m
.96031 .35376 L
s
.25 Mabswid
.03223 .29778 m
.57217 0 L
s
.14878 .23351 m
.15409 .23702 L
s
[(-0.2)] .13814 .22647 1 .66155 Mshowa
.27978 .16126 m
.28494 .165 L
s
[(0)] .26946 .15376 1 .72639 Mshowa
.42235 .08262 m
.42732 .08662 L
s
[(0.2)] .41243 .07463 1 .80532 Mshowa
.125 Mabswid
.0573 .28396 m
.06055 .28597 L
s
.08718 .26748 m
.09041 .26952 L
s
.11767 .25066 m
.12088 .25274 L
s
.18052 .216 m
.18369 .21814 L
s
.21292 .19813 m
.21607 .20031 L
s
.246 .17989 m
.24912 .1821 L
s
.31428 .14223 m
.31735 .14451 L
s
.34953 .12279 m
.35257 .12511 L
s
.38554 .10293 m
.38855 .10529 L
s
.45999 .06187 m
.46293 .06431 L
s
.49847 .04064 m
.50138 .04312 L
s
.53783 .01894 m
.54071 .02146 L
s
.25 Mabswid
.03223 .29778 m
0 .53211 L
s
.02735 .33331 m
.03282 .33657 L
s
gsave
.01639 .32679 -43.5 -7.96821 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-11) show
grestore
.01664 .41112 m
.0222 .41425 L
s
[(0)] .00554 .40486 1 .5639 Mshowa
.00545 .49246 m
.01108 .49545 L
s
gsave
-0.0058 .48647 -37.5 -7.57335 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-11) show
grestore
.125 Mabswid
.02524 .3486 m
.02854 .35054 L
s
.02312 .36403 m
.02643 .36595 L
s
.02098 .37959 m
.02429 .3815 L
s
.01882 .39528 m
.02214 .39718 L
s
.01445 .4271 m
.01779 .42896 L
s
.01223 .44322 m
.01558 .44507 L
s
.00999 .45948 m
.01335 .46131 L
s
.00773 .4759 m
.0111 .47771 L
s
.02943 .31815 m
.03271 .32012 L
s
.0315 .30312 m
.03477 .30511 L
s
.00315 .50917 m
.00654 .51095 L
s
.00083 .52604 m
.00423 .5278 L
s
.25 Mabswid
.46573 .56185 m
.46325 .77122 L
s
.46325 .77122 m
1 .58708 L
s
1 .58708 m
.97016 .35799 L
s
.97016 .35799 m
.46573 .56185 L
s
.03223 .29778 m
.57217 0 L
s
.57217 0 m
.57719 .25617 L
s
.57719 .25617 m
0 .53211 L
s
0 .53211 m
.03223 .29778 L
s
.46573 .56185 m
.46325 .77122 L
s
.46325 .77122 m
0 .53211 L
s
0 .53211 m
.03223 .29778 L
s
.03223 .29778 m
.46573 .56185 L
s
.97016 .35799 m
.57217 0 L
s
.57217 0 m
.57719 .25617 L
s
.57719 .25617 m
1 .58708 L
s
1 .58708 m
.97016 .35799 L
s
0 0 m
1 0 L
1 .77122 L
0 .77122 L
closepath
clip
newpath
.5 Mabswid
.643 .765 .937 r
.46452 .66368 .49707 .65149 .47017 .63595 .43749 .64841 Metetra
.642 .763 .936 r
.43749 .64841 .47017 .63595 .44261 .62001 .40981 .6326 Metetra
.64 .759 .934 r
.40981 .6326 .44261 .62001 .41438 .6036 .38148 .61594 Metetra
.633 .749 .931 r
.38148 .61594 .41438 .6036 .38545 .58664 .35249 .59795 Metetra
.617 .733 .929 r
.35249 .59795 .38545 .58664 .3558 .56904 .32288 .57802 Metetra
.583 .706 .927 r
.32288 .57802 .3558 .56904 .32541 .55067 .2927 .55535 Metetra
.519 .662 .925 r
.2927 .55535 .32541 .55067 .29427 .53138 .26204 .52899 Metetra
.399 .584 .916 r
.26204 .52899 .29427 .53138 .26238 .51101 .23106 .49788 Metetra
.17 .429 .864 r
.23106 .49788 .26238 .51101 .22972 .48938 .19995 .4608 Metetra
0 .132 .677 r
.19995 .4608 .22972 .48938 .19631 .46629 .16897 .41648 Metetra
.653 .246 0 r
.16897 .41648 .19631 .46629 .16216 .44153 .13843 .36361 Metetra
.886 .497 .291 r
.13843 .36361 .16216 .44153 .12729 .41488 .10405 .34153 Metetra
.88 .483 .275 r
.10405 .34153 .12729 .41488 .09174 .3861 .06863 .31995 Metetra
.872 .459 .237 r
.06863 .31995 .09174 .3861 .05554 .35496 .03223 .29778 Metetra
.643 .765 .937 r
.49707 .65149 .53024 .63907 .50348 .62321 .47017 .63595 Metetra
.643 .765 .937 r
.47017 .63595 .50348 .62321 .47606 .60683 .44261 .62001 Metetra
.644 .765 .936 r
.44261 .62001 .47606 .60683 .44797 .58967 .41438 .6036 Metetra
.649 .764 .933 r
.41438 .6036 .44797 .58967 .4192 .57138 .38545 .58664 Metetra
.66 .763 .926 r
.38545 .58664 .4192 .57138 .38975 .55144 .3558 .56904 Metetra
.678 .761 .914 r
.3558 .56904 .38975 .55144 .35964 .52924 .32541 .55067 Metetra
.704 .758 .894 r
.32541 .55067 .35964 .52924 .32895 .50403 .29427 .53138 Metetra
.736 .752 .865 r
.29427 .53138 .32895 .50403 .29774 .47496 .26238 .51101 Metetra
.769 .742 .829 r
.26238 .51101 .29774 .47496 .26616 .44105 .22972 .48938 Metetra
.798 .73 .788 r
.22972 .48938 .26616 .44105 .23439 .40126 .19631 .46629 Metetra
.821 .716 .749 r
.19631 .46629 .23439 .40126 .20265 .3545 .16216 .44153 Metetra
.838 .702 .713 r
.16216 .44153 .20265 .3545 .17057 .30666 .12729 .41488 Metetra
.848 .692 .689 r
.12729 .41488 .17057 .30666 .13528 .28412 .09174 .3861 Metetra
.841 .69 .695 r
.09174 .3861 .13528 .28412 .099 .26096 .05554 .35496 Metetra
.643 .765 .937 r
.53024 .63907 .56405 .62641 .53745 .61028 .50348 .62321 Metetra
.642 .764 .937 r
.50348 .62321 .53745 .61028 .51018 .59388 .47606 .60683 Metetra
.639 .76 .936 r
.47606 .60683 .51018 .59388 .48222 .57741 .44797 .58967 Metetra
.627 .751 .937 r
.44797 .58967 .48222 .57741 .45353 .56122 .4192 .57138 Metetra
.596 .735 .941 r
.4192 .57138 .45353 .56122 .42405 .54575 .38975 .55144 Metetra
.528 .701 .949 r
.38975 .55144 .42405 .54575 .39371 .53162 .35964 .52924 Metetra
.373 .622 .949 r
.35964 .52924 .39371 .53162 .36239 .51958 .32895 .50403 Metetra
.017 .402 .854 r
.32895 .50403 .36239 .51958 .32994 .51055 .29774 .47496 Metetra
.541 .05 0 r
.29774 .47496 .32994 .51055 .29616 .50564 .26616 .44105 Metetra
.853 .408 0 r
.26616 .44105 .29616 .50564 .26078 .5062 .23439 .40126 Metetra
.932 .554 .241 r
.23439 .40126 .26078 .5062 .22342 .51387 .20265 .3545 Metetra
.938 .606 .375 r
.20265 .3545 .22342 .51387 .18422 .52375 .17057 .30666 Metetra
.904 .597 .455 r
.17057 .30666 .18422 .52375 .14628 .50262 .13528 .28412 Metetra
.904 .597 .455 r
.13528 .28412 .14628 .50262 .10719 .48086 .099 .26096 Metetra
.643 .766 .938 r
.56405 .62641 .59853 .6135 .57209 .59705 .53745 .61028 Metetra
.643 .767 .938 r
.53745 .61028 .57209 .59705 .54498 .58032 .51018 .59388 Metetra
.643 .77 .941 r
.51018 .59388 .54498 .58032 .51719 .56353 .48222 .57741 Metetra
.643 .777 .945 r
.48222 .57741 .51719 .56353 .48866 .54702 .45353 .56122 Metetra
.642 .789 .952 r
.45353 .56122 .48866 .54702 .45935 .53127 .42405 .54575 Metetra
.64 .806 .962 r
.42405 .54575 .45935 .53127 .42919 .5169 .39371 .53162 Metetra
.636 .83 .975 r
.39371 .53162 .42919 .5169 .39807 .5047 .36239 .51958 Metetra
.624 .86 .987 r
.36239 .51958 .39807 .5047 .36584 .49561 .32994 .51055 Metetra
.597 .892 .989 r
.32994 .51055 .36584 .49561 .3323 .49078 .29616 .50564 Metetra
.535 .907 .956 r
.29616 .50564 .3323 .49078 .29719 .4916 .26078 .5062 Metetra
.411 .862 .842 r
.26078 .5062 .29719 .4916 .26014 .49978 .22342 .51387 Metetra
.353 .826 .79 r
.22342 .51387 .26014 .49978 .22151 .50687 .18422 .52375 Metetra
.629 .778 .952 r
.18422 .52375 .22151 .50687 .18367 .48524 .14628 .50262 Metetra
.629 .778 .952 r
.14628 .50262 .18367 .48524 .14468 .46294 .10719 .48086 Metetra
.643 .766 .938 r
.59853 .6135 .63369 .60033 .60743 .58352 .57209 .59705 Metetra
.643 .767 .938 r
.57209 .59705 .60743 .58352 .58049 .56619 .54498 .58032 Metetra
.646 .771 .939 r
.54498 .58032 .58049 .56619 .55286 .54816 .51719 .56353 Metetra
.656 .779 .939 r
.51719 .56353 .55286 .54816 .52451 .52919 .48866 .54702 Metetra
.679 .793 .935 r
.48866 .54702 .52451 .52919 .49544 .50892 .45935 .53127 Metetra
.718 .811 .922 r
.45935 .53127 .49544 .50892 .46563 .48691 .42919 .5169 Metetra
.773 .827 .895 r
.42919 .5169 .46563 .48691 .43509 .46265 .39807 .5047 Metetra
.832 .834 .849 r
.39807 .5047 .43509 .46265 .40386 .43553 .36584 .49561 Metetra
.88 .827 .791 r
.36584 .49561 .40386 .43553 .37201 .40485 .3323 .49078 Metetra
.913 .809 .731 r
.3323 .49078 .37201 .40485 .33961 .36985 .29719 .4916 Metetra
.931 .787 .68 r
.29719 .4916 .33961 .36985 .3068 .32973 .26014 .49978 Metetra
.926 .748 .642 r
.26014 .49978 .3068 .32973 .27376 .28362 .22151 .50687 Metetra
.893 .691 .622 r
.22151 .50687 .27376 .28362 .2407 .23067 .18367 .48524 Metetra
.895 .686 .613 r
.18367 .48524 .2407 .23067 .20495 .20252 .14468 .46294 Metetra
.643 .765 .937 r
.63369 .60033 .66956 .5869 .64348 .56973 .60743 .58352 Metetra
.643 .764 .937 r
.60743 .58352 .64348 .56973 .61673 .55195 .58049 .56619 Metetra
.644 .762 .935 r
.58049 .56619 .61673 .55195 .58927 .53324 .55286 .54816 Metetra
.647 .758 .93 r
.55286 .54816 .58927 .53324 .56109 .51312 .52451 .52919 Metetra
.654 .752 .922 r
.52451 .52919 .56109 .51312 .53217 .49094 .49544 .50892 Metetra
.666 .743 .908 r
.49544 .50892 .53217 .49094 .50253 .46588 .46563 .48691 Metetra
.683 .732 .888 r
.46563 .48691 .50253 .46588 .47221 .43698 .43509 .46265 Metetra
.704 .719 .861 r
.43509 .46265 .47221 .43698 .44128 .4031 .40386 .43553 Metetra
.727 .704 .828 r
.40386 .43553 .44128 .4031 .40988 .363 .37201 .40485 Metetra
.749 .688 .793 r
.37201 .40485 .40988 .363 .37818 .31534 .33961 .36985 Metetra
.769 .672 .756 r
.33961 .36985 .37818 .31534 .34646 .25876 .3068 .32973 Metetra
.786 .658 .722 r
.3068 .32973 .34646 .25876 .31269 .23216 .27376 .28362 Metetra
.731 .629 .744 r
.27376 .28362 .31269 .23216 .27782 .20751 .2407 .23067 Metetra
.675 .733 .894 r
.2407 .23067 .27782 .20751 .24193 .18213 .20495 .20252 Metetra
.643 .765 .937 r
.66956 .5869 .70615 .5732 .68027 .55571 .64348 .56973 Metetra
.642 .763 .936 r
.64348 .56973 .68027 .55571 .65372 .53776 .61673 .55195 Metetra
.64 .759 .934 r
.61673 .55195 .65372 .53776 .62648 .51935 .58927 .53324 Metetra
.633 .749 .932 r
.58927 .53324 .62648 .51935 .59851 .50044 .56109 .51312 Metetra
.615 .731 .929 r
.56109 .51312 .59851 .50044 .56978 .48103 .53217 .49094 Metetra
.579 .703 .927 r
.53217 .49094 .56978 .48103 .54027 .46108 .50253 .46588 Metetra
.512 .656 .924 r
.50253 .46588 .54027 .46108 .50994 .44058 .47221 .43698 Metetra
.39 .573 .911 r
.47221 .43698 .50994 .44058 .47877 .41951 .44128 .4031 Metetra
.168 .419 .857 r
.44128 .4031 .47877 .41951 .4467 .39784 .40988 .363 Metetra
0 .15 .692 r
.40988 .363 .4467 .39784 .41371 .37554 .37818 .31534 Metetra
0 0 .387 r
.37818 .31534 .41371 .37554 .37975 .35259 .34646 .25876 Metetra
.893 .479 .205 r
.34646 .25876 .37975 .35259 .34478 .32895 .31269 .23216 Metetra
.892 .484 .227 r
.31269 .23216 .34478 .32895 .30875 .3046 .27782 .20751 Metetra
.892 .484 .227 r
.27782 .20751 .30875 .3046 .27162 .2795 .24193 .18213 Metetra
.643 .765 .938 r
.70615 .5732 .74349 .55922 .71783 .54139 .68027 .55571 Metetra
.642 .765 .938 r
.68027 .55571 .71783 .54139 .6915 .52328 .65372 .53776 Metetra
.64 .765 .939 r
.65372 .53776 .6915 .52328 .66449 .50515 .62648 .51935 Metetra
.633 .764 .942 r
.62648 .51935 .66449 .50515 .63678 .48748 .59851 .50044 Metetra
.614 .76 .949 r
.59851 .50044 .63678 .48748 .60833 .47087 .56978 .48103 Metetra
.573 .75 .961 r
.56978 .48103 .60833 .47087 .57909 .45614 .54027 .46108 Metetra
.483 .721 .976 r
.54027 .46108 .57909 .45614 .54897 .44431 .50994 .44058 Metetra
.282 .633 .964 r
.50994 .44058 .54897 .44431 .51784 .43661 .47877 .41951 Metetra
0 .374 .793 r
.47877 .41951 .51784 .43661 .48552 .43456 .4467 .39784 Metetra
.602 .051 0 r
.4467 .39784 .48552 .43456 .45175 .44 .41371 .37554 Metetra
.822 .342 .016 r
.41371 .37554 .45175 .44 .41616 .45522 .37975 .35259 Metetra
.889 .478 .218 r
.37975 .35259 .41616 .45522 .37998 .43514 .34478 .32895 Metetra
.892 .484 .227 r
.34478 .32895 .37998 .43514 .34274 .41127 .30875 .3046 Metetra
.892 .484 .227 r
.30875 .3046 .34274 .41127 .30429 .38664 .27162 .2795 Metetra
.643 .766 .938 r
.74349 .55922 .78161 .54495 .75617 .52674 .71783 .54139 Metetra
.643 .767 .939 r
.71783 .54139 .75617 .52674 .73007 .50814 .6915 .52328 Metetra
.644 .772 .941 r
.6915 .52328 .73007 .50814 .70328 .48929 .66449 .50515 Metetra
.647 .782 .945 r
.66449 .50515 .70328 .48929 .67578 .47042 .63678 .48748 Metetra
.656 .798 .951 r
.63678 .48748 .67578 .47042 .64753 .45186 .60833 .47087 Metetra
.673 .823 .956 r
.60833 .47087 .64753 .45186 .61851 .43401 .57909 .45614 Metetra
.701 .857 .957 r
.57909 .45614 .61851 .43401 .58866 .41738 .54897 .44431 Metetra
.743 .899 .948 r
.54897 .44431 .58866 .41738 .5579 .40259 .51784 .43661 Metetra
.797 .94 .921 r
.51784 .43661 .5579 .40259 .52612 .39038 .48552 .43456 Metetra
.856 .969 .869 r
.48552 .43456 .52612 .39038 .49318 .38164 .45175 .44 Metetra
.906 .976 .796 r
.45175 .44 .49318 .38164 .4589 .37739 .41616 .45522 Metetra
.868 .772 .754 r
.41616 .45522 .4589 .37739 .42302 .37889 .37998 .43514 Metetra
.823 .777 .81 r
.37998 .43514 .42302 .37889 .3852 .38764 .34274 .41127 Metetra
.666 .784 .937 r
.34274 .41127 .3852 .38764 .3468 .36631 .30429 .38664 Metetra
.643 .766 .938 r
.78161 .54495 .82051 .53038 .79532 .51175 .75617 .52674 Metetra
.643 .767 .938 r
.75617 .52674 .79532 .51175 .76944 .49248 .73007 .50814 Metetra
.646 .77 .938 r
.73007 .50814 .76944 .49248 .74284 .47231 .70328 .48929 Metetra
.655 .776 .938 r
.70328 .48929 .74284 .47231 .71548 .45085 .67578 .47042 Metetra
.677 .787 .933 r
.67578 .47042 .71548 .45085 .68731 .42755 .64753 .45186 Metetra
.714 .802 .919 r
.64753 .45186 .68731 .42755 .65831 .40176 .61851 .43401 Metetra
.767 .817 .892 r
.61851 .43401 .65831 .40176 .62847 .37266 .58866 .41738 Metetra
.825 .824 .847 r
.58866 .41738 .62847 .37266 .5978 .3393 .5579 .40259 Metetra
.876 .819 .788 r
.5579 .40259 .5978 .3393 .56635 .30064 .52612 .39038 Metetra
.912 .803 .725 r
.52612 .39038 .56635 .30064 .53421 .25551 .49318 .38164 Metetra
.934 .781 .668 r
.49318 .38164 .53421 .25551 .50153 .20272 .4589 .37739 Metetra
.945 .76 .623 r
.4589 .37739 .50153 .20272 .46839 .15054 .42302 .37889 Metetra
.95 .746 .592 r
.42302 .37889 .46839 .15054 .43418 .12346 .3852 .38764 Metetra
.92 .701 .589 r
.3852 .38764 .43418 .12346 .39892 .09555 .3468 .36631 Metetra
.643 .765 .937 r
.82051 .53038 .86024 .51551 .83531 .49647 .79532 .51175 Metetra
.643 .764 .936 r
.79532 .51175 .83531 .49647 .80969 .4768 .76944 .49248 Metetra
.643 .76 .934 r
.76944 .49248 .80969 .4768 .78334 .45621 .74284 .47231 Metetra
.642 .754 .93 r
.74284 .47231 .78334 .45621 .75622 .43433 .71548 .45085 Metetra
.641 .743 .923 r
.71548 .45085 .75622 .43433 .72829 .41063 .68731 .42755 Metetra
.638 .727 .912 r
.68731 .42755 .72829 .41063 .69949 .38445 .65831 .40176 Metetra
.634 .706 .898 r
.65831 .40176 .69949 .38445 .66983 .35499 .62847 .37266 Metetra
.628 .681 .881 r
.62847 .37266 .66983 .35499 .63928 .32133 .5978 .3393 Metetra
.619 .652 .861 r
.5978 .3393 .63928 .32133 .60789 .28241 .56635 .30064 Metetra
.607 .619 .838 r
.56635 .30064 .60789 .28241 .57573 .23711 .53421 .25551 Metetra
.594 .585 .813 r
.53421 .25551 .57573 .23711 .54293 .18423 .50153 .20272 Metetra
.591 .589 .819 r
.50153 .20272 .54293 .18423 .50966 .12891 .46839 .15054 Metetra
.653 .754 .924 r
.46839 .15054 .50966 .12891 .47567 .10116 .43418 .12346 Metetra
.653 .754 .924 r
.43418 .12346 .47567 .10116 .44062 .07255 .39892 .09555 Metetra
.643 .765 .937 r
.86024 .51551 .90081 .50031 .87616 .48092 .83531 .49647 Metetra
.642 .764 .937 r
.83531 .49647 .87616 .48092 .85085 .46113 .80969 .4768 Metetra
.639 .76 .936 r
.80969 .4768 .85085 .46113 .82487 .44119 .78334 .45621 Metetra
.628 .75 .935 r
.78334 .45621 .82487 .44119 .79821 .42144 .75622 .43433 Metetra
.601 .733 .937 r
.75622 .43433 .79821 .42144 .77086 .40239 .72829 .41063 Metetra
.545 .699 .941 r
.72829 .41063 .77086 .40239 .74281 .38466 .69949 .38445 Metetra
.431 .633 .94 r
.69949 .38445 .74281 .38466 .71401 .36905 .66983 .35499 Metetra
.206 .491 .9 r
.66983 .35499 .71401 .36905 .68441 .35652 .63928 .32133 Metetra
0 .212 .731 r
.63928 .32133 .68441 .35652 .65391 .34825 .60789 .28241 Metetra
.589 .147 0 r
.60789 .28241 .65391 .34825 .62236 .34561 .57573 .23711 Metetra
.821 .399 0 r
.57573 .23711 .62236 .34561 .58957 .35032 .54293 .18423 Metetra
.919 .53 .141 r
.54293 .18423 .58957 .35032 .55514 .35586 .50966 .12891 Metetra
.927 .563 .311 r
.50966 .12891 .55514 .35586 .51882 .32939 .47567 .10116 Metetra
.927 .563 .311 r
.47567 .10116 .51882 .32939 .48127 .30203 .44062 .07255 Metetra
.643 .766 .938 r
.90081 .50031 .94226 .48479 .9179 .46496 .87616 .48092 Metetra
.643 .767 .938 r
.87616 .48092 .9179 .46496 .89287 .4446 .85085 .46113 Metetra
.644 .771 .94 r
.85085 .46113 .89287 .4446 .86715 .42375 .82487 .44119 Metetra
.649 .779 .943 r
.82487 .44119 .86715 .42375 .84071 .40245 .79821 .42144 Metetra
.66 .793 .946 r
.79821 .42144 .84071 .40245 .81352 .38077 .77086 .40239 Metetra
.681 .815 .947 r
.77086 .40239 .81352 .38077 .78556 .35881 .74281 .38466 Metetra
.716 .844 .943 r
.74281 .38466 .78556 .35881 .75679 .33667 .71401 .36905 Metetra
.767 .877 .927 r
.71401 .36905 .75679 .33667 .72717 .31448 .68441 .35652 Metetra
.829 .908 .893 r
.68441 .35652 .72717 .31448 .69665 .29239 .65391 .34825 Metetra
.89 .924 .837 r
.65391 .34825 .69665 .29239 .66517 .27057 .62236 .34561 Metetra
.94 .921 .765 r
.62236 .34561 .66517 .27057 .63267 .24919 .58957 .35032 Metetra
.962 .873 .703 r
.58957 .35032 .63267 .24919 .59906 .22848 .55514 .35586 Metetra
.906 .748 .674 r
.55514 .35586 .59906 .22848 .56424 .20865 .51882 .32939 Metetra
.902 .752 .685 r
.51882 .32939 .56424 .20865 .52809 .18995 .48127 .30203 Metetra
.643 .766 .938 r
.94226 .48479 .98461 .46894 .96057 .44869 .9179 .46496 Metetra
.642 .766 .938 r
.9179 .46496 .96057 .44869 .93588 .42806 .89287 .4446 Metetra
.641 .766 .939 r
.89287 .4446 .93588 .42806 .91054 .40736 .86715 .42375 Metetra
.635 .766 .942 r
.86715 .42375 .91054 .40736 .88457 .38705 .84071 .40245 Metetra
.619 .764 .948 r
.84071 .40245 .88457 .38705 .85799 .36781 .81352 .38077 Metetra
.587 .757 .96 r
.81352 .38077 .85799 .36781 .83078 .35047 .78556 .35881 Metetra
.519 .738 .974 r
.78556 .35881 .83078 .35047 .80296 .33608 .75679 .33667 Metetra
.381 .685 .978 r
.75679 .33667 .80296 .33608 .7745 .32595 .72717 .31448 Metetra
.105 .536 .913 r
.72717 .31448 .7745 .32595 .74531 .32165 .69665 .29239 Metetra
0 .223 .656 r
.69665 .29239 .74531 .32165 .71529 .32509 .66517 .27057 Metetra
.662 .123 0 r
.66517 .27057 .71529 .32509 .68425 .33868 .63267 .24919 Metetra
.82 .34 0 r
.63267 .24919 .68425 .33868 .64981 .31301 .59906 .22848 Metetra
.808 .319 0 r
.59906 .22848 .64981 .31301 .61412 .28508 .56424 .20865 Metetra
.784 .282 0 r
.56424 .20865 .61412 .28508 .57719 .25617 .52809 .18995 Metetra
0 g
.25 Mabswid
.03223 .29778 m
.57217 0 L
s
.57217 0 m
.57719 .25617 L
s
.57719 .25617 m
0 .53211 L
s
0 .53211 m
.03223 .29778 L
s
.97016 .35799 m
.57217 0 L
s
.57217 0 m
.57719 .25617 L
s
.57719 .25617 m
1 .58708 L
s
1 .58708 m
.97016 .35799 L
s
.97016 .35799 m
.57217 0 L
s
.89367 .28919 m
.88782 .29171 L
s
[(0.5)] .90539 .28416 -1 .43009 Mshowa
.7977 .20287 m
.79192 .20555 L
s
[(1)] .80927 .1975 -1 .46415 Mshowa
.69115 .10702 m
.68546 .10989 L
s
[(1.5)] .70254 .10129 -1 .50408 Mshowa
.57217 0 m
.56659 .00308 L
s
[(2)] .58333 -0.00616 -1 .55151 Mshowa
.125 Mabswid
.87525 .27262 m
.87175 .27415 L
s
.85645 .25571 m
.85296 .25726 L
s
.83727 .23846 m
.83378 .24003 L
s
.81769 .22085 m
.81421 .22244 L
s
.77729 .18451 m
.77383 .18614 L
s
.75645 .16576 m
.753 .16741 L
s
.73515 .1466 m
.73171 .14828 L
s
.71339 .12703 m
.70997 .12873 L
s
.66842 .08657 m
.66501 .08832 L
s
.64517 .06566 m
.64178 .06743 L
s
.62139 .04427 m
.61801 .04607 L
s
.59706 .02239 m
.5937 .02421 L
s
.91174 .30544 m
.90822 .30693 L
s
.92945 .32137 m
.92592 .32284 L
s
.94682 .33699 m
.94328 .33845 L
s
.96385 .35232 m
.96031 .35376 L
s
.25 Mabswid
.03223 .29778 m
0 .53211 L
s
.02735 .33331 m
.03282 .33657 L
s
gsave
.01639 .32679 -43.5 -7.96821 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-11) show
grestore
.01664 .41112 m
.0222 .41425 L
s
[(0)] .00554 .40486 1 .5639 Mshowa
.00545 .49246 m
.01108 .49545 L
s
gsave
-0.0058 .48647 -37.5 -7.57335 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-11) show
grestore
.125 Mabswid
.02524 .3486 m
.02854 .35054 L
s
.02312 .36403 m
.02643 .36595 L
s
.02098 .37959 m
.02429 .3815 L
s
.01882 .39528 m
.02214 .39718 L
s
.01445 .4271 m
.01779 .42896 L
s
.01223 .44322 m
.01558 .44507 L
s
.00999 .45948 m
.01335 .46131 L
s
.00773 .4759 m
.0111 .47771 L
s
.02943 .31815 m
.03271 .32012 L
s
.0315 .30312 m
.03477 .30511 L
s
.00315 .50917 m
.00654 .51095 L
s
.00083 .52604 m
.00423 .5278 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[75]:=",
  ImageSize->{225.375, 173.75},
  ImageMargins->{{0, 0}, {0, 0.75}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000fB000`400?l00000o`00003oo`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ
0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ0?ooo`00o`3ooolJ
0?ooo`00^@3oool5000005/0oooo002i0?ooo`050000003oool0oooo0?ooo`000000F`3oool00;X0
oooo00<000000?ooo`3oool0G03oool00;/0oooo00<000000?ooo`3oool0F`3oool00;`0oooo00<0
00000?ooo`3oool0FP3oool00;d0oooo00<000000?ooo`3oool0F@3oool00;T0oooo00D000000?oo
o`3oool0oooo0000001K0?ooo`00^P3oool3000005`0oooo003o0?oooaX0oooo002e0?ooo`030000
003oool0oooo0640oooo002c0?ooo`@00000HP3oool00;40oooo0P0000020?ooo`030000003oool0
00000640oooo002_0?ooo`800000103oool010000000oooo0?ooo`00001P0?ooo`00[@3oool20000
00H0oooo00@000000?ooo`3oool0oooo0P00001N0?ooo`00[03oool00`000000oooo000000060?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0F`3oool00:X0oooo0P0000090?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`000000G03oool00:P0oooo0P00000;0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0F@3oool007/0oooo100000050?ooo`800000103o
ool5000001L0oooo0P00000=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0F03o
ool007X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000103oool0
1@000000oooo0?ooo`3oool0000001D0oooo0P00000?0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0E`3oool007X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`0000003`3oool00`000000oooo0?ooo`08
0?ooo`800000E`3oool007X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0180oooo0P00000B0?ooo`030000003oool0oooo00P0oooo0P00001G0?oo
o`00NP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool03`3oool2000001@0oooo00<000000?ooo`3oool02P3oool2000005D0oooo001j0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`800000
5P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0580oooo001j0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000`0oooo
0P00000H0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0D@3oool007/0oooo1000
000<0?ooo`<000002`3oool2000000030?ooo`000000oooo01L0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`1@0?ooo`00V03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`0000003@3oool5000000@0oooo0P0000050?ooo`@00000<03oool0
09H0oooo0P00000M0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`040?ooo`800000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02d0oooo002D0?ooo`D00000703oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0]0?ooo`00TP3oool300000080Yl7/
00@000000>f@C`00000000006P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0]0?ooo`00T03oool3000000D0Yl7/
00@000000>f@C`3]T4l000006@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02`3oool400000300oooo002?0?ooo`8000001`2W`N`01@000000kI1?
0>f@C`3]T4l0000001P0oooo00<000000?ooo`3oool0503oool2000000T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0a0?ooo`00S@3oool2000000T0Yl7/00<000000>f@C`3]T4l0
0P3]T4l2000001H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`<00000
3@3oool00`000000oooo0?ooo`0a0?ooo`00R`3oool2000000030?ooo`000000000000P0Yl7/00<0
00000>f@C`3]T4l0103]T4l00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`D00000;`3oool008T0oooo0`000002
0?ooo`040000003[/iH00000000000H0Yl7/00<000000>f@C`3]T4l0103]T4l2000001@0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`160?ooo`00Q`3oool2000000@0oooo00<00000
0>^cUP3[/iH00P3[/iH00`000000Yl7/0:O1k0030:O1k0030000003]T4l0kI1?00@0kI1?00<00000
0>f@C`0000004`3oool00`000000oooo0?ooo`0G0?ooo`<00000A`3oool008H0oooo00<000000?oo
o`3oool0103oool00`000000jk>F0>^cUP030>^cUP030000002W`N`0Yl7/00<0Yl7/00<000000>f@
C`3]T4l0103]T4l00`000000kI1?0000000B0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0A03oool006X0oooo1000000F0?ooo`8000001`3oool00`000000jk>F0>^cUP040>^cUP80
000000@0Yl7/00000000000000001P3]T4l00`000000kI1?0>f@C`0200000100oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`130?ooo`00J@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0140oooo0P0000090?ooo`030000003[/iH0jk>F00H0jk>F00@000000:O1k02W
`N`000001P3]T4l00`000000kI1?0>f@C`020>f@C`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`120?ooo`00J@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00l0oooo0P0000000`3oool000000?ooo`080?ooo`030000003[/iH0jk>F00H0
jk>F0P0000000`2W`N`000000>f@C`050>f@C`030000003]T4l0kI1?00<0kI1?00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0M0?ooo`800000@P3oool006T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0=0?ooo`800000303oool00`000000jk>F0>^cUP070>^cUP040000
003c_YL00000000000H0kI1?00<000000>f@C`3]T4l0103]T4l00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`000000@@3oool006T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000>^cUP3[/iH0
1P3[/iH01@000000lkjG0?>nU`3c_YL0000000L0kI1?00<000000>f@C`3]T4l00`3]T4l2000000d0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0n0?ooo`00J@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00X0oooo0P00000?0?ooo`030000003[/iH0jk>F00H0jk>F
00<000000?>nU`3c_YL00P3c_YL00`000000kI1?0>f@C`040>f@C`030000003]T4l0kI1?00<0kI1?
0P00000=0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0?@3oool006T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`<00000403oool00`000000jk>F0>^c
UP060>^cUP030000003c_YL0lkjG0080lkjG00<000000>f@C`3]T4l0103]T4l00`000000kI1?0>f@
C`040>f@C`800000303oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03`0oooo001Z
0?ooo`@000002@3oool2000001<0oooo00<000000>^cUP3[/iH01P3[/iH00`000000lkjG0?>nU`02
0?>nU`030000003]T4l0kI1?00@0kI1?00<000000>f@C`3]T4l0103]T4l00`000000jhLT0000000;
0?ooo`030000003oool0oooo0240oooo0P00000m0?ooo`00M@3oool2000001@0oooo00<000000>^c
UP3[/iH01`3[/iH00`000000lkjG0?>nU`020?>nU`030000003]T4l0kI1?00@0kI1?00<000000>f@
C`3]T4l0103]T4l00`000000jhLT0000000;0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0>P3oool007<0oooo0P00000F0?ooo`030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c
_YL00`3c_YL00`000000kI1?0>f@C`040>f@C`030000003]T4l0kI1?00@0kI1?00@000000>^7903[
Qb@000002P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo03T0oooo001b0?ooo`03
0000003oool0oooo01H0oooo00<000000>^cUP3[/iH01P3[/iH00`000000lkjG0?>nU`030?>nU`03
0000003]T4l0kI1?00D0kI1?00<000000>f@C`3]T4l00`3]T4l01@000000jhLT0>^7903[Qb@00000
00T0oooo00<000000?ooo`3oool09@3oool2000003T0oooo001`0?ooo`80000000<0oooo0000003o
ool05P3oool00`000000jk>F0>^cUP060>^cUP030000003c_YL0lkjG00@0lkjG00<000000>f@C`3]
T4l0103]T4l00`000000kI1?0>f@C`040>f@C`040000003[Qb@0jhLT000000T0oooo00<000000?oo
o`3oool09P3oool2000003P0oooo001^0?ooo`8000006`3oool00`000000jk>F0>^cUP060>^cUP03
0000003c_YL0lkjG00@0lkjG00<000000>f@C`3]T4l0103]T4l00`000000kI1?0>f@C`040>f@C`05
0000003[Qb@0jhLT0>^790000000203oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00X0oooo1@00000V0?ooo`00K03oool2000001d0oooo00<000000>^cUP3[/iH01P3[/iH00`000000
lkjG0?>nU`040?>nU`030000003]T4l0kI1?00@0kI1?00<000000>f@C`3]T4l0103]T4l00`000000
jhLT0>^790020>^790030000003oool0oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo001Z0?ooo`8000007P3oool00`000000jk>F
0>^cUP060>^cUP030000003c_YL0lkjG00D0lkjG00<000000>f@C`3]T4l0103]T4l00`000000kI1?
0>f@C`040>f@C`030000003[Qb@0jhLT0080jhLT00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool006T0oooo0`00
000N0?ooo`030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c_YL01@3c_YL00`000000kI1?0>f@
C`050>f@C`030000003]T4l0kI1?00<0kI1?00<000000>^7903[Qb@00`3[Qb@00`000000oooo0?oo
o`040?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0V0?ooo`00I`3oool2000000030:bki0000000000001h0oooo00<000000>^cUP3[/iH01P3[/iH0
0`000000lkjG0?>nU`050?>nU`030000003]T4l0kI1?00D0kI1?00<000000>f@C`3]T4l00`3]T4l0
0`000000jhLT0>^790030>^7908000001@3oool00`000000oooo0?ooo`0[0?ooo`8000002P3oool0
0`000000oooo0?ooo`0V0?ooo`00?03oool4000000D0oooo0P0000040?ooo`D000005@3oool20000
00@0[;_T0`00000L0?ooo`030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c_YL01P3c_YL00`00
0000kI1?0>f@C`040>f@C`030000003]T4l0kI1?00@0kI1?0P0000040>^790030000003oool0oooo
00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02H0oooo000k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool2000000@0
oooo00D000000?ooo`3oool0oooo0000000C0?ooo`8000001P2/^n@010000000i7/j0>Ak>P00000K
0?ooo`030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c_YL01P3c_YL00`000000kI1?0>f@C`04
0>f@C`030000003]T4l0kI1?00@0kI1?100000020>^790800000103oool00`000000oooo0?ooo`0^
0?ooo`8000001@3oool3000002P0oooo000k0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`800000202/^n@01@000000i7/j0>Ak>P3TNcX0
000001T0oooo00<000000>^cUP3[/iH01P3[/iH00`000000lkjG0?>nU`070?>nU`030000003]T4l0
kI1?00@0kI1?00<000000>f@C`3]T4l0103]T4l010000000i/2_00000038B004000000@0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo000c
0?ooo`H000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0403oool3000000P0[;_T00<000000>Ak>P3TNcX00P3TNcX2000001L0oooo00<00000
0>^cUP3[/iH01P3[/iH00`000000lkjG0?>nU`060?>nU`8000001`3]T4l00`000000kI1?0>f@C`03
0>f@C`040000003V`:l0i/2_00000080b4P00`0000030?ooo`030000003oool0oooo02l0oooo0`00
000^0?ooo`00>`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool03@3oool2000000040?ooo`000000iJnL000000P0[;_T00<000000>Ak>P3TNcX00`3T
NcX00`000000oooo0?ooo`0D0?ooo`030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c_YL01P3c
_YL2000000L0kI1?00<000000>f@C`3]T4l00P3]T4l00`000000i/2_0>K0[`020>K0[`0400000038
B000b4P00<Q8008000000P3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo02/0oooo
000k0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0:0?ooo`8000000P3oool01@000000iJnL0>F_W03U[i`0000000L0[;_T00<000000>Ak>P3TNcX0
0`3TNcX3000001@0oooo00<000000>^cUP3[/iH01P3[/iH00`000000lkjG0?>nU`060?>nU`030000
003a`Yl0000000H0kI1?00<000000>f@C`3]T4l00P3]T4l00`000000i/2_0>K0[`030>K0[`030000
0038B000b4P00080b4P00`00000e0?ooo`030000003oool0oooo02X0oooo000k0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0203oool01@000000oooo0?ooo`3oool0000000X0oooo
0`0000030?ooo`030000003U[i`0iJnL0080iJnL0P0000050:bki0030000003TNcX0i7/j00@0i7/j
00<000000>Ak>P0000004`3oool00`000000jk>F0>^cUP060>^cUP030000003c_YL0lkjG00H0lkjG
00<000000?72W`0000001P3]T4l01@000000kI1?0>f@C`3]T4l0000000H0i/2_00<000000<Q80038
B0000P38B00010000000cU4000000000000e0?ooo`030000003oool0oooo02T0oooo000l0?ooo`@0
0000303oool3000000T0oooo0P0000060?ooo`030000003U[i`0iJnL00@0iJnL00<000000:bki02/
^n@00P2/^n@00`000000i7/j0>Ak>P040>Ak>P030000003TNcX0i7/j00800000403oool00`000000
jk>F0>^cUP060>^cUP030000003c_YL0lkjG00L0lkjG00<000000?72W`0000001P3]T4l01@000000
kI1?0>f@C`3]T4l0000000L0i/2_00<000000<Q80038B0000P38B002000000030<iA000000000000
03<0oooo0P00000Z0?ooo`00E`3oool00`000000oooo0?ooo`060?ooo`030000003U[i`0iJnL00D0
iJnL00H000000:bki000000000000;^Q_P0000050>Ak>P030000003TNcX0i7/j0080i7/j0P00000>
0?ooo`030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c_YL01P3c_YL010000000lL:O0?72W`00
00060>f@C`040000003]T4l0kI1?000000T0i/2_00<000000<Q80038B0000P38B00010000000cU40
0<iA003>D@02000003<0oooo00<000000?ooo`3oool09`3oool005D0oooo0P0000080?ooo`030000
003U[i`0iJnL00L0iJnL00D000000;^Q_P2kXKh0^j6n000000060>Ak>P030000003TNcX0i7/j00<0
i7/j00<000000?ooo`3oool02`3oool00`000000jk>F0>^cUP060>^cUP030000003c_YL0lkjG00H0
lkjG00@000000?72W`3a`Yl000001`3]T4l00`000000kI1?000000090>K0[`8000000`38B0020000
00@0cU400P00000b0?ooo`8000009`3oool005<0oooo0`0000090?ooo`030000003U[i`0iJnL00L0
iJnL0P0000020;^Q_P030000003TNcX0i7/j00@0i7/j00<000000>Ak>P3TNcX00`3TNcX2000000`0
oooo00<000000>^cUP3[/iH01P3[/iH00`000000lkjG0?>nU`060?>nU`040000003a`Yl0lL:O0000
00L0kI1?00<000000>f@C`0000002@3V`:l2000000<0b4P00P0000040<iA00030000003AE`000000
03<0oooo00<000000?ooo`3oool0903oool00540oooo0P00000<0?ooo`030000003U[i`0iJnL00L0
iJnL0P0000030;^Q_P030000003TNcX0i7/j00<0i7/j00<000000>Ak>P3TNcX0103TNcX3000000X0
oooo00<000000>^cUP3[/iH01P3[/iH00`000000lkjG0?>nU`060?>nU`050000003a`Yl0lL:O0?72
W`0000001P3]T4l2000000T0i/2_00@000000>No[03W_j`000000P38B0000`000000b4P000000004
0<iA00040000003AE`00000000000300oooo0`00000U0?ooo`00C`3oool2000000h0oooo00<00000
0>F_W03U[i`01P3U[i`010000000i;2O0>B`W`0000020;^Q_P030000003TNcX0i7/j00@0i7/j00<0
00000>Ak>P3TNcX00`3TNcX010000000i7Xd0>Aj=00000080?ooo`030000003[/iH0jk>F00H0jk>F
00<000000?>nU`3c_YL01`3c_YL01@000000lL:O0?72W`3a`Yl0000000H0kI1?0P0000090>K0[`07
0000003W_j`0ikn/0>No[0000000b4P0000000020<Q800050000003>D@00cU400<iA000000000`3A
E`0200000340oooo00<000000?ooo`3oool08P3oool004d0oooo0P00000?0?ooo`030000003U[i`0
iJnL00L0iJnL00L000000>B`W`3T/9l0i;2O0000002kXKh0000000H0i7/j00<000000>Ak>P3TNcX0
0`3TNcX01@000000i7Xd0>Aj=03TNS@0000000L0oooo00<000000>^cUP3[/iH01P3[/iH00`000000
lkjG0?>nU`060?>nU`030000003a`Yl0lL:O0080lL:O00<000000>f@C`3]T4l0103]T4l00`000000
i/2_0>K0[`080>K0[`030000003W_j`0ikn/0080ikn/0P0000020<Q800030000003>D@00cU400080
cU4000<000000=5G003AE`000P3AE`000`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0240
oooo001<0?ooo`<000003`3oool00`000000iJnL0>F_W0070>F_W0070000003T/9l0i;2O0>B`W`00
0000^j6n000000060>Ak>P030000003TNcX0i7/j00@0i7/j00@000000>Aj=03TNS@0i7Xd0P000005
0?ooo`030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c_YL01P3c_YL00`000000lL:O0?72W`02
0?72W`030000003]T4l0kI1?00@0kI1?00<000000>K0[`3V`:l01`3V`:l00`000000ikn/0>No[003
0>No[08000000`38B0000`000000cU400<iA00020<iA00030000003AE`00dEL00080dEL00P00000`
0?ooo`030000003oool0oooo0200oooo001:0?ooo`8000004P3oool00`000000iJnL0>F_W0070>F_
W0030000003T/9l0i;2O0080i;2O00<000000;^Q_P0000001@3TNcX00`000000i7/j0>Ak>P040>Ak
>P030000003TNS@0i7Xd00<0i7Xd00<000000?ooo`3oool00P3oool00`000000jk>F0>^cUP060>^c
UP030000003c_YL0lkjG00H0lkjG00<000000?72W`3a`Yl00P3a`Yl00`000000kI1?0>f@C`030>f@
C`030000003V`:l0i/2_00P0i/2_00<000000>No[03W_j`00`3W_j`2000000@0b4P000D000000<iA
003>D@00cU40000000040=5G00030000002Y7`00000002l0oooo0P00000<0?ooo`@000001@3oool2
000000D0oooo100000010?ooo`00B03oool2000001@0oooo00<000000>F_W03U[i`01P3U[i`00`00
0000i;2O0>B`W`040>B`W`8000001P3TNcX00`000000i7/j0>Ak>P030>Ak>P030000003TNS@0i7Xd
00<0i7Xd0P0000030?ooo`030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c_YL01P3c_YL00`00
0000lL:O0?72W`020?72W`030000003]T4l0kI1?00<0kI1?00<000000>K0[`3V`:l0203V`:l01000
0000ikn/0>No[03W_j`200000080ikn/0P0000020<Q800030000003>D@00cU400080cU4000<00000
0=5G003AE`000P3AE`0010000000ZAl000000000000_0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?oo
o`020?ooo`40000000160?ooo`80000000@0oooo00000000000000004@3oool00`000000iJnL0>F_
W0070>F_W0030000003T/9l0i;2O00@0i;2O0P0000060>Ak>P030000003TNcX0i7/j00@0i7/j00<0
00000>Aj=03TNS@00`3TNS@010000000oooo0?ooo`0000090>^cUP030000003c_YL0lkjG00D0lkjG
00<000000?72W`3a`Yl0103a`Yl00`000000kI1?0>f@C`020>f@C`030000003V`:l0i/2_00L0i/2_
00<000000>No[03W_j`00P0000050>No[08000000P38B0001@000000cU400<iA003>D@00000000@0
dEL000@000000:TO002Y7`00ZAl00P00000^0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`40000000140?ooo`80000000@0oooo00000000
000000000P3WV7@00`000000oooo0?ooo`0>0?ooo`030000003U[i`0iJnL00L0iJnL00<000000>B`
W`3T/9l01@3T/9l00`000000i7/j0>Ak>P040>Ak>P030000003TNcX0i7/j00@0i7/j00<000000>Aj
=03TNS@00`3TNS@2000000030?ooo`000000jk>F00L0jk>F00<000000?>nU`3c_YL01P3c_YL00`00
0000lL:O0?72W`040?72W`050000003]T4l0kI1?0>f@C`0000002P3V`:l3000000L0ikn/00H00000
0?KO/`00000000000<Q8000000030<iA00030000003AE`00dEL00080dEL000<000000:TO002Y7`00
0P2Y7`000`000000oooo0?ooo`0/0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00d0oooo0@00000004<0oooo00<000000?ooo`3oool00P3oool2000000<0iiQd0P00
000>0?ooo`030000003U[i`0iJnL00L0iJnL00<000000>B`W`3T/9l01P3T/9l00`000000i7/j0>Ak
>P040>Ak>P030000003TNcX0i7/j00<0i7/j00<000000>Aj=03TNS@00`3TNS@2000000030?ooo`00
0000jk>F00L0jk>F00<000000?>nU`3c_YL01P3c_YL00`000000lL:O0?72W`040?72W`050000003]
T4l0kI1?0>f@C`0000002@3V`:l2000000P0ikn/00@000000?KO/`3fgk<0m]nc0P0000000`38B000
00000<iA00020<iA00050000003AE`00dEL00=5G000000001@2Y7`02000002`0oooo0`0000060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool400000040oooo00110?ooo`80
0000103oool00`000000ek2a000000050>NHM0800000303oool00`000000iJnL0>F_W0070>F_W003
0000003T/9l0i;2O00H0i;2O00<000000>Ak>P3TNcX0103TNcX00`000000i7/j0>Ak>P030>Ak>P03
0000003TNS@0i7Xd00@0i7Xd0`0000080>^cUP030000003c_YL0lkjG00H0lkjG00<000000?72W`3a
`Yl0103a`Yl010000000kI1?0>f@C`0000080>K0[`<000002@3W_j`00`000000m]nc0?KO/`020?KO
/`<000000`3>D@000`000000dEL00=5G00020=5G00030000002Y7`00ZAl000<0ZAl00P00000^0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0080oooo000o0?ooo`8000001P3oool00`000000ek2a000000070>NHM003
0000003oool0oooo00T0oooo00<000000>F_W03U[i`01P3U[i`00`000000i;2O0>B`W`070>B`W`<0
0000103TNcX00`000000i7/j0>Ak>P040>Ak>P030000003TNS@0i7Xd00<0i7Xd0`0000080>^cUP03
0000003c_YL0lkjG00H0lkjG00<000000?72W`3a`Yl0103a`Yl010000000kI1?0>f@C`0000060>K0
[`8000000P3V`:l00`000000ikn/0>No[0070>No[0030000003fgk<0m]nc00@0m]nc0P0000030<iA
00030000003AE`00dEL00080dEL000<000000:TO002Y7`000`2Y7`02000002h0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00P3oool000X0oooo1@0000020?ooo`050000003oool0oooo0?ooo`000000103oool50000
00<0oooo1000000G0?ooo`80000000<0oooo0000003oool0103oool010000000ek2a0=N`/@000007
0>NHM0<00000203oool00`000000iJnL0>F_W0070>F_W0030000003T/9l0i;2O00P0i;2O00<00000
0>Ak>P000000103TNcX00`000000i7/j0>Ak>P030>Ak>P030000003TNS@0i7Xd00<0i7Xd0P000009
0>^cUP030000003c_YL0lkjG00D0lkjG00<000000?72W`3a`Yl01@3a`Yl00`000000kI1?00000005
0>K0[`800000103V`:l00`000000ikn/0>No[0060>No[0030000003fgk<0m]nc00H0m]nc0P000002
0<iA00030000003AE`00dEL00080dEL000<000000:TO002Y7`000`2Y7`001000000003VW00000000
000]0?ooo`030000003oool0oooo0080oooo1000000<0?ooo`D00000000<0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04P3oool2000000T0oooo00@000000=N`/@3G/;4000001`3W
V7@010000000iiQd0>NHM00000070?ooo`030000003U[i`0iJnL00L0iJnL00<000000>B`W`3T/9l0
203T/9l00`000000i7/j0>Ak>P0200000080i7/j00<000000>Ak>P3TNcX00`3TNcX00`000000i7Xd
0>Aj=0040>Aj=0030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c_YL01P3c_YL00`000000lL:O
0?72W`060?72W`8000000`3V`:l2000000D0i/2_00<000000>No[03W_j`01`3W_j`00`000000m]nc
0?KO/`060?KO/`<000000P3>D@000`000000dEL00=5G00020=5G00030000002Y7`00ZAl000<0ZAl0
00@00000000iY`00>JL00000:`3oool00`000000oooo0000000H0?ooo`00303oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0203oool01@000000ek2a
0=N`/@3G/;40000000L0iiQd00@000000>NHM03WV7@0iiQd0P0000050?ooo`030000003U[i`0iJnL
00L0iJnL00<000000>B`W`3T/9l01`3T/9l2000000@0i7/j00<000000>Ak>P0000001P3TNcX00`00
0000i7Xd0>Aj=0030>Aj=0030000003[/iH0jk>F00H0jk>F00<000000?>nU`3c_YL01P3c_YL00`00
0000lL:O0?72W`060?72W`030000003V`:l0i/2_008000001`3V`:l00`000000ikn/0>No[0070>No
[0030000003fgk<0m]nc00D0m]nc00<000000?3[``3`jl<00P0000020<iA00050000003AE`00dEL0
0=5G000000001P2Y7`000`00000003VW000iY`02000002`0oooo00<000000?ooo`3oool05@3oool0
00030?ooo`000000000000@000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0140oooo0`0000080?ooo`050000003G/;40ek2a0=N`/@0000001`3WV7@00`000000iiQd0>NHM003
0>NHM08000000`3oool00`000000iJnL0>F_W0060>F_W0030000003T/9l0i;2O00P0i;2O00<00000
0>foY0000000103TNcX3000000D0i7/j00<000000>Aj=03TNS@00`3TNS@00`000000jk>F0>^cUP06
0>^cUP030000003c_YL0lkjG00H0lkjG00<000000?72W`3a`Yl01@3a`Yl4000000P0i/2_00<00000
0>No[03W_j`01`3W_j`00`000000m]nc0?KO/`060?KO/`030000003`jl<0l>_30080l>_30`000004
0=5G00030000002Y7`00ZAl000@0ZAl000D00000000iY`00>JL003VW0000000/0?ooo`030000003o
ool0oooo01@0oooo000<0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0@0?ooo`<0000000<0ggDl0000000000001@3oool00`000000ek2a0=N`/@020=N`/@030000003W
V7@0iiQd00D0iiQd00<000000>NHM03WV7@01@3WV7@00`000000oooo000000090>F_W0030000003T
/9l0i;2O00P0i;2O00<000000>foY00000001P3TNcX00`000000i7/j0>Ak>P030>Ak>P030000003T
NS@0i7Xd00<0i7Xd00<000000>^cUP3[/iH01P3[/iH00`000000lkjG0?>nU`060?>nU`030000003a
`Yl0lL:O00@0lL:O100000090>K0[`030000003W_j`0ikn/00L0ikn/00<000000?KO/`3fgk<01@3f
gk<00`000000l>_30?3[``040?3[``<000000`3AE`000`000000ZAl00:TO00050:TO000400000000
>JL003VW000iY`800000:P3oool3000001@0oooo000<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo0P00
00020=me?0800000103oool00`000000ek2a0=N`/@020=N`/@030000003WV7@0iiQd00D0iiQd00<0
00000>NHM03WV7@01@3WV7@3000000T0iJnL00<000000>B`W`3T/9l0203T/9l00`000000kKnT0000
00060>Ak>P<00000103TNcX00`000000i7Xd0>Aj=0020>Aj=0030000003[/iH0jk>F00H0jk>F00<0
00000?>nU`3c_YL01@3c_YL00`000000lL:O0?72W`030?72W`80000000@0lL:O0000003_aj/0klN[
0P0000070>K0[`030000003W_j`0ikn/00L0ikn/00<000000?KO/`3fgk<01@3fgk<00`000000l>_3
0?3[``050?3[``800000103AE`000`000000ZAl00:TO00050:TO000300000000>JL003VW008003VW
0P00000[0?ooo`030000003oool0oooo0140oooo000:0?ooo`<000003@3oool3000000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000000<0ggDl
0P0000000`3oool000000=N`/@040=N`/@030000003WV7@0iiQd00D0iiQd00<000000>NHM03WV7@0
1@3WV7@3000000T0iJnL00<000000>B`W`3T/9l01`3T/9l01@000000kKnT0>foY03]_j@0000000H0
i7/j00<000000>Ak>P0000000`3TNcX01@000000i7Xd0>Aj=03TNS@0000000P0jk>F00<000000?>n
U`3c_YL01P3c_YL010000000lL:O0?72W`3a`Yl2000000<0lL:O00<000000>o7Z`3_aj/00P3_aj/0
0`000000i/2_0>K0[`030>K0[`030000003W_j`0ikn/00L0ikn/00<000000?KO/`3fgk<01@3fgk<0
0`000000l>_30?3[``060?3[``<00000103AE`000`000000ZAl00:TO00040:TO000300000000>JL0
03VW00@003VW00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0@0?ooo`00303oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo100000070?ooo`X000000P3oool20000
00030?ooo`000000ggDl00@0ggDl0P0000060=N`/@030000003WV7@0iiQd00@0iiQd00<000000>NH
M03WV7@01@3WV7@00`000000l9]O000000090>F_W0030000003T/9l0i;2O00L0i;2O00D000000>fo
Y03]_j@0kKnT000000060>Ak>P030000003TNcX0i7/j0080000000<0i7/j0000003TNS@00P3TNS@0
0`000000jk>F0>^cUP060>^cUP030000003c_YL0lkjG00H0lkjG00@000000?72W`0000000000103a
`Yl00`000000klN[0>o7Z`040>o7Z`030000003V`:l0i/2_0080i/2_00<000000>No[03W_j`01`3W
_j`00`000000m]nc0?KO/`050?KO/`030000003`jl<0l>_300H0l>_300@000000>?/eP3Sk=H00000
0`3AE`000`000000ZAl00:TO00050:TO000300000000>JL003VW00@003VW1000000X0?ooo`030000
003oool0oooo00l0oooo000_0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000050=me?0030000003G/;40ek2a00D0ek2a00<000000>NHM03WV7@0
1@3WV7@00`000000iiQd0>NHM0040>NHM08000002@3U[i`00`000000i;2O0>B`W`080>B`W`050000
003]_j@0kKnT0>foY00000001P3TNcX00`000000i7/j0>Ak>P020>Ak>P<000000P3TNS@00`000000
jk>F0>^cUP060>^cUP030000003c_YL0lkjG00H0lkjG0P0000060?72W`030000003_aj/0klN[00D0
klN[0P0000020>K0[`030000003W_j`0ikn/00L0ikn/00<000000?KO/`3fgk<01@3fgk<00`000000
l>_30?3[``050?3[``030000003Sk=H0hncF0080hncF0P0000020=5G00030000002Y7`00ZAl000D0
ZAl000<00000000iY`00>JL00P00>JL9000002<0oooo0`00000@0?ooo`00:@3oool3000000<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
0000103OMC`00`000000ek2a0=N`/@050=N`/@030000003WV7@0iiQd00D0iiQd00<000000>NHM03W
V7@0103WV7@2000000T0iJnL00<000000>B`W`3T/9l0203T/9l00`000000kKnT0>foY0020>foY003
0000003TNcX0i7/j00@0i7/j00<000000>Ak>P3TNcX00`3TNcX010000000i7Xd0>Aj=00000080>^c
UP030000003c_YL0lkjG00@0lkjG0`0000070?72W`030000003_aj/0klN[00H0klN[0`0000090>No
[0030000003fgk<0m]nc00D0m]nc00<000000?3[``3`jl<01@3`jl<00`000000hncF0>?/eP040>?/
eP80000000<0dEL00000002Y7`001P2Y7`05000000<0a>3]00@00000066_nP1Q[oX0HJoj1@00000S
0?ooo`030000003oool0oooo00d0oooo000_0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool0oooo0P0000030?ooo`050000003OMC`0ggDl0=me?0000000203G/;400`000000iiQd0>NH
M0050>NHM0030000003WV7@0iiQd00@0iiQd0P0000090>F_W0030000003T/9l0i;2O00L0i;2O00<0
00000>foY03]_j@00`3]_j@00`000000i7/j0>Ak>P040>Ak>P030000003TNcX0i7/j00<0i7/j0P00
00000`3TNS@000000>^cUP070>^cUP030000003c_YL0lkjG0080lkjG0P0000000`3c_YL000000?72
W`070?72W`030000003_aj/0klN[00H0klN[00<000000>W=^@0000002@3W_j`00`000000m]nc0?KO
/`050?KO/`030000003`jl<0l>_300D0l>_300<000000>?/eP3Sk=H01@3Sk=H2000000030=5G0000
0000ZAl000<0ZAl00`0000080<CPk@8000001P1Q[oX300000240oooo00<000000?ooo`3oool0303o
ool002l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool0
1@000000ggDl0=me?03OMC`0000000P0ek2a00<000000>NHM03WV7@01@3WV7@00`000000iiQd0>NH
M0040>NHM08000002@3U[i`00`000000i;2O0>B`W`070>B`W`030000003]_j@0kKnT00<0kKnT00<0
00000>Ak>P3TNcX0103TNcX00`000000i7/j0>Ak>P040>Ak>P800000203[/iH010000000lkjG0?>n
U`3c_YL2000000<0lkjG00<000000?72W`3a`Yl01@3a`Yl00`000000klN[0>o7Z`070>o7Z`040000
003YcKT0jLfi000000P0ikn/00<000000?KO/`3fgk<0103fgk<00`000000l>_30?3[``050?3[``03
0000003Sk=H0hncF00D0hncF00<000000=CXi03Dj>@00P0000020:TO0080000000<0e>ST00000034
h>d02P34h>d<000001l0oooo00<000000?ooo`3oool02`3oool002h0oooo0P0000030?ooo`800000
103oool00`000000oooo0?ooo`020?ooo`030000003OMC`0000000T0ek2a00<000000>NHM03WV7@0
1@3WV7@00`000000iiQd0>NHM0040>NHM0800000203U[i`00`000000i;2O0>B`W`080>B`W`030000
003]_j@0kKnT00<0kKnT00<000000>Ak>P3TNcX01@3TNcX00`000000i7/j0>Ak>P030>Ak>P800000
203[/iH010000000lkjG0000000000050?>nU`030000003a`Yl0lL:O00D0lL:O00<000000>o7Z`3_
aj/01P3_aj/00`000000jLfi0>W=^@020>W=^@8000001@3W_j`00`000000m]nc0?KO/`050?KO/`03
0000003`jl<0l>_300D0l>_300<000000>?/eP3Sk=H01@3Sk=H010000000e>ST0=CXi03Dj>@30000
0080e>ST00<000000<CPk@34h>d02@34h>d00`000000]mSa0000000:08Bln@800000703oool01000
0000oooo00000000000;0?ooo`00>03oool00`000000oooo0?ooo`030?ooo`030000003OMC`00000
00T0ek2a00<000000>NHM03WV7@01@3WV7@00`000000iiQd0>NHM0040>NHM0030000003U[i`0iJnL
00L0iJnL00<000000>B`W`3T/9l0203T/9l00`000000kKnT0>foY0040>foY0030000003TNcX0i7/j
00@0i7/j00<000000>Ak>P3TNcX00`3TNcX2000000P0jk>F0P0000070?>nU`030000003a`Yl0lL:O
00D0lL:O00<000000>o7Z`3_aj/01P3_aj/00`000000jLfi0>W=^@040>W=^@030000003W_j`0ikn/
0080ikn/00<000000?KO/`3fgk<0103fgk<00`000000l>_30?3[``020?3[``L00000103Sk=H00`00
0000e>ST0=CXi0030=CXi080000000<0e>ST00000034h>d02@34h>d2000000<0]mSa00<0000008Bl
n@24_?T02@24_?T2000001h0oooo00<000000?ooo`3oool0203oool003P0oooo0P0000050?ooo`03
0000003G/;40ek2a00P0ek2a00<000000>NHM03WV7@01@3WV7@00`000000iiQd0>NHM0040>NHM003
0000003U[i`0iJnL00L0iJnL00<000000>B`W`3T/9l01`3T/9l00`000000kKnT0>foY0050>foY003
0000003TNcX0i7/j00@0i7/j00<000000>Ak>P3TNcX0103TNcX00`000000jk>F0>^cUP030>^cUP@0
00001`3c_YL00`000000lL:O0?72W`060?72W`030000003_aj/0klN[00H0klN[00<000000>W=^@3Y
cKT01@3YcKT01@000000ikn/0>No[03W_j`0000000D0m]nc1P0000070:2^h@D000001`3Dj>@00`00
0000a>3]0<CPk@080<CPk@030000002gf?40]mSa00@0]mSa0P00000:08Bln@<000007@3oool00`00
0000oooo0?ooo`070?ooo`00>03oool00`000000oooo0?ooo`040?ooo`030000003G/;40ek2a00P0
ek2a00<000000>NHM03WV7@01@3WV7@00`000000iiQd0>NHM0040>NHM0030000003U[i`0iJnL00L0
iJnL00<000000>B`W`3T/9l01`3T/9l00`000000kKnT0>foY0050>foY0030000003TNcX0i7/j00D0
i7/j00<000000>Ak>P3TNcX00`3TNcX010000000jk>F0>^cUP3[/iH2000000<0jk>F00<000000?>n
U`3c_YL01@3c_YL00`000000lL:O0?72W`050?72W`030000003_aj/0klN[00H0klN[00<000000>W=
^@3YcKT01`3YcKT300000080m]nc100000000`3PdLT000000=?Bf0030=?Bf0030000002P[^40X:kQ
00T0X:kQ100000020=CXi00300000034h>d0000000P0a>3]00<000000;OHl@2gf?401`2gf?401000
0000Q;ci08Bln@24_?T6000000<0U/7e0P00000J0?ooo`<00000203oool003P0oooo00<000000?oo
o`3oool01@3oool00`000000ek2a0=N`/@070=N`/@030000003WV7@0iiQd00D0iiQd00<000000>NH
M03WV7@0103WV7@00`000000iJnL0>F_W0060>F_W0030000003T/9l0i;2O00P0i;2O00<000000>fo
Y03]_j@01P3]_j@00`000000i7/j0>Ak>P040>Ak>P030000003TNcX0i7/j0080i7/j00<000000>^c
UP3[/iH00P0000040>^cUP030000003c_YL0lkjG00H0lkjG00<000000?72W`3a`Yl01@3a`Yl00`00
0000klN[0>o7Z`060>o7Z`030000003YcKT0jLfi00H0jLfi00<000000>3Ab@3PdLT00`0000040>3A
b@030000003Cd]P0dm;H00<0dm;H00<000000:2^h@2P[^402@2P[^42000000030::di@0000000000
008000000P34h>d00`000000a>3]0<CPk@040<CPk@030000002gf?40]mSa00T0]mSa0`00000;09K1
m@030000003oool0oooo01T0oooo0P0000070?ooo`00>03oool00`000000oooo0?ooo`060?ooo`03
0000003G/;40ek2a00D0ek2a0P0000070>NHM0030000003WV7@0iiQd00<0iiQd00<000000>F_W03U
[i`01`3U[i`00`000000i;2O0>B`W`080>B`W`030000003]_j@0kKnT00H0kKnT00<000000>Ak>P3T
NcX0103TNcX00`000000i7/j0>Ak>P020>Ak>P<000001P3[/iH00`000000lkjG0?>nU`060?>nU`03
0000003a`Yl0lL:O00D0lL:O00<000000>o7Z`3_aj/01P3_aj/00`000000jLfi0>W=^@060>W=^@03
0000003PdLT0h=7900L0h=7900<000000=?Bf03Cd]P0103Cd]P00`000000X:kQ0:2^h@060:2^h@80
0000102R]>D00`000000KZ;`00000002000000030<CPk@00000000000080a>3]0P00000:0;OHl@80
000000<0[]3b000000000000302F`OD2000001L0oooo0P0000000`3oool000000?ooo`060?ooo`00
=`3oool2000000T0oooo00<000000=N`/@3G/;40103G/;42000000L0iiQd00<000000>NHM03WV7@0
0`3WV7@00`000000iJnL0>F_W0070>F_W0030000003T/9l0i;2O00P0i;2O00<000000>foY03]_j@0
1P3]_j@00`000000i7/j0>Ak>P050>Ak>P030000003TNcX0i7/j00800000203[/iH00`000000lkjG
0?>nU`060?>nU`030000003a`Yl0lL:O00D0lL:O00<000000>o7Z`3_aj/01@3_aj/00`000000jLfi
0>W=^@070>W=^@030000003PdLT0h=7900H0h=7900<000000=?Bf03Cd]P01P3Cd]P00`000000X:kQ
0:2^h@030:2^h@8000001`2R]>D010000000KZ;`06jRl01^X_02000000030<CPk@000000000000X0
]mSa0P0000050:k@lP030000002F`OD0U/7e00X0U/7e0P00000C0?ooo`<000000`3oool00`000000
oooo0?ooo`050?ooo`00;@3oool4000000H0oooo00<000000?ooo`3oool02@3oool00`000000ek2a
0=N`/@030=N`/@8000001`3WV7@00`000000iiQd0>NHM0030>NHM0030000003U[i`0iJnL00L0iJnL
00<000000>B`W`3T/9l01`3T/9l00`000000kKnT0>foY0070>foY08000001P3TNcX4000000030:[8
k`000000000000H0jk>F00<000000?>nU`3c_YL01@3c_YL00`000000lL:O0?72W`050?72W`030000
003_aj/0klN[00H0klN[00<000000>W=^@3YcKT01P3YcKT00`000000h=790>3Ab@060>3Ab@030000
003Cd]P0dm;H00P0dm;H00<000000:2^h@2P[^400P0000090::di@030000001^X_00KZ;`00<0KZ;`
0`0000090;OHl@030000002^d?80[]3b00H0[]3b00<0000009K1m@2F`OD01P2F`OD300000080W/?b
00<000000?ooo`3oool03P3oool2000000H0oooo00<000000?ooo`3oool01@3oool002`0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00L0
00000=N`/@3G/;40ek2a0000003I/K00000000L0iiQd00<000000>NHM03WV7@00`3WV7@00`000000
iJnL0>F_W0070>F_W0030000003T/9l0i;2O00L0i;2O00<000000>foY03]_j@01P3]_j@00`000000
k/V^000000050>Ak>P<000001@2Zb>l00`000000jk>F0>^cUP030>^cUP030000003c_YL0lkjG00D0
lkjG00<000000?72W`3a`Yl01@3a`Yl00`000000klN[0>o7Z`060>o7Z`030000003YcKT0jLfi00H0
jLfi00<000000>3Ab@3PdLT01P3PdLT00`000000dm;H0=?Bf0090=?Bf0800000302R]>D00`000000
KZ;`06jRl00406jRl0<000001@2gf?42000000X0[]3b0P00000209K1m@@000001P2N`o800`000000
oooo0?ooo`0:0?ooo`<00000203oool00`000000oooo0?ooo`050?ooo`00;03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool01P000000ek2a
0=N`/@000000fK6`000000L0iiQd00<000000>NHM03WV7@00P3WV7@00`000000iJnL0>F_W0070>F_
W0030000003T/9l0i;2O00P0i;2O00<000000>foY03]_j@01P3]_j@00`000000k/V^000000030>Ak
>P<00000202Zb>l200000080jk>F00<000000?>nU`3c_YL0103c_YL>000000@0klN[00<000000>W=
^@3YcKT01P3YcKT00`000000h=790>3Ab@060>3Ab@030000003Cd]P0dm;H00T0dm;H00<000000<CA
i00000003@2R]>D00`000000KZ;`06jRl00506jRl08000000P2gf?42000000h0[]3b0P00000;09k3
lP800000203oool2000000`0oooo00<000000?ooo`3oool0103oool002`0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`8000003@3oool200000080fK6`00<000000>NHM03W
V7@01@3WV7@00`000000iiQd0>NHM0020>NHM0030000003U[i`0iJnL00L0iJnL00<000000>B`W`3T
/9l0203T/9l00`000000kKnT0>foY0060>foY0030000003^bJh0k/V^00@00000302Zb>l300000080
lkjG100000000`3Ba/l000000=k5`@060=k5`@030000003WnL/0ioW;0080ioW;1P0000070>W=^@03
0000003PdLT0h=7900H0h=7900<000000=?Bf03Cd]P0203Cd]P01@000000a=7T0<CAi034dN@00000
00`0X[CU3000000>0:k@lP80000000<0Z<_b0000002N`o80302N`o800`000000oooo0?ooo`020?oo
o`<000003P3oool00`000000oooo0?ooo`040?ooo`00;03oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool010000000fK6`0=Va/00000070>NH
M0030000003WV7@0iiQd0080iiQd00<000000>F_W03U[i`01`3U[i`00`000000i;2O0>B`W`070>B`
W`030000003]_j@0kKnT00L0kKnT00<000000>k9[P0000000P00000@0:[8k`<00000103Ba/l00`00
0000g/G10=k5`@060=k5`@030000003WnL/0ioW;00D0ioW;00<000000=_hgP3Kn=h0100000020>W=
^@030000003PdLT0h=7900H0h=7900<000000=?Bf03Cd]P0203Cd]P00`000000a=7T0<CAi0030<CA
i0800000202R]>D200000080Xk[Y00<0000008^bl02;/_001P2;/_03000000X0[]3b0P0000040:S;
lP030000002N`o80W/?b00X0W/?b0P0000000`3oool000000000000A0?ooo`030000003oool0oooo
00@0oooo000/0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0>0?ooo`030000003I/K00000000L0iiQd00<000000>NHM03WV7@00P3WV7@00`000000
iJnL0>F_W0070>F_W0030000003T/9l0i;2O00L0i;2O00<000000>foY03]_j@01P3]_j@300000080
k/V^0P00000=0:[8k`8000001`3Ba/l00`000000g/G10=k5`@050=k5`@030000003WnL/0ioW;00H0
ioW;00<000000=_hgP3Kn=h0103Kn=h4000000H0h=7900<000000=?Bf03Cd]P0203Cd]P00`000000
a=7T0<CAi0060<CAi0030000002R]>D0X[CU00<0X[CU0P0000050:>jj@030000002;/_00Rk;`00H0
Rk;`100000060:k@lP8000001`2Xbo82000000L0W/?b0`0000020:;4l@8000004P3oool00`000000
oooo0?ooo`040?ooo`00;03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
0P00000A0?ooo`800000203WV7@010000000iiQd0>NHM00000090>F_W0030000003T/9l0i;2O00P0
i;2O00<000000>foY03]_j@0103]_j@3000000H0k/V^0P0000090:[8k`800000203Ba/l00`000000
g/G10=k5`@060=k5`@030000003WnL/0ioW;00D0ioW;00<000000=_hgP3Kn=h01P3Kn=h00`000000
c?3[0<c`j`0400000080h=7900<000000=?Bf03Cd]P01`3Cd]P00`000000a=7T0<CAi0080<CAi003
0000002R]>D0X[CU00800000202S^^T2000000P0Rk;`00@0000008^bl000000000000P2^d?820000
00/0Z<_b00<0000009k3lP2N`o80100000070:;4l@030000003oool0oooo00l0oooo00<000000?oo
o`3oool0103oool002d0oooo100000050?ooo`030000003oool0oooo0140oooo00<000000>NHM03W
V7@01P3WV7@010000000iiQd0>NHM00000090>F_W0030000003T/9l0i;2O00P0i;2O00<000000>fo
Y03]_j@00P3]_j@200000080kKnT00<000000>k9[P3^bJh01P3^bJh2000000D0Z/S_0P0000090=;6
c`030000003NaL40g/G100H0g/G100<000000>Oib`3WnL/01@3WnL/00`000000foSN0=_hgP060=_h
gP030000003<l>/0c?3[00D0c?3[0P00000:0=?Bf00300000034dN@0a=7T00T0a=7T0P00000<0:>j
j@030000002;/_00Rk;`00H0Rk;`1@00000>0:S;lP800000302Ra?42000000l0oooo00<000000?oo
o`3oool0103oool003H0oooo00<000000?ooo`3oool04@3oool00`000000iiQd0>NHM0060>NHM004
0000003WV7@0iiQd000000T0iJnL00<000000>B`W`3T/9l01`3T/9l010000000kKnT0>foY03]_j@2
000000@0kKnT00<000000>k9[P3^bJh01P3^bJh01@000000jLnk000000000000Z/S_008000002P3B
a/l00`000000g/G10=k5`@070=k5`@030000003WnL/0ioW;00D0ioW;00<000000=_hgP3Kn=h01@3K
n=h00`000000c?3[0<c`j`060<c`j`040000002ni_800000000000L0dm;H00<000000<CAi034dN@0
2@34dN@00`000000]/g[0000000=0:>jj@040000002;/_00Rk;`08^bl0L0000000<0VK__0000002X
bo802`2Xbo82000000030:K7l@000000X/Ca00`0X/Ca0P00000>0?ooo`030000003oool0oooo00@0
oooo000f0?ooo`030000003oool0oooo0140oooo00<000000>NHM03WV7@01P3WV7@010000000iiQd
0>NHM00000090>F_W0030000003T/9l0i;2O00L0i;2O00@000000>foY000000000001@3]_j@00`00
0000k/V^0>k9[P070>k9[P050000003Yck/0jLnk0>W?^`000000303Ba/l00`000000g/G10=k5`@06
0=k5`@030000003WnL/0ioW;00D0ioW;00<000000=_hgP3Kn=h01@3Kn=h00`000000c?3[0<c`j`06
0<c`j`030000002ni_80_^Kb0080_^Kb0P0000040=?Bf00300000034dN@0a=7T00T0a=7T00D00000
0;K=j`2fcN/0]/g[0000000<0:>jj@@000001`2I^nl00`000000VK__000000090:S;lP800000102V
ao400`000000X/Ca0:;4l@080:;4l@8000000P2Ta?000`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00@0oooo000f0?ooo`8000004P3oool00`000000iiQd0>NHM0060>NHM0040000003WV7@0
iiQd000000T0iJnL00<000000>B`W`3T/9l01`3T/9l2000000L0kKnT00<000000>k9[P3^bJh01P3^
bJh00`000000jLnk0>W?^`030>W?^`030000003Ba/l0d/K?00P0d/K?00<000000=k5`@3NaL401`3N
aL400`000000ioW;0>Oib`040>Oib`030000003Kn=h0foSN00D0foSN00<000000<c`j`3<l>/01P3<
l>/00`000000_^Kb0;kVlP050;kVlP80000000<0dm;H00000034dN@02P34dN@00`000000]/g[0;K=
j`030;K=j`800000202S^^T200000080Y;k/00<0000009Vkk`2I^nl01`2I^nl010000000VK__0000
000000050:S;lP8000001`2Vao42000000D0X/Ca0`0000050:C4l0030000003oool0oooo00X0oooo
00<000000?ooo`3oool0103oool003H0oooo00<000000?ooo`3oool04@3oool00`000000iiQd0>NH
M0060>NHM0030000003WV7@0000000T0iJnL00<000000>B`W`3T/9l01P3T/9l3000000P0kKnT00<0
00000>k9[P3^bJh01P3^bJh00`000000jLnk0>W?^`040>W?^`8000001`3Ba/l00`000000g/G10=k5
`@070=k5`@030000003WnL/0ioW;00@0ioW;00<000000=_hgP3Kn=h01@3Kn=h00`000000c?3[0<c`
j`050<c`j`8000002P2ni_800`000000a=7T0<CAi0080<CAi0800000202fcN/00`000000Xk[Y0:>j
j@030:>jj@8000001@2T_^`00`000000VK__09Vkk`0709Vkk`040000002I^nl0VK__00000080Z<_b
0P00000;0:K7l@030000002Ra?40X/Ca008000002@2Ta?02000000/0oooo00<000000?ooo`3oool0
0`3oool003H0oooo00<000000?ooo`3oool04@3oool00`000000iiQd0>NHM0060>NHM0030000003W
V7@0000000T0iJnL00<000000>B`W`3T/9l0103T/9l2000000030>B`W`000000kKnT00P0kKnT00<0
00000>k9[P3^bJh01P3^bJh00`000000jLnk0>W?^`060>W?^`030000003Ba/l0d/K?00<0d/K?00<0
00000=k5`@3NaL40203NaL400`000000ioW;0>Oib`040>Oib`030000003Kn=h0foSN00@0foSN00<0
00000<c`j`3<l>/01@3<l>/00`000000_^Kb0;kVlP080;kVlP80000000<0/m_d0000000000001`34
dN@00`000000]/g[0;K=j`090;K=j`030000002S^^T0Xk[Y00800000202T_^`00`000000VK__09Vk
k`0709Vkk`D000003@2Vao43000000d0Y<C`00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`030?ooo`00=@3oool2000001@0oooo00<000000>NHM03WV7@01@3WV7@00`000000iiQd00000009
0>F_W0030000003T/9l0i;2O0080i;2O0P0000030>B`W`030000003]_j@0kKnT00H0kKnT00<00000
0>k9[P3^bJh01P3^bJh00`000000jLnk0>W?^`070>W?^`800000103Ba/l00`000000g/G10=k5`@07
0=k5`@030000003WnL/0ioW;00@0ioW;00<000000=_hgP3Kn=h0103Kn=h00`000000c?3[0<c`j`05
0<c`j`030000002ni_80_^Kb00P0_^Kb00<000000;?Km02cfo@00`2cfo@2000000@0a=7T00<00000
0;K=j`2fcN/02`2fcN/2000000/0Y;k/00<0000009Vkk`2I^nl01@2I^nl4000000030:2ok`000000
000000X0Y/Oa0P0000020:C5l0030000002Ta?00Y<C`00/0Y<C`0P0000090?ooo`030000003oool0
oooo00<0oooo000e0?ooo`030000003oool0oooo01<0oooo00<000000>NHM03WV7@01@3WV7@00`00
0000iiQd000000090>F_W0030000003T/9l0i;2O008000001@3T/9l00`000000kKnT0>foY0060>fo
Y0030000003^bJh0k/V^00H0k/V^00<000000>W?^`3Yck/01P3Yck/00`000000hM?:0>7CbP020000
00030=;6c`000000g/G100T0g/G100<000000>Oib`3WnL/00`3WnL/00`000000foSN0=_hgP040=_h
gP030000003<l>/0c?3[00D0c?3[00<000000;kVlP2ni_801`2ni_82000000P0/m_d0P0000000`34
dN@000000;K=j`0;0;K=j`80000000<0[LW^0000002T_^`02`2T_^`00`000000VK__09Vkk`040000
00@0X;o_00@000000:2ok`2P_nl000001P2Vao43000000D0Y<G`00<000000:C4l02Ta?00202Ta?02
00000080Y<C`00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`00=@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003WV7@0iiQd00D0iiQd0P0000090>F_W0040000003T/9l00000
000000L0i;2O00<000000>foY03]_j@01P3]_j@00`000000k/V^0>k9[P060>k9[P030000003Yck/0
jLnk00H0jLnk00<000000>7CbP3QdlX00P3QdlX2000000T0g/G100<000000>Oib`3WnL/0103WnL/0
0`000000foSN0=_hgP0=000000P0_^Kb00<000000;?Km02cfo@02P2cfo@00`000000]/g[0;K=j`0:
0;K=j`030000002]bNh0[LW^0080[LW^00<000000:Bnk02T_^`02@2T_^`3000000T0X;o_00<00000
0:2ok`2P_nl00P0000020:K7l@8000002@2TaO02000000D0Y<C`0`0000050:C4l0030000003oool0
oooo00D0oooo00<000000?ooo`3oool00`3oool003D0oooo00<000000?ooo`3oool04`3oool00`00
0000iiQd0>NHM0050>NHM0800000203U[i`3000000T0i;2O00<000000>foY03]_j@01P3]_j@00`00
0000k/V^0>k9[P050>k9[P030000003Yck/0jLnk00H0jLnk00<000000>7CbP3QdlX01@3QdlX20000
00L0g/G100<000000>Oib`3WnL/00P3WnL/5000000030:jkh`000000PjO/0080PjO/300000020;kV
lP8000002`2cfo@2000000030:cBm0000000000000P0]/g[0P0000060:g9kP8000001P2T_^`30000
0080Y<7^0P0000090:2ok`80000000@0X;o_00000000000000003@2TaO000`000000Y<C`0:C4l002
000000T0Y<C`00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00=@3oool20000
01@0oooo00<000000>NHM03WV7@01@3WV7@2000000H0iJnL0P0000000`3U[i`000000>B`W`080>B`
W`030000003]_j@0kKnT00H0kKnT00<000000>k9[P3^bJh01P3^bJh00`000000jLnk0>W?^`060>W?
^`030000003QdlX0hM?:00L0hM?:0P0000040=k5`@040000003WnL/0ioW;0>Oib`8000000P2d^=`2
000000<0[[_S00<0000008>Wk023Yn`01@23Yn`200000080NkSi1P00000:0;?Km08000001@2/d_@2
000000D0]/g[00<000000:g9kP2]bNh0202]bNh00`000000Y;k/0:Bnk003000000L0Y<7^00<00000
0:2ok`2P_nl01`2P_nl200000080Xl;_00<000000:C5l02TaO002`2TaO03000000`0Y<C`00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`00103oool500000080oooo00D000000?oo
o`3oool0oooo000000040?ooo`D000000`3oool4000001D0oooo00<000000?ooo`3oool04`3oool0
0`000000iiQd0>NHM0050>NHM0800000103U[i`2000000<0iJnL00<000000>B`W`3T/9l01`3T/9l0
0`000000kKnT0>foY0060>foY0030000003^bJh0k/V^00H0k/V^00<000000>W?^`3Yck/01@3Yck/0
0`000000hM?:0>7CbP080>7CbP040000003DeMT0000000000080g/G1100000030;Bhg0030000002^
^n<0[[_S00@0[[_S00<0000008>Wk023Yn`01P23Yn`00`000000NkSi07^hn@0507^hn@8000001P2c
fo@2000000T0[=;d0P0000000`2fcN/000000000000<0:g9kP8000002`2T`Nh00`000000X;o_0:2o
k`040:2ok`8000000P2S`^l010000000Xl;_0:?2k`00000:0:C5l08000000P2Ta?000`000000Y<C`
0:C4l00:0:C4l0800000103oool00`000000oooo0?ooo`030?ooo`001P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04`3oool00`000000iiQd0>NH
M0050>NHM0040000003U[i`0iJnL0>F_W08000001@3U[i`00`000000i;2O0>B`W`070>B`W`030000
003]_j@0kKnT00H0kKnT00<000000>k9[P3^bJh01@3^bJh00`000000jLnk0>W?^`060>W?^`030000
003QdlX0hM?:00L0hM?:00<000000=CEf@3DeMT00P3DeMT4000000@0];SL00<000000:jkh`2^^n<0
1P2^^n<00`000000PjO/08>Wk00608>Wk0030000001k^?T0NkSi00H0NkSi0P0000020;?Km0800000
302/d_@2000000`0[LW^0P0000000`2Wa_0000000:C1kP0;0:C1kP8000000P2P_nl2000000D0Xl;_
0P0000000`2S`^l00000000000050:C5l0<000001@2Ta?000`000000Y<C`0:C4l0070:C4l0800000
0P2Ta?001@000000oooo0?ooo`3oool0000000D0oooo00060?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04@3oool2000001D0oooo00<000000>NHM03WV7@01@3WV7@010000000iJnL
0000000000060>F_W0030000003T/9l0i;2O00P0i;2O00<000000>foY03]_j@01P3]_j@00`000000
k/V^0>k9[P050>k9[P030000003Yck/0jLnk00H0jLnk00<000000>7CbP3QdlX01`3QdlX00`000000
e=GI0=CEf@060=CEf@040000002d^=`00000000000X0[[_S00<0000008>Wk023Yn`01P23Yn`20000
00D0NkSi1P00000;0:cBm08000000P2Wc?<2000000P0[LW^0P0000040:O6l0030000002T`Nh0Y<7^
00X0Y<7^0`0000090:?2k`040000002S`^l0Xl;_00000080Y<G`0P0000090:C4l08000001@2Ta?02
000000D0Y<C`00D000000?ooo`3oool0oooo000000040?ooo`001P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0140oooo0P00000E0?ooo`030000003WV7@0iiQd00D0iiQd0P000008
0>F_W0030000003T/9l0i;2O00L0i;2O00<000000>foY03]_j@01P3]_j@00`000000k/V^0>k9[P05
0>k9[P030000003Yck/0jLnk00H0jLnk00<000000>7CbP3QdlX01`3QdlX00`000000e=GI0=CEf@08
0=CEf@030000002^^n<0[[_S00/0[[_S00<0000008>Wk023Yn`00`23Yn`9000000H0T[of0P000007
0:cBm08000001P2Wc?<00`000000[LW^0:g9kP030:g9kP8000001`2Wa_02000000L0Y<7^0`000002
0:C2k`8000002@2S`^l00`000000Xl;_00000002000000d0Y<C`00<000000:C4l02Ta?000P000008
0:C4l080000000<0oooo0000003oool00`3oool000H0oooo00<000000?ooo`3oool00P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0503oool00`000000iiQd0>NHM003
0>NHM080000000<0XLOc0000000000001`3U[i`00`000000i;2O0>B`W`070>B`W`030000003]_j@0
kKnT00H0kKnT00<000000>k9[P3^bJh01@3^bJh00`000000jLnk0>W?^`060>W?^`030000003QdlX0
hM?:00H0hM?:00<000000=CEf@3DeMT0203DeMT00`000000aM?U0000000=0:jkh`D000001@2D/nd2
000000X0T[of0P0000030:cBm08000002@2Wc?<2000000030:g9kP000000000000/0YlK`00<00000
0:C1kP2T`Nh0100000070:C2k`030000002S`^l0Xl;_00D0Xl;_0`0000020:C3k`800000302Ta?03
000000`0Y<C`0P0000040?ooo`001P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01@0oooo00@000000>NHM03WV7@0iiQd0P0000050:77l`8000001@3U[i`00`000000i;2O0>B`W`07
0>B`W`030000003]_j@0kKnT00H0kKnT00<000000>k9[P3^bJh01@3^bJh00`000000jLnk0>W?^`05
0>W?^`030000003QdlX0hM?:00L0hM?:00<000000=CEf@3DeMT01`3DeMT01@000000aM?U0<GCi@35
dnD0000000X0[[_S0P0000000`2Z_^P0000009Bck@0909Bck@8000002@2B_oH4000000`0Ylcc0P00
000=0:O6l0<00000302T`^l200000080Xl;_0`0000030:C3k`8000000P2T`nl00`000000Y<C`0:C4
l0060:C4l0<000000P2Ta?000`000000Y<C`0:C4l00:0:C4l0800000103oool000@0oooo0`00000=
0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0503oool010000000iiQd0000000000090:77l`8000000P3U[i`00`000000i;2O0>B`
W`080>B`W`030000003]_j@0kKnT00H0kKnT00<000000>k9[P3^bJh0103^bJh00`000000jLnk0>W?
^`060>W?^`030000003QdlX0hM?:00H0hM?:00<000000=CEf@3DeMT01`3DeMT00`000000aM?U0<GC
i@030<GCi@8000001`2^^n<00`000000Z[kX0:Znj0020:Znj0030000002D/nd0U;?]00T0U;?]0P00
000309:omP@000000`2M`_82000000T0Ylcc0P0000020:G8l@8000002@2Wa_0200000080YLG`0P00
000<0:C2k`<00000202T`nl00`000000Y<?_0:C3k`0200000080Y<C`100000060:C4l08000001`2T
a?03000000030?ooo`000000oooo00<0oooo00060?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool4000000L0oooo2P0000030?ooo`8000005@3oool2000000d0XLOc0`000009
0>B`W`030000003]_j@0kKnT00H0kKnT00<000000>k9[P3^bJh01@3^bJh00`000000jLnk0>W?^`05
0>W?^`030000003QdlX0hM?:00L0hM?:00<000000=CEf@3DeMT01P3DeMT00`000000aM?U0<GCi@06
0<GCi@030000002^^n<0[[_S0080[[_S0P0000060:Znj08000002P2D/nd4000000T0WL;b00<00000
0:O<l`2Wc?<0102Wc?<2000000H0YLSa00<000000:O6l02Wa_00102Wa_02000000H0YLG`00<00000
0:C2k`2T`^l01`2T`^l200000080Y<?_00<000000:C3k`2T`nl01`2T`nl00`000000Y<?_0:C3k`03
000000`0Y<C`00<000000:C4l02Ta?00100000040?ooo`030000003oool0oooo0080oooo000Y0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?oo
o`80000000<0oooo0000000000003P2Qao<00`000000i;2O0>B`W`070>B`W`030000003]_j@0kKnT
00H0kKnT00<000000>k9[P3^bJh01@3^bJh00`000000jLnk0>W?^`050>W?^`030000003QdlX0hM?:
00H0hM?:00<000000=CEf@3DeMT01P3DeMT00`000000aM?U0<GCi@080<GCi@040000002^^n<00000
000000X0Z[kX00<0000009Bck@2D/nd0102D/nd300000080WK_]00<0000009g2lP2M`_802@2M`_82
00000080Ylcc0P0000090:G8l@8000000P2Wa_02000000T0YLG`00<000000:C2k`2T`^l0102T`^l2
000000D0Y<?_00<000000:C3k`2T`nl01`2T`nl200000080Y<?_00<000000:C4l02Ta?002P2Ta?03
000000P0oooo00<000000?ooo`3oool00P3oool002<0oooo0`0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`<000001@3oool20000
00X0XLOc0P0000000`2Qao<00000000000070>B`W`030000003]_j@0kKnT00H0kKnT00<000000>k9
[P3^bJh0103^bJh00`000000jLnk0>W?^`050>W?^`030000003QdlX0hM?:00H0hM?:00<000000=CE
f@3DeMT01`3DeMT00`000000aM?U0<GCi@090<GCi@030000002Z_^P0Z[kX00/0Z[kX00<0000009Bc
k@2D/nd00`00000609fkk@030000002M`_80WL;b00T0WL;b0`00000<0:G8l@<00000302UaO020000
0080Y<;_0P0000080:C3k`8000001@2T`nl200000080Y<?_00@000000:C3k`2T`nl000002@2Ta?02
000000/0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo0P00000:0?ooo`8000001P2Qao<20000
00D0XLOc0P0000050>B`W`030000003]_j@0kKnT00H0kKnT00<000000>k9[P3^bJh00`3^bJh=0000
00D0hM?:00<000000=CEf@3DeMT01P3DeMT00`000000aM?U0<GCi@090<GCi@040000002gcn`00000
000000`0Z[kX0P00000:09fkk@8000001P2M`_8300000080X/?a0P0000090:G8l@8000000P2TaO00
0`000000YLG`0:G5l00;0:G5l0<00000302T`nl00`000000Y<?_0:C3k`02000000D0Y<?_00<00000
0:C3k`2T`nl00P0000050:C4l08000003P3oool00`000000oooo0?ooo`010?ooo`00:@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`00000<0?ooo`8000003P3oool20000
0080XLOc0P0000090:77l`8000000P3T/9l00`000000kKnT0>foY0060>foY0030000003^bJh0k/V^
00@000001P28j?@2000000D0V>Cm1P0000070=CEf@0300000035dnD0aM?U00T0aM?U00<000000;O?
k02gcn`00P2gcn`00`000000Z[kX0:Znj0070:Znj080000000<0Yl3/0000000000002`2M^nd00`00
0000WL;b09g2lP03000000L0X/?a00<000000:G8l@2Ub?40102Ub?42000000D0Y<G`00<000000:G5
l02UaO00202UaO0200000080Y<C`00<000000:C3k`2T`nl02P2T`nl3000000P0Y<?_00D000000:C3
k`2T`nl0Y<?_000000020:C4l0800000403oool00`000000oooo0?ooo`010?ooo`00:03oool20000
00<0oooo0P0000040?ooo`030000003oool0oooo00X0oooo0P00000B0?ooo`8000003@2Qao<30000
00@0kKnT2@00000508SXm0<00000202Hi?d2000000<0Wmcl100000020=CEf@0300000035dnD0aM?U
00T0aM?U00<000000;O?k02gcn`0102gcn`00`000000Z[kX0:Znj0040:Znj08000001@2W`>`00`00
0000WK_]09fkk@0809fkk@<000002`2R`o4200000080YLSa0P0000080:C5l08000001@2UaO030000
00D0Y<C`0P0000070:C3k`<000000P2T`nl00`000000Y<?_0:C3k`070:C3k`80000000@0Y<?_0000
0000000000004P3oool00`000000oooo0?ooo`010?ooo`00<`3oool00`000000oooo0?ooo`080?oo
o`8000005@3oool2000000d0XLOc5P00000609STo@<000002@2Og?`3000000T0aM?U0P0000080;O?
k08000000P2Z_^P2000000P0Yl3/00<0000009fkk@2M^nd01@2M^nd200000080X[o^0P00000;0:;3
l@<00000302TaO000`000000YLG`0:G5l002000000X0Y<C`00<000000:C3k`2T`nl0100000060:C3
k`8000001`2T`nl3000001D0oooo00<000000?ooo`3oool00@3oool003<0oooo0P0000070?ooo`80
00006@3oool00`000000XLOc0:77l`080:77l`8000000`1JdlX50000000306JEjP000000000000/0
_<3M1P00000:09oLo08000000`2Re?T2000000H0aM?U00<000000;O?k02gcn`02P2gcn`2000000/0
Yl3/0P00000209fkk@<000001P2R_nh2000000L0X/?a0P0000020:?3l08000002`2TaO03000000`0
Y<C`0`00000<0:C3k`030000002T`nl0Y<?_00@000000`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0040oooo000c0?ooo`030000003oool0oooo00@0oooo0P00000L0?ooo`800000
1P2Qao<20000000305[CbP000000000000<000000`3oool010000000IYGZ06JEjP1VUNX2000000X0
_<3M0P0000030;C2i0@000000`2Og?`3000000L0X]Ci0`0000020<GCi@030000002gcn`0]lo/00T0
]lo/0P0000000`2]bnl000000000000;0:O0k0<000002`2R_nh200000080X/?a0`0000060:?3l080
00001`2TaO0200000080Y<C`0P0000090:C4l08000000P2Ta?000`000000Y<?_0:C3k`0:0:C3k`<0
0000203oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0040oooo000b0?ooo`030000
003oool0oooo00<0oooo0P00000P0?ooo`8000000P2Qao<5000000T0oooo00<0000006JEjP1VUNX0
0P1VUNX00`000000_<3M0;c0g@060;c0g@030000002d`^@0]<;T00D0]<;T00<0000005nOlP000000
0P00000=0:;Dn@8000002P2gcn`2000000D0[L__00<000000:O0k02W`>`01@2W`>`300000080YL;^
0P00000;0::okP<000002`2S`o0200000080Y<G`0`0000060:C4l0030000002Ta?00Y<C`00@0Y<C`
0P0000050:C4l0030000002T`nl0Y<?_00L0Y<?_0P00000<0?ooo`8000004@3oool00`000000oooo
0?ooo`010?ooo`00<P3oool010000000oooo0?ooo`3oool2000002@0oooo0`00000>0?ooo`030000
001VUNX0IYGZ0080IYGZ0P0000050;c0g@030000002d`^@0]<;T00L0]<;T0P00000205nOlP800000
202Re?T300000080Xlkf0P0000060;O?k0800000202]bnl200000080Yl3/0`0000070:G2kP030000
002R_nh0X[o^00D0X[o^0`0000020:?2k`8000002`2S`o03000000X0Y<C`0P0000020:C4l0800000
202Ta?02000000D0Y<?_0P00000@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0@3oool00380oooo1000000h0?ooo`@000000P1VUNX2000000030;c0g@000000000000`0]<;T1P00
00030:;Dn@<000001`2Sc_H200000080]lo/0P00000<0:g;k`8000002`2U`^h200000080X[o^0`00
00070:?2k`030000002S`o00Xl?`00D0Xl?`0`0000020:C3l08000002P2Ta?03000000`0Y<C`00<0
00000:C3k`2T`nl00P00000C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00@3o
ool00380oooo0P00000k0?ooo`0300000024ZN`0Q:W/00D00000302d`^@2000000040:g2j@000000
Qk?b08NclPD00000302Sc_H3000000/0[L__0P0000000`2Wao0000000000000<0:G2kP8000002`2S
`^l200000080Xl?`0`0000070:C3l0030000002Ta?00Y<C`00D0Y<C`0P0000020:C4l08000002`2T
a?03000001H0oooo0P00000>0?ooo`4000000@3oool10?ooo`00<`3oool2000003/0oooo00<00000
08BYk024ZN`01024ZN`2000000T0]<;T00<000000:g2j@2]`^T00P2]`^T00`000000Qk?b08NclP04
08NclP800000202Sc_H2000000<0Y<Wc0P0000070:g;k`8000001@2Wao000`000000YL;^0:G2kP07
0:G2kP80000000<0Y<?_000000000000302S`^l2000000/0Y<?`0P0000020:C4l0<000001P2Ta?00
0`000000Y<C`0:C4l0050:C4l0<000006`3oool00`000000oooo0?ooo`0;0?ooo`4000000@3oool1
0?ooo`00=@3oool2000003X0oooo0P00000608BYk08000001@2d`^@2000000H0[L;Y0P00000608Nc
lP8000000`2Sc_H3000000L0Y<Wc0P0000030:g;k`800000202Wao000`000000YL;^0:G2kP040:G2
kP8000001@2T`nl00`000000Xl;_0:?2k`070:?2k`80000000<0Y<?_0000000000002`2T`o030000
00X0Y<C`0P0000020:C4l0<000007`3oool00`000000oooo0?ooo`0:0?ooo`4000000@3oool10?oo
o`00=`3oool2000003X0oooo00<0000008BYk024ZN`01@24ZN`2000000030;C2i0000000000000X0
[L;Y00<0000008NclP27/o800`27/o85000000`0Y<Wc0`00000;0:O7l08000000P2U`^h2000000P0
Y<?_00<000000:?2k`2S`^l0102S`^l2000000D0Y<?_00<000000:C3l02T`o001@2T`o0300000080
Y<?`0P00000:0:C4l0<000008`3oool00`000000oooo0?ooo`090?ooo`4000000@3oool10?ooo`00
>@3oool2000003T0oooo00<0000008BYk024ZN`00`24ZN`4000000d0[L;Y1@00000409Rll0800000
2P2TbO<2000000030:C6l@000000000000/0YlO`0`00000;0:C3k`8000000P2S`^l2000000P0Y<?_
0P0000020:C3l0<000001`2T`o000`000000Y<C`0:C4l0050:C4l08000009`3oool2000000T0oooo
0@0000010?ooo`40oooo000k0?ooo`800000>03oool5000000@0UKC]0P0000090:g2j@80000000<0
Z<?]000000000000202H_?02000000H0Y<Wc0P0000050:C6l@8000001`2Wao0200000080YLG`0P00
000;0:C3k`<00000302T`nl2000000/0Y<?`0P0000020:C4l0<00000:`3oool00`000000oooo0?oo
o`060?ooo`4000000@3oool10?ooo`00?@3oool2000003L0oooo00<0000009Fdk@2E]>d01`2E]>d0
0`000000[L;Y0:g2j@050:g2j@030000002X`nd0Z<?]00<0Z<?]00<0000009Rll02H_?001`2H_?02
00000080Y<Wc0P0000090:C6l@8000000P2Wao03000000H0YLG`00<000000:C3k`2T`nl01@2T`nl3
00000080Y<?_0P0000090:C3k`80000000<0Y<?_0000000000002`2T`o03000002l0oooo00<00000
0?ooo`3oool01@3oool100000040oooo0@3oool003l0oooo0P00000f0?ooo`030000002E]>d0UKC]
00L0UKC]00<000000:g2j@2]`^T00`2]`^T00`000000Z<?]0:S3k@050:S3k@030000002H_?00V;c`
00L0V;c`0`00000<0:C6l@<000002P2UaO0200000080Y<?_0`0000070:C3k`030000002T`nl0Y<?_
00@0Y<?_0P0000050:C3k`030000002T`o00Y<?`00D0Y<?`0`00000c0?ooo`030000003oool0oooo
00@0oooo0@0000010?ooo`40oooo00110?ooo`800000=@3oool2000000P0UKC]0P0000000`2]`^T0
0000000000090:S3k@8000000`2H_?04000000<0X<3_0P0000080:C6l@8000000P2TaO02000000X0
YLG`0`00000;0:C3k`8000000P2T`nl2000000P0Y<?_0P0000020:C3l0<00000=`3oool2000000@0
oooo0@0000010?ooo`40oooo00130?ooo`800000=@3oool00`000000UKC]09Fdk@0609Fdk@800000
3@2X`nd3000000T0X<3_0P0000030:C6l@<000001P2TaO000`000000YLG`0:G5l0050:G5l0800000
0P2Ta?02000000/0Y<?_0`00000<0:C3k`800000?03oool00`000000oooo0?ooo`020?ooo`400000
0@3oool004D0oooo0P00000d0?ooo`040000002E]>d0UKC]09Fdk@@000000P2M^nd2000000T0Z<?]
0P0000000`2V`nh000000000000;0:30k`<000002P2TaO0200000080YLG`0`0000060:C4l0030000
002T`nl0Y<?_00D0Y<?_0`0000020:C3k`8000002@2T`nl2000003l0oooo00D000000?ooo`3oool0
oooo000000010?ooo`00A`3oool2000003<0oooo0`00000809fkk@030000002X`nd0Z<?]00@0Z<?]
0P0000050:K3kP8000001`2P`>l200000080Xl;_0P00000:0:C5l0<000002P2Ta?0200000080Y<?_
0`0000070:C3k`030000002T`nl0Y<?_00@0Y<?_0P0000120?ooo`8000000@3oool100000040oooo
00190?ooo`800000<P3oool2000000T0WK_]0P0000020:S3k@8000002@2V`nh200000080X<3_0`00
00060:?2k`030000002TaO00Y<G`00D0Y<G`0P0000020:C4l08000002P2Ta?03000000/0Y<?_0P00
00020:C3k`800000AP3oool200000040oooo001;0?ooo`800000<P3oool2000000P0WK_]0`00000<
0:K3kP<000002P2S`^l200000080Y<G`0`0000060:C4l0030000002Ta?00Y<C`00D0Y<C`0P000002
0:C4l08000002`2T`nl3000004P0oooo0P0000010?ooo`00C@3oool00`000000oooo0?ooo`0a0?oo
o`8000000P2M^nd4000000<0X[o^0P0000080:K3kP8000000P2T`nl2000000X0Xl;_0`00000:0:C4
l08000000P2Ta?03000000H0Y<C`00<000000:C3k`2T`nl01@2T`nl3000004P0oooo0`0000030?oo
o`00CP3oool2000003<0oooo0P0000090::okP8000000`2V`nh3000000H0Y<?_00<000000:?2k`2S
`^l01@2S`^l200000080Y<?_0P00000:0:C4l0<000002P2Ta?0200000080Y<?_0`0000180?ooo`<0
00001P3oool00500oooo0P00000b0?ooo`8000002P2R_nh3000000X0Y<?_0P0000020:?2k`<00000
1P2T`nl00`000000Y<C`0:C4l0050:C4l08000000P2Ta?02000000X0Y<C`0`0000180?ooo`<00000
2@3oool00580oooo0P00000b0?ooo`8000001P2R_nh200000080Xl;_0P00000:0:C3k`<000002P2T
`nl200000080Y<C`0`0000060:C4l0030000002Ta?00Y<C`00D0Y<C`0P0000180?ooo`<00000303o
ool005@0oooo0P00000b0?ooo`8000000P2R_nh2000000H0Xl;_0P0000060:C3k`8000000P2T`nl2
000000X0Y<?_0`00000:0:C4l08000000P2Ta?03000004L0oooo0`00000?0?ooo`00EP3oool20000
0380oooo0P00000:0:?2k`8000000P2T`nl2000000H0Y<?_0P0000060:C3k`8000000P2T`nl20000
00X0Y<C`0`0000170?ooo`<000004P3oool005P0oooo0P00000a0?ooo`8000002P2S`^l3000000X0
Y<?_0P0000020:C3k`8000001P2T`nl00`000000Y<C`0:C4l0050:C4l0800000B03oool2000001D0
oooo001J0?ooo`800000<@3oool00`000000Xl;_0:?2k`050:?2k`8000000P2T`nl2000000X0Y<?_
0`0000090:C3k`8000000P2Ta?03000004L0oooo0`00000G0?ooo`00G03oool200000300oooo0P00
00020:?2k`<000001P2T`nl00`000000Y<?_0:C3k`050:C3k`8000000P2T`nl2000000T0Y<?_0`00
00170?ooo`<000006P3oool005h0oooo0P00000`0?ooo`8000002P2T`nl200000080Y<?_0`000006
0:C3k`030000002T`nl0Y<?_00@0Y<?_0P0000170?ooo`<000007@3oool00600oooo0P00000_0?oo
o`8000002P2T`nl3000000X0Y<?_0P0000020:C3k`800000AP3oool300000200oooo001R0?ooo`80
0000;`3oool00`000000Y<?_0:C3k`050:C3k`8000000P2T`nl2000000X0Y<?_0`0000150?ooo`<0
00008`3oool006@0oooo0P00000^0?ooo`8000000P2T`nl3000000H0Y<?_0P0000040:C3k`@00000
A@3oool3000002H0oooo001V0?ooo`030000003oool0oooo02d0oooo0P00000;0:C3k`@00000AP3o
ool3000002T0oooo001W0?ooo`800000;`3oool2000000L0Y<?_0P0000170?ooo`<00000;03oool0
06T0oooo0P00000_0?ooo`8000000`2T`nl2000004H0oooo0`00000_0?ooo`00J`3oool2000002l0
oooo0`0000150?ooo`<00000<P3oool006d0oooo0P00000]0?ooo`030000003oool0oooo0480oooo
0`00000e0?ooo`00K`3oool2000002/0oooo00<000000?ooo`3oool0?`3oool3000003P0oooo001a
0?ooo`800000:@3oool00`000000oooo0?ooo`0l0?ooo`<00000>`3oool007<0oooo0P00000W0?oo
o`030000003oool0oooo03X0oooo0P00000n0?ooo`00M@3oool2000002D0oooo00<000000?ooo`3o
ool0=`3oool300000400oooo001g0?ooo`8000008`3oool00`000000oooo0?ooo`0d0?ooo`<00000
@`3oool007T0oooo0P00000Q0?ooo`030000003oool0oooo0340oooo0`0000160?ooo`00N`3oool2
000001l0oooo00<000000?ooo`3oool0;P3oool3000004T0oooo001m0?ooo`8000007@3oool00`00
0000oooo0?ooo`0[0?ooo`<00000C03oool007l0oooo0P00000K0?ooo`030000003oool0oooo02P0
oooo0`00001?0?ooo`00P@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo02D0oooo
0`00001B0?ooo`00PP3oool2000001P0oooo00<000000?ooo`3oool08P3oool3000005D0oooo0024
0?ooo`8000005P3oool00`000000oooo0?ooo`0O0?ooo`<00000F03oool008H0oooo0P00000D0?oo
o`030000003oool0oooo01`0oooo0`00001K0?ooo`00R03oool200000180oooo00<000000?ooo`3o
ool06@3oool3000005h0oooo002:0?ooo`800000403oool00`000000oooo0?ooo`0F0?ooo`<00000
H@3oool008`0oooo0P00000>0?ooo`030000003oool0oooo01<0oooo0`00001T0?ooo`00SP3oool2
000000`0oooo00<000000?ooo`3oool04@3oool2000006L0oooo002@0?ooo`8000002P3oool00`00
0000oooo0?ooo`0>0?ooo`<00000J@3oool00980oooo0P0000080?ooo`030000003oool0oooo00/0
oooo0`00001/0?ooo`00U03oool2000000H0oooo00<000000?ooo`3oool0203oool3000006l0oooo
002F0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`<00000LP3oool009P0oooo0P000002
0?ooo`030000003oool0oooo0080oooo0`00001e0?ooo`00VP3oool3000000040?ooo`0000000000
000007P0oooo002L0?ooo`800000N`3oool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3o
ool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3o
ool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3oool00?l0oooo6P3o
ool00?l0oooo6P3oool00001\
\>"],
  ImageRangeCache->{{{0, 280.688}, {216.188, 0}} -> {-0.216487, -0.0378841, \
0.00534604, 0.00534604}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[75]="]
}, Open  ]],

Cell[TextData[{
  "The last example shows that ",
  StyleBox["DifferentialEquations`LdeApprox`",
    FontFamily->"Courier New"],
  " package allows one to get polynomials with symbolic coefficients as an \
approximate solution of an LDE. The approximate solution gives uniform \
approximation of some class of functions on an interval. For more examples of \
this kind see ",
  ButtonBox["symbolic examples",
    ButtonData:>{"symbolic.nb", None},
    Active->True,
    ButtonStyle->"Hyperlink"],
  " of the package."
}], "Text"],

Cell["References", "Subsubsection"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[InvisibleSpace]\)\([1]\)\)\)], 
    "InlineFormula"],
  " ",
  StyleBox["Approximation Methods of Differential and Integral Equations \
Solving", "TI"],
  ", V. K. Dzyadyk, Naukova Dumka, Kiev, 1988. (see QA371.D98 1995\n      in \
",
  ButtonBox["http://nvl.nist.gov/pub/new/newbook/1997/9715-nb.htm",
    ButtonData:>{
      URL[ "http://nvl.nist.gov/pub/new/newbook/1997/9715-nb.htm"], None},
    ButtonStyle->"Hyperlink"],
  ")\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[InvisibleSpace]\)\([2]\)\)\)], 
    "InlineFormula"],
  " ",
  StyleBox["On the Theory of Special Functions and its ",
    FontSlant->"Italic"],
  StyleBox["Approximations", "TI"],
  ", V. K. Dzyadyk, Matematichesky Sbornik, 131, No.  4, P. 438 - 464, 1986.\n\
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[InvisibleSpace]\)\([3]\)\)\)], 
    "InlineFormula"],
  " ",
  StyleBox["Approximation Method for Boundary Value Problem Solution", "TI"],
  ", V. K. Dzyadyk and L. A. Ostroveszky, Ukrainsky Matematichesky Zhurnal, \
39, No. 3, P. 378-379, 1987."
}], "Text"]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
ScreenStyleEnvironment->"Working",
WindowToolbars->"LinksBar",
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowElements->{
  "StatusArea", "MemoryMonitor", "MagnificationPopUp", "HorizontalScrollBar", 
    "VerticalScrollBar", "MenuBar"},
CellLabelAutoDelete->False,
GridBoxOptions->{ColumnWidths->Automatic},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 54, 0, 39, "Subsection"],
Cell[1762, 52, 381, 12, 22, "SmallText"],
Cell[2146, 66, 2846, 64, 285, "Text"],
Cell[4995, 132, 98, 2, 25, "Text"],
Cell[5096, 136, 153, 5, 25, "Text"],
Cell[5252, 143, 3083, 73, 58, "DefinitionBox"],
Cell[8338, 218, 116, 3, 17, "Caption"],
Cell[8457, 223, 46, 0, 31, "MathCaption"],
Cell[8506, 225, 93, 2, 29, "Input"],
Cell[8602, 229, 50, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[8677, 233, 94, 2, 29, "Input"],
Cell[8774, 237, 244, 7, 23, "Output"]
}, Open  ]],
Cell[9033, 247, 631, 20, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[9689, 271, 160, 4, 29, "Input"],
Cell[9852, 277, 285, 5, 39, "Output"]
}, Open  ]],
Cell[10152, 285, 210, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[10387, 297, 141, 4, 29, "Input"],
Cell[10531, 303, 195, 4, 36, "Output"]
}, Open  ]],
Cell[10741, 310, 55, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[10821, 314, 148, 3, 29, "Input"],
Cell[10972, 319, 47861, 945, 140, 6064, 424, "GraphicsData", "PostScript", \
"Graphics"],
Cell[58836, 1266, 155, 4, 23, "Output"]
}, Open  ]],
Cell[59006, 1273, 154, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[59185, 1280, 161, 4, 29, "Input"],
Cell[59349, 1286, 1718, 36, 332, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61104, 1327, 148, 3, 29, "Input"],
Cell[61255, 1332, 78786, 1948, 149, 18510, 1199, "GraphicsData", \
"PostScript", "Graphics"],
Cell[140044, 3282, 155, 4, 23, "Output"]
}, Open  ]],
Cell[140214, 3289, 2241, 63, 103, "DefinitionBox"],
Cell[142458, 3354, 58, 0, 17, "Caption"],
Cell[142519, 3356, 2321, 44, 260, "Text"],
Cell[144843, 3402, 698, 18, 81, "Text"],
Cell[145544, 3422, 967, 25, 42, "DefinitionBox"],
Cell[146514, 3449, 102, 4, 17, "Caption"],
Cell[146619, 3455, 264, 10, 25, "Text"],
Cell[146886, 3467, 74, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[146985, 3473, 102, 2, 29, "Input"],
Cell[147090, 3477, 247, 7, 23, "Output"]
}, Open  ]],
Cell[147352, 3487, 744, 19, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[148121, 3510, 173, 4, 29, "Input"],
Cell[148297, 3516, 170, 4, 23, "Message"],
Cell[148470, 3522, 156, 3, 23, "Message"],
Cell[148629, 3527, 1922, 31, 118, "Output"]
}, Open  ]],
Cell[150566, 3561, 101, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[150692, 3567, 91, 2, 29, "Input"],
Cell[150786, 3571, 2061, 37, 118, "Output"]
}, Open  ]],
Cell[152862, 3611, 56, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[152943, 3615, 103, 2, 29, "Input"],
Cell[153049, 3619, 101, 2, 26, "Output"]
}, Open  ]],
Cell[153165, 3624, 73, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[153263, 3628, 91, 2, 29, "Input"],
Cell[153357, 3632, 173, 4, 81, "Output"]
}, Open  ]],
Cell[153545, 3639, 55, 0, 31, "MathCaption"],
Cell[153603, 3641, 40, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[153668, 3645, 173, 3, 29, "Input"],
Cell[153844, 3650, 36520, 783, 138, 5845, 399, "GraphicsData", "PostScript", \
"Graphics"],
Cell[190367, 4435, 155, 4, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[190559, 4444, 149, 3, 29, "Input"],
Cell[190711, 4449, 130, 3, 23, "Output"]
}, Open  ]],
Cell[190856, 4455, 40, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[190921, 4459, 173, 3, 29, "Input"],
Cell[191097, 4464, 43799, 902, 150, 6442, 436, "GraphicsData", "PostScript", \
"Graphics"],
Cell[234899, 5368, 155, 4, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235091, 5377, 149, 3, 29, "Input"],
Cell[235243, 5382, 130, 3, 23, "Output"]
}, Open  ]],
Cell[235388, 5388, 685, 19, 59, "Text"],
Cell[236076, 5409, 1264, 32, 42, "DefinitionBox"],
Cell[237343, 5443, 67, 0, 17, "Caption"],
Cell[237413, 5445, 515, 11, 42, "Text"],
Cell[237931, 5458, 63, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[238019, 5462, 98, 2, 29, "Input"],
Cell[238120, 5466, 236, 7, 23, "Output"]
}, Open  ]],
Cell[238371, 5476, 59, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[238455, 5480, 129, 3, 29, "Input"],
Cell[238587, 5485, 153, 3, 23, "Message"],
Cell[238743, 5490, 67, 2, 23, "Output"]
}, Open  ]],
Cell[238825, 5495, 192, 6, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[239042, 5505, 109, 2, 29, "Input"],
Cell[239154, 5509, 870, 17, 61, "Output"]
}, Open  ]],
Cell[240039, 5529, 56, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[240120, 5533, 132, 4, 29, "Input"],
Cell[240255, 5539, 681, 12, 42, "Output"]
}, Open  ]],
Cell[240951, 5554, 199, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[241175, 5566, 103, 2, 29, "Input"],
Cell[241281, 5570, 172, 4, 49, "Output"]
}, Open  ]],
Cell[241468, 5577, 45, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[241538, 5581, 148, 3, 29, "Input"],
Cell[241689, 5586, 60292, 1126, 146, 6868, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[301984, 6714, 155, 4, 23, "Output"]
}, Open  ]],
Cell[302154, 6721, 117, 3, 25, "Text"],
Cell[302274, 6726, 73, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[302372, 6732, 148, 3, 29, "Input"],
Cell[302523, 6737, 490, 14, 23, "Output"]
}, Open  ]],
Cell[303028, 6754, 209, 6, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[303262, 6764, 103, 2, 29, "Input"],
Cell[303368, 6768, 753, 13, 81, "Output"]
}, Open  ]],
Cell[304136, 6784, 207, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[304368, 6796, 84, 2, 29, "Input"],
Cell[304455, 6800, 100, 2, 48, "Output"]
}, Open  ]],
Cell[304570, 6805, 175, 7, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[304770, 6816, 214, 4, 29, "Input"],
Cell[304987, 6822, 54613, 1136, 146, 8582, 563, "GraphicsData", "PostScript", \
"Graphics"],
Cell[359603, 7960, 155, 4, 23, "Output"]
}, Open  ]],
Cell[359773, 7967, 178, 7, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[359976, 7978, 216, 4, 29, "Input"],
Cell[360195, 7984, 58802, 1211, 144, 9048, 592, "GraphicsData", "PostScript", \
"Graphics"],
Cell[419000, 9197, 155, 4, 23, "Output"]
}, Open  ]],
Cell[419170, 9204, 266, 11, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[419461, 9219, 220, 4, 29, "Input"],
Cell[419684, 9225, 87655, 1595, 199, 20605, 762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[507342, 10822, 162, 4, 23, "Output"]
}, Open  ]],
Cell[507519, 10829, 272, 11, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[507816, 10844, 214, 4, 29, "Input"],
Cell[508033, 10850, 81818, 1568, 187, 21595, 819, "GraphicsData", \
"PostScript", "Graphics"],
Cell[589854, 12420, 162, 4, 23, "Output"]
}, Open  ]],
Cell[590031, 12427, 266, 11, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[590322, 12442, 292, 6, 49, "Input"],
Cell[590617, 12450, 79831, 1585, 181, 22335, 870, "GraphicsData", \
"PostScript", "Graphics"],
Cell[670451, 14037, 162, 4, 23, "Output"]
}, Open  ]],
Cell[670628, 14044, 529, 13, 42, "Text"],
Cell[671160, 14059, 35, 0, 35, "Subsubsection"],
Cell[671198, 14061, 1115, 30, 98, "Text"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

