(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    408582,       9609]*)
(*NotebookOutlinePosition[    409348,       9635]*)
(*  CellTagsIndexPosition[    409304,       9631]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "BVP examples of the ",
  StyleBox["DifferentialEquations`LdeApprox`",
    FontSlant->"Italic"],
  " package"
}], "Subsection",
  CellFrame->False,
  Background->None],

Cell[TextData[{
  StyleBox["Copyright \[Copyright] 2003-2005 ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Graph Tree Ltd",
    ButtonData:>{
      URL[ "http://www.mathshop.digi-area.com/"], None},
    Active->True,
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[". All rights reserved.",
    FontSlant->"Italic"]
}], "SmallText",
  TextAlignment->Right],

Cell[TextData[{
  "This notebook illustrates ",
  StyleBox["DifferentialEquations`LdeApprox`",
    FontFamily->"Courier New"],
  " package capability of working with BVPs. "
}], "Text",
  Background->None],

Cell["This loads the package.", "MathCaption",
  Background->None],

Cell[BoxData[
    \(<< DifferentialEquations`LdeApprox`\)], "Input",
  CellLabel->"In[1]:=",
  Background->None],

Cell[TextData[StyleBox["Example 1",
  CellFrame->False,
  Background->None]], "Subsubsection",
  Background->None],

Cell["Boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''\)[x] - y[x] \[Equal] \(-2\)*x, y[0] \[Equal] \(y'\)[0], 
        y[a] + \(y'\)[a] \[Equal] 0}\)], "Input",
  CellLabel->"In[2]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(-y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], 
          "==", \(\(-2\)\ x\)}], ",", 
        RowBox[{\(y[0]\), "==", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}]}], ",", 
        RowBox[{
          RowBox[{\(y[a]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "a", "]"}]}], "==", "0"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[2]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, a}, 3]\)], "Input",
  CellLabel->"In[3]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(32\ a\^2\ \((2949120 + 983040\ a + 138240\ a\^2 + \
15040\ a\^3 + 2464\ a\^4 + 350\ a\^5 + 15\ a\^6)\)\)\/\(\((3072 + 1536\ a + \
320\ a\^2 + 32\ a\^3 + a\^4)\)\ \((61440 + 30720\ a + 6720\ a\^2 + 800\ a\^3 \
+ 50\ a\^4 + a\^5)\)\) + \(2\ a\^2\ \((47185920 + 15728640\ a + 1382400\ a\^2 \
- 124928\ a\^3 - 25984\ a\^4 + 128\ a\^5 + 82\ a\^6 + a\^7)\)\ x\)\/\(\((3072 \
+ 1536\ a + 320\ a\^2 + 32\ a\^3 + a\^4)\)\ \((61440 + 30720\ a + 6720\ a\^2 \
+ 800\ a\^3 + 50\ a\^4 + a\^5)\)\) + \(1536\ a\^2\ \((30720 + 15040\ a + 3040\
\ a\^2 + 290\ a\^3 + 9\ a\^4)\)\ x\^2\)\/\(\((3072 + 1536\ a + 320\ a\^2 + 32\
\ a\^3 + a\^4)\)\ \((61440 + 30720\ a + 6720\ a\^2 + 800\ a\^3 + 50\ a\^4 + a\
\^5)\)\) - \(10240\ \((2 + a)\)\ x\^3\)\/\(61440 + 30720\ a + 6720\ a\^2 + \
800\ a\^3 + 50\ a\^4 + a\^5\)}}\)], "Output",
  CellLabel->"Out[3]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[4]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\[ExponentialE]\^\(\(-a\) - x\)\)\ \((\(-\
\[ExponentialE]\^a\) + \[ExponentialE]\^\(2\ x\) + 
                a\ \[ExponentialE]\^\(2\ x\) - 
                2\ \[ExponentialE]\^\(a + x\)\ x)\)}}\)], "Output",
  CellLabel->"Out[4]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(a = 1\/3\)]],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr)\))\) /. 
        a \[Rule] 1/3, {x, 0, 1/3}]\)], "Input",
  CellLabel->"In[5]:=",
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 2.85714 0.315621 235046 [
[.16667 .30312 -12 -9 ]
[.16667 .30312 12 0 ]
[.30952 .30312 -9 -9 ]
[.30952 .30312 9 0 ]
[.45238 .30312 -12 -9 ]
[.45238 .30312 12 0 ]
[.59524 .30312 -9 -9 ]
[.59524 .30312 9 0 ]
[.7381 .30312 -12 -9 ]
[.7381 .30312 12 0 ]
[.88095 .30312 -9 -9 ]
[.88095 .30312 9 0 ]
[.01131 .08058 -39 -6.25 ]
[.01131 .08058 0 6.25 ]
[.01131 .1981 -39 -6.25 ]
[.01131 .1981 0 6.25 ]
[.01131 .43314 -33 -6.25 ]
[.01131 .43314 0 6.25 ]
[.01131 .55067 -33 -6.25 ]
[.01131 .55067 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .31562 m
.16667 .32187 L
s
[(0.05)] .16667 .30312 0 1 Mshowa
.30952 .31562 m
.30952 .32187 L
s
[(0.1)] .30952 .30312 0 1 Mshowa
.45238 .31562 m
.45238 .32187 L
s
[(0.15)] .45238 .30312 0 1 Mshowa
.59524 .31562 m
.59524 .32187 L
s
[(0.2)] .59524 .30312 0 1 Mshowa
.7381 .31562 m
.7381 .32187 L
s
[(0.25)] .7381 .30312 0 1 Mshowa
.88095 .31562 m
.88095 .32187 L
s
[(0.3)] .88095 .30312 0 1 Mshowa
.125 Mabswid
.05238 .31562 m
.05238 .31937 L
s
.08095 .31562 m
.08095 .31937 L
s
.10952 .31562 m
.10952 .31937 L
s
.1381 .31562 m
.1381 .31937 L
s
.19524 .31562 m
.19524 .31937 L
s
.22381 .31562 m
.22381 .31937 L
s
.25238 .31562 m
.25238 .31937 L
s
.28095 .31562 m
.28095 .31937 L
s
.3381 .31562 m
.3381 .31937 L
s
.36667 .31562 m
.36667 .31937 L
s
.39524 .31562 m
.39524 .31937 L
s
.42381 .31562 m
.42381 .31937 L
s
.48095 .31562 m
.48095 .31937 L
s
.50952 .31562 m
.50952 .31937 L
s
.5381 .31562 m
.5381 .31937 L
s
.56667 .31562 m
.56667 .31937 L
s
.62381 .31562 m
.62381 .31937 L
s
.65238 .31562 m
.65238 .31937 L
s
.68095 .31562 m
.68095 .31937 L
s
.70952 .31562 m
.70952 .31937 L
s
.76667 .31562 m
.76667 .31937 L
s
.79524 .31562 m
.79524 .31937 L
s
.82381 .31562 m
.82381 .31937 L
s
.85238 .31562 m
.85238 .31937 L
s
.90952 .31562 m
.90952 .31937 L
s
.9381 .31562 m
.9381 .31937 L
s
.96667 .31562 m
.96667 .31937 L
s
.99524 .31562 m
.99524 .31937 L
s
.25 Mabswid
0 .31562 m
1 .31562 L
s
.02381 .08058 m
.03006 .08058 L
s
gsave
.01131 .08058 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .1981 m
.03006 .1981 L
s
gsave
.01131 .1981 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .43314 m
.03006 .43314 L
s
gsave
.01131 .43314 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .55067 m
.03006 .55067 L
s
gsave
.01131 .55067 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.02381 .10408 m
.02756 .10408 L
s
.02381 .12758 m
.02756 .12758 L
s
.02381 .15109 m
.02756 .15109 L
s
.02381 .17459 m
.02756 .17459 L
s
.02381 .2216 m
.02756 .2216 L
s
.02381 .24511 m
.02756 .24511 L
s
.02381 .26861 m
.02756 .26861 L
s
.02381 .29212 m
.02756 .29212 L
s
.02381 .33913 m
.02756 .33913 L
s
.02381 .36263 m
.02756 .36263 L
s
.02381 .38614 m
.02756 .38614 L
s
.02381 .40964 m
.02756 .40964 L
s
.02381 .45665 m
.02756 .45665 L
s
.02381 .48015 m
.02756 .48015 L
s
.02381 .50366 m
.02756 .50366 L
s
.02381 .52716 m
.02756 .52716 L
s
.02381 .05707 m
.02756 .05707 L
s
.02381 .03357 m
.02756 .03357 L
s
.02381 .01006 m
.02756 .01006 L
s
.02381 .57417 m
.02756 .57417 L
s
.02381 .59768 m
.02756 .59768 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07708 m
.04262 .20357 L
.06244 .31306 L
.08255 .40095 L
.09409 .44158 L
.10458 .47274 L
.12415 .51706 L
.13491 .53431 L
.13976 .54052 L
.14509 .54629 L
.14976 .55047 L
.15478 .55405 L
.15756 .55564 L
.16009 .55686 L
.16267 .55787 L
.16506 .55861 L
.16725 .55912 L
.16847 .55933 L
.16958 .55948 L
.1708 .55961 L
.17212 .55968 L
.17337 .55971 L
.17452 .55968 L
.17559 .55963 L
.1766 .55954 L
.1777 .55941 L
.17889 .55923 L
.1813 .55872 L
.1835 .55812 L
.18831 .5563 L
.19342 .55367 L
.20259 .54719 L
.21246 .53789 L
.22335 .52508 L
.26355 .45913 L
.30224 .37739 L
.34338 .28346 L
.383 .19713 L
.42111 .12663 L
.44236 .09521 L
.46167 .0726 L
.47131 .06363 L
.48176 .05572 L
.48655 .05275 L
.49162 .05007 L
.49629 .04801 L
.50072 .04644 L
.50308 .04575 L
.50565 .04513 L
.50801 .04466 L
Mistroke
.51015 .04433 L
.51138 .04418 L
.5127 .04405 L
.51343 .04399 L
.5141 .04395 L
.51541 .04389 L
.51655 .04386 L
.51779 .04386 L
.51908 .0439 L
.52029 .04396 L
.52143 .04404 L
.52267 .04415 L
.52492 .04444 L
.52711 .04482 L
.52914 .04525 L
.53373 .04652 L
.5386 .04832 L
.548 .05308 L
.55811 .0601 L
.57641 .07774 L
.59649 .10415 L
.6176 .13934 L
.65576 .21954 L
.69637 .32135 L
.73547 .42441 L
.75542 .47441 L
.77702 .52323 L
.7961 .55927 L
.80693 .57582 L
.81705 .58819 L
.82199 .593 L
.82666 .59678 L
.82924 .59851 L
.83205 .60012 L
.83459 .60129 L
.83697 .60216 L
.83828 .60254 L
.83949 .60282 L
.84082 .60307 L
.84153 .60316 L
.84227 .60324 L
.84294 .60329 L
.84366 .60332 L
.84496 .60332 L
.84575 .60328 L
.8465 .60321 L
.84717 .60313 L
.8479 .60302 L
.84912 .60279 L
.85046 .60245 L
Mistroke
.85317 .60149 L
.85568 .60029 L
.85803 .59887 L
.86299 .59494 L
.86842 .58913 L
.87829 .57424 L
.8879 .55399 L
.89682 .52972 L
.9074 .49353 L
.91736 .45157 L
.93597 .35057 L
.95606 .2046 L
.97454 .03209 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{223.188, 137.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003O0000RB000`400?l00000o`00003og`3oool0
0=l0oooo003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3o
ool00=l0oooo000Y0?ooo`030000003oool0oooo0;<0oooo000Y0?ooo`030000003oool0oooo0;<0
oooo000Y0?ooo`800000]03oool002T0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`030?ooo`00:@3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo00<0oooo000Y0?oo
o`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00`3oool002T0oooo0P00002^0?ooo`03
0000003oool0oooo00<0oooo000Y0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0
0`3oool002T0oooo00<000000?ooo`3oool0E@3oool700000540oooo00<000000?ooo`3oool00`3o
ool002T0oooo00<000000?ooo`3oool0D`3oool2000000L0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`030?ooo`00:@3oool2000005<0oooo0P0000090?ooo`800000CP3oool00`00
0000oooo0?ooo`030?ooo`001`3oool5000000030?ooo`000000oooo0080oooo00<000000?ooo`00
0000100000020?ooo`8000003@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo00/0
oooo0P00001<0?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`040?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0CP3oool200000180oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`040?ooo`0000<0oooo0000000000000P0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`040?ooo`002@3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000`0oooo0P00001=
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`04
0?ooo`00203oool2000000X0oooo0P0000040?ooo`8000003@3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`040?oo
o`00903oool00`30`<00/;2`092@T0020?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00@0oooo000T0?ooo`030:2P
X03oool0`<300080oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0103oool001h0oooo00@0h>3P0820P020P800P820
0P3oool00`1PH600T92@0:2PX0020?ooo`800000BP3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool0103oool002@0oooo00<0X:2P0?ooo`3oool00P3o
ool2000004T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00@0oooo000U0?ooo`040:2PX02`/;00oooo0?ooo`800000B03oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0103oool002T0oooo0P000018
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`05
0?ooo`00:@3oool2000004L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo00D0oooo000Y0?ooo`800000AP3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool01@3oool002T0oooo0P0000160?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`050?ooo`00:@3o
ool2000004D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo00D0oooo000Y0?ooo`030000003oool0000004@0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00D0oooo000Y0?ooo`<00000@`3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool01@3oool002T0
oooo00<000000?ooo`000000@`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool01@3oool002T0oooo00<000000?ooo`000000@P3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool01@3oool002T0oooo00<0
00000?ooo`000000@P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool01@3oool002T0oooo0`0000110?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`050?ooo`00203oool2000000<0oooo00H000000?oo
o`3oool0oooo0000003oool500000080oooo0P00000=0?ooo`030000003oool000000440oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00H0oooo0007
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo000000100?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`060?ooo`002P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000?`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01P3oool000030?oo
o`0000000000008000000`3oool2000000@0oooo00<000000?ooo`000000103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000n0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`060?oo
o`00203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000000030?ooo`000000
oooo03d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00H0oooo00080?ooo`<000002@3oool2000000@0oooo0P00000=0?ooo`040000003oool0oooo
000003d0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00H0oooo000U0?ooo`050;2`/03oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`06
0?ooo`009@3oool01@2`/;00oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01P3oool0
01h0oooo00@0h>3P0820P020P800P8200`3oool0103Ph>00`<300?ooo`3oool200000080oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool01P3oool002H0oooo00@0X:2P0?ooo`3oool000000`3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`070?ooo`008`3oool01030`<00L71`0820P020P8020?ooo`050000003oool0oooo0?ooo`000000
>P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
1`3oool002T0oooo00D000000?ooo`3oool0oooo0000000i0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`070?ooo`00:@3oool200000080oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool01`3oool002T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`07
0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00L0oooo000Y0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0203oool2000000@0oooo0P0000040?ooo`80
0000103oool2000000X0oooo0P0000040?ooo`8000000`3oool5000000L0oooo0P0000040?ooo`80
00000`3oool500000080oooo0P00000:0?ooo`800000103oool2000000<0oooo100000060?ooo`04
0000003oool00000000000@0oooo0P0000030?ooo`@000000`3oool2000000X0oooo0P0000040?oo
o`800000103oool2000000H0oooo00<000000?ooo`3oool01`3oool002T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000X0oooo
0P0000070?ooo`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`07
0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0203oool002T0oooo0P0000030?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool000002P3oool2000000L0oooo00@000000?ooo`3oool000002P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000003
0?ooo`8000002@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00H0oooo00@0
00000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`8000002@3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`020?ooo`8000002@3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0203oool002T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
00P0oooo000Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000X0
oooo0P0000040?ooo`<000002@3oool2000000X0oooo0P0000090?ooo`8000002P3oool2000000@0
oooo0`0000090?ooo`8000002P3oool2000000T0oooo0P00000:0?ooo`800000103oool3000000T0
oooo0P00000:0?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`00:@3oool2000000@0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0203oool002T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`090?ooo`00:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000Y0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool002@0oooo^`00000002T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool01P000000oooo0?ooo`000000oooo000000@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`020?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`4000000@3oool002T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`00
:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000Y0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02P3oool002T0oooo0P0000060?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00X0oooo000Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02P3oool002T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0:0?ooo`00:@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00X0oooo000Y0?ooo`8000001`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0:0?ooo`00:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo000Y0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool002T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0;0?ooo`00:@3oool2000000P0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
2`3oool002T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0<0?ooo`00:@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00`0oooo000Y0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0303oool002T0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0<0?ooo`00:@3oool2000000T0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0303oool000P0oooo0P00
00030?ooo`060000003oool0oooo0?ooo`000000oooo1@0000020?ooo`8000003@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo00070?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo000:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
00d0oooo00080?ooo`800000103oool00`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`8000002P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0=0?oo
o`00203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00h0oooo00080?ooo`<000002@3oool2000000@0oooo0P0000090?oo
o`050;2`/03oool0oooo0?ooo`000000303oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0>0?ooo`009@3oool01@2`
/;00oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool001h0oooo00@0h>3P0820
P020P800P8200`3oool0103Ph>00`<300?ooo`3oool2000000`0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03P3o
ool002H0oooo00@0X:2P0?ooo`3oool000003@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`008`3oool0
1030`<00L71`0820P020P8020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03P3o
ool002T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0?0?ooo`00:@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00l0oooo000Y0?ooo`8000003P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0?0?ooo`00:@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo
000Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1M0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03`3oool002T0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`00:@3oool2000000l0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0403oool002T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`00
:@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo000Y0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1R0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0403oool002T0oooo0P00000A0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0140oooo000Y0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool04@3oool000L0
oooo1@0000000`3oool000000?ooo`020?ooo`030000003oool0000000@000000P3oool2000000d0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0B0?ooo`002@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo06P0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0B0?ooo`00
2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0C0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00000E0?ooo`80
00001P3oool2000006d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`00
2@3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo000000`0oooo00<000000?ooo`3oool05P3oool600000700oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`00203oool2000000X0oooo0P0000040?oo
o`800000203oool00`30`<00/;2`092@T0020?ooo`030000003oool0oooo01P0oooo0P00001c0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0503oool002@0oooo00<0X:2P0?ooo`30
`<000P3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool05@3oool001h0oooo00@0h>3P0820P020P800P8200P3oool00`1PH600T92@0:2PX0020?ooo`80
0000S`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo000T0?ooo`030:2P
X03oool0oooo0080oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo01H0oooo000U0?ooo`050:2PX02`/;00oooo0?ooo`000000T@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`00:@3oool00`000000oooo0?ooo`2A
0?ooo`8000001@3oool00`000000oooo0?ooo`0H0?ooo`00:@3oool2000009<0oooo0`0000000`3o
ool000000000000K0?ooo`00:@3oool00`000000oooo0?ooo`2D0?ooo`<00000703oool002T0oooo
00<000000?ooo`3oool0/`3oool002T0oooo00<000000?ooo`3oool0/`3oool00=l0oooo003O0?oo
o`00g`3oool00=l0oooo003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3oool00=l0oooo003O
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 222.188}, {136.875, 0}} -> {-0.0780484, \
-1.59959*^-06, 0.00188902, 2.29623*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["Example 2", "Subsubsection",
  Background->None],

Cell["Boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''\)[x] + y[x] \[Equal] a*x^2, y[0] \[Equal] 0, 
        y[Pi/2] \[Equal] 0}\)], "Input",
  CellLabel->"In[6]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], 
          "==", \(a\ x\^2\)}], ",", \(y[0] == 0\), 
        ",", \(y[\[Pi]\/2] == 0\)}], "}"}]], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, Pi/2}, 4]\)], "Input",
  CellLabel->"In[7]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(2\ a\ \[Pi]\^6\ \((5406720 - 131968\ \[Pi]\^2 + 219\ \
\[Pi]\^4)\)\)\/\(\((491520 - 3200\ \[Pi]\^2 + \[Pi]\^4)\)\ \((\(-94371840\) + \
2654208\ \[Pi]\^2 - 6720\ \[Pi]\^4 + \[Pi]\^6)\)\) - \(192\ a\ \[Pi]\^3\ \
\((\(-2516582400\) + 8683520\ \[Pi]\^2 - 139072\ \[Pi]\^4 + 77\ \[Pi]\^6)\)\ \
x\)\/\(\((491520 - 3200\ \[Pi]\^2 + \[Pi]\^4)\)\ \((\(-94371840\) + 2654208\ \
\[Pi]\^2 - 6720\ \[Pi]\^4 + \[Pi]\^6)\)\) + \(a\ \[Pi]\^4\ \((15571353600 - \
308305920\ \[Pi]\^2 + 125248\ \[Pi]\^4 + \[Pi]\^6)\)\ x\^2\)\/\(\((491520 - \
3200\ \[Pi]\^2 + \[Pi]\^4)\)\ \((\(-94371840\) + 2654208\ \[Pi]\^2 - 6720\ \
\[Pi]\^4 + \[Pi]\^6)\)\) + 
            40960\ a\ \[Pi]\ \((1\/\(491520 - 3200\ \[Pi]\^2 + \[Pi]\^4\) - \
\(12\ \((\(-16\) + \[Pi]\^2)\)\)\/\(\(-94371840\) + 2654208\ \[Pi]\^2 - 6720\ \
\[Pi]\^4 + \[Pi]\^6\))\)\ x\^3 + \(491520\ a\ \((\(-16\) + \[Pi]\^2)\)\ \
x\^4\)\/\(\(-94371840\) + 2654208\ \[Pi]\^2 - 6720\ \[Pi]\^4 + \
\[Pi]\^6\)}}\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[8]:=",
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 
          1\/4\ \((\(-8\)\ a + 4\ a\ x\^2 + 8\ a\ Cos[x] + 8\ a\ Sin[x] - 
                a\ \[Pi]\^2\ Sin[x])\)}}\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
              apr[\([1]\)])\))\), {x, 0, Pi/2}, {a, 0, 1}]\)], "Input",
  CellLabel->"In[9]:=",
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1984e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.2187 .17096 -17.442 -9 ]
[.2187 .17096 .55804 0 ]
[.42503 .08982 -5.4158 -9 ]
[.42503 .08982 .5842 0 ]
[.64842 .00203 -15.0528 -9 ]
[.64842 .00203 2.94718 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 18 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 24 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.01963 .29321 -42 -2.76606 ]
[.01963 .29321 0 6.23394 ]
[.00672 .37412 -6 -2.83465 ]
[.00672 .37412 0 6.16535 ]
[-0.00688 .45935 -36 -2.90729 ]
[-0.00688 .45935 0 6.09271 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.22768 .18054 m
.23217 .18532 L
s
[(0.5)] .2187 .17096 .938 1 Mshowa
.43326 .10004 m
.43737 .10515 L
s
[(1)] .42503 .08982 .80527 1 Mshowa
.65575 .01292 m
.65941 .01836 L
s
[(1.5)] .64842 .00203 .67254 1 Mshowa
.125 Mabswid
.07414 .24066 m
.07698 .24338 L
s
.11167 .22596 m
.11448 .22872 L
s
.14976 .21105 m
.15253 .21384 L
s
.18843 .19591 m
.19116 .19874 L
s
.26753 .16493 m
.27019 .16784 L
s
.30801 .14908 m
.31061 .15203 L
s
.34911 .13299 m
.35167 .13598 L
s
.39085 .11664 m
.39337 .11967 L
s
.47634 .08317 m
.47875 .08628 L
s
.52011 .06603 m
.52247 .06918 L
s
.56459 .04861 m
.5669 .0518 L
s
.60979 .03091 m
.61205 .03414 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(0.25)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0.5)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.75)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03187 .28849 m
.038 .28613 L
s
[(-0.0002)] .01963 .29321 1 -0.38532 Mshowa
.01903 .36956 m
.02518 .36728 L
s
[(0)] .00672 .37412 1 -0.37008 Mshowa
.00549 .45497 m
.01168 .45278 L
s
[(0.0002)] -0.00688 .45935 1 -0.35394 Mshowa
.125 Mabswid
.02872 .30837 m
.0324 .30697 L
s
.02553 .32851 m
.02922 .32711 L
s
.0223 .3489 m
.02599 .34752 L
s
.01571 .39049 m
.01941 .38914 L
s
.01235 .4117 m
.01605 .41036 L
s
.00894 .43319 m
.01265 .43186 L
s
.03498 .26886 m
.03865 .26744 L
s
.00199 .47704 m
.00571 .47574 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.907 .713 .629 r
.37519 .77391 .39826 .80009 .4415 .60868 .41953 .59392 Metetra
.441 .731 .988 r
.41953 .59392 .4415 .60868 .47878 .60991 .45714 .59411 Metetra
.844 .38 .025 r
.45714 .59411 .47878 .60991 .51669 .6785 .49501 .65735 Metetra
.743 .255 0 r
.49501 .65735 .51669 .6785 .5569 .7403 .53512 .71404 Metetra
.359 .579 .925 r
.53512 .71404 .5569 .7403 .59835 .75314 .57674 .72495 Metetra
.805 .739 .791 r
.57674 .72495 .59835 .75314 .63915 .70915 .61812 .68283 Metetra
.88 .754 .72 r
.61812 .68283 .63915 .70915 .67821 .62956 .6581 .6074 Metetra
.898 .777 .719 r
.6581 .6074 .67821 .62956 .71618 .54903 .6971 .53093 Metetra
.862 .818 .805 r
.6971 .53093 .71618 .54903 .75524 .49999 .73698 .48385 Metetra
.411 .708 .984 r
.73698 .48385 .75524 .49999 .7983 .50346 .7804 .48601 Metetra
.569 .067 0 r
.7804 .48601 .7983 .50346 .84763 .56179 .82953 .53954 Metetra
.633 .169 0 r
.82953 .53954 .84763 .56179 .90204 .64317 .88337 .61439 Metetra
.442 .607 .917 r
.88337 .61439 .90204 .64317 .95102 .65344 .93253 .62273 Metetra
.973 .747 .537 r
.93253 .62273 .95102 .65344 .97003 .43424 .95459 .41651 Metetra
.905 .714 .635 r
.35159 .74711 .37519 .77391 .41953 .59392 .39691 .57872 Metetra
.462 .74 .988 r
.39691 .57872 .41953 .59392 .45714 .59411 .43487 .57785 Metetra
.817 .337 0 r
.43487 .57785 .45714 .59411 .49501 .65735 .47274 .63564 Metetra
.689 .191 0 r
.47274 .63564 .49501 .65735 .53512 .71404 .51281 .68714 Metetra
.391 .595 .927 r
.51281 .68714 .53512 .71404 .57674 .72495 .55462 .69609 Metetra
.798 .738 .797 r
.55462 .69609 .57674 .72495 .61812 .68283 .59656 .65586 Metetra
.873 .755 .729 r
.59656 .65586 .61812 .68283 .6581 .6074 .63744 .58463 Metetra
.892 .779 .73 r
.63744 .58463 .6581 .6074 .6971 .53093 .67743 .51227 Metetra
.854 .819 .814 r
.67743 .51227 .6971 .53093 .73698 .48385 .71813 .4672 Metetra
.434 .72 .985 r
.71813 .4672 .73698 .48385 .7804 .48601 .76194 .46802 Metetra
.507 .002 0 r
.76194 .46802 .7804 .48601 .82953 .53954 .8109 .51664 Metetra
.577 .112 0 r
.8109 .51664 .82953 .53954 .88337 .61439 .86422 .58486 Metetra
.461 .618 .917 r
.86422 .58486 .88337 .61439 .93253 .62273 .91356 .59125 Metetra
.97 .75 .549 r
.91356 .59125 .93253 .62273 .95459 .41651 .93865 .3982 Metetra
.902 .716 .642 r
.32744 .71969 .35159 .74711 .39691 .57872 .37361 .56307 Metetra
.483 .749 .988 r
.37361 .56307 .39691 .57872 .43487 .57785 .41193 .56111 Metetra
.781 .283 0 r
.41193 .56111 .43487 .57785 .47274 .63564 .44986 .61334 Metetra
.618 .114 0 r
.44986 .61334 .47274 .63564 .51281 .68714 .48994 .65958 Metetra
.421 .611 .928 r
.48994 .65958 .51281 .68714 .55462 .69609 .53197 .66653 Metetra
.79 .737 .803 r
.53197 .66653 .55462 .69609 .59656 .65586 .57446 .6282 Metetra
.866 .756 .739 r
.57446 .6282 .59656 .65586 .63744 .58463 .6162 .56122 Metetra
.885 .78 .741 r
.6162 .56122 .63744 .58463 .67743 .51227 .65716 .49304 Metetra
.845 .82 .824 r
.65716 .49304 .67743 .51227 .71813 .4672 .69868 .45 Metetra
.457 .731 .986 r
.69868 .45 .71813 .4672 .76194 .46802 .74289 .44945 Metetra
0 .07 .565 r
.74289 .44945 .76194 .46802 .8109 .51664 .79171 .49306 Metetra
0 0 .486 r
.79171 .49306 .8109 .51664 .86422 .58486 .84455 .55455 Metetra
.481 .628 .917 r
.84455 .55455 .86422 .58486 .91356 .59125 .8941 .55895 Metetra
.967 .753 .562 r
.8941 .55895 .91356 .59125 .93865 .3982 .92216 .37927 Metetra
.898 .718 .65 r
.30271 .69162 .32744 .71969 .37361 .56307 .3496 .54694 Metetra
.503 .757 .987 r
.3496 .54694 .37361 .56307 .41193 .56111 .3883 .54386 Metetra
.73 .215 0 r
.3883 .54386 .41193 .56111 .44986 .61334 .42636 .59042 Metetra
.527 .022 0 r
.42636 .59042 .44986 .61334 .48994 .65958 .46651 .63132 Metetra
.449 .624 .927 r
.46651 .63132 .48994 .65958 .53197 .66653 .50876 .63625 Metetra
.782 .735 .81 r
.50876 .63625 .53197 .66653 .57446 .6282 .55179 .59983 Metetra
.858 .756 .75 r
.55179 .59983 .57446 .6282 .6162 .56122 .59434 .53714 Metetra
.877 .782 .753 r
.59434 .53714 .6162 .56122 .65716 .49304 .63625 .4732 Metetra
.836 .821 .834 r
.63625 .4732 .65716 .49304 .69868 .45 .67858 .43224 Metetra
.478 .742 .986 r
.67858 .43224 .69868 .45 .74289 .44945 .72322 .43027 Metetra
0 .15 .639 r
.72322 .43027 .74289 .44945 .79171 .49306 .77195 .46877 Metetra
0 .031 .561 r
.77195 .46877 .79171 .49306 .84455 .55455 .82436 .52342 Metetra
.499 .638 .916 r
.82436 .52342 .84455 .55455 .8941 .55895 .87413 .5258 Metetra
.963 .757 .578 r
.87413 .5258 .8941 .55895 .92216 .37927 .9051 .35968 Metetra
.894 .72 .659 r
.2774 .66288 .30271 .69162 .3496 .54694 .32485 .5303 Metetra
.522 .764 .985 r
.32485 .5303 .3496 .54694 .3883 .54386 .36395 .52608 Metetra
.66 .128 0 r
.36395 .52608 .3883 .54386 .42636 .59042 .4022 .56687 Metetra
0 .084 .581 r
.4022 .56687 .42636 .59042 .46651 .63132 .44248 .60235 Metetra
.476 .637 .926 r
.44248 .60235 .46651 .63132 .50876 .63625 .48498 .60522 Metetra
.773 .733 .816 r
.48498 .60522 .50876 .63625 .55179 .59983 .52852 .57071 Metetra
.848 .756 .761 r
.52852 .57071 .55179 .59983 .59434 .53714 .57186 .51236 Metetra
.867 .783 .766 r
.57186 .51236 .59434 .53714 .63625 .4732 .61468 .45274 Metetra
.825 .821 .845 r
.61468 .45274 .63625 .4732 .67858 .43224 .6578 .41388 Metetra
.499 .752 .985 r
.6578 .41388 .67858 .43224 .72322 .43027 .7029 .41045 Metetra
0 .236 .714 r
.7029 .41045 .72322 .43027 .77195 .46877 .75157 .44373 Metetra
0 .116 .64 r
.75157 .44373 .77195 .46877 .82436 .52342 .80362 .49144 Metetra
.517 .647 .915 r
.80362 .49144 .82436 .52342 .87413 .5258 .85363 .49177 Metetra
.958 .761 .595 r
.85363 .49177 .87413 .5258 .9051 .35968 .88745 .33941 Metetra
.888 .722 .669 r
.25147 .63345 .2774 .66288 .32485 .5303 .29932 .51315 Metetra
.54 .77 .983 r
.29932 .51315 .32485 .5303 .36395 .52608 .33883 .50774 Metetra
.562 .019 0 r
.33883 .50774 .36395 .52608 .4022 .56687 .37735 .54265 Metetra
0 .2 .69 r
.37735 .54265 .4022 .56687 .44248 .60235 .41784 .57264 Metetra
.501 .649 .924 r
.41784 .57264 .44248 .60235 .48498 .60522 .46061 .57342 Metetra
.763 .731 .823 r
.46061 .57342 .48498 .60522 .52852 .57071 .50464 .54083 Metetra
.837 .756 .773 r
.50464 .54083 .52852 .57071 .57186 .51236 .54872 .48686 Metetra
.857 .784 .78 r
.54872 .48686 .57186 .51236 .61468 .45274 .59241 .43161 Metetra
.813 .82 .856 r
.59241 .43161 .61468 .45274 .6578 .41388 .63632 .39489 Metetra
.519 .761 .984 r
.63632 .39489 .6578 .41388 .7029 .41045 .68189 .38997 Metetra
0 .326 .786 r
.68189 .38997 .7029 .41045 .75157 .44373 .73057 .41791 Metetra
0 .209 .718 r
.73057 .41791 .75157 .44373 .80362 .49144 .7823 .45858 Metetra
.535 .656 .914 r
.7823 .45858 .80362 .49144 .85363 .49177 .83258 .45682 Metetra
.952 .765 .614 r
.83258 .45682 .85363 .49177 .88745 .33941 .86918 .31842 Metetra
.882 .724 .681 r
.22491 .60329 .25147 .63345 .29932 .51315 .27297 .49545 Metetra
.557 .776 .98 r
.27297 .49545 .29932 .51315 .33883 .50774 .31291 .48883 Metetra
.43 0 0 r
.31291 .48883 .33883 .50774 .37735 .54265 .3518 .51773 Metetra
0 .319 .789 r
.3518 .51773 .37735 .54265 .41784 .57264 .39255 .54216 Metetra
.524 .659 .921 r
.39255 .54216 .41784 .57264 .46061 .57342 .43562 .54082 Metetra
.753 .729 .83 r
.43562 .54082 .46061 .57342 .50464 .54083 .48012 .51015 Metetra
.825 .755 .786 r
.48012 .51015 .50464 .54083 .54872 .48686 .52489 .4606 Metetra
.844 .785 .794 r
.52489 .4606 .54872 .48686 .59241 .43161 .5694 .40979 Metetra
.8 .82 .867 r
.5694 .40979 .59241 .43161 .63632 .39489 .61409 .37525 Metetra
.539 .769 .983 r
.61409 .37525 .63632 .39489 .68189 .38997 .66016 .36879 Metetra
0 .416 .85 r
.66016 .36879 .68189 .38997 .73057 .41791 .7089 .39128 Metetra
0 .307 .792 r
.7089 .39128 .73057 .41791 .7823 .45858 .76039 .4248 Metetra
.551 .664 .912 r
.76039 .4248 .7823 .45858 .83258 .45682 .81096 .42092 Metetra
.943 .768 .636 r
.81096 .42092 .83258 .45682 .86918 .31842 .85023 .29667 Metetra
.873 .726 .696 r
.19768 .57239 .22491 .60329 .27297 .49545 .24576 .47717 Metetra
.573 .781 .977 r
.24576 .47717 .27297 .49545 .31291 .48883 .28617 .4693 Metetra
0 .266 .704 r
.28617 .4693 .31291 .48883 .3518 .51773 .3255 .49209 Metetra
.033 .431 .868 r
.3255 .49209 .3518 .51773 .39255 .54216 .3666 .51087 Metetra
.546 .669 .917 r
.3666 .51087 .39255 .54216 .43562 .54082 .41 .50738 Metetra
.742 .726 .837 r
.41 .50738 .43562 .54082 .48012 .51015 .45493 .47863 Metetra
.811 .754 .8 r
.45493 .47863 .48012 .51015 .52489 .4606 .50033 .43354 Metetra
.829 .785 .81 r
.50033 .43354 .52489 .4606 .5694 .40979 .54563 .38723 Metetra
.785 .818 .878 r
.54563 .38723 .5694 .40979 .61409 .37525 .59108 .35491 Metetra
.557 .777 .981 r
.59108 .35491 .61409 .37525 .66016 .36879 .63767 .34686 Metetra
.099 .503 .904 r
.63767 .34686 .66016 .36879 .7089 .39128 .68654 .3638 Metetra
.031 .403 .856 r
.68654 .3638 .7089 .39128 .76039 .4248 .73786 .39006 Metetra
.568 .672 .909 r
.73786 .39006 .76039 .4248 .81096 .42092 .78873 .38403 Metetra
.931 .771 .662 r
.78873 .38403 .81096 .42092 .85023 .29667 .8306 .27412 Metetra
.862 .728 .714 r
.16978 .54071 .19768 .57239 .24576 .47717 .21766 .45829 Metetra
.588 .786 .974 r
.21766 .45829 .24576 .47717 .28617 .4693 .25854 .44913 Metetra
0 .42 .833 r
.25854 .44913 .28617 .4693 .3255 .49209 .29842 .4657 Metetra
.184 .527 .921 r
.29842 .4657 .3255 .49209 .3666 .51087 .33995 .47874 Metetra
.567 .677 .914 r
.33995 .47874 .3666 .51087 .41 .50738 .38371 .47308 Metetra
.729 .723 .844 r
.38371 .47308 .41 .50738 .45493 .47863 .42905 .44624 Metetra
.794 .751 .814 r
.42905 .44624 .45493 .47863 .50033 .43354 .47503 .40565 Metetra
.812 .784 .827 r
.47503 .40565 .50033 .43354 .54563 .38723 .52105 .36392 Metetra
.769 .816 .89 r
.52105 .36392 .54563 .38723 .59108 .35491 .56724 .33384 Metetra
.575 .784 .978 r
.56724 .33384 .59108 .35491 .63767 .34686 .61438 .32416 Metetra
.217 .581 .944 r
.61438 .32416 .63767 .34686 .68654 .3638 .66344 .33541 Metetra
.163 .494 .905 r
.66344 .33541 .68654 .3638 .73786 .39006 .71468 .35432 Metetra
.583 .68 .907 r
.71468 .35432 .73786 .39006 .78873 .38403 .76589 .3461 Metetra
.915 .774 .69 r
.76589 .3461 .78873 .38403 .8306 .27412 .81022 .25072 Metetra
.847 .73 .735 r
.14116 .50822 .16978 .54071 .21766 .45829 .18861 .43877 Metetra
.602 .79 .971 r
.18861 .43877 .21766 .45829 .25854 .44913 .22999 .4283 Metetra
.138 .557 .925 r
.22999 .4283 .25854 .44913 .29842 .4657 .27053 .4385 Metetra
.319 .604 .949 r
.27053 .4385 .29842 .4657 .33995 .47874 .31259 .44575 Metetra
.587 .685 .909 r
.31259 .44575 .33995 .47874 .38371 .47308 .35672 .43788 Metetra
.716 .719 .852 r
.35672 .43788 .38371 .47308 .42905 .44624 .40245 .41296 Metetra
.774 .748 .829 r
.40245 .41296 .42905 .44624 .47503 .40565 .44893 .37689 Metetra
.791 .782 .845 r
.44893 .37689 .47503 .40565 .52105 .36392 .49562 .33979 Metetra
.751 .813 .902 r
.49562 .33979 .52105 .36392 .56724 .33384 .54253 .312 Metetra
.592 .791 .975 r
.54253 .312 .56724 .33384 .61438 .32416 .59025 .30064 Metetra
.328 .649 .968 r
.59025 .30064 .61438 .32416 .66344 .33541 .63958 .30609 Metetra
.288 .574 .937 r
.63958 .30609 .66344 .33541 .71468 .35432 .69082 .31754 Metetra
.598 .687 .904 r
.69082 .31754 .71468 .35432 .76589 .3461 .74239 .30709 Metetra
.893 .774 .723 r
.74239 .30709 .76589 .3461 .81022 .25072 .78906 .22642 Metetra
.825 .731 .762 r
.11181 .4749 .14116 .50822 .18861 .43877 .15857 .41859 Metetra
.616 .794 .967 r
.15857 .41859 .18861 .43877 .22999 .4283 .20048 .40675 Metetra
.317 .661 .973 r
.20048 .40675 .22999 .4283 .27053 .4385 .24179 .41049 Metetra
.432 .661 .957 r
.24179 .41049 .27053 .4385 .31259 .44575 .28447 .41185 Metetra
.605 .692 .905 r
.28447 .41185 .31259 .44575 .35672 .43788 .32903 .40173 Metetra
.702 .715 .859 r
.32903 .40173 .35672 .43788 .40245 .41296 .37509 .37872 Metetra
.751 .743 .845 r
.37509 .37872 .40245 .41296 .44893 .37689 .42201 .34723 Metetra
.766 .778 .863 r
.42201 .34723 .44893 .37689 .49562 .33979 .4693 .31482 Metetra
.731 .809 .913 r
.4693 .31482 .49562 .33979 .54253 .312 .5169 .28935 Metetra
.608 .797 .972 r
.5169 .28935 .54253 .312 .59025 .30064 .56523 .27624 Metetra
.429 .704 .979 r
.56523 .27624 .59025 .30064 .63958 .30609 .61492 .27577 Metetra
.403 .64 .953 r
.61492 .27577 .63958 .30609 .69082 .31754 .66625 .27967 Metetra
.613 .694 .901 r
.66625 .27967 .69082 .31754 .74239 .30709 .71821 .26695 Metetra
.861 .771 .761 r
.71821 .26695 .74239 .30709 .78906 .22642 .76708 .20118 Metetra
.792 .73 .795 r
.08169 .4407 .11181 .4749 .15857 .41859 .12748 .3977 Metetra
.629 .797 .963 r
.12748 .3977 .15857 .41859 .20048 .40675 .16995 .38447 Metetra
.463 .73 .984 r
.16995 .38447 .20048 .40675 .24179 .41049 .21216 .3816 Metetra
.524 .702 .951 r
.21216 .3816 .24179 .41049 .28447 .41185 .25557 .37701 Metetra
.622 .698 .9 r
.25557 .37701 .28447 .41185 .32903 .40173 .30058 .36462 Metetra
.686 .71 .866 r
.30058 .36462 .32903 .40173 .37509 .37872 .34695 .34351 Metetra
.724 .736 .861 r
.34695 .34351 .37509 .37872 .42201 .34723 .39422 .3166 Metetra
.736 .772 .882 r
.39422 .3166 .42201 .34723 .4693 .31482 .44203 .28895 Metetra
.708 .804 .925 r
.44203 .28895 .4693 .31482 .5169 .28935 .49029 .26583 Metetra
.623 .802 .968 r
.49029 .26583 .5169 .28935 .56523 .27624 .53927 .25094 Metetra
.516 .747 .979 r
.53927 .25094 .56523 .27624 .61492 .27577 .58941 .24442 Metetra
.503 .693 .953 r
.58941 .24442 .61492 .27577 .66625 .27967 .64095 .24066 Metetra
.626 .7 .898 r
.64095 .24066 .66625 .27967 .71821 .26695 .69333 .22564 Metetra
.815 .761 .802 r
.69333 .22564 .71821 .26695 .76708 .20118 .74422 .17493 Metetra
.74 .723 .835 r
.05077 .4056 .08169 .4407 .12748 .3977 .0953 .37608 Metetra
.642 .8 .959 r
.0953 .37608 .12748 .3977 .16995 .38447 .13836 .3614 Metetra
.573 .772 .973 r
.13836 .3614 .16995 .38447 .21216 .3816 .1816 .35181 Metetra
.598 .729 .936 r
.1816 .35181 .21216 .3816 .25557 .37701 .22586 .34118 Metetra
.637 .704 .894 r
.22586 .34118 .25557 .37701 .30058 .36462 .27135 .32649 Metetra
.669 .704 .873 r
.27135 .32649 .30058 .36462 .34695 .34351 .31799 .30727 Metetra
.692 .726 .877 r
.31799 .30727 .34695 .34351 .39422 .3166 .36553 .28498 Metetra
.7 .763 .901 r
.36553 .28498 .39422 .3166 .44203 .28895 .41376 .26213 Metetra
.683 .798 .936 r
.41376 .26213 .44203 .28895 .49029 .26583 .46265 .24141 Metetra
.638 .807 .964 r
.46265 .24141 .49029 .26583 .53927 .25094 .51232 .22467 Metetra
.591 .779 .97 r
.51232 .22467 .53927 .25094 .58941 .24442 .563 .21197 Metetra
.587 .732 .944 r
.563 .21197 .58941 .24442 .64095 .24066 .61487 .20046 Metetra
.64 .706 .894 r
.61487 .20046 .64095 .24066 .69333 .22564 .6677 .1831 Metetra
.749 .74 .844 r
.6677 .1831 .69333 .22564 .74422 .17493 .72043 .14761 Metetra
.651 .701 .882 r
.01903 .36956 .05077 .4056 .0953 .37608 .06196 .35367 Metetra
.654 .802 .954 r
.06196 .35367 .0953 .37608 .13836 .3614 .10563 .33751 Metetra
.654 .795 .95 r
.10563 .33751 .13836 .3614 .1816 .35181 .15007 .32107 Metetra
.656 .747 .917 r
.15007 .32107 .1816 .35181 .22586 .34118 .19529 .30433 Metetra
.652 .709 .889 r
.19529 .30433 .22586 .34118 .27135 .32649 .24132 .2873 Metetra
.651 .698 .88 r
.24132 .2873 .27135 .32649 .31799 .30727 .28817 .26996 Metetra
.653 .714 .892 r
.28817 .26996 .31799 .30727 .36553 .28498 .33588 .2523 Metetra
.656 .749 .919 r
.33588 .2523 .36553 .28498 .41376 .26213 .38445 .23433 Metetra
.655 .789 .946 r
.38445 .23433 .41376 .26213 .46265 .24141 .43393 .21602 Metetra
.652 .812 .96 r
.43393 .21602 .46265 .24141 .51232 .22467 .48432 .19737 Metetra
.654 .802 .954 r
.48432 .19737 .51232 .22467 .563 .21197 .53566 .17837 Metetra
.656 .76 .926 r
.53566 .17837 .563 .21197 .61487 .20046 .58798 .159 Metetra
.653 .711 .891 r
.58798 .159 .61487 .20046 .6677 .1831 .6413 .13927 Metetra
.651 .701 .883 r
.6413 .13927 .6677 .1831 .72043 .14761 .69565 .11916 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.22768 .18054 m
.23217 .18532 L
s
[(0.5)] .2187 .17096 .938 1 Mshowa
.43326 .10004 m
.43737 .10515 L
s
[(1)] .42503 .08982 .80527 1 Mshowa
.65575 .01292 m
.65941 .01836 L
s
[(1.5)] .64842 .00203 .67254 1 Mshowa
.125 Mabswid
.07414 .24066 m
.07698 .24338 L
s
.11167 .22596 m
.11448 .22872 L
s
.14976 .21105 m
.15253 .21384 L
s
.18843 .19591 m
.19116 .19874 L
s
.26753 .16493 m
.27019 .16784 L
s
.30801 .14908 m
.31061 .15203 L
s
.34911 .13299 m
.35167 .13598 L
s
.39085 .11664 m
.39337 .11967 L
s
.47634 .08317 m
.47875 .08628 L
s
.52011 .06603 m
.52247 .06918 L
s
.56459 .04861 m
.5669 .0518 L
s
.60979 .03091 m
.61205 .03414 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[9]:=",
  ImageSize->{210.938, 171.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003B0000Zb000`400?l00000o`00003odP3oool0
0=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3o
ool00=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3oool00=80oooo00200?ooo`D0
00000P3oool2000000@0oooo0P0000130?ooo`00PP3oool00`000000oooo0?ooo`070?ooo`040000
003oool0oooo00000480oooo00220?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
@03oool00880oooo00<000000?ooo`3oool0203oool2000000T0oooo0P00000h0?ooo`00PP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000=`3o
ool00840oooo0P00000:0?ooo`<000001`3oool010000000oooo0?ooo`00000g0?ooo`00U`3oool0
10000000oooo0?ooo`00000g0?ooo`00U`3oool010000000oooo0?ooo`00000g0?ooo`00T`3oool2
000000<0oooo0P00000h0?ooo`00T@3oool5000003`0oooo002>0?ooo`<000000`3oool2000003`0
oooo002<0?ooo`8000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000>`3oool008T0
oooo0`0000080?ooo`040000003oool0oooo000003X0oooo00270?ooo`8000002`3oool010000000
oooo00000000000j0?ooo`00IP3oool5000001T0oooo0`0000000`3oool000000?ooo`0:0?ooo`05
0000003oool0oooo0?ooo`000000>@3oool006P0oooo00<000000?ooo`3oool05P3oool300000100
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0f0?ooo`00J03oool00`000000oooo
0?ooo`0D0?ooo`<000004P3oool00`000000oooo0?ooo`020?ooo`800000=`3oool006P0oooo00<0
00000?ooo`3oool04@3oool3000001D0oooo00<000000?ooo`3oool00P3oool2000003L0oooo001X
0?ooo`030000003oool0oooo00l0oooo0P00000I0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0=03oool006L0oooo0P00000>0?ooo`@000006P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo03@0oooo001e0?ooo`8000007P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03<0oooo001b0?ooo`<00000803oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo03<0oooo001`0?ooo`80000000<0oooo0000003oool0803oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0380oooo001]0?ooo`<000009@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`8000000`3oool4000000<0oooo0P00000I
0?ooo`00J`3oool2000002P0oooo00<000000?ooo`3oool01P3oool2000000@0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000001P0oooo001X
0?ooo`<0000000<0oooo0000003oool09`3oool00`000000oooo0?ooo`060?ooo`800000103oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool05P3o
ool006H0oooo0P00000]0?ooo`030000003oool0oooo00P0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool2000001T0oooo000j
0?ooo`800000103oool2000000@0oooo0P00000K0?ooo`<00000;P3oool2000000X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0H0?ooo`00>@3oool010000000oooo0?ooo`0000080?ooo`040000
003oool0oooo000001P0oooo0P00000_0?ooo`80000000<0Y[?R0000000000002P3oool010000000
oooo0?ooo`3oool2000000X0oooo0P0000040?ooo`<00000603oool003T0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0C0?ooo`<00000;P3oool3000000<0Y[?R00<000000:Jc
hP000000203oool00`000000oooo0000000_0?ooo`00>@3oool010000000oooo0?ooo`0000090?oo
o`8000004`3oool4000002d0oooo0`0000060:JchP030000002V/n80000000X0oooo00<000000?oo
o`3oool0;@3oool003T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0@0?oo
o`800000;P3oool300000080YkKT00<000000:JchP2V/n80102V/n8010000000Y[?R0:JchP00000:
0?ooo`030000003oool0oooo02`0oooo000j0?ooo`8000002P3oool3000000d0oooo0`00000]0?oo
o`<000001@2W]^@00`000000Y[?R0:JchP040:JchP050000002V/n80Y[?R0:JchP0000002@3oool2
000002d0oooo001D0?ooo`800000;P3oool2000000T0YkKT00<000000:JchP2V/n800`2V/n801P00
0000Y[?R000000000000_kgH000000T0oooo00<000000?ooo`3oool0:`3oool00540oooo0`00000^
0?ooo`80000000<0Yl;]0000002W]^@0202W]^@00`000000Y[?R0:JchP030:JchP800000102o_MP0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02X0oooo001?0?ooo`<00000;P3oool20000
00<0Yl;]00<000000:Nfi02W]^@0202W]^@010000000Y[?R0:JchP2V/n82000000H0_kgH00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`00C03oool3000002l0oooo0P0000060:O2
k@030000002W]^@0YkKT00L0YkKT00H000000:JchP00000000000;nmf00000070;nmf0030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0:@3oool004X0oooo0P00000_0?ooo`<00000202W`^d0
0`000000YkKT0:Nfi0070:Nfi08000000`2o_MP00`000000_kgH0;nmf0040;nmf0030000003@`/d0
000000P0oooo00<000000?ooo`3oool0:03oool004L0oooo0`0000000`3oool000000?ooo`0/0?oo
o`8000000P2WcO@00`000000Yl;]0:O2k@070:O2k@030000002W]^@0YkKT00<0YkKT0`0000020:>d
i0050000002o_MP0_kgH0;nmf0000000102o_MP01@000000d<;=0=32c@3@`/d0000000P0oooo00<0
00000?ooo`3oool09`3oool004@0oooo0`00000_0?ooo`<000001@2WcO@00`000000Yl;]0:O2k@06
0:O2k@030000002W]^@0YkKT00<000001@2S]>@01@000000_kgH0;nmf02o_MP0000000<0_kgH00<0
00000=32c@3@`/d00`3@`/d00`000000oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo000W
0?ooo`8000006@3oool4000002d0oooo0`0000080:O=m0030000002W`^d0Yl;]00H0Yl;]0`000009
0:>di0040000002o_MP0_kgH00000080_kgH00<000000=32c@3@`/d01@3@`/d00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02H0oooo000V0?ooo`040000003oool0oooo000001H0oooo0P00
000_0?ooo`8000000P2VcoD00`000000Ylgd0:O=m0070:O=m0040000002W`^d0Yl;]0:O2k@@00000
0P2F^o400`000000XkCT0:>di0070:>di0060000002o_MP0_kgH0000002o_MP000001`3@`/d00`00
0000g<G2000000070?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`800000103oool20000
01<0oooo000V0?ooo`040000003oool0oooo000001<0oooo0`00000^0?ooo`<000001@2VcoD00`00
0000Ylgd0:O=m0060:O=m0@000001P2F^o400`000000XkCT0:>di0080:>di0040000002o_MP00000
000000P0d<;=00<000000=c5`P0000001`3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000004P3oool002H0oooo00@000000?ooo`3oool00000
403oool3000002h0oooo0`0000090:K?m@040000002WcO@0Ylgd0:O=m0@000000P2GaoP00`000000
U[_a09Jkl@0609Jkl@030000002S]>@0XkCT00L0XkCT00<000000;nmf0000000203@`/d01@000000
g<G20=c5`P3LaL80000000H0oooo0P0000040?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool0403oool002H0oooo00@000000?ooo`3oool000003P3oool2000002l0oooo0P000002
0:O9lP030000002VcoD0Y/oe00L0Y/oe1000000709O7n0030000002F^o40U[_a00H0U[_a00<00000
0:>di02S]>@01P2S]>@3000000L0d<;=00<000000=c5`P3LaL800`3LaL800`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000002@3oool2000001<0oooo000W
0?ooo`800000303oool3000000030?ooo`000000oooo02/0oooo0`0000050:O9lP030000002VcoD0
Y/oe00@0Y/oe0P0000020:?>mP030000002GaoP0UlOh00H0UlOh00<0000009Jkl@2F^o401`2F^o40
0`000000XkCT0:>di0030:>di08000000P2P/nD00`000000d<;=0=32c@040=32c@030000003LaL80
g<G200<0g<G200<000000>C6^@0000001P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0B0?ooo`00<`3oool2000002h0oooo0`000009
0:O9lP030000002VcoD0Y/oe00<000001@2Sc_H00`000000UlOh09O7n00609O7n0030000002F^o40
U[_a00H0U[_a00<000000:>di02S]>@00`0000040:2ci@030000003@`/d0d<;=00@0d<;=00<00000
0=c5`P3LaL800`3LaL8010000000i<Ji0>C6^@0000050?ooo`8000000`3oool2000000X0oooo0`00
000B0?ooo`00<03oool4000002/0oooo100000020:Noj`030000002WbO80YlWb00L0YlWb0`000009
0:?>mP030000002GaoP0UlOh00<0UlOh3P0000060:2ci@<00000103@`/d00`000000g<G20=c5`P03
0=c5`P030000003Ta[T0i<Ji0080i<Ji00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0R
0?ooo`00;P3oool2000002/0oooo100000070:Noj`030000002WbO80YlWb00@0YlWb0P0000020:k<
k`030000002Sc_H0Xlkf00L0Xlkf1P00000408BonP0300000020/O<0P;7c00H0P;7c00@000000:2c
i@2P/nD0X;?U0`0000020:2ci@050000003@`/d0d<;=0=32c@0000001P3LaL800`000000i<Ji0>C6
^@030>C6^@030000003oool0oooo00<0oooo00<000000?ooo`3oool08@3oool002`0oooo0P00000[
0?ooo`8000000P2W]^@00`000000Yko[0:Noj`070:Noj`030000002WbO80YlWb00<000001@2^c>l2
000000D0Xlkf0P00000209o=m`0300000024_oX0Q;oj00H0Q;oj00<00000082al`20/O<01@20/O<4
000000D0X;?U0P0000000`3@`/d000000=c5`P050=c5`P030000003Ta[T0i<Ji00<0i<Ji00<00000
0>[6/00000001@3oool00`000000oooo0?ooo`0P0?ooo`00;03oool2000002P0oooo0`0000050:Nf
i0030000002W_n/0Yko[00L0Yko[0P00000:0:k<k`030000002Sc_H0Xlkf008000001@2OcOL00`00
0000Q;oj08BonP0508BonP0300000020/O<0P;7c00<0P;7c100000080:2ci@030000003@`/d00000
00H0g<G200<000000>C6^@3Ta[T00`3Ta[T00`000000j/J`000000050?ooo`030000003oool0oooo
0200oooo000/0?ooo`<00000903oool3000000P0YkKT00<000000:Noj`2W_n/01@2W_n/200000003
0;?3iP000000[/c_00T0[/c_0`00000809o=m`0300000024_oX0Q;oj00D0Q;oj00<00000082al`20
/O<00P000004082al`030000002P/nD0X;?U00D0X;?U0P0000060=c5`P030000003Ta[T0i<Ji00<0
i<Ji00D000000>[6/03Za[00j/J`000000050?ooo`030000003oool0oooo01l0oooo000/0?ooo`04
0000003oool0oooo00000240oooo0P0000020:Jbh@030000002W]^@0YkKT00L0YkKT00<000000:No
j`2W_n/00P2W_n/2000000@0/l?V0P0000060:k<k`8000000P2ecN`00`000000Wlgg09o=m`0609o=
m`h000000`20/O<010000000X;?U0:2ci@2P/nD400000080W;7V00<000000=c5`P3LaL800`3LaL80
0`000000i<Ji0>C6^@030>C6^@030000003Za[00j/J`0080j/J`00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0N0?ooo`00:`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01`0oooo0P0000050:Jbh@030000002W]^@0YkKT00L0YkKT00@000000:Noj`0000000000202c`nH0
0`000000[/c_0:k<k`03000000D0]Lg/0P00000209o=m`@000000P2Kc?P00`000000KKCj06fdnP03
00000080KKCj00@0000006NSl`1WXo<0Ij?c1`00000609baiP030000003LaL80g<G20080g<G200<0
00000>C6^@3Ta[T00`3Ta[T00`000000j/J`0>[6/0030>[6/0800000103oool00`000000oooo0?oo
o`0N0?ooo`00:`3oool2000000@0oooo00<000000?ooo`3oool0603oool3000000L0Y[;Q00<00000
0:Nfi02W]^@01`2W]^@2000000/0/l?V0P00000:0;G=k08000001P2Kc?P3000000H0KKCj00<00000
06NSl`1WXo<01@1WXo<00`000000W;7V09baiP0609baiP050000003LaL80g<G20=c5`P0000001@3T
a[T00`000000j/J`0>[6/0020>[6/0040000003^aJT0k/FY000000@0oooo00<000000?ooo`3oool0
7@3oool000P0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3o
ool400000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`8000000P2V
]N<00`000000Y[;Q0:Jbh@060:Jbh@030000002W]^@0YkKT00@0YkKT0P0000020;6ih0030000002c
`nH0/l?V00H0/l?V0P0000000`2laN4000000;G=k0070;G=k080000000<0^loY0000002Kc?P00P2K
c?P300000080Vlch00<0000006fdnP1]]?X0101]]?X00`000000Ij?c06NSl`0506NSl`030000002L
/NH0W;7V00L0W;7V00<000000=c5`P0000001@3Ta[T00`000000j/J`0>[6/0030>[6/0050000003^
aJT0k/FY0>k5Z@000000103oool00`000000oooo0?ooo`0L0?ooo`001`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool2
000001<0oooo0P0000050:Jeh`030000002V/^40Y[;Q00H0Y[;Q00<000000:Nfi02W]^@00`000005
0;6ih0030000002c`nH0/l?V00@0/l?V00<000000;c5h@2laN400P2laN400`000000]Lg/0;G=k003
0;G=k0800000102kcnT3000000D0Vlch1@00000306fdnP030000001WXo<0Ij?c00D0Ij?c00<00000
09baiP2L/NH01P2L/NH3000000D0i<Ji00<000000>[6/03Za[000P3Za[000`000000k/FY0>k5Z@02
0>k5Z@8000000`3oool00`000000oooo0?ooo`0L0?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P0000080?ooo`030000003oool0oooo00d0
oooo0`0000070:Jeh`030000002V/^40Y[;Q00H0Y[;Q0`0000080;6ih0030000002c`nH0/l?V0080
/l?V0P0000060;c5h@030000002ecN`0]Lg/008000000`2kcnT3000000040;_?j@000000Vlch09_<
n0@000000P2Gb_T00`000000DjKg05>Vm`07000000D0Ij?c00<0000009baiP2L/NH01@2L/NH20000
00D0i<Ji00<000000>[6/03Za[000`3Za[001`000000k/FY0>k5Z@3^aJT000000?74XP000000103o
ool00`000000oooo0?ooo`0K0?ooo`0000<0oooo0000000000000P0000020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000@0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003oool0
oooo00P0oooo100000020:NojP030000002V]N<0Y[GS00H0Y[GS00<000000:Jbh@2V/^400`2V/^42
00000080ZkCO00<000000;6ih02a^N001`2a^N0010000000/l?V0000000000090;c5h@8000000P2k
cnT3000000D0^loY0P00000709O:n@030000001CY_L0DjKg00@0DjKg00<0000004VBk`0000000`00
00000`1WXo<0000009baiP0209baiP@0000000<0VJoW000000000000103Ta[T00`000000j/J`0>[6
/0030>[6/0050000003^aJT0k/FY0>k5Z@0000000P3aa:800`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`800000
0`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`00
0000oooo000000`0oooo00<000000?ooo`3oool00`3oool4000000H0YkoZ00<000000:Jeh`2V]N<0
1`2V]N<00`000000Y[;Q0:Jbh@02000000D0ZkCO00<000000;6ih02a^N001`2a^N000`000000_<GQ
0;c5h@080;c5h@0300000034am`00000008000001P2kcnT2000000030<3@iP000000Ul[i00L0Ul[i
00<0000005>Vm`1CY_L0101CY_L00`000000BI;_04VBk`0204VBk`D000001P2I[nL200000080i<Ji
00<000000>[6/03Za[000`3Za[000`000000k/FY0>k5Z@020>k5Z@050000003aa:80lLBR0?74XP00
00000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`4000000@3oool10?ooo`00203oool2000000X0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P0000020?ooo`800000303oool00`000000oooo0?ooo`020000
0080Yl_c00<000000:NojP2W_nX01P2W_nX00`000000Y[GS0:Jeh`060:Jeh`<000001`2[]=l00`00
0000/KWP0;6ih0050;6ih080000000<0^KcL0000002laN401`2laN45000000D0^loY0P0000040<3@
iP800000102Gb_T5000000@0DjKg00<0000004VBk`19T^l01019T^l00`000000VJoW09V_i`0609V_
i`050000003Ta[T000000>C6^@0000001@3Za[001@000000k/FY0>k5Z@3^aJT0000000@0lLBR0P00
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00@0oooo0@0000010?ooo`40oooo000Z0?ooo`030000003oool0oooo00`0oooo0P00
00050:O;l`030000002W_nX0YkoZ00H0YkoZ00<000000:Jeh`2V]N<00`2V]N<200000080XkCT00<0
00000:^dg`2[]=l01P2[]=l00`000000/KWP0;6ih0020;6ih0800000102i_=`00`000000_<GQ0;c5
h@030;c5h@<000001034am`00`000000^loY0;_?j@02000000P0`=3V1000000409?8nPD0000000<0
DjKg00000019T^l01@19T^l00`000000VJoW09V_i`0609V_i`<000001@3Za[000`000000k/FY0>k5
Z@020>k5Z@050000003aa:80lLBR0?74XP0000000P3c`id01@000000oooo0?ooo`3oool000000080
oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`3oool2000000<0oooo000Z0?oo
o`030000003oool0oooo00T0oooo0`0000080:O;l`030000002W_nX0YkoZ00D0YkoZ00<000000:Je
h`2V]N<00`0000040:>di0030000002[]=l0ZkCO00L0ZkCO00@000000;6ih000000000001`2i_=`0
0`000000_<GQ00000002000000P0a<OL0P0000080<3@iP80000000<0a=3S0000002Cb?X01P2Cb?X2
00000080=iCa1000000404VBk`030000002I[nL0VJoW00H0VJoW00<000000>C6^@0000001@3Za[00
0`000000k/FY0>k5Z@020>k5Z@050000003aa:80lLBR0?74XP0000000`3c`id010000000oooo0000
000000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`020?ooo`00:P3oool00`000000oooo0?ooo`070?ooo`8000000P2WcO@00`000000
Yl_c0:O;l`070:O;l`030000002W_nX0YkoZ0080YkoZ1@0000080:>di0030000002[]=l0ZkCO00H0
ZkCO0P0000080;Vlg0<0000000<0_<GQ00000034am`01`34am`00`000000b/SH000000070<3@iP03
00000034d><0a=3S0080a=3S00<0000009?8nP2Cb?X01@2Cb?X3000000<0=iCa0`00000304VBk`03
0000002I[nL0VJoW00D0VJoW0P0000000`3Za[0000000>[6/0020>[6/0030000003^aJT0k/FY00<0
k/FY00D000000?74XP3aa:80lLBR000000030??3W@8000000P3oool00`000000oooo0?ooo`020000
00T0oooo100000030?ooo`<000000P3oool002X0oooo0P0000060?ooo`8000001@2WcO@2000000L0
Yl_c1@00000409Vjk`030000002S]>@0XkCT00L0XkCT00<000000:^dg`2[]=l00`2[]=l200000080
[kGM00<000000;Vlg02i_=`00P2i_=`3000000<0^KcL00<000000<C7g034am`01P34am`01@000000
b/SH0<[8f03:b=P0000000@0`=3V0P0000060<C@h`030000002Cb?X0TlSj00@000000P2>a_/30000
0080=iCa00<0000002Uni`0000000`00000309V_i`@000000P2E[^P00`000000j/J`000000020>[6
/0030000003^aJT0k/FY0080k/FY00<000000?74XP3aa:800P3aa:801`000000ll>M0??3W@3c`id0
00000?G2V00000000P3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`03
0?ooo`<000002@2WcO@00`000000Yl_c0:O;l`0400000080T/Gi00<0000009Vjk`2I^^l01@2I^^l0
0`000000XkCT0:>di0060:>di0030000002[]=l0ZkCO00<00000102_]Md00`000000^KcL00000002
000000@0^KcL0P0000000`30_]P000000<C7g0040<C7g08000001@3:b=P010000000`=3V00000000
00090<C@h`8000001`2>a_/00`0000006H3W00000003000000<0:GkW1000000609F^j0030000003Z
a[0000000080j/J`00<000000>k5Z@3^aJT00P3^aJT01@000000lLBR0?74XP3aa:80000000<0ll>M
00L000000?G2V03e`YP0mL:H0000003oool0000001P0oooo000Y0?ooo`030000003oool0000000<0
00000P2V/n42000000P0Ylgd0`00000709;5n@030000002I^^l0VK[_00D0VK[_00<000000:>di02S
]>@01@2S]>@3000000L0[kGM0P0000060;Vlg00300000030_]P0`;kH0080`;kH00D000000<C7g034
am`0a<OL000000080<[8f00300000034d><0a=3S00L0a=3S0P0000000`38dN00000008k6n`0708k6
n`040000000IP>L06H3W01V0i`800000100YO^L00`000000UJkX09F^j00609F^j0040000003Za[00
0000000000D0k/FY00D000000?74XP3aa:80lLBR000000030??3W@050000003e`YP0mL:H0?G2V000
00000P3oool00`000000oooo0?ooo`0E0?ooo`00:@3oool2000000P0Y[?Q0P0000030:O=m0<00000
0P2Tc?D2000000L0T/Gi00<0000009Vjk`2I^^l01@2I^^l00`000000XkCT0:>di00400000080Wk;V
00<000000:neg@2_]Md00P2_]Md300000080[kGM00@000000;Vlg02i_=`0^KcL0P0000060<2nf003
00000034am`0000000P0b/SH00<000000<o8d`0000001`34d><00`000000b=7P0<SAh0020<SAh003
0000002>a_/0S/Kk00<0S/Kk1000000401V0i`8000000`0YO^L00`000000UJkX09F^j00609F^j003
0000003Za[00000000@0k/FY00<000000?74XP3aa:800P3aa:801@000000ll>M0??3W@3c`id00000
00<0mL:H0P0000000`3oool000000?ooo`0F0?ooo`008`3oool2000000@0oooo0P00000:0:Jch@<0
00001`2Tc?D2000000H0T/Gi00<0000009Vjk`2I^^l00P2I^^l5000000L0Wk;V100000050:neg@04
0000002i_=`00000000000T0`;kH00<000000<[8f03:b=P01P3:b=P01@000000clSC0<o8d`3?b=<0
000000@0a=3S0P0000060<SAh0D000001029a?/2000000806H3W00H0000000MWf`000000000002Un
i`00000809F^j080000000<0k/FY0000003^aJT00P3^aJT00`000000lLBR0?74XP020?74XP050000
003c`id0ll>M0??3W@0000000P3e`YP00`000000m/6C000000020?ooo`030000003oool0oooo01@0
oooo000R0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000202V/n4200000003
0;fie@000000Y<ce00P0Y<ce2`00000408Jcl`030000002O/^H0Wk;V00<0Wk;V0`0000080:neg@80
00002P30_]P00`000000a[oD000000060<[8f0030000003?b=<0clSC00<0clSC00@000000<C@h`00
000000001P38dN02000000030<cAg@000000RLCk00L0RLCk0`000000100IP>L0000000MWf`07Im/3
000000D0UJkX100000000`3^aJT000000>k5Z@020>k5Z@050000003aa:80lLBR0?74XP0000000`3c
`id01@000000mL:H0?G2V03e`YP000000080m/6C00@000000?ooo`3oool000005@3oool00280oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000070:Jch@030000002m^MD0_KWE0080
_KWE0P0000050:C<m@80000000<0XLcf0000001f^_/01@1f^_/00`000000Q[?c08Jcl`0508Jcl`03
0000002O/^H00000008000000`2O/^H00`000000[kGM0:neg@030:neg@8000000P2c]m/00`000000
`;kH0<2nf0060<2nf00500000036_m@0a[oD0<Joe0000000103:b=P00`000000clSC0<o8d`050<o8
d`0300000038dN00b=7P00D0b=7P00<000000<cAg@3<dMd00P3<dMd2000000@0RLCk100000000`00
J]T000000000000400MWf`H00000102A[>P01@000000k/FY0000003^aJT0000000@0lLBR00D00000
0??3W@3c`id0ll>M000000030?G2V0030000003f`I<0m/6C0080000000<0oooo0000003oool0503o
ool00280oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000@0Y[?Q
0P0000070;fie@030000002Tc?D0Y<ce00800000102Qc?H2000000D0M[[k00<0000008Jcl`26/o<0
0`26/o<3000000L0Wk;V00<000000:neg@2_]Md00P0000050;>gf`0300000030_]P0`;kH00<0`;kH
0P0000040<Joe0050000003:b=P0b/SH0<[8f00000001`3?b=<00`000000e<S?000000050<SAh003
0000003<dMd0c=7M00D0c=7M1000000408C2n`80000000<006[I00000007Im/01007Im/00`000000
TJcX096/j005096/j0030000003^aJT0k/FY00800000103aa:801@000000ll>M0??3W@3c`id00000
00<0mL:H00P000000?K1T`3f`I<000000?O0S`000000oooo000001@0oooo000R0?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool010000000Y[?Q00000000000:0;fie@80
0000202Qc?H00`000000M[[k07Jjn`0307Jjn`0300000026/o<00000008000000P26/o<00`000000
Wk;V09nbiP0509nbiP<00000202c]m/01@000000`;kH0<2nf030_]P0000000L0a[oD00<000000<[8
f00000001`3?b=<010000000e<S?0=C8c`3Db<l2000000030<SAh0000000000000L0c=7M00<00000
0=3Af`0000001P24`_/01000000005?900000000J]T2000000<01fOK00<00000096/j02A[>P01P2A
[>P010000000k/FY0000000000030?74XP030000003c`id0ll>M0080ll>M00D000000?G2V03e`YP0
mL:H000000020?K1T`060000003g`8l0ml2?0000003oool000001@3oool5000000T0oooo000S0?oo
o`8000000`3oool00`000000oooo0?ooo`030?ooo`030000002m^MD0_KWE00T0_KWE00@000000<Zj
b`00000000001`2Qc?H8000000H0Q[?c00<0000009nbiP2O/^H01000000209Zai`030000002c]m/0
/kOK00L0/kOK00<000000<2nf00000002@36_m@00`000000clSC0<o8d`050<o8d`030000003Db<l0
e<S?00@0e<S?00<000000<cAg@3<dMd01P3<dMd01@000000d=7K0=3Af`3@dM/0000000H0Q<;k00<0
0000001Cb@0000001000000200MWf`030000002A[>P0TJcX00H0TJcX00<000000>k5Z@0000000`3a
a:801@000000ll>M0??3W@3c`id0000000@0mL:H00<000000?K1T`0000000`3g`8l3000000L0oooo
00<000000?ooo`3oool02@3oool002P0oooo0P0000050?ooo`030000002m^MD0_KWE00H0_KWE0P00
00040<Zjb`8000000P2Qc?H300000080WL_g3`00000609Zai`030000002c]m/0/kOK00P0/kOK00<0
00000<Joe036_m@01`36_m@00`000000bl3@000000050<o8d`030000003Db<l0e<S?00@0e<S?00<0
00000=S8b`0000001@3<dMd2000000D0d=7K20000002001Cb@80000000D004k:0000000000001fOK
00000007096/j080000000D0lLBR0000003aa:80lLBR000000030??3W@050000003e`YP0mL:H0?G2
V00000000P3f`I<01P000000ml2?0?O0S`3g`8l000000?RoS08000001P3oool00`000000oooo0?oo
o`090?ooo`00:03oool00`000000oooo0?ooo`050?ooo`030000002m^MD0_KWE00@0_KWE00<00000
0<Zjb`3:^//01P3:^//2000000<0WL_g0`0000000`2MboL0000000000003056Yn@030000001^ZO@0
KZWd00@0KZWd00<0000009Zai`2J/NL01@2J/NL00`000000/kOK0;>gf`050;>gf`80000000<0]kSJ
00000036_m@01P36_m@01@000000bl3@0<_0d03;`=00000000<0clSC00<000000=C8c`3Db<l0103D
b<l01@000000f<S;0=S8b`3Hb</0000000<0c=7M00<000000=3Af`3@dM/0103@dM/00`000000dm;H
0000000607o0o08000000P00DlT00`00000004k:001>bP02000000D0TJcX100000020?74XP030000
003aa:80000000<0ll>M00D000000?G2V03e`YP0mL:H000000020?K1T`050000003g`8l0ml2?0?O0
S`0000000P3h_h`2000000D0oooo00<000000?ooo`3oool02@3oool002P0oooo00<000000?ooo`3o
ool01P3oool00`000000_KWE0;fie@020;fie@030000003:^//0b[[;00H0b[[;00<000000=>k``00
00000`00000509g;m`<000000P1AZOT2000000D0KZWd00<0000009Zai`2J/NL01@2J/NL00`000000
/kOK0;>gf`020;>gf`800000102g^=X00`000000a[oD0<Joe0020<Joe08000001@3;`=000`000000
clSC000000070=C8c`030000003Hb</0f<S;0080f<S;00<000000<cAg@0000001P3@dM/010000000
dm;H0=?Bf03Cd]P2000000D0Ol3l0P000002001Cb@0400000000C/X004k:001>bPD000000`2=ZNT0
0`000000lLBR0?74XP02000000@0ll>M00D000000?G2V03e`YP0mL:H000000020?K1T`040000003g
`8l0ml2?000000<0n;n<0P0000050?ooo`030000003oool0oooo00T0oooo000W0?ooo`8000002@3o
ool010000000_KWE0000000000080<Zjb`H000000P2MboL400000080V/[h1P00000406jYm0030000
002J/NL0V[7W00D0V[7W00<000000;>gf`2c]m/00P0000060;NhfP0500000036_m@0a[oD0<Joe000
0000203;`=000`000000e<S?0=C8c`050=C8c`030000003Hb</0f<S;00@0f<S;00<000000=3Af`3@
dM/00`3@dM/2000000H0dm;H30000002001>bP030000002=ZNT0SJWY00D0SJWY00@000000?74XP3a
a:8000000`3c`id00`000000mL:H0?G2V0020?G2V0040000003f`I<0m/6C00000080ml2?00L00000
0?RoS03h_h`0n;n<0000003i_hT0000000<0oooo0P00000;0?ooo`009`3oool00`000000oooo0?oo
o`090?ooo`030000003:^//0b[[;00H0b[[;0`0000050=>k``8000001`2Jb_P2000000808hk/1000
000206jYm0030000002J/NL0V[7W0080V[7W1@0000090;NhfP0300000036_m@0000000P0bl3@00<0
00000<o1c00000001@3Db<l00`000000f<S;0=S8b`040=S8b`030000003Kb<L0000000<0d=7K00<0
00000=?Bf03Cd]P01@3Cd]P00`000000e];E0000000607Zmo0<0000000@003Fg00000000C/X00000
1`2=ZNT00`000000lLBR0?74XP0200000080ll>M00<000000?G2V03e`YP00P3e`YP010000000m/6C
0?K1T`0000020?O0S`070000003h_h`0n;n<0?RoS0000000nKn90000000@0?ooo`009`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003:^//0b[[;0080b[[;100000060=>k``040000003H^[`00000
000000P0V/[h00H0000002>>k00SS^`08hk/0000001AV_87000000@0UZoX00<000000;NhfP2g^=X0
202g^=X00`000000bl3@0<_0d0060<_0d0050000003?`L`0cl7<0<o1c00000000`3Db<l00`000000
f<S;0=S8b`040=S8b`070000003Kb<L0flS70=_8a`000000d=7K000000070=?Bf0050000003Fd]D0
e];E0=KBe@0000001P1j_O`01`00000003bf00000000=KL00000001>bP0000001`2=ZNT01`000000
lLBR0000003c`id000000??3W@0000000`3e`YP01@000000m/6C0?K1T`3f`I<000000080ml2?00@0
00000?RoS03h_h`000000P3i_hT00`000000oooo0?ooo`0>0?ooo`009`3oool2000000`0oooo1000
00030<Zjb`030000003C^l<0dk_300@0dk_300@000000=Rj_03H^[`0f;Zl0P00000409[:n0D00000
0P0SS^`00`000000DI[b056JlP02056JlP030000002F[nP0UZoX00D0UZoX00<000000;NhfP2g^=X0
1@2g^=X2000000030;Zif0000000bl3@00D0bl3@00<000000<o1c03?`L`00P3?`L`01@000000e<S?
0=C8c`3Db<l0000000H0f<S;00<000000=_8a`3Kb<L00P3Kb<L00`000000dm;H0=?Bf0050=?Bf003
0000003Fd]D0e];E00<0e];E2P0000000`00=KL000000000000708fYj@8000000P3c`id00`000000
ll>M000000030?G2V0040000003f`I<0m/6C000000<0ml2?00@000000?RoS03h_h`000000P3i_hT0
0`000000oooo0?ooo`0>0?ooo`009`3oool00`000000oooo0?ooo`090?ooo`<000001@3:^//00`00
0000dk_30=>k``040=>k``030000003H^[`0f;Zl00@0f;Zl1000000409K9n@D00000101AV_800`00
0000UZoX09J_j00409J_j0030000002g^=X0]kSJ00@0]kSJ00<000000;Zif02j^MP00P2j^MP00`00
0000bl3@0<_0d0020<_0d0030000003?`L`0cl7<00@0cl7<00<000000=C8c`0000001P3Hb</00`00
0000flS70=_8a`020=_8a`030000003Mb<@0000000D0dm;H00<000000=KBe@3Fd]D00`3Fd]D00`00
0000f=7B0000000607Bko0@0000000<003Fg0000000000001`0000030??3W@030000003e`YP0mL:H
0080mL:H00@000000?K1T`3f`I<000000`3g`8l010000000n;n<0?RoS00000020?VoR@8000003`3o
ool000<0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3oool4
000000<0oooo00<000000?ooo`3oool01`3oool2000000<0oooo00D000000<Zjb`3:^//0b[[;0000
00060=>k``030000003H^[`0f;Zl00@0f;Zl00@000000=bj]P00000000001P2FbOT200000004001[
e@0000000000000000<0DI[b00<0000009J_j02F[nP0102F[nP00`000000]kSJ0;NhfP020;NhfP03
0000002j^MP0^[WH00<0^[WH00D000000<_0d03;`=00bl3@000000080<o1c0030000003Hb</0f<S;
00@0f<S;00<000000=_8a`3Kb<L00`3Kb<L010000000gLS40=g8a00000030=?Bf0030000003Fd]D0
e];E00<0e];E00D000000=SAdP3HdM80f=7B0000000607Bko080000000@001fS00000000=KL00000
1P28YnT010000000ll>M0??3W@3c`id2000000<0mL:H00@000000?K1T`3f`I<000000`3g`8l01000
0000n;n<0?RoS00000020?VoR@8000003`3oool00080oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`0000060?ooo`03
0000003:^//0000000L0dk_300<000000=Rj_03H^[`0103H^[`010000000g;Zf0=bj]P3L^[H20000
00@0U/Wi0`000002001[e@H000001P2F[nP010000000]kSJ0000000000070;Zif0030000003;`=00
000000P0cl7<00<000000=?1b@000000103Hb</00`000000flS70=_8a`030=_8a`030000003Mb<@0
gLS40080gLS400<000000=?Bf00000001@3Fd]D00`000000f=7B0=SAdP030=SAdPT0000000@001fS
00000000=KL000001P28YnT01P000000ll>M0??3W@000000mL:H00000080mL:H00@000000?K1T`3f
`I<000000`3g`8l020000000n;n<0?RoS0000000nKn90000003oool000003`3oool00080oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`8000000`3oool3
000000X0oooo00<000000=>k``3C^l<01@3C^l<00`000000f;Zl0=Rj_0040=Rj_0030000003L^[H0
g;Zf00@0g;Zf1000000309;7nP80000000<006_E0000000_Q^/00P0_Q^/9000000X0^[WH00<00000
0<o1c03?`L`01P3?`L`01@000000dl790=?1b@3C`LT0000000<0f<S;00<000000=_8a`3Kb<L00`3K
b<L00`000000gLS40=g8a0030=g8a0030000003Fd]D0e];E00<0e];E00<000000=SAdP3HdM800`3H
dM8010000000f]7@00000000000506nho080000000<001fS0000000000001P28YnT020000000ll>M
0??3W@000000mL:H0000003e`YP000000`3f`I<010000000ml2?0?O0S`0000030?RoS0050000003i
_hT000000?ooo`0000003`3oool00080oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
1P000000oooo0?ooo`3oool000000?ooo`<000003P3oool00`000000dk_30=>k``040=>k``030000
003H^[`0f;Zl00@0f;Zl00<000000=bj]P3L^[H00`3L^[H00`000000gkVb0000000609;7nP<00000
1@0_Q^/00`000000TJgY096]j@04096]j@030000002j^MP0^[WH00D0^[WH0P0000000`2m^MH00000
0<o1c0050<o1c0030000003C`LT0dl7900<0dl7900<000000=S8b`0000001@3Kb<L00`000000gLS4
0=g8a0030=g8a0030000003Pb<00000000<0e];E00<000000=SAdP3HdM800`3HdM800`000000f]7@
0=[Ad0020=[Ad0@000000P1_^?`20000008001fS00<0000008RWj@28YnT01028YnT2000000<0mL:H
0P0000030?K1T`040000003g`8l0ml2?000000<0n;n<00D000000?VoR@000000oooo0000000?0?oo
o`000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo0P00000B0?ooo`030000003C^l<0dk_30080dk_300<000000=Rj_03H^[`0103H^[`00`000000
g;Zf0=bj]P040=bj]P030000003O^K80gkVb00800000102BaoX4000000@0;hK[00<00000096]j@2A
[NT01@2A[NT00`000000^[WH0;Zif0030;Zif0030000002m^MH0_KWF0080_KWF00<000000<o1c03?
`L`00P3?`L`00`000000dl790=?1b@050=?1b@030000003Kb<L0flS700<0flS700<000000=g8a03M
b<@0103Mb<@01P000000h<S00>38`0000000e];E000000D0f=7B00<000000=[Ad03JdM000P3JdM00
0`000000g=7>0000000206Ven`D000000P007J<400000080R:OY0P0000040?G2V0050000003f`I<0
m/6C0?K1T`0000000P3g`8l02@000000n;n<0?RoS03h_h`000000?VoR@000000oooo0000000?0?oo
o`000`3oool2000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`03
0000003oool0oooo0140oooo00@000000=>k``3C^l<000001P3H^[`00`000000g;Zf0=bj]P040=bj
]P030000003O^K80gkVb00<0gkVb1000000308k6nP<000000`0_Q^/00`000000TJgY096]j@04096]
j@030000002j^MP0^[WH0080^[WH00<000000;fieP2m^MH00`2m^MH01@000000cl7<0<o1c03?`L`0
000000L0dl7900<000000=K1a@000000103Kb<L00`000000gLS40=g8a0030=g8a0030000003Pb<00
h<S00080h<S000<000000=SAdP3HdM800`3HdM800`000000f]7@0=[Ad0020=[Ad0050000003LdLh0
g=7>0=cAcP0000001@1Y]O/200000003000MX`000000Q:GZ0080Q:GZ100000040?G2V080000000<0
m/6C0000003g`8l00P3g`8l010000000n;n<0?RoS00000020?VoR@030000003oool0000000l0oooo
000X0?ooo`8000004P3oool00`000000dk_3000000060=Rj_0030000003L^[H0g;Zf00@0g;Zf00<0
00000=ni/P3O^K800`3O^K82000000H0S/Kj1000000202n6j`030000002A[NT0TJgY00@0TJgY00@0
00000;Zif000000000001`2m^MH00`000000cl7<000000070=?1b@050000003F`LD0e/750=K1a@00
00000P3Kb<L00`000000gLS40=g8a0030=g8a0030000003Pb<00h<S00080h<S000<000000>;7_@00
00000`3HdM800`000000f]7@0=[Ad0030=[Ad0030000003LdLh0g=7>0080g=7>200000000`007J<0
000008BUjP0508BUjP040000003e`YP0mL:H0?G2V080000000<0m/6C0000003g`8l00P3g`8l01000
0000n;n<0?RoS00000020?VoR@040000003oool0oooo000000h0oooo000Z0?ooo`030000003oool0
oooo0100oooo00<000000=Rj_03H^[`0103H^[`00`000000g;Zf0=bj]P040=bj]P030000003O^K80
gkVb00<0gkVb00<000000>6i[P3Q^Jh00P00000408k6nP<0000000@026kN0000000000000000102A
[NT4000000X0_KWF00<000000=?1b@3C`LT01@3C`LT00`000000e/750=K1a@030=K1a@030000003K
b<L0000000@0gLS400<000000>38`03Pb<000`3Pb<001P000000h/Nm0>;7_@000000f=7B000000D0
f]7@00<000000=cAcP3LdLh00P3LdLh00`000000oooo0?ooo`050?ooo`<000001`24YNX01@000000
mL:H0?G2V0000000m/6C008000000`3g`8l010000000n;n<0?RoS00000020?VoR@040000003oool0
oooo000000h0oooo000[0?ooo`030000003oool0oooo0100oooo00<000000=Rj_03H^[`00P3H^[`0
0`000000g;Zf0=bj]P050=bj]P030000003O^K80gkVb00<0gkVb00<000000>6i[P3Q^Jh00P3Q^Jh4
000000<0R/Gk00<0000000Q^gP08K]h01@00000408^[jP030000002m^MH0_KWF00D0_KWF0P000000
0`30^]@000000=?1b@040=?1b@030000003F`LD0e/7500D0e/7500<000000=g8a03Mb<@00`3Mb<@0
0`000000h<S00>38`0020>38`0030000003Rakd0h/Nm0080h/Nm00<000000=[Ad03JdM000`3JdM00
0`000000g=7>0=cAcP020=cAcP030000003oool0oooo00L0oooo0`00000608BUjP030000003e`YP0
000000<0m/6C00D000000?O0S`3g`8l0ml2?000000020?RoS0040000003i_hT0nKn900000080oooo
00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool0403oool01@000000f;Zl0=Rj
_03H^[`0000000H0g;Zf00<000000=ni/P3O^K800`3O^K800`000000hKV^0>6i[P030>6i[P800000
1P2:aO/01@00000026kN00Q^gP08K]h0000000L0Rj_Z00<000000;fieP2m^MH00`2m^MH00`000000
`;[D0<2je0020<2je0030000003C`LT0dl790080dl7900<000000=K1a@3F`LD0103F`LD00`000000
fL72000000030=g8a0030000003Pb<00h<S000<0h<S000L000000>;7_@3Rakd0h/Nm0000003TakX0
000000<0f]7@00<000000=cAcP3LdLh00`3LdLh00`000000oooo0?ooo`080?ooo`8000001`24YNX2
000000<0m/6C00@000000?O0S`3g`8l000000`3h_h`010000000nKn90?VoR@0000020?ooo`030000
003oool0oooo00`0oooo000]0?ooo`800000403oool010000000f;Zl0=Rj_00000070=bj]P030000
003O^K80gkVb00<0gkVb00<000000>6i[P3Q^Jh00P3Q^Jh00`000000hkR[0>>hZ`02000000@0R/Gk
0`00000200Q^gP030000002;ZnX0Rj_Z00@0Rj_Z00<000000;fieP2m^MH00P2m^MH00`000000`;[D
0<2je0030<2je0050000003C`LT0dl790=?1b@0000001P3F`LD010000000fL720=W1`P0000020=g8
a0030000003Pb<00h<S000<0h<S000<000000>;7_@3Rakd00P3Rakd00`000000i<Nj0>C7^P020000
00030=[Ad0000000g=7>00<0g=7>00<000000?ooo`3oool02P3oool:000000<0m/6C0P0000000`3g
`8l000000?RoS0020?RoS0040000003i_hT0nKn900000080oooo00<000000?ooo`3oool0303oool0
02l0oooo00<000000?ooo`3oool03P3oool00`000000f;Zl000000060=bj]P030000003O^K80gkVb
00<0gkVb00<000000>6i[P3Q^Jh00`3Q^Jh00`000000hkR[0>>hZ`020>>hZ`@000000P25`o`40000
00L0Rj_Z00@000000;fieP00000000001`30^]@00`000000dl79000000070=K1a@070000003I`L80
fL720=W1`P000000gLS4000000050>38`0050000003Rakd0h/Nm0>;7_@0000001@3TakX00`000000
g=7>0=cAcP020=cAcP030000003oool0oooo00`0oooo0P00000707nSjP050000003f`I<0m/6C0000
003g`8l00P0000030?RoS0040000003i_hT0nKn900000080oooo00<000000?ooo`3oool0303oool0
0300oooo00<000000?ooo`3oool03P3oool00`000000g;Zf0=bj]P050=bj]P030000003O^K80gkVb
00<0gkVb00<000000>6i[P3Q^Jh00P3Q^Jh00`000000hkR[0>>hZ`030>>hZ`<000001@25`o`30000
00@0Rj_Z1000000:0<2je0030000003F`LD0e/7500D0e/7500<000000=W1`P3I`L800`3I`L800`00
0000h<S00>38`0030>38`0030000003Rakd0h/Nm0080h/Nm00<000000>C7^P3TakX00P3TakX00`00
0000iLJh000000020=cAcP030000003oool0oooo00d0oooo0P00000707nSjP030000003f`I<00000
00<0ml2?00D000000?RoS03h_h`0n;n<000000020?VoR@040000003oool0oooo000000h0oooo000a
0?ooo`030000003oool0oooo00h0oooo00<000000=bj]P3L^[H00`3L^[H00`000000gkVb0=ni/P03
0=ni/P030000003Q^Jh0hKV^00<0hKV^00<000000>>hZ`3S^:/00P3S^:/010000000i;RX0>BhZ03T
^:P700000003001Ab@0000000000008000001026Z>/00`000000`;[D0<2je0060<2je00300000033
^m80000000D0e/7500<000000=W1`P3I`L800`3I`L800`000000fl6o000000040>38`0050000003R
akd0h/Nm0>;7_@0000001@3TakX01P000000iLJh0>G6^0000000g=7>00000100oooo0P00000707nS
jP8000000`3g`8l010000000n;n<0?RoS00000020?VoR@030000003oool0oooo0080oooo00<00000
0?ooo`3oool02`3oool00380oooo0P00000?0?ooo`030000003L^[H0g;Zf0080g;Zf00<000000=ni
/P3O^K800`3O^K800`000000hKV^0>6i[P020>6i[P030000003S^:/0hkR[00<0hkR[00<000000>Bh
Z03T^:P00P3T^:P2000000<0P<7l1000000608JXj`0300000030^]@0`;[D00D0`;[D00D000000<>k
dP33^m80`k_B000000030=K1a@030000003I`L80fL7200@0fL7200@000000=_1_`3K`Kl000000P3P
b<000`000000h/Nm0>;7_@020>;7_@030000003TakX0i<Nj0080i<Nj00<000000>G6^03Ua[P00P3U
a[P00`000000oooo0?ooo`0@0?ooo`030000001oXnX0Oj?Z00D0Oj?Z0P0000030?O0S`80000000D0
n;n<0000003i_hT0nKn9000000040?ooo`030000003oool0oooo00/0oooo000d0?ooo`030000003o
ool0oooo00d0oooo00@000000=bj]P3L^[H000001@3O^K800`000000hKV^0>6i[P030>6i[P030000
003S^:/0hkR[00<0hkR[00D000000>BhZ03T^:P0i;RX000000020>FgYP8000000P20`O`010000000
03>`00000000000608JXj`0300000030^]@0`;[D0080`;[D0P0000040<>kdP050000003F`LD0e/75
0=K1a@0000001@3I`L800`000000fl6o0=_1_`020=_1_`030000003Pb<00000000<0h/Nm00<00000
0>C7^P3TakX00`3TakX00`000000iLJh0>G6^0020>G6^0030000003oool0oooo0140oooo2@000003
0?O0S`040000003h_h`0000000000080nKn900<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0;0?ooo`00=@3oool00`000000oooo0?ooo`0=0?ooo`030000003L^[H0000000D0gkVb00<00000
0>6i[P3Q^Jh00`3Q^Jh00`000000hkR[0>>hZ`020>>hZ`030000003T^:P0i;RX0080i;RX00<00000
0>FgYP3U]jH00P3U]jH400000003000c/0000000000000H0QZS[00@000000<2je030^]@000001`33
^m800`000000e/75000000050=W1`P030000003K`Kl0fl6o00@0fl6o00<000000>;7_@3Rakd00P3R
akd00`000000i<Nj0>C7^P020>C7^P030000003Ua[P0iLJh0080iLJh00<000000?ooo`3oool04`3o
ool00`000000Nj3Z07^PjP0507^PjP040000003g`8l0ml2?00000080n;n<00@000000?VoR@3i_hT0
0000103oool00`000000oooo0?ooo`0;0?ooo`00=P3oool00`000000oooo0?ooo`0=0?ooo`030000
003O^K80gkVb00<0gkVb00<000000>6i[P3Q^Jh00`3Q^Jh00`000000hkR[0>>hZ`030>>hZ`030000
003T^:P0i;RX0080i;RX00<000000>FgYP3U]jH00P3U]jH30000000407^oo000000003>`000c/0@0
00000P26Z>/00`000000`;[D000000090<>kdP030000003I`L80fL7200<0fL7200<000000=_1_`3K
`Kl0103K`Kl00`000000gL6m000000020>;7_@030000003TakX0i<Nj0080i<Nj00<000000>G6^03U
a[P00`3Ua[P00`000000oooo0?ooo`0C0?ooo`030000001kX>X0Nj3Z00D0Nj3Z00<000000?O0S`00
00000`3h_h`010000000nKn90?VoR@0000040?ooo`030000003oool0oooo00/0oooo000g0?ooo`80
00003P3oool00`000000gkVb0=ni/P020=ni/P030000003Q^Jh0hKV^00<0hKV^00<000000>>hZ`3S
^:/00`3S^:/01@000000i;RX0>BhZ03T^:P0000000@0iKNV00@000000>JgY03V]j@0i[NT10000000
1000<k000000082Vk020Y^`4000000T0`k_B00<000000<Fkd0000000103I`L800`000000fl6o0=_1
_`040=_1_`060000003M`Kd0gL6m0000003Rakd00000103TakX00`000000iLJh0>G6^0020>G6^003
0000003oool0oooo01D0oooo00<0000007^PjP1kX>X01@1kX>X2000000<0n;n<0P0000000`3i_hT0
00000?ooo`030?ooo`030000003oool0oooo00/0oooo000i0?ooo`030000003oool0oooo00`0oooo
00@000000=ni/P3O^K8000001@3Q^Jh00`000000hkR[0>>hZ`030>>hZ`030000003T^:P0i;RX0080
i;RX00<000000>FgYP3U]jH00P3U]jH00`000000i[NT0>JgY0020>JgY0@0000000<003>`00000020
Y^`01020Y^`00`000000`k_B0<>kdP050<>kdP0400000035^m00aK_@000000<0fL7200<000000=_1
_`3K`Kl0103K`Kl00`000000gL6m0=g1_@020=g1_@030000003TakX0i<Nj0080i<Nj00<000000>G6
^03Ua[P00`3Ua[P00`000000oooo0?ooo`0F0?ooo`@000000`1kX>X2000000<0n;n<00@000000?Vo
R@0000000000103oool00`000000oooo0?ooo`0;0?ooo`00>P3oool00`000000oooo0?ooo`0;0?oo
o`040000003O^K80gkVb000000D0hKV^00<000000>>hZ`3S^:/00`3S^:/00`000000i;RX0>BhZ002
0>BhZ0030000003U]jH0iKNV0080iKNV00D000000>JgY03V]j@0i[NT000000020>NfXP040000001f
_O`00000000000H0P:K/00<000000<>kdP33^m800P33^m82000000@0aK_@00<000000=W1`P000000
1P3K`Kl00`000000gL6m0=g1_@020=g1_@030000003O`KX0000000<0i<Nj00<000000>G6^03Ua[P0
0P3Ua[P00`000000oooo0?ooo`0G0?ooo`8000000P1fW^X5000000<0n;n<00@000000?VoR@3i_hT0
00001@3oool00`000000oooo0?ooo`0:0?ooo`00>`3oool00`000000oooo0?ooo`0;0?ooo`800000
1P3Q^Jh00`000000hkR[0>>hZ`030>>hZ`030000003T^:P0i;RX0080i;RX00<000000>FgYP3U]jH0
0P3U]jH01@000000i[NT0>JgY03V]j@0000000<0ikJR10000005082Vk00500000033^m80`k_B0<>k
dP0000001P35^m000`000000fL72000000050=_1_`030000003M`Kd0gL6m00<0gL6m00<000000=o1
^P0000000P3TakX00`000000iLJh0>G6^0030>G6^0030000003oool0oooo01P0oooo00<0000007JN
jP1fW^X01@1fW^X00`000000n;n<000000030?VoR@030000003oool0oooo00<0oooo00<000000?oo
o`3oool02P3oool003`0oooo0P00000<0?ooo`030000003Q^Jh0hKV^00<0hKV^00<000000>>hZ`3S
^:/00`3S^:/00`000000i;RX0>BhZ0020>BhZ0030000003U]jH0iKNV0080iKNV00<000000>JgY03V
]j@00P3V]j@010000000ikJR0>NfXP3W]Z8800000080P:K/00<000000<>kdP0000002035^m000`00
0000fl6o0=_1_`040=_1_`030000003M`Kd0gL6m0080gL6m00L000000=o1^P3O`KX0gl6j0000003T
akX0000000@0iLJh00<000000?ooo`3oool06P3oool00`000000MYkZ07JNjP0407JNjP030000003h
_h`0000000<0nKn90P0000040?ooo`030000003oool0oooo00X0oooo000n0?ooo`030000003oool0
oooo00X0oooo00<000000>6i[P3Q^Jh00P3Q^Jh00`000000hkR[0>>hZ`030>>hZ`030000003T^:P0
i;RX0080i;RX00<000000>FgYP3U]jH00P3U]jH00`000000i[NT0>JgY0020>JgY0050000003W]Z80
ikJR0>NfXP0000000P3X]Z4300000080NJ?]100000080<Fkd00300000038_<l0000000@0fl6o00<0
00000=g1_@3M`Kd00`3M`Kd00`000000gl6j0=o1^P020=o1^P030000003Ua[P0iLJh00<0iLJh00<0
00000?ooo`3oool06P3oool00`000000MYkZ07JNjP0507JNjP8000000`3i_hT00`000000oooo0000
00030?ooo`030000003oool0oooo00X0oooo000o0?ooo`030000003oool0oooo00X0oooo00@00000
0>6i[P3Q^Jh000001P3S^:/00`000000i;RX0>BhZ0020>BhZ0030000003U]jH0iKNV0080iKNV00D0
00000>JgY03V]j@0i[NT000000030>NfXP030000003X]Z40j;JQ0080j;JQ0`00000507VSk@030000
0035^m00aK_@00@0aK_@00D000000<Rlc`38_<l0b;c?000000020=_1_`030000003M`Kd0gL6m00<0
gL6m00<000000=o1^P3O`KX00P3O`KX00`000000hL6h000000030>G6^0030000003oool0oooo01`0
oooo1000000307JNjP8000000`3i_hT010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00X0oooo00100?ooo`030000003oool0oooo00T0oooo00@000000>6i[P3Q^Jh000001@3S^:/00`00
0000i;RX0>BhZ0020>BhZ0030000003U]jH0iKNV0080iKNV00<000000>JgY03V]j@00P3V]j@01@00
0000ikJR0>NfXP3W]Z80000000@0j;JQ00<000000?ooo`0000001@1iXnd00`000000aK_@0<Fkd002
0<Fkd08000001@38_<l00`000000fl6o000000040=g1_@030000003O`KX0gl6j00<0gl6j00@00000
0>71^03Q`KP000000P3Ua[P00`000000oooo0?ooo`0M0?ooo`030000001aVnX0LI_Z00D000000P3i
_hT01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00440oooo0P00
000:0?ooo`8000001P3S^:/00`000000i;RX0>BhZ0020>BhZ0030000003U]jH0iKNV0080iKNV00<0
00000>JgY03V]j@00P3V]j@01@000000ikJR0>NfXP3W]Z80000000<0j;JQ00D000000?ooo`3oool0
oooo0000000507VSk@0400000035^m00aK_@000000P0b;c?00<000000=g1_@3M`Kd00`3M`Kd00`00
0000gl6j0=o1^P020=o1^P030000003Q`KP0hL6h0080hL6h0P00000P0?ooo`030000001aVnX0LI_Z
00D0LI_Z00<000000?VoR@000000103oool00`000000oooo0000000<0?ooo`00@`3oool00`000000
oooo0?ooo`080?ooo`030000003S^:/0hkR[00@0hkR[00<000000>BhZ03T^:P00P3T^:P00`000000
iKNV0>FgYP020>FgYP050000003V]j@0i[NT0>JgY0000000103W]Z801@000000j;JQ0>RfX@3X]Z40
000000@0oooo0`00000207VSk@0300000035^m00000000P0b;c?00<000000<Zlc@0000000`3M`Kd0
0`000000gl6j0=o1^P030=o1^P030000003Q`KP0hL6h00<0hL6h00<000000?ooo`3oool07`3oool0
0`000000LI_Z076KjP04076KjP030000003i_hT0000000D0oooo00<000000?ooo`0000002`3oool0
04@0oooo00<000000?ooo`3oool0203oool00`000000hkR[0>>hZ`020>>hZ`030000003T^:P0i;RX
0080i;RX00<000000>FgYP3U]jH00`3U]jH01@000000i[NT0>JgY03V]j@0000000<0ikJR00<00000
0>RfX@3X]Z400P3X]Z400`000000oooo0?ooo`020?ooo`80000000<0LYo]0000000000000P000008
0<Rlc`040000003:_<d0b[c=000000<0gL6m00<000000=o1^P3O`KX00P3O`KX00`000000hL6h0>71
^0030>71^0030000003oool0oooo0200oooo00<00000076KjP1aVnX01@1aVnX2000000H0oooo0P00
000;0?ooo`00A@3oool00`000000oooo0?ooo`080?ooo`050000003S^:/0hkR[0>>hZ`000000103T
^:P00`000000iKNV0>FgYP020>FgYP030000003V]j@0i[NT0080i[NT00D000000>NfXP3W]Z80ikJR
000000040>RfX@030000003oool0oooo00<0oooo00<0000007:Ok@1bWnd00`1bWnd00`000000b;c?
0<Rlc`030<Rlc`800000103:_<d00`000000gL6m000000050=o1^P030000003Q`KP0hL6h00<0hL6h
00<000000?ooo`3oool08@3oool4000000<0LI_Z0P0000060?ooo`8000002`3oool004H0oooo0P00
00090?ooo`040000003S^:/0hkR[000000@0i;RX00<000000>FgYP3U]jH00P3U]jH01@000000i[NT
0>JgY03V]j@0000000@0ikJR00D000000>RfX@3X]Z40j;JQ000000070?ooo`030000001bWnd0LYo]
00<0LYo]00D000000<Rlc`38_<l0b;c?000000060<Zlc@030000003M`Kd0000000@0gl6j00<00000
0>71^03Q`KP00`3Q`KP00`000000oooo0?ooo`0V0?ooo`D000001P3oool2000000/0oooo00180?oo
o`030000003oool0oooo00L0oooo0P0000050>BhZ0030000003U]jH0iKNV0080iKNV00D000000>Jg
Y03V]j@0i[NT000000040>NfXP050000003X]Z40j;JQ0>RfX@000000203oool400000080LYo]00<0
00000<Rlc`000000203:_<d00`000000gl6j0=o1^P030=o1^P030000003Q`KP0hL6h00<0hL6h00<0
00000?ooo`3oool0;@3oool4000000d0oooo00190?ooo`030000003oool0oooo00L0oooo00<00000
0>BhZ03T^:P00P3T^:P00`000000iKNV0>FgYP030>FgYP050000003V]j@0i[NT0>JgY00000000`3W
]Z800`000000j;JQ0>RfX@020>RfX@030000003oool0oooo00L0oooo00<0000006^Lk@1[W>d01000
00080<Zlc@030000003<_<`0000000<0gl6j00<000000>71^03Q`KP00`3Q`KP00`000000oooo0?oo
o`0Z0?ooo`@000004@3oool004X0oooo0P0000080?ooo`050000003T^:P0i;RX0>BhZ0000000103U
]jH00`000000i[NT0>JgY0020>JgY0050000003W]Z80ikJR0>NfXP000000103X]Z400`000000oooo
0?ooo`080?ooo`030000001[W>d0Jic]00<0Jic]00<000000<Zlc@3:_<d0103:_<d01@000000c;c<
0<blc03<_<`000000080gl6j00<000000>71^03Q`KP00P3Q`KP00`000000oooo0?ooo`0W0?ooo`@0
00005@3oool004`0oooo00<000000?ooo`3oool01P3oool010000000i;RX0>BhZ00000040>FgYP05
0000003V]j@0i[NT0>JgY0000000103W]Z800`000000j;JQ0>RfX@020>RfX@030000003oool0oooo
00P0oooo00<0000006^Lk@1[W>d0101[W>d00`000000b[c=0<Zlc@020<Zlc@030000003<_<`0c;c<
00<0c;c<0P0000050>71^0030000003oool0oooo02<0oooo1000000I0?ooo`00C@3oool00`000000
oooo0?ooo`060?ooo`8000001@3U]jH01@000000i[NT0>JgY03V]j@0000000@0ikJR00D000000>Rf
X@3X]Z40j;JQ0000000<0?ooo`030000001[W>d0Jic]00<0Jic]00D000000<Zlc@3:_<d0b[c=0000
00070<blc0030000003Q`KP0hL6h0080hL6h00<000000?ooo`3oool0803oool4000001d0oooo001>
0?ooo`030000003oool0oooo00H0oooo00<000000>FgYP3U]jH00P3U]jH00`000000i[NT0>JgY002
0>JgY0050000003W]Z80ikJR0>NfXP000000103X]Z400`000000oooo0?ooo`0;0?ooo`@000000P1[
W>d00`000000b[c=000000070<blc0030000003>_LX0000000<0hL6h00<000000?ooo`3oool07@3o
ool300000240oooo001?0?ooo`8000001`3oool01@000000iKNV0>FgYP3U]jH0000000<0i[NT00<0
00000>NfXP3W]Z800P3W]Z800`000000j;JQ0>RfX@020>RfX@030000003oool0oooo00`0oooo00<0
000006BHk@1TV>d0100000070<blc0040000003>_LX0c[g:00000080hL6h00<000000?ooo`3oool0
6P3oool4000002@0oooo001A0?ooo`030000003oool0oooo00D0oooo00@000000>FgYP3U]jH00000
0`3V]j@00`000000ikJR0>NfXP020>NfXP030000003X]Z40j;JQ0080j;JQ00<000000?ooo`3oool0
3@3oool00`000000I9S]06BHk@0306BHk@030000003<_<`0c;c<00<0c;c<00<000000<jmbP3>_LX0
0P3>_LX00`000000hL6h0000000H0?ooo`@00000:03oool00580oooo00<000000?ooo`3oool0103o
ool010000000iKNV0>FgYP0000030>JgY0030000003W]Z80ikJR0080ikJR00D000000>RfX@3X]Z40
j;JQ0000000A0?ooo`030000001TV>d0I9S]0080I9S]00<000000<blc03<_<`00P3<_<`00`000000
c[g:0<jmbP040<jmbP030000003oool0oooo01<0oooo1000000/0?ooo`00D`3oool00`000000oooo
0?ooo`040?ooo`8000000`3V]j@00`000000ikJR0>NfXP020>NfXP030000003X]Z40j;JQ0080j;JQ
00<000000?ooo`3oool0403oool2000000<0I9S]00@000000<blc03<_<`000001P3>_LX00`000000
oooo0?ooo`0@0?ooo`@00000<03oool005@0oooo0P0000050?ooo`050000003V]j@0i[NT0>JgY000
0000103W]Z800`000000j;JQ0>RfX@020>RfX@030000003oool0oooo0140oooo1@0000000`3<_<`0
00000<jmbP050<jmbP030000003oool0oooo00d0oooo1000000d0?ooo`00EP3oool00`000000oooo
0?ooo`030?ooo`040000003V]j@0i[NT000000@0ikJR00<000000>RfX@3X]Z400P3X]Z400`000000
oooo0?ooo`0A0?ooo`040000001KU>`0FiC/05^Dk08000001P3>_LX00`000000oooo0?ooo`0;0?oo
o`<00000>03oool005L0oooo00<000000?ooo`3oool00P3oool010000000i[NT0>JgY00000040>Nf
XP050000003X]Z40j;JQ0>RfX@0000005@3oool00`000000FiC/05^Dk00205^Dk0030000003>_LX0
c[g:00<0c[g:00<000000?ooo`3oool01`3oool4000003/0oooo001H0?ooo`030000003oool0oooo
0080oooo0P0000040>NfXP030000003X]Z40j;JQ0080j;JQ00<000000?ooo`3oool0503oool20000
00<0FiC/00D000000<jmbP3>_LX0c[g:000000060?ooo`@00000?`3oool005T0oooo0P0000030?oo
o`030000003W]Z80ikJR0080ikJR00<000000>RfX@3X]Z400P3X]Z400`000000oooo0?ooo`0F0?oo
o`D0000000<0c[g:0000003oool00P3oool4000004<0oooo001K0?ooo`050000003oool0oooo0?oo
o`0000000`3W]Z800`000000j;JQ0>RfX@020>RfX@030000003oool0oooo01X0oooo1P0000170?oo
o`00G03oool01@000000oooo0?ooo`3oool000000080ikJR00<000000>RfX@3X]Z400P3X]Z400`00
0000oooo0?ooo`0H0?ooo`@00000B`3oool005d0oooo00H000000?ooo`3oool000000>NfXP000004
0>RfX@030000003oool0oooo01D0oooo1000001?0?ooo`00GP3oool2000000030?ooo`0000000000
00@0j;JQ00<000000?ooo`3oool04P3oool3000005<0oooo001P0?ooo`030000003oool0000000@0
j;JQ00<000000?ooo`3oool03P3oool4000005H0oooo001Q0?ooo`030000003oool0000000<0j;JQ
00<000000?ooo`3oool02P3oool4000005X0oooo001R0?ooo`050000003oool000000>RfX@000000
2@3oool4000005h0oooo001S0?ooo`@000001@3oool400000680oooo001U0?ooo`80000000<0oooo
0000000000000P00001V0?ooo`00IP3oool2000006X0oooo003B0?ooo`00dP3oool00=80oooo003B
0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3oool00=80oooo
003B0?ooo`00dP3oool00=80oooo003B0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 209.938}, {170.063, 0}} -> {-0.232241, -0.0828736, \
0.00597466, 0.00597466}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell["Example 3", "Subsubsection",
  Background->None],

Cell["Boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y'''\)[x] + \[Lambda]*y[x] \[Equal] 2*x, y[0] \[Equal] 0, 
        y[1] \[Equal] 0, \(y'\)[0] \[Equal] \(y'\)[1]}\)], "Input",
  CellLabel->"In[10]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\[Lambda]\ y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "[", "x", "]"}]}], "==", \(2\ x\)}],
         ",", \(y[0] == 0\), ",", \(y[1] == 0\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "1", "]"}]}]}], "}"}]], "Output",\

  CellLabel->"Out[10]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[11]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(\(99090432\ x\^5\ \[Lambda]\ \((\(-13212057600\) \
- 172032000\ \[Lambda] + 
                        47488\ \[Lambda]\^2 + \
\[Lambda]\^3)\)\)\/\(2513641910770335744000 + 
                    124173216833863680\ \[Lambda]\^2 + 
                    36326670336\ \[Lambda]\^4 + 
                    7\ \[Lambda]\^6\)\)\) - \(491520\ x\^3\ \[Lambda]\ \
\((10099296829440 - 84433305600\ \[Lambda] + 16093056\ \[Lambda]\^2 + 509\ \
\[Lambda]\^3)\)\)\/\(2513641910770335744000 + 124173216833863680\ \
\[Lambda]\^2 + 36326670336\ \[Lambda]\^4 + 7\ \[Lambda]\^6\) + \(384\ \
\[Lambda]\ \((4122161971200 - 24380375040\ \[Lambda] - 18670080\ \[Lambda]\^2 \
+ 3157\ \[Lambda]\^3)\)\)\/\(2513641910770335744000 + 124173216833863680\ \
\[Lambda]\^2 + 36326670336\ \[Lambda]\^4 + 7\ \[Lambda]\^6\) + \(1720320\ \
x\^4\ \((121762322841600 - 126835752960\ \[Lambda] - 26046627840\ \
\[Lambda]\^2 + 6021120\ \[Lambda]\^3 + 151\ \
\[Lambda]\^4)\)\)\/\(2513641910770335744000 + 124173216833863680\ \
\[Lambda]\^2 + 36326670336\ \[Lambda]\^4 + 7\ \[Lambda]\^6\) + \(30720\ x\^2\ \
\((\(-13637380158259200\) + 154042021969920\ \[Lambda] - 514006843392\ \
\[Lambda]\^2 + 77844480\ \[Lambda]\^3 + 3515\ \
\[Lambda]\^4)\)\)\/\(2513641910770335744000 + 124173216833863680\ \
\[Lambda]\^2 + 36326670336\ \[Lambda]\^4 + 7\ \[Lambda]\^6\) + \(2\ x\ \
\((104735079615430656000 - 429455712662323200\ \[Lambda] + 1027496434728960\ \
\[Lambda]\^2 - 68259151872\ \[Lambda]\^3 - 10054656\ \[Lambda]\^4 + 7\ \
\[Lambda]\^5)\)\)\/\(2513641910770335744000 + 124173216833863680\ \
\[Lambda]\^2 + 36326670336\ \[Lambda]\^4 + 7\ \[Lambda]\^6\)}}\)], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[12]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \((2\ \[ExponentialE]\^\(\(-x\)\ \[Lambda]\^\(1/3\) - \
\((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\)\ \((\[ExponentialE]\^\(\((\(-1\
\))\)\^\(2/3\)\ \[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\)\) - \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \
\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\)\) - \((\(-1\))\)\^\(1/3\)\ \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \
\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\)\) + \((\(-1\))\)\^\(1/3\)\ \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(1/3\)\ \
\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \[Lambda]\^\(1/3\) + x\ \[Lambda]\
\^\(1/3\)\) - \((\(-1\))\)\^\(2/3\)\ \[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \
\((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\) + \((\(-1\))\)\^\(1/3\)\ \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \
\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\) + \((\(-1\
\))\)\^\(2/3\)\ \[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\
\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\) - \
\((\(-1\))\)\^\(1/3\)\ \[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\
\(1/3\)\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \[Lambda]\^\(1/3\) + \((\
\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\) + \((\(-1\))\)\^\(2/3\)\ \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \
\((\(-1\))\)\^\(1/3\)\ x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \
\[Lambda]\^\(1/3\)\) - \[ExponentialE]\^\(\((\(-1\))\)\^\(2/3\)\ \
\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(1/3\)\ x\ \
\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\) + \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \
\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(1/3\)\ x\ \
\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\) - \((\(-1\
\))\)\^\(2/3\)\ \[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\
\ \[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(1/3\)\ x\ \
\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\) - \
\[ExponentialE]\^\(x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \
\[Lambda]\^\(1/3\)\)\ x + \((\(-1\))\)\^\(2/3\)\ \[ExponentialE]\^\(x\ \
\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\)\ x + \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \
\((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\)\ x + \((\(-1\))\)\^\(1/3\)\ \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \
\((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\)\ x - \((\(-1\))\)\^\(1/3\)\ \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(1/3\)\ \
\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \
\[Lambda]\^\(1/3\)\)\ x - \((\(-1\))\)\^\(2/3\)\ \[ExponentialE]\^\(\[Lambda]\
\^\(1/3\) + \((\(-1\))\)\^\(1/3\)\ \[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) \
+ \((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\)\ x - \((\(-1\))\)\^\(1/3\)\ \
\[ExponentialE]\^\(\((\(-1\))\)\^\(2/3\)\ \[Lambda]\^\(1/3\) + x\ \[Lambda]\^\
\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\)\ x - \
\((\(-1\))\)\^\(2/3\)\ \[ExponentialE]\^\(\((\(-1\))\)\^\(2/3\)\ \
\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \
\[Lambda]\^\(1/3\)\)\ x + \[ExponentialE]\^\(\((\(-1\))\)\^\(1/3\)\ \[Lambda]\
\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) \
+ \((\(-1\))\)\^\(2/3\)\ x\ \[Lambda]\^\(1/3\)\)\ x + \((\(-1\))\)\^\(1/3\)\ \
\[ExponentialE]\^\(\((\(-1\))\)\^\(1/3\)\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\
\(2/3\)\ \[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \
x\ \[Lambda]\^\(1/3\)\)\ x - \[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \
\((\(-1\))\)\^\(1/3\)\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \
\[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \
\[Lambda]\^\(1/3\)\)\ x + \((\(-1\))\)\^\(2/3\)\ \[ExponentialE]\^\(\[Lambda]\
\^\(1/3\) + \((\(-1\))\)\^\(1/3\)\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\
\ \[Lambda]\^\(1/3\) + x\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ x\ \
\[Lambda]\^\(1/3\)\)\ x)\))\)/\((\((1 + \((\(-1\))\)\^\(1/3\))\)\ \((\(-1\) + \
\((\(-1\))\)\^\(1/3\) - \((\(-1\))\)\^\(1/3\)\ \[ExponentialE]\^\(\[Lambda]\^\
\(1/3\) + \((\(-1\))\)\^\(1/3\)\ \[Lambda]\^\(1/3\)\) + \
\[ExponentialE]\^\(\((\(-1\))\)\^\(1/3\)\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\
\(2/3\)\ \[Lambda]\^\(1/3\)\) - \[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \
\((\(-1\))\)\^\(1/3\)\ \[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \
\[Lambda]\^\(1/3\)\) + \((\(-1\))\)\^\(1/3\)\ \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(1/3\)\ \
\[Lambda]\^\(1/3\) + \((\(-1\))\)\^\(2/3\)\ \[Lambda]\^\(1/3\)\) + \
\[ExponentialE]\^\(\[Lambda]\^\(1/3\)\) - \((\(-1\))\)\^\(1/3\)\ \
\[ExponentialE]\^\(\((\(-1\))\)\^\(2/3\)\ \[Lambda]\^\(1/3\)\))\)\ \[Lambda])\
\)}}\)], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[
      Chop[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\)], {x, 0.1, 1}, {\[Lambda], 1, 
        500}]\)], "Input",
  CellLabel->"In[13]:=",
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
4.27718e-017 1.04977 -0.0679587 1.04977 [
[.09267 .22056 -18 -8.89284 ]
[.09267 .22056 0 .10716 ]
[.22808 .16727 -17.3856 -9 ]
[.22808 .16727 .61442 0 ]
[.37094 .11108 -16.5516 -9 ]
[.37094 .11108 1.44839 0 ]
[.52186 .05175 -15.7176 -9 ]
[.52186 .05175 2.28236 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.76694 .09625 0 -6.16263 ]
[.76694 .09625 18 2.83737 ]
[.82777 .18939 0 -6.07297 ]
[.82777 .18939 18 2.92703 ]
[.88347 .2747 0 -5.99249 ]
[.88347 .2747 18 3.00751 ]
[.93468 .35312 0 -5.91984 ]
[.93468 .35312 18 3.08016 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 18 3.14607 ]
[.02068 .28661 -48 -2.76047 ]
[.02068 .28661 0 6.23953 ]
[.00724 .37085 -6 -2.83187 ]
[.00724 .37085 0 6.16813 ]
[-0.00695 .45979 -42 -2.90767 ]
[-0.00695 .45979 0 6.09233 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10206 .22973 m
.10675 .23431 L
s
[(0.2)] .09267 .22056 1 .97619 Mshowa
.23703 .17687 m
.2415 .18167 L
s
[(0.4)] .22808 .16727 .93173 1 Mshowa
.37937 .12114 m
.38359 .12616 L
s
[(0.6)] .37094 .11108 .83907 1 Mshowa
.52971 .06227 m
.53364 .06753 L
s
[(0.8)] .52186 .05175 .7464 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.13514 .21677 m
.13793 .21955 L
s
.16866 .20365 m
.17141 .20646 L
s
.20262 .19035 m
.20534 .1932 L
s
.2719 .16322 m
.27455 .16613 L
s
.30724 .14938 m
.30985 .15233 L
s
.34306 .13535 m
.34564 .13834 L
s
.41618 .10672 m
.41867 .10977 L
s
.4535 .09211 m
.45595 .0952 L
s
.49134 .07729 m
.49374 .08041 L
s
.56863 .04703 m
.57093 .05022 L
s
.60809 .03158 m
.61035 .0348 L
s
.64813 .0159 m
.65033 .01916 L
s
.0694 .24251 m
.07225 .24523 L
s
.03716 .25514 m
.04004 .25782 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75463 .1008 m
.74848 .10307 L
s
[(100)] .76694 .09625 -1 .36947 Mshowa
.81538 .19372 m
.80919 .19589 L
s
[(200)] .82777 .18939 -1 .34955 Mshowa
.87102 .27883 m
.86479 .28089 L
s
[(300)] .88347 .2747 -1 .33166 Mshowa
.92217 .35707 m
.91591 .35904 L
s
[(400)] .93468 .35312 -1 .31552 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(500)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70187 .02008 m
.69819 .0215 L
s
.71543 .04083 m
.71175 .04224 L
s
.72874 .0612 m
.72506 .06259 L
s
.74181 .08118 m
.73812 .08256 L
s
.76722 .12006 m
.76353 .12141 L
s
.77959 .13897 m
.77589 .14031 L
s
.79173 .15755 m
.78803 .15887 L
s
.80366 .17579 m
.79995 .17711 L
s
.8269 .21133 m
.82317 .21262 L
s
.83821 .22865 m
.83449 .22992 L
s
.84933 .24566 m
.84561 .24692 L
s
.86027 .26238 m
.85654 .26364 L
s
.88159 .295 m
.87785 .29623 L
s
.89199 .3109 m
.88824 .31212 L
s
.90221 .32654 m
.89846 .32775 L
s
.91227 .34193 m
.90852 .34312 L
s
.93191 .37196 m
.92815 .37314 L
s
.94149 .38662 m
.93773 .38779 L
s
.95092 .40105 m
.94716 .40221 L
s
.96021 .41526 m
.95644 .4164 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03292 .28187 m
.03904 .27951 L
s
[(-0.00005)] .02068 .28661 1 -0.38656 Mshowa
.01955 .36629 m
.0257 .36401 L
s
[(0)] .00724 .37085 1 -0.3707 Mshowa
.00542 .45542 m
.01161 .45323 L
s
[(0.00005)] -0.00695 .45979 1 -0.35385 Mshowa
.125 Mabswid
.0303 .2984 m
.03398 .29699 L
s
.02766 .3151 m
.03134 .3137 L
s
.02498 .33198 m
.02867 .33059 L
s
.02228 .34904 m
.02597 .34766 L
s
.01678 .38372 m
.02048 .38236 L
s
.01399 .40135 m
.01769 .4 L
s
.01117 .41917 m
.01487 .41784 L
s
.00831 .43719 m
.01202 .43587 L
s
.03551 .26553 m
.03918 .2641 L
s
.0025 .47384 m
.00622 .47254 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.911 .527 .273 r
.38283 .5903 .40512 .60371 .43924 .70182 .41674 .68436 Metetra
.876 .436 .1 r
.41674 .68436 .43924 .70182 .47649 .7806 .45391 .75695 Metetra
.638 .722 .909 r
.45391 .75695 .47649 .7806 .51647 .77466 .49423 .74741 Metetra
.868 .737 .716 r
.49423 .74741 .51647 .77466 .5565 .69657 .53499 .67039 Metetra
.889 .741 .692 r
.53499 .67039 .5565 .69657 .59523 .601 .57461 .57899 Metetra
.863 .771 .758 r
.57461 .57899 .59523 .601 .63365 .53927 .61383 .52154 Metetra
.489 .723 .975 r
.61383 .52154 .63365 .53927 .67409 .53681 .65475 .52092 Metetra
.648 .13 0 r
.65475 .52092 .67409 .53681 .71841 .58834 .69912 .5704 Metetra
.713 .22 0 r
.69912 .5704 .71841 .58834 .76617 .65769 .74663 .63425 Metetra
.075 .43 .872 r
.74663 .63425 .76617 .65769 .81343 .68757 .79374 .65868 Metetra
.837 .761 .779 r
.79374 .65868 .81343 .68757 .85481 .63703 .83572 .60783 Metetra
.92 .765 .673 r
.83572 .60783 .85481 .63703 .88989 .53153 .8723 .50824 Metetra
.87 .806 .785 r
.8723 .50824 .88989 .53153 .92894 .47337 .9127 .45519 Metetra
.827 .396 0 r
.9127 .45519 .92894 .47337 .99548 .62042 .97743 .58865 Metetra
.906 .514 .257 r
.35984 .57706 .38283 .5903 .41674 .68436 .39363 .66605 Metetra
.852 .394 .037 r
.39363 .66605 .41674 .68436 .45391 .75695 .4308 .73166 Metetra
.667 .722 .89 r
.4308 .73166 .45391 .75695 .49423 .74741 .47148 .71861 Metetra
.863 .734 .718 r
.47148 .71861 .49423 .74741 .53499 .67039 .51296 .64336 Metetra
.883 .741 .7 r
.51296 .64336 .53499 .67039 .57461 .57899 .55345 .55692 Metetra
.855 .775 .773 r
.55345 .55692 .57461 .57899 .61383 .52154 .59344 .50418 Metetra
.442 .712 .981 r
.59344 .50418 .61383 .52154 .65475 .52092 .63482 .50526 Metetra
.626 .1 0 r
.63482 .50526 .65475 .52092 .69912 .5704 .67925 .55202 Metetra
.659 .156 0 r
.67925 .55202 .69912 .5704 .74663 .63425 .72649 .60951 Metetra
.206 .51 .911 r
.72649 .60951 .74663 .63425 .79374 .65868 .77347 .62805 Metetra
.832 .755 .778 r
.77347 .62805 .79374 .65868 .83572 .60783 .81609 .57726 Metetra
.91 .763 .686 r
.81609 .57726 .83572 .60783 .8723 .50824 .85422 .48446 Metetra
.852 .807 .806 r
.85422 .48446 .8723 .50824 .9127 .45519 .89601 .43709 Metetra
.8 .356 0 r
.89601 .43709 .9127 .45519 .97743 .58865 .95883 .55532 Metetra
.898 .495 .235 r
.33611 .56404 .35984 .57706 .39363 .66605 .36987 .64679 Metetra
.812 .332 0 r
.36987 .64679 .39363 .66605 .4308 .73166 .40715 .70455 Metetra
.689 .719 .872 r
.40715 .70455 .4308 .73166 .47148 .71861 .44823 .68809 Metetra
.856 .73 .722 r
.44823 .68809 .47148 .71861 .51296 .64336 .49039 .61547 Metetra
.876 .742 .71 r
.49039 .61547 .51296 .64336 .55345 .55692 .5317 .53489 Metetra
.843 .781 .791 r
.5317 .53489 .55345 .55692 .59344 .50418 .57244 .48733 Metetra
.391 .699 .982 r
.57244 .48733 .59344 .50418 .63482 .50526 .61427 .48991 Metetra
.592 .057 0 r
.61427 .48991 .63482 .50526 .67925 .55202 .65876 .53315 Metetra
.58 .069 0 r
.65876 .53315 .67925 .55202 .72649 .60951 .70576 .58332 Metetra
.331 .577 .931 r
.70576 .58332 .72649 .60951 .77347 .62805 .75263 .59552 Metetra
.825 .748 .778 r
.75263 .59552 .77347 .62805 .81609 .57726 .79591 .54521 Metetra
.898 .761 .702 r
.79591 .54521 .81609 .57726 .85422 .48446 .83563 .46027 Metetra
.827 .806 .831 r
.83563 .46027 .85422 .48446 .89601 .43709 .87884 .41917 Metetra
.758 .298 0 r
.87884 .41917 .89601 .43709 .95883 .55532 .93965 .52028 Metetra
.886 .468 .202 r
.31158 .55135 .33611 .56404 .36987 .64679 .34547 .62643 Metetra
.737 .232 0 r
.34547 .62643 .36987 .64679 .40715 .70455 .38297 .67536 Metetra
.706 .714 .855 r
.38297 .67536 .40715 .70455 .44823 .68809 .42447 .65572 Metetra
.848 .725 .728 r
.42447 .65572 .44823 .68809 .49039 .61547 .46726 .58671 Metetra
.867 .742 .723 r
.46726 .58671 .49039 .61547 .5317 .53489 .50934 .51302 Metetra
.828 .787 .814 r
.50934 .51302 .5317 .53489 .57244 .48733 .55077 .47114 Metetra
.337 .685 .98 r
.55077 .47114 .57244 .48733 .61427 .48991 .59306 .47496 Metetra
.541 0 0 r
.59306 .47496 .61427 .48991 .65876 .53315 .63762 .51374 Metetra
0 .054 .54 r
.63762 .51374 .65876 .53315 .70576 .58332 .6844 .55551 Metetra
.443 .631 .934 r
.6844 .55551 .70576 .58332 .75263 .59552 .73119 .56088 Metetra
.817 .739 .778 r
.73119 .56088 .75263 .59552 .79591 .54521 .77516 .5116 Metetra
.882 .757 .72 r
.77516 .5116 .79591 .54521 .83563 .46027 .81651 .4357 Metetra
.794 .803 .859 r
.81651 .4357 .83563 .46027 .87884 .41917 .86118 .4016 Metetra
.687 .206 0 r
.86118 .4016 .87884 .41917 .93965 .52028 .91988 .48335 Metetra
.866 .428 .153 r
.28619 .53908 .31158 .55135 .34547 .62643 .3204 .60481 Metetra
.59 .067 0 r
.3204 .60481 .34547 .62643 .38297 .67536 .35829 .64384 Metetra
.717 .707 .84 r
.35829 .64384 .38297 .67536 .42447 .65572 .40023 .62131 Metetra
.836 .719 .735 r
.40023 .62131 .42447 .65572 .46726 .58671 .44357 .55708 Metetra
.854 .742 .739 r
.44357 .55708 .46726 .58671 .50934 .51302 .48631 .49147 Metetra
.806 .794 .841 r
.48631 .49147 .50934 .51302 .55077 .47114 .5284 .45583 Metetra
.284 .671 .972 r
.5284 .45583 .55077 .47114 .59306 .47496 .57113 .46054 Metetra
.464 0 0 r
.57113 .46054 .59306 .47496 .63762 .51374 .6158 .49373 Metetra
0 .22 .694 r
.6158 .49373 .63762 .51374 .6844 .55551 .6624 .52586 Metetra
.538 .669 .922 r
.6624 .52586 .6844 .55551 .73119 .56088 .70914 .52391 Metetra
.806 .729 .779 r
.70914 .52391 .73119 .56088 .77516 .5116 .75384 .47631 Metetra
.859 .751 .743 r
.75384 .47631 .77516 .5116 .81651 .4357 .79684 .41085 Metetra
.747 .795 .892 r
.79684 .41085 .81651 .4357 .86118 .4016 .843 .38453 Metetra
.556 .05 0 r
.843 .38453 .86118 .4016 .91988 .48335 .89949 .44435 Metetra
.829 .359 .073 r
.25986 .52736 .28619 .53908 .3204 .60481 .29468 .58174 Metetra
0 .19 .67 r
.29468 .58174 .3204 .60481 .35829 .64384 .33313 .60967 Metetra
.724 .698 .825 r
.33313 .60967 .35829 .64384 .40023 .62131 .37551 .58466 Metetra
.821 .712 .744 r
.37551 .58466 .40023 .62131 .44357 .55708 .41929 .52661 Metetra
.836 .741 .76 r
.41929 .52661 .44357 .55708 .48631 .49147 .46256 .47044 Metetra
.774 .802 .876 r
.46256 .47044 .48631 .49147 .5284 .45583 .50524 .44165 Metetra
.234 .659 .959 r
.50524 .44165 .5284 .45583 .57113 .46054 .54843 .44677 Metetra
0 .214 .623 r
.54843 .44677 .57113 .46054 .6158 .49373 .59327 .47303 Metetra
0 .423 .852 r
.59327 .47303 .6158 .49373 .6624 .52586 .63976 .49413 Metetra
.615 .694 .9 r
.63976 .49413 .6624 .52586 .70914 .52391 .6865 .4844 Metetra
.792 .718 .782 r
.6865 .4844 .70914 .52391 .75384 .47631 .73193 .43928 Metetra
.826 .741 .77 r
.73193 .43928 .75384 .47631 .79684 .41085 .7766 .38583 Metetra
.678 .778 .926 r
.7766 .38583 .79684 .41085 .843 .38453 .82427 .36818 Metetra
0 .232 .689 r
.82427 .36818 .843 .38453 .89949 .44435 .87846 .40309 Metetra
.75 .23 0 r
.23252 .51631 .25986 .52736 .29468 .58174 .2683 .55696 Metetra
.102 .479 .896 r
.2683 .55696 .29468 .58174 .33313 .60967 .30756 .57253 Metetra
.726 .688 .813 r
.30756 .57253 .33313 .60967 .37551 .58466 .35035 .54564 Metetra
.799 .701 .757 r
.35035 .54564 .37551 .58466 .41929 .52661 .39439 .49537 Metetra
.809 .739 .787 r
.39439 .49537 .41929 .52661 .46256 .47044 .43803 .45018 Metetra
.723 .808 .917 r
.43803 .45018 .46256 .47044 .50524 .44165 .48121 .42887 Metetra
.194 .653 .942 r
.48121 .42887 .50524 .44165 .54843 .44677 .52489 .43376 Metetra
0 .385 .756 r
.52489 .43376 .54843 .44677 .59327 .47303 .56998 .45151 Metetra
.276 .617 .958 r
.56998 .45151 .59327 .47303 .63976 .49413 .61646 .46006 Metetra
.675 .708 .872 r
.61646 .46006 .63976 .49413 .6865 .4844 .66327 .44215 Metetra
.774 .704 .785 r
.66327 .44215 .6865 .4844 .73193 .43928 .70943 .40046 Metetra
.777 .723 .802 r
.70943 .40046 .73193 .43928 .7766 .38583 .75575 .36079 Metetra
.575 .743 .956 r
.75575 .36079 .7766 .38583 .82427 .36818 .80494 .35272 Metetra
.228 .649 .957 r
.80494 .35272 .82427 .36818 .87846 .40309 .85678 .35943 Metetra
.531 0 0 r
.20408 .50599 .23252 .51631 .2683 .55696 .24128 .5302 Metetra
.449 .656 .949 r
.24128 .5302 .2683 .55696 .30756 .57253 .28161 .53217 Metetra
.724 .676 .803 r
.28161 .53217 .30756 .57253 .35035 .54564 .32477 .5042 Metetra
.768 .687 .773 r
.32477 .5042 .35035 .54564 .39439 .49537 .36884 .46354 Metetra
.764 .733 .825 r
.36884 .46354 .39439 .49537 .43803 .45018 .41263 .43097 Metetra
.637 .804 .963 r
.41263 .43097 .43803 .45018 .48121 .42887 .45622 .41773 Metetra
.174 .658 .926 r
.45622 .41773 .48121 .42887 .52489 .43376 .50043 .42152 Metetra
.097 .597 .898 r
.50043 .42152 .52489 .43376 .56998 .45151 .5459 .42895 Metetra
.532 .746 .974 r
.5459 .42895 .56998 .45151 .61646 .46006 .59251 .42344 Metetra
.721 .715 .844 r
.59251 .42344 .61646 .46006 .66327 .44215 .63946 .39712 Metetra
.752 .688 .79 r
.63946 .39712 .66327 .44215 .70943 .40046 .68634 .35998 Metetra
.701 .691 .837 r
.68634 .35998 .70943 .40046 .75575 .36079 .73427 .3359 Metetra
.423 .676 .968 r
.73427 .3359 .75575 .36079 .80494 .35272 .78497 .33825 Metetra
.713 .908 .964 r
.78497 .33825 .80494 .35272 .85678 .35943 .83447 .31338 Metetra
.066 .597 .864 r
.17448 .4962 .20408 .50599 .24128 .5302 .21364 .5012 Metetra
.643 .718 .902 r
.21364 .5012 .24128 .5302 .28161 .53217 .25532 .48864 Metetra
.718 .664 .796 r
.25532 .48864 .28161 .53217 .32477 .5042 .29876 .46068 Metetra
.723 .667 .795 r
.29876 .46068 .32477 .5042 .36884 .46354 .3426 .43149 Metetra
.684 .717 .874 r
.3426 .43149 .36884 .46354 .41263 .43097 .38628 .41306 Metetra
.491 .771 .994 r
.38628 .41306 .41263 .43097 .45622 .41773 .43017 .40819 Metetra
.191 .684 .92 r
.43017 .40819 .45622 .41773 .50043 .42152 .47497 .40973 Metetra
.4 .791 .989 r
.47497 .40973 .50043 .42152 .5459 .42895 .521 .40499 Metetra
.701 .799 .926 r
.521 .40499 .5459 .42895 .59251 .42344 .56792 .3842 Metetra
.755 .717 .817 r
.56792 .3842 .59251 .42344 .63946 .39712 .6151 .34964 Metetra
.723 .67 .797 r
.6151 .34964 .63946 .39712 .68634 .35998 .66269 .31825 Metetra
.581 .634 .869 r
.66269 .31825 .68634 .35998 .73427 .3359 .7121 .31126 Metetra
.221 .566 .938 r
.7121 .31126 .73427 .3359 .78497 .33825 .76424 .32443 Metetra
.911 .924 .811 r
.76424 .32443 .78497 .33825 .83447 .31338 .81158 .26535 Metetra
.65 .884 .983 r
.14371 .48612 .17448 .4962 .21364 .5012 .1854 .46991 Metetra
.738 .732 .845 r
.1854 .46991 .21364 .5012 .25532 .48864 .22868 .44285 Metetra
.707 .654 .795 r
.22868 .44285 .25532 .48864 .29876 .46068 .27226 .41625 Metetra
.654 .64 .824 r
.27226 .41625 .29876 .46068 .3426 .43149 .31556 .39994 Metetra
.535 .671 .925 r
.31556 .39994 .3426 .43149 .38628 .41306 .35887 .39636 Metetra
.279 .682 .971 r
.35887 .39636 .38628 .41306 .43017 .40819 .40296 .39942 Metetra
.27 .742 .94 r
.40296 .39942 .43017 .40819 .47497 .40973 .44845 .39727 Metetra
.647 .889 .984 r
.44845 .39727 .47497 .40973 .521 .40499 .49526 .37897 Metetra
.793 .807 .864 r
.49526 .37897 .521 .40499 .56792 .3842 .5427 .34273 Metetra
.778 .718 .796 r
.5427 .34273 .56792 .3842 .6151 .34964 .59026 .30095 Metetra
.688 .654 .811 r
.59026 .30095 .6151 .34964 .66269 .31825 .63849 .27639 Metetra
.399 .542 .883 r
.63849 .27639 .66269 .31825 .7121 .31126 .68919 .28678 Metetra
.013 .431 .864 r
.68919 .28678 .7121 .31126 .76424 .32443 .74259 .30997 Metetra
.968 .882 .694 r
.74259 .30997 .76424 .32443 .81158 .26535 .78822 .21671 Metetra
.822 .863 .878 r
.11199 .47347 .14371 .48612 .1854 .46991 .15651 .43682 Metetra
.784 .733 .806 r
.15651 .43682 .1854 .46991 .22868 .44285 .20141 .39754 Metetra
.694 .654 .807 r
.20141 .39754 .22868 .44285 .27226 .41625 .245 .37381 Metetra
.549 .609 .865 r
.245 .37381 .27226 .41625 .31556 .39994 .28757 .37014 Metetra
.282 .568 .935 r
.28757 .37014 .31556 .39994 .35887 .39636 .33036 .37979 Metetra
.098 .576 .908 r
.33036 .37979 .35887 .39636 .40296 .39942 .37463 .38858 Metetra
.428 .817 .987 r
.37463 .38858 .40296 .39942 .44845 .39727 .42091 .38122 Metetra
.779 .885 .922 r
.42091 .38122 .44845 .39727 .49526 .37897 .46868 .34973 Metetra
.834 .795 .814 r
.46868 .34973 .49526 .37897 .5427 .34273 .51687 .30049 Metetra
.792 .723 .788 r
.51687 .30049 .5427 .34273 .59026 .30095 .56494 .25415 Metetra
.647 .648 .837 r
.56494 .25415 .59026 .30095 .63849 .27639 .61378 .23679 Metetra
.167 .421 .859 r
.61378 .23679 .63849 .27639 .68919 .28678 .66543 .26168 Metetra
0 .338 .799 r
.66543 .26168 .68919 .28678 .74259 .30997 .71974 .29137 Metetra
.979 .842 .637 r
.71974 .29137 .74259 .30997 .78822 .21671 .76464 .17071 Metetra
.845 .805 .811 r
.07995 .4535 .11199 .47347 .15651 .43682 .12675 .40368 Metetra
.802 .739 .794 r
.12675 .40368 .15651 .43682 .20141 .39754 .1728 .35874 Metetra
.68 .685 .848 r
.1728 .35874 .20141 .39754 .245 .37381 .21633 .33894 Metetra
.404 .596 .923 r
.21633 .33894 .245 .37381 .28757 .37014 .25837 .3437 Metetra
.047 .46 .881 r
.25837 .3437 .28757 .37014 .33036 .37979 .30091 .35991 Metetra
.134 .577 .925 r
.30091 .35991 .33036 .37979 .37463 .38858 .34551 .36909 Metetra
.602 .821 .984 r
.34551 .36909 .37463 .38858 .42091 .38122 .3926 .35566 Metetra
.808 .819 .859 r
.3926 .35566 .42091 .38122 .46868 .34973 .44132 .31565 Metetra
.837 .773 .79 r
.44132 .31565 .46868 .34973 .51687 .30049 .49035 .26095 Metetra
.798 .742 .801 r
.49035 .26095 .51687 .30049 .56494 .25415 .53911 .21535 Metetra
.605 .68 .894 r
.53911 .21535 .56494 .25415 .61378 .23679 .58855 .20365 Metetra
0 .343 .82 r
.58855 .20365 .61378 .23679 .66543 .26168 .64069 .23381 Metetra
0 .372 .83 r
.64069 .23381 .66543 .26168 .71974 .29137 .69531 .26156 Metetra
.965 .805 .634 r
.69531 .26156 .71974 .29137 .76464 .17071 .74119 .13359 Metetra
.8 .735 .792 r
.04876 .41928 .07995 .4535 .12675 .40368 .09561 .37376 Metetra
.789 .761 .827 r
.09561 .37376 .12675 .40368 .1728 .35874 .14152 .33536 Metetra
.661 .792 .944 r
.14152 .33536 .1728 .35874 .21633 .33894 .18516 .31892 Metetra
.301 .679 .975 r
.18516 .31892 .21633 .33894 .25837 .3437 .22773 .32133 Metetra
.161 .578 .934 r
.22773 .32133 .25837 .3437 .30091 .35991 .27106 .33019 Metetra
.429 .665 .96 r
.27106 .33019 .30091 .35991 .34551 .36909 .31644 .33077 Metetra
.658 .704 .881 r
.31644 .33077 .34551 .36909 .3926 .35566 .3641 .31274 Metetra
.756 .715 .814 r
.3641 .31274 .3926 .35566 .44132 .31565 .41328 .27556 Metetra
.795 .742 .803 r
.41328 .27556 .44132 .31565 .49035 .26095 .46289 .22981 Metetra
.782 .794 .863 r
.46289 .22981 .49035 .26095 .53911 .21535 .51245 .19318 Metetra
.556 .797 .989 r
.51245 .19318 .53911 .21535 .58855 .20365 .56263 .18218 Metetra
.007 .475 .87 r
.56263 .18218 .58855 .20365 .64069 .23381 .61484 .19951 Metetra
.287 .559 .929 r
.61484 .19951 .64069 .23381 .69531 .26156 .66903 .21117 Metetra
.895 .746 .688 r
.66903 .21117 .69531 .26156 .74119 .13359 .71819 .11362 Metetra
.641 .616 .809 r
.01941 .36715 .04876 .41928 .09561 .37376 .06247 .35012 Metetra
.663 .795 .945 r
.06247 .35012 .09561 .37376 .14152 .33536 .10621 .33315 Metetra
.532 .907 .953 r
.10621 .33315 .14152 .33536 .18516 .31892 .15058 .31675 Metetra
.51 .9 .946 r
.15058 .31675 .18516 .31892 .22773 .32133 .19567 .30073 Metetra
.638 .825 .972 r
.19567 .30073 .22773 .32133 .27106 .33019 .24157 .28458 Metetra
.641 .659 .852 r
.24157 .28458 .27106 .33019 .31644 .33077 .28834 .26777 Metetra
.627 .584 .786 r
.28834 .26777 .31644 .33077 .3641 .31274 .33602 .24999 Metetra
.631 .589 .788 r
.33602 .24999 .3641 .31274 .41328 .27556 .38459 .23127 Metetra
.655 .681 .862 r
.38459 .23127 .41328 .27556 .46289 .22981 .43405 .21199 Metetra
.641 .869 .984 r
.43405 .21199 .46289 .22981 .51245 .19318 .48438 .19274 Metetra
.444 .879 .883 r
.48438 .19274 .51245 .19318 .56263 .18218 .53565 .17406 Metetra
.531 .9 .965 r
.53565 .17406 .56263 .18218 .61484 .19951 .58792 .15593 Metetra
.644 .695 .882 r
.58792 .15593 .61484 .19951 .66903 .21117 .64122 .13715 Metetra
.633 .57 .766 r
.64122 .13715 .66903 .21117 .71819 .11362 .69538 .11442 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10206 .22973 m
.10675 .23431 L
s
[(0.2)] .09267 .22056 1 .97619 Mshowa
.23703 .17687 m
.2415 .18167 L
s
[(0.4)] .22808 .16727 .93173 1 Mshowa
.37937 .12114 m
.38359 .12616 L
s
[(0.6)] .37094 .11108 .83907 1 Mshowa
.52971 .06227 m
.53364 .06753 L
s
[(0.8)] .52186 .05175 .7464 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.13514 .21677 m
.13793 .21955 L
s
.16866 .20365 m
.17141 .20646 L
s
.20262 .19035 m
.20534 .1932 L
s
.2719 .16322 m
.27455 .16613 L
s
.30724 .14938 m
.30985 .15233 L
s
.34306 .13535 m
.34564 .13834 L
s
.41618 .10672 m
.41867 .10977 L
s
.4535 .09211 m
.45595 .0952 L
s
.49134 .07729 m
.49374 .08041 L
s
.56863 .04703 m
.57093 .05022 L
s
.60809 .03158 m
.61035 .0348 L
s
.64813 .0159 m
.65033 .01916 L
s
.0694 .24251 m
.07225 .24523 L
s
.03716 .25514 m
.04004 .25782 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{210.938, 171.063},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003B0000Zb000`400?l00000o`00003odP3oool0
0=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3o
ool00=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00
dP3oool00=80oooo002>0?ooo`D00000?`3oool00900oooo00<000000?ooo`3oool0?`3oool00900
oooo00<000000?ooo`3oool0?`3oool00900oooo00<000000?ooo`3oool0?`3oool00900oooo00<0
00000?ooo`3oool0?`3oool008l0oooo0P0000110?ooo`00dP3oool00=80oooo003B0?ooo`00dP3o
ool006d0oooo0P0000040?ooo`800000103oool2000001P0oooo0P00000m0?ooo`00K03oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo000001D0oooo0P0000000`3oool000000000
000l0?ooo`00K03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000140oooo
100000030?ooo`800000?03oool006`0oooo00@000000?ooo`3oool000002@3oool200000100oooo
100000050?ooo`<00000>`3oool006`0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000=0?ooo`8000002@3oool010000000oooo0?ooo`00000j0?ooo`00K@3oool2000000X0
oooo0P00000;0?ooo`<000002`3oool010000000oooo0?ooo`00000j0?ooo`00Q03oool2000000h0
oooo00<000000?ooo`3oool00P00000i0?ooo`00P@3oool300000100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0f0?ooo`00O`3oool2000000030?ooo`000000oooo0100oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0f0?ooo`00E@3oool2000000@0oooo0P000003
0?ooo`<000006@3oool3000001D0oooo00<000000?ooo`3oool00P3oool2000003L0oooo001D0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000005@3oool4000001P0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`D000000P3oool2000000@0oooo0P00
000S0?ooo`00E03oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001<0oooo
0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0P0?oo
o`00E03oool010000000oooo0?ooo`0000080?ooo`<000004@3oool3000001h0oooo00<000000?oo
o`3oool00`3oool2000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0803oool005@0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0>0?ooo`8000008@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool0803oool005D0oooo0P00000:0?ooo`<000002`3oool3000002<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0200oooo001]0?ooo`80
00009P3oool00`000000oooo0?ooo`040?ooo`<000000P3oool2000000@0oooo0P0000040?ooo`80
00008`3oool006X0oooo0`00000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
<@3oool003l0oooo0P0000040?ooo`8000001@3oool3000001P0oooo0`00000Z0?ooo`D000001P3o
ool00`000000oooo0?ooo`0`0?ooo`00?P3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo01D0oooo0P00000[0?ooo`80000000@0XY740000002RTL@0XY740P0000050?ooo`800000
<@3oool003h0oooo00@000000?ooo`3oool00000203oool5000001<0oooo0`0000000`3oool00000
0?ooo`0X0?ooo`8000000`2RTL@00`000000XY74000000020>Fn/0030000003oool0oooo00<0oooo
00<000000?ooo`3oool0;`3oool003h0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000B0?ooo`800000;03oool2000000D0XY7400<000000::Aa00000000`3U_[000`000000
oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo000n0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`0000003`3oool4000002X0oooo0`0000070::Aa0800000103U_[02000000@0
oooo0P00000_0?ooo`00?`3oool2000000/0oooo0P00000<0?ooo`<00000:P3oool4000000030:Ba
h@000000XY7400L0XY740P0000030>Fn/0030000003gcZ80000000D0oooo00<000000?ooo`3oool0
;@3oool005P0oooo0P0000000`3oool000000?ooo`0V0?ooo`@000001P2T/N400`000000XY740::A
a0050::Aa0030000003U_[00iKj`0080iKj`00@000000?O>XP3gcZ8000001@3oool00`000000oooo
0?ooo`0/0?ooo`00E@3oool3000002T0oooo0P00000208OVm`030000002T/N40Y;7Q00D0Y;7Q00<0
00000::Aa02RTL@01@2RTL@00`000000iKj`0>Fn/0020>Fn/0050000003gcZ80mljR0?O>XP000000
0`3oool3000000@0oooo100000030?ooo`800000103oool2000001X0oooo000Z0?ooo`800000103o
ool2000000<0oooo1000000J0?ooo`80000000<0oooo0000003oool09`3oool2000000@0QnKg00<0
00000:Bah@2T/N401P2T/N400`000000XY740::Aa0030::Aa08000000`3U_[000`000000mljR0?O>
XP020?O>XP030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000006@3oool002T0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0H0?ooo`<00000:@3oool3000000L0
QnKg00<000000:Bah@2T/N401@2T/N400`000000XY740::Aa0030::Aa08000000`3U_[000`000000
mljR0?O>XP030?O>XP030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000006@3oool0
02T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0E0?ooo`@00000:03oool2
000000<0LN7R1000000308OVm`030000002T/N40Y;7Q00H0Y;7Q00L000000::Aa02RTL@0XY740000
003U_[00000000<0iKj`00<000000?O>XP3gcZ800`3gcZ800`000000oooo0?ooo`020?ooo`030000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool05`3oool002T0oooo00@000000?ooo`3oool000002P3oool00`00
0000oooo0?ooo`0A0?ooo`<00000:@3oool300000080LN7R1000000208k<o@<000000P27i_L00`00
0000Y;7Q0:Bah@050:Bah@050000002RTL@0XY740::Aa00000000P3U_[000`000000iKj`00000005
0?O>XP030000003jej<0000000D0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool05`3oool002T0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000?0?ooo`@00000:03oool80000
00L0S/cm00<00000005igP0000000P0000080:Bah@030000002RTL@0000000<0iKj`00<000000>Fn
/00000001@3gcZ800`000000n]NS000000050?ooo`8000000P3oool2000000@0oooo0P0000040?oo
o`8000006P3oool002X0oooo0P00000:0?ooo`8000003P3oool2000002X0oooo0P0000030:CNn`80
000000<0b<_L0000002>c?d0202>c?d00`0000000GWN005igP04000000D0Y;7Q00<000000::Aa000
00000`3U_[000`000000iKj`000000040?O>XP050000003jej<0n]NS0?[GX`0000001P3oool00`00
0000oooo0?ooo`0W0?ooo`00@`3oool4000002P0oooo0`0000040:CNn`0300000038bm`0b<_L0080
b<_L0P00000508k<o@@000000`01NMh00`000000BHo]0000000300000080Y;7Q00<000000>Fn/03U
_[000P3U_[000`000000iKj`000000040?O>XP050000003jej<0n]NS0?[GX`0000001P3oool00`00
0000oooo0?ooo`0W0?ooo`00@@3oool2000002T0oooo0`0000060:CNn`0300000038bm`0b<_L00D0
b<_L1@00000409Z^i08000000P01NMh00`000000BHo]04V?k@0204V?k@<00000103U_[02000000D0
mljR00<000000?[GX`3jej<00P3jej<00`000000oooo0?ooo`030?ooo`800000:03oool003h0oooo
1000000X0?ooo`8000000`2W[]`200000080Y=kk0P0000070<S;g0030000003<_Ld0000000L0VZkT
00<00000001Gd@0000000P00000704V?k@040000003U_[00iKj`0>Fn/0800000103gcZ800`000000
n]NS0?[GX`030?[GX`030000003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool003`0oooo
0P00000Z0?ooo`8000001`2W[]`2000000P0b<_L00@000000<bmc@3<_Ld00000202J[^@00`000000
05OA001Gd@02000000H0BHo]00@000000>Fn/03U_[00iKj`0P0000040?O>XP030000003jej<0n]NS
00<0n]NS0P0000050?ooo`8000009`3oool003T0oooo1000000X0?ooo`<000002@2W[]`00`000000
bkg=000000060<S;g0030000003<_Ld0c;g=0080c;g=00<0000009Z^i02J[^@01@2J[^@00`000000
05OA001Gd@02001Gd@8000001@19Snd010000000iKj`0>Fn/00000040?O>XP030000003jej<0n]NS
00<0n]NS00<000000?OQ/@0000001`3oool00`000000oooo0?ooo`0T0?ooo`00=P3oool3000002P0
oooo100000020:6Fb@030000002W[]`0YjkL00H0YjkL00D000000<^mc@3;_Ld0bkg=000000040<S;
g0030000003<_Ld0c;g=00@0c;g=00<0000009Z^i02J[^@0102J[^@3000000<005OA0`00000304V?
k@040000003U_[00iKj`000000@0mljR00<000000?[GX`3jej<00`3jej<010000000mn6a0?OQ/@00
00070?ooo`030000003oool0oooo02<0oooo000d0?ooo`80000000<0oooo0000003oool09@3oool3
000000H0XIK900<000000:N^g02W[]`01@2W[]`00`000000bkg=0<^mc@020<^mc@0500000038bm`0
b<_L0<S;g00000001`3<_Ld00`000000VZkT09Z^i00400000080YJGF0`000002001Gd@0400000000
Gm@0000000000080BHo]0`0000040?O>XP030000003jej<0n]NS0080n]NS00D000000?OQ/@3ghK40
mn6a000000060?ooo`8000001P3oool2000000@0oooo0P0000040?ooo`8000004@3oool00380oooo
0P00000X0?ooo`80000000<0X9G90000002QU/T01`2QU/T00`000000YjkL0:N^g0020:N^g0800000
1P3;_Ld00`000000b<_L000000090<bmc@8000001`2UYMH00`000000:V_K000000030000008005oD
100000001@3gcZ8000000?O>XP3gcZ80000000D0n]NS00<000000?OQ/@3ghK400P3ghK400`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000100oooo000b0?ooo`8000009P3oool2
000000@0X9G900<000000:6Fb@2QU/T01P2QU/T010000000YjkL0:N^g00000090<^mc@030000003<
_Ld0c;g=00L0c;g=00<000000<Zib@0000001`2UYMH00`000000:V_K02Y[f`0202Y[f`<000000P00
Gm@2000000050?O>XP000000mljR0?O>XP000000103jej<00`000000mn6a0?OQ/@030?OQ/@030000
003oool0oooo00D0oooo0P0000050?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo000b0?ooo`030000003oool000000280
oooo0`0000060:2Eb@030000002QU/T0XIK900H0XIK900<000000:N^g00000002@3;_Ld00`000000
e/G:000000070<bmc@040000003:^LT0b[W9000000P0YJGF1000000202Y[f`8000000`00Gm@01@00
0000mljR0000003gcZ80000000@0n]NS00<000000?OQ/@3ghK40103ghK400`000000oooo0?ooo`04
0?ooo`8000001P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool03P3oool00340oooo00D000000?ooo`3oool0oooo0000000O0?ooo`800000
00<0Y:SJ0000002PULT01`2PULT00`000000XIK90:6Fb@060:6Fb@030000003;_Ld0bkg=00L0bkg=
00@000000=K5bP3FaLX000001P3<_Ld00`000000b[W90<Zib@020<Zib@030000002UYMH0YJGF00<0
YJGF1@00000402Y[f`8000000P00Gm@010000000mljR0?O>XP0000040?[GX`030000003ghK40mn6a
00@0mn6a0P0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo000a0?ooo`8000000`3o
ool00`000000oooo0?ooo`0J0?ooo`800000102TZ=X00`000000X9G90:2Eb@050:2Eb@030000002Q
U/T0XIK900D0XIK900<000000<6gd00000001`3;_Ld00`000000e/G:0=K5bP020=K5bP030000003<
_Ld0c;g=0080c;g=00<000000<Zib@3:^LT00`3:^LT00`000000YJGF0:FUeP03000000040:FUeP00
000000000;2Wc`D0000000L0:V_K0000000000000000001Oe0000000mljR008000000`3jej<00`00
0000mn6a0?OQ/@030?OQ/@040000003Yk<l0jNc?000000H0oooo0`0000020?ooo`800000103oool2
000000@0oooo0P00000A0?ooo`00203oool2000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000040?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0F0?ooo`<000001P2TZ=X00`000000X9G90:2Eb@050:2Eb@030000002QU/T0XIK9
00@0XIK900@000000<6gd031]m0000001P3;_Ld00`000000e/G:0=K5bP040=K5bP040000003<_Ld0
c;g=000000H0b[W90`0000020:FUeP8000000`2`Yll00`000000IX[R06J:hP0206J:hPL0000000D0
n]NS0000003jej<0n]NS000000060?OQ/@040000003Yk<l0jNc?000000P0oooo00<000000?ooo`3o
ool07`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0A0?ooo`@000000P2SdoP00`000000Y:SJ0:BXfP050:BXfP030000002PULT0X9G900D0
X9G900@000000:6Fb@2QU/T0XIK90P0000040<6gd0030000003;_Ld0bkg=0080bkg=00<000000=K5
bP3FaLX01@3FaLX00`000000c;g=000000040<Zib@<0000000<0b[W90000002UYMH00P0000060;2W
c`030000001VR^80IX[R00@0IX[R100000020?[GX`030000003jej<0000000D0mn6a00<000000>W/
c`3Yk<l00P3Yk<l00`000000oooo0?ooo`050?ooo`800000803oool000L0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0000
00L0oooo00<000000?ooo`3oool03@3oool3000000H0Xm?h00<000000:BXfP2TZ=X01@2TZ=X00`00
0000X9G90:2Eb@050:2Eb@040000002QU/T0XIK9000000L0`KO@00@000000<^mc@3;_Ld000002@3F
aLX00`000000b[W90<Zib@03000000D0b[W900<000000;2Wc`2`Yll01P2`Yll00`000000IX[R06J:
hP0406J:hP0300000003K]d00fkM00<0000000<0n]NS0000003ghK40103ghK400`000000jNc?0>W/
c`030>W/c`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool000030?ooo`000000
0000008000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000<0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool4
00000080P^Kb0P0000060:?Cn0030000002TZ=X0Y:SJ00@0Y:SJ00<000000:2Eb@2PULT01P2PULT2
000000P0`KO@00<000000<^mc@0000002@3FaLX010000000eL_@0000000000070<Zib@0300000037
]l/0000000P0/:O?00<0000006J:hP1VR^80101VR^800`0000000fkM00=^g@0200=^g@800000103g
hK400`000000jNc?0>W/c`050>W/c`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3o
ool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000003
0?ooo`040000003oool0oooo0?ooo`8000002@3oool2000000D0oooo1000000708;VlP800000102S
doP00`000000Y:SJ0:BXfP050:BXfP030000002PULT0X9G900@0X9G90P00000:0<6gd0030000003F
aLX0e/G:00L0e/G:100000070<Zib@0400000037]l/0akO;000000P0/:O?00<0000006J:hP1VR^80
0P1VR^85000000@00fkM00D000000?OQ/@3ghK40mn6a000000070>W/c`030000003oool0oooo00D0
oooo0`00000N0?ooo`00203oool2000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo
0P0000040?ooo`<0000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`02000000@0R>Sc
2`0000030:?Cn0030000002TZ=X0Y:SJ00@0Y:SJ00<000000:2Eb@2PULT00P2PULT200000080Z;CQ
00<000000<6gd031]m001P31]m000`000000c]7K000000050=K5bP<00000103Ebm000`000000b[W9
0<Zib@020<Zib@8000001037]l/00`000000/:O?0;2Wc`060;2Wc`@00000102DX]h50000000400=^
g@000000mn6a000000H0jNc?0P0000000`2fj?H000000?ooo`070?ooo`030000003oool0oooo01`0
oooo000`0?ooo`030000003oool0oooo00/0oooo0P00000408SXl`<000000P2Yb_42000000D0CJgi
1@0000070:BXfP040000002PULT00000000000@0Z;CQ00<000000<6gd031]m001@31]m001P000000
c]7K0<kAf`3>dM/000000=K5bP<0000000<0e/G:0000003Ebm001@3Ebm0010000000b[W90<Zib@00
00060<Ngb`030000002`Yll0/:O?00@0/:O?0`00000809BRgP040000000hT?00>93`03R@l0<00000
1@3Yk<l2000000<0]^Sf00<000000?ooo`3oool01P3oool2000000H0oooo0`0000020?ooo`800000
103oool2000000X0oooo000`0?ooo`8000002@3oool9000000L0ZL[a0P00000404f]n@030000000Y
Tnl0:I?_00X000001`2X]>400`000000`KO@0<6gd0020<6gd08000000`3>dM/3000000<0e/G:00<0
00000=G;d03Ebm001@3Ebm000`000000b[W9000000080<Ngb`040000002`Yll0/:O?0;2Wc`800000
0`2iZl`00`000000U:;N09BRgP0609BRgP@0000000D0>93`00000000000000000>W/c`02000000H0
]^Sf00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`00<03oool00`00
0000oooo0?ooo`050?ooo`<000001P2Ybo400`000000bL;C000000080:W:l@@000000P1=[OT01@00
0000:I?_02VCk`0YTnl0000000H0KJ[e00<000000:Rdh@2X]>401P2X]>4010000000`KO@0<6gd000
00020<kAf`<000000`3>dM/00`000000e/G:000000090=G;d00300000037]l/0akO;00L0akO;00@0
00000;2Wc`00000000001@2iZl`00`000000U:;N09BRgP0409BRgP80000000@0/k3F0000001/[OL0
K:gg1@0000080;KXmP030000003oool0oooo00H0oooo0P0000030?ooo`D0000000D0oooo0000003o
ool0oooo000000020?ooo`040000003oool0oooo000000T0oooo000`0?ooo`030000003oool0oooo
0080oooo0`0000080:W;l@0500000039`]<0bL;C0<W2d`0000001@2Yb_4200000080[ZoI00<00000
06NHk00000001000000202VCk`030000001]Z_D0KJ[e00@0KJ[e00<000000:Rdh@2X]>401@2X]>40
0`000000`KO@00000003000000L0c]7K00<000000=G;d03Ebm001`3Ebm02000000X0akO;00<00000
0;V[c02iZl`01P2iZl`010000000U:;N09BRgP2DX]h2000000@0/k3F00<0000006b]m`1/[OL00P1/
[OL010000000K:gg0000000000070;KXmP030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool01`3oool002l0oooo00@000000?ooo`3oool0oooo0P0000020:BMc`030000002Ybo40
ZL_a00@0ZL_a0P0000050<W2d`030000002Yb_40ZL[a008000001@2^[mT00`000000IiS/06NHk002
06NHk0D000001@1]Z_D00`000000Z;CQ0:Rdh@050:Rdh@<00000203>dM/2000000030<ORk0000000
eL_@00H0eL_@00@000000<_>g@3;c]d000002037]l/2000000P0^J_<00@0000009BRgP0000000000
1`2c/=H00`000000K:gg06b]m`0206b]m`L000000`2fj?H00`000000oooo0?ooo`080?ooo`060000
003oool0oooo0000003oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000T0oooo000_0?ooo`040000003oool00000000000D0Y9g?0P0000030:W;l@0300000039
`]<0bL;C00H0bL;C0P0000070:j_f@030000001WV>`0IiS/00<0IiS/0P0000000`0<MN4000000000
000300000080KJ[e00<000000:Rdh@2X]>401000000209[Bn`030000003>dM/0c]7K00D0c]7K00<0
00000<ORk037h^`00P37h^`00`000000eL_@0=G;d0020=G;d08000000`3;c]d00`000000akO;0<Ng
b`040<Ngb`8000000P31]m400`000000^J_<0;V[c0060;V[c0030000002c/=H0/k3F00P0/k3F1@00
000309>nm080000000<0>ZKd0000000000000`0000080?ooo`8000000`3oool2000000<0oooo0P00
00040?ooo`8000002P3oool002l0oooo0P0000090:BMc`030000002Ybo40000000P0bL;C00<00000
0<fmb`000000202^[mT00`000000IiS/06NHk00206NHk0@0000000@037GQ0000000000008Y?/1P00
000609[Bn`030000003>dM/0c]7K0080c]7K0P0000050<ORk0050000003Ebm00eL_@0=G;d0000000
1P3;c]d00`000000akO;0<Ngb`020<Ngb`0300000031]m40`KOA0080`KOA00<000000;V[c02iZl`0
1@2iZl`00`000000`;3:000000080;>`eP0300000036^Ld0000000<0Tkkd00@0000009>nm02C__@0
Tkkd0P00000403ZVm0030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool002T0oooo
0P0000040?ooo`8000002P2TWLl00`000000bL;C0<W2d`060<W2d`050000003=_L/0cKg;0<fmb`00
0000202^[mT4000000<0S9_M200000000`0RTn`000000000000709[Bn`040000003>dM/000000000
00P0an;/00<000000=G;d00000001`3;c]d01@000000akO;0<Ngb`37]l/0000000D0`KOA00<00000
0;V[c02iZl`0102iZl`010000000`;3:0<2`bP0000070;>`eP0400000036^Ld0a[W=000000@0Tkkd
0`0000020:g7k@8000000`0jY_@00`000000oooo0?ooo`060?ooo`<00000603oool002P0oooo00@0
00000?ooo`3oool000000`3oool2000000T0Y9g?00<000000<blbP0000001P39`]<00`000000cKg;
0<fmb`020<fmb`030000002^[mT0[ZoI00@0[ZoI0P0000000`2aYlh0000008bKg@0508bKg@T00000
00<08Y?/000000000000102Jd_/3000000X0an;/0P0000090<_>g@<000001`31]m4010000000^J_<
0;V[c02iZl`2000000@0`;3:00<000000;>`eP2c/=H00P2c/=H2000000@0a[W=00<0000009>nm02C
__@00P0000050:g7k@8000000P0jY_@00`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0
oooo000X0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`0000001`2TWLl01@000000
c;c:0<blbP3<_<X0000000@0bL;C00<000000<fmb`3=_L/0103=_L/00`000000[ZoI0:j_f@020:j_
f@050000002aYlh0/JO>0;6WcP000000102<Vmd4000000@0B97_0P0000000`0ITnP0000000000005
000000<0KM7l0P0000060<ORk08000000P2Uho/00`000000blkM0<_>g@050<_>g@8000002@31]m40
10000000^J_<0;V[c00000070<2`bP040000002c/=H0/k3F000000L0a[W=0P0000020:g7k@030000
002]and0[LO]00<0[LO]0`0000000`0jY_@000000?ooo`080?ooo`8000005`3oool002P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000060:BMc`030000003<_<X0c;c:0080
c;c:00D000000<W2d`39`]<0bL;C000000080<fmb`040000002^[mT00000000000D0/JO>10000004
08bKg@0300000018TNl0B97_0080B97_2000000606gAo08000000P37h^`2000000@0YN?k00<00000
0<_>g@3;c]d00`3;c]d200000080/lc]00<000000<6gd@31]m401`31]m42000000P0`;3:00<00000
0;>`eP0000001`36^Ld00`000000dkg5000000030:g7k@030000002]and0[LO]0080000000<0_l_T
00000000>k000P00000;0?ooo`030000003oool0oooo01@0oooo000X0?ooo`040000003oool0oooo
00000080oooo0P0000020?ooo`030000002TWLl0Y9g?0080Y9g?00<000000<blbP3<_<X0103<_<X0
0`000000bL;C0000000:0<fmb`030000002aYlh0/JO>00<0/JO>1000000608bKg@D000000`28Zn`0
0`000000Ajkh04N^n00<000000L0YN?k00<000000<_>g@3;c]d00P0000050;?<k@0300000031]m40
`KOA00D0`KOA0P00000:0<2`bP0300000036^Ld0a[W=00D0a[W=00@000000=>ma@3C_LD00000102]
and2000000@0_l_T00@00000000k/000>k0000002@3oool2000000D0oooo0P0000040?ooo`800000
103oool2000000<0oooo000Y0?ooo`8000000`3oool00`000000oooo0?ooo`020?ooo`040000002T
WLl0Y9g?000000P0c;c:00<000000<fmb`3=_L/01`3=_L/2000000030<RkcP000000/JO>00<00000
0`2aYlh00`000000S9_M08bKg@0400000080Yj?B00<0000008R[k028Zn`01028Zn`2000000@0Ajkh
4P0000070;?<k@0300000031]m40`KOA00<0`KOA0P0000020;Rgf00300000030/<X0`;3:00H0`;3:
0P0000060<Jic@030000003C_LD0dkg50080dkg500<000000:g7k@0000000P0000040;o;i0050000
003;cM/00000000k/00000002`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`4000000@3oool10?ooo`00;P3oool0
0`000000oooo0?ooo`020?ooo`030000002TWLl0000000P0c;c:00<000000=S>c`0000001`3=_L/0
0`000000b;_>0<RkcP03000000L0/JO>0P0000070:NSdP0300000028Zn`0R:_/00D0R:_/10000004
07g5oP8000001@0`[n/2000000@0I/[m00<000000;?<k@2cc>d01P2cc>d00`000000`KOA0<6gd@02
000000@0^;OH00<000000<2`bP30/<X01@30/<X010000000a[C80<Jdb00000040<Jic@030000003C
_LD0dkg500@0dkg500D000000;o;i02obn@0_l_T000000020;o;i0030000003;cM/0blgK00800000
00<003^`0000003oool02@3oool2000000D0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`4000000@3oool10?ooo`00;P3oool2000000@0oooo00<000000<blbP3<
_<X01P3<_<X010000000f<k?0=S>c`3Hc/l2000000@0cKg;100000020<RkcP030000002aYlh0/JO>
00<0/JO>0P0000000`2dYl/000000:NSdP060:NSdP0300000028Zn`0R:_/00<0R:_/0P0000000`2_
]ml0000007g5oP0707g5oP/0000000<0I/[m000000000000102cc>d5000000L0^;OH00<000000<2`
bP30/<X00P30/<X2000000<0a[C800<000000<Jic@36^Ld00P36^Ld00`000000dkg50=>ma@030=>m
a@030000003K`;h0000000<0_l_T0P0000040<_=f`0300000000>k00000000/0oooo00@000000?oo
o`3oool0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool002h0oooo00<000000?ooo`3oool0103oool00`000000c;c:0<blbP040<blbP030000003H
c/l0f<k?00@0f<k?00<000000<fmb`0000000P0000060<RkcP050000002aYlh0/JO>0;6WcP000000
0`2dYl/00`000000Yj?B0:NSdP060:NSdP0300000028Zn`0R:_/00800000102_]ml200000080OLGn
100000030:?=mPL0000000<069SU0000000000001@00000408Rnn@030000002h]mP0^;OH00H0^;OH
00@000000<2`bP30/<X000001P36]<P010000000a[W=0<Jic@0000050=>ma@060000003K`;h0fl2n
0=_0_P000000_l_T0P0000050<_=f`80000000<003^`0000003oool02@3oool200000080oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo000]0?ooo`8000001`3oool00`000000c;c:0<blbP020<blbP030000003Hc/l0f<k?00D0f<k?
0`0000080<RkcP040000002aYlh00000000000D0]:O;00<000000:NSdP2WXm801P2WXm82000000P0
[kOO0P0000060:?=mP80000000@0^LkZ000000000000<JOa1@00000201RHi@0300000028__T0R;ki
00@0R;ki00<000000;Rgf02h]mP01P2h]mP00`000000`;3:000000070<Jdb00300000036^Ld00000
00H0dkg500<000000=_0_P3K`;h00P3K`;h010000000blgK0<_=f`0000030<_=f`030000003Cc]@0
dlkD008000001`3oool500000080oooo0`0000030?ooo`800000103oool2000000<0oooo000]0?oo
o`8000001`3oool01@000000c;c:0<blbP3<_<X0000000D0f<k?100000000`3Bg>0000000<RkcP08
0<RkcP030000002dYl/0]:O;00D0]:O;00<000000:NSdP2WXm80102WXm82000000030;VZb`000000
[kOO00D0[kOO0P0000000`33^m<00000000000030:?=mP8000001@2ic^X80000000301RHi@000000
R;ki00D0R;ki00<000000;Rgf02h]mP01@2h]mP2000000T0a[C800<000000=>ma@3C_LD0103C_LD0
0`000000fl2n0=_0_P020=_0_P030000003Q`KP000000080blgK00<000000<_=f`0000000`3Cc]@3
00000080oooo100000040?ooo`030000003oool0oooo0140oooo000]0?ooo`030000003oool0oooo
00L0oooo00<000000<blbP0000000`3Hc/l300000080f<k?00D000000=;Lh03Bg>00d]cP00000006
0<RkcP80000000<0_;_H0000002dYl/01P2dYl/010000000Yj?B0:NSdP2WXm82000000@0^J[;00<0
00000:ngg`2_]ml00P2_]ml00`000000`k_C0<>kd`030<>kd`<000001`2ic^X01@000000a/gP0000
00000000>jSe00H000001P28__T00`000000^;OH0;Rgf0020;Rgf080000000<0[;GO00000036]<P0
1`36]<P00`000000b[O8000000040=>ma@030000003K`;h0fl2n00<0fl2n00<000000>71^0000000
0`3;cM/00`000000dlkD0=?>e0030=?>e0@00000203oool00`000000oooo0?ooo`0A0?ooo`00;@3o
ool2000000T0oooo00<000000=S>c`0000000P0000030=S>c`800000103Bg>000`000000b;_>0<Rk
cP020<RkcP8000000`2l^mP00`000000]:O;0;BWb`050;BWb`040000002WXm800000000000L0^J[;
00@000000:ngg`00000000001P33^m<00`000000ckg9000000060;W>jP0300000036cN00a/gP0080
a/gP100000000`0kZ?D000000000000400000080R;ki00<000000;Rgf02h]mP00P0000040:beg`03
00000036]<P0a[C800@0a[C800@000000<Zgb03:]lP000000`3C_LD00`000000fl2n0=_0_P030=_0
_P060000003Q`KP0hL6h0>71^0000000blgK0P0000040=?>e0030000003Jc/h0000000800000203o
ool00`000000oooo0?ooo`0A0?ooo`000`3oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool01`3oool4
000000@0f<k?00<000000=;Lh03Bg>001@3Bg>0010000000b;_>0000000000060;bkf0030000002d
Yl/0]:O;00D0]:O;00<000000;VZb`2iZ//0202iZ//00`000000`k_C0<>kd`050<>kd`050000003?
_LT0ckg90<nmb@0000000`2ic^X2000000D0a/gP00@000000<k;e`000000B:_h1@00000204JMm@D0
00001P2/]Ml00`000000a[C80<Jdb0030<Jdb0030000003:]lP0b[O80080b[O800@000000=>ma@3C
_LD000001@3K`;h00`000000hL6h0>71^0020>71^0040000003Cc]@0dlkD00000080dlkD00@00000
0=[>cP3Jc/h0f/k>0`0000080?ooo`030000003oool0oooo0100oooo00020?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00@0oooo0`0000040?ooo`80000000<0f<k?0000003Bg>00203B
g>000`000000_;_H0;bkf0060;bkf0030000002dYl/0]:O;00<0]:O;0P0000000`2gZL/000000;VZ
b`070;VZb`0300000034[lD0000000D0`k_C00<000000<nmb@3?_LT00`3?_LT00`000000^LkZ0000
00060<K=h0050000003>bmL0c/_G0<k;e`0000001018ZoP2000000D0AYge00<000000:beg`2/]Ml0
1@2/]Ml01@000000a[C80<Jdb036]<P0000000D0b[O800<000000=>ma@0000001@3K`;h00`000000
hL6h0>71^0030>71^0040000003Cc]@0dlkD0=?>e08000000`3Jc/h5000000L0oooo00<000000?oo
o`3oool0403oool00080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo008000000`3oool3000000T0oooo0P0000070=;Lh080
000000<0Y^;k0000002l^mP01`2l^mP01@000000]:O;0;BWb`2dYl/0000000<0]jW;00<000000;VZ
b`2iZ//01@2iZ//010000000a:o50<B_a@0000040<>kd`030000003?_LT0ckg900D0ckg900<00000
0<K=h036cN000`36cN02000000D0c/_G2000000304JMm@030000002/]Ml0[;GO00D0[;GO00@00000
0<Jdb036]<P000001`3:]lP00`000000fl2n0=_0_P030=_0_P030000003Q`KP0hL6h00<0hL6h00<0
00000>G2/`0000000P3Cc]@2000000<0f/k>00H000000=k>b000000000000==U000000060?ooo`03
0000003oool0oooo0100oooo00020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000`3oool2000000<0oooo00<000000?ooo`0000000P00000>0?ooo`800000
0`3Bg>02000000@0Y^;k00<000000;bkf02l^mP01@2l^mP010000000]:O;0000000000050;NYb`03
0000002iZ//0^J[;00<0^J[;00<000000<B_a@34[lD00P34[lD010000000`k_C0<>kd`0000070<nm
b@030000003F_L80000000<0a/gP00<000000<k;e`3>bmL0103>bmL010000000dlW@000000000004
05J_nP<000000P16WOD00`000000[;GO0:beg`050:beg`8000001`3:]lP2000000D0fl2n00<00000
0>71^03Q`KP00`3Q`KP01`000000iL:c0000003Cc]@000000=[>cP0000000P3Jc/h00`000000g/k8
0=k>b004000000H0oooo00<000000?ooo`3oool0403oool00080oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0P00
000C0?ooo`@000001@2Vh_/00`000000_;_H0;bkf0050;bkf08000001`2gZL/00`000000^J[;0;VZ
b`020;VZb`0300000034[lD0a:o500<0a:o500<000000<>kd`0000001`3?_LT01`000000e[g20=Jm
`P3F_L8000000<K=h00000001P3>bmL00`000000dlW@0=?9d0020=?9d0X00000102/]Ml4000000L0
b[O800@000000<jja`3>^/L000000`3K`;h00`000000hL6h0>71^0030>71^0050000003U`[<0iL:c
0>G2/`0000000`3Jc/h2000000@0g/k80P0000000`3CI@0000000?ooo`040?ooo`030000003oool0
oooo0100oooo00030?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo0`0000030?ooo`030000003oool0oooo01D0oooo1@000000102Vh_/000000;bkf02l^mP4
00000080Y;OV00<000000;NYb`2gZL/01@2gZL/010000000^J[;0;VZb`0000070<B_a@030000003?
_LT0ckg900D0ckg900<000000=Jm`P3F_L800`3F_L800`000000c/_G0<k;e`040<k;e`030000003C
bM00dlW@0080dlW@00<000000=O7bP000000101T/_/200000003001/fP000000000000<00000102M
/NH00`000000b[O80<Zgb0040<Zgb0040000003>^/L0c[[7000000<0fl2n00<000000>71^03Q`KP0
0`3Q`KP010000000iL:c0>G2/`3U`[<200000080f/k>0P0000040=k>b0@000001@3oool00`000000
oooo0?ooo`0@0?ooo`00;P3oool2000001P0oooo1P0000060:BgiP030000002gZL/0]jW;00D0]jW;
00<000000;VZb`0000001`34[lD00`000000c;?1000000050<nmb@030000003F_L80e[g200<0e[g2
00<000000=Zm_@000000103>bmL00`000000dlW@0=?9d0020=?9d0050000003GalX0elO:0=O7bP00
00001@1T/_/200000003001/fP000000WK7V00D0WK7V00<000000<Zgb03:]lP00`3:]lP00`000000
c[[70<jja`020<jja`030000003K`;h0000000D0hL6h00D000000>G2/`3U`[<0iL:c000000020>S3
[`040000003Jc/h00000000000<0g/k800H000000?ooo`00000000000==U000000040?ooo`030000
003oool0oooo0100oooo000`0?ooo`030000003oool0oooo01L0oooo0P0000000`0@V=d000000:Bg
iP060:BgiP030000002gZL/0]jW;00D0]jW;00<000000<B_a@34[lD01@34[lD01@000000c;?10<bc
`@3</l40000000@0ckg900<000000=Jm`P3F_L800`3F_L800`000000f[fm0=Zm_@02000000030<k;
e`000000dlW@00<0dlW@00<000000=O7bP3GalX00`3GalX800000003001/fP000000WK7V00D0WK7V
00D000000<Zgb03:]lP0b[O8000000050<jja`030000003K`;h0000000D0hL6h00D000000>G2/`3U
`[<0iL:c000000030>S3[`040000003Nc/P0g/k800000080g/k800<000000?ooo`3oool00`000004
0?ooo`030000003oool0oooo0100oooo000a0?ooo`030000003oool0oooo01P0oooo100000050:Bg
iP030000002gZL/0]jW;00<0]jW;0P0000000`2i[Ld000000<B_a@050<B_a@050000003</l40c;?1
0<bc`@0000000`3?_LT00`000000e[g20=Jm`P030=Jm`P030000003J_Kd0f[fm00<0f[fm00<00000
0=?9d03CbM000`3CbM000`000000elO:0=O7bP020=O7bP040000003Ja/D00000000000@0LKKk0`00
000709faiP030000003:]lP0000000L0c[[700<000000>71^03Q`KP00`3Q`KP01@000000iL:c0>G2
/`3U`[<0000000@0j<>_0P0000020=k>b08000000`3oool3000000D0oooo00<000000?ooo`3oool0
3`3oool00380oooo00<000000?ooo`3oool06@3oool3000000D0Y;OV00D000000;NYb`2gZL/0]jW;
000000030;V]c@0300000034[lD0a:o500<0a:o500<000000<bc`@3</l400`3</l400`000000ckg9
000000050=Jm`P030000003J_Kd0f[fm00<0f[fm00<000000=fm^@0000000`3CbM000`000000elO:
0=O7bP020=O7bP030000003Ja/D0f/K50080f/K52000000609faiP030000003:]lP0000000H0c[[7
00<000000=6ma`000000103Q`KP01@000000iL:c0>G2/`3U`[<0000000<0j<>_00<000000>_3[000
00000P3Nc/P2000000@0oooo0`0000040?ooo`030000003oool0oooo00l0oooo000c0?ooo`030000
003oool0oooo01X0oooo100000020:BgiP040000002gZL/00000000000D0^Jg=00D000000<B_a@34
[lD0a:o5000000070<bc`@030000003F_L80e[g200@0e[g200<000000=Zm_@3J_Kd00`3J_Kd01P00
0000gKfi0=fm^@000000dlW@000000@0elO:00<000000=[6a@3Ja/D00P3Ja/D00`000000g<G20000
000407fin@0300000000>;40000000L000001P3>^/L01@000000dKg70=6ma`3A_LL000000080hL6h
00<000000>G2/`3U`[<00P3U`[<01@000000j<>_0>S3[`3X`jl000000080jl>/00@000000=k>b000
000000001@3oool2000000@0oooo00<000000?ooo`3oool03`3oool003@0oooo0P00000L0?ooo`03
0000001bYo80000000<00000202i[Ld00`000000a:o5000000070<bc`@030000003B][h0000000@0
e[g200<000000=Zm_@3J_Kd00`3J_Kd00`000000gKfi0=fm^@020=fm^@030000003GalX0elO:00<0
elO:00<000000=[6a@3Ja/D00P3Ja/D010000000g<G20=c5`P00000407fin@<000001P29Zn`00`00
0000c[[70<jja`020<jja`030000003A_LL0dKg70080dKg700@000000>71^03Q`KP000000`3U`[<0
0`000000j<>_0>S3[`020>S3[`050000003[`j`0jl>/0>_3[00000000P3oool00`000000oooo0?oo
o`020?ooo`<000000`3oool00`000000oooo0?ooo`0?0?ooo`00=P3oool00`000000oooo0?ooo`0J
0?ooo`050000001bYo80LZOb07:WlP000000202i[Ld00`000000a:o5000000070<bc`@040000003B
][h0d[Jn00000080e[g200<000000=Zm_@3J_Kd00`3J_Kd00`000000gKfi0=fm^@020=fm^@030000
003P_KD0000000<0elO:00<000000=[6a@3Ja/D00P3Ja/D00`000000g<G20=c5`P020=c5`P@00000
00<0oooo0000000000001P29Zn`00`000000c[[70<jja`020<jja`030000003A_LL0dKg700<0dKg7
0P0000040>G2/`050000003X`jl0j<>_0>S3[`000000103[`j`01@000000oooo0?ooo`3oool00000
00@0oooo0P0000030?ooo`030000003oool0oooo00l0oooo000g0?ooo`030000003oool0oooo01X0
oooo00D0000007:WlP1bYo80LZOb000000080;V]c@030000003</l40c;?100D0c;?100<000000=:f
_P3B][h00P3B][h00`000000e[g2000000050=Zm_@030000003M_KT0gKfi0080gKfi00H000000>2m
]@3P_KD000000=O7bP0000040=[6a@030000003LaL80g<G20080g<G200<000000?ooo`3oool0103o
ool2000000H0RJ_/00@000000<jja`3>^/L000001`3A_LL00`000000iL:c0>G2/`020>G2/`050000
003X`jl0j<>_0>S3[`0000000`3[`j`00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo0P0000030?ooo`030000003oool0oooo00l0oooo000h0?ooo`030000003oool0oooo01X0oooo
00@0000007:WlP1bYo8000001P2i[Ld2000000030;V`d0000000c;?100@0c;?100<000000=:f_P3B
][h0103B][h00`000000f[fm0=Zm_@030=Zm_@030000003M_KT0gKfi0080gKfi00<000000>2m]@3P
_KD00P3P_KD00`000000f/K50=[6a@030=[6a@030000003LaL80g<G20080g<G200<000000?ooo`3o
ool01@3oool500000080RJ_/00<000000<jja`0000001`3A_LL00`000000dko7000000020>G2/`03
0000003X`jl0j<>_0080j<>_00D000000>_3[03[`j`0jl>/000000050?ooo`030000003oool0oooo
0080oooo0P0000020?ooo`030000003oool0oooo00l0oooo000i0?ooo`8000006`3oool200000003
07:WlP000000^Jg=0080^Jg=0P0000030;V`d0030000003</l40c;?100<0c;?100<000000=:f_P3B
][h00`3B][h00`000000e[Rl000000040=Zm_@030000003M_KT0gKfi0080gKfi00<000000>2m]@3P
_KD00P3P_KD2000000<0f/K500<000000=c5`P3LaL800P3LaL800`000000oooo0?ooo`070?ooo`80
00000P1aXNl4000000L0dKg700@000000=>oa`3C_lL000000P3U`[<01@000000j<>_0>S3[`3X`jl0
000000<0jl>/00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo00000140oooo000k0?ooo`030000003oool0oooo01T0oooo0`0000000`2i[Ld0000000000006
0;V`d0050000003</l40c;?10<bc`@0000001P3B][h00`000000e[Rl000000030=Zm_@030000003M
_KT0gKfi0080gKfi00<000000>2m]@3P_KD00P3P_KD00`000000h[fc000000020=[6a@030000003L
aL80g<G200<0g<G200<000000?ooo`3oool0203oool00`000000LJ7_076Qk`04076Qk`030000003A
_LL0dKg700<0dKg700<000000=>oa`3C_lL00P3C_lL2000000@0j<>_00D000000>_3[03[`j`0jl>/
000000080?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0403oool003`0oooo
00<000000?ooo`3oool06@3oool00`0000006W[U000000090;V`d0030000003</l40000000H0d[Jn
00L000000=Jh_03F^;`0e[Rl0000003J_Kd0000000D0gKfi00<000000>2m]@3P_KD00P3P_KD01P00
0000h[fc0>:m/`000000f/K5000000@0g<G200<000000?ooo`3oool02P3oool00`000000LJ7_076Q
k`03076Qk`030000003A_LL0dKg70080dKg700<000000=>oa`3C_lL0103C_lL00`000000j<>_0>S3
[`020>S3[`050000003[`j`0jl>/0>_3[0000000203oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo00000100oooo000m0?ooo`030000003oool0oooo01T0oooo00<0000001Yji@000000
202i/=000`000000c;?1000000050=:f_P030000003F^;`0e[Rl0080e[Rl00<000000=Zm_@000000
103M_KT00`000000h;fe0>2m]@020>2m]@030000003R_K<0h[fc0080h[fc00<000000=c5`P3LaL80
0`3LaL800`000000oooo0?ooo`0:0?ooo`<00000101aXNl010000000dKg70=6ma`0000060=>oa`03
0000003D`LL000000080j<>_00D000000>_3[03[`j`0jl>/0000000:0?ooo`040000003oool0oooo
0?ooo`80000000<0oooo0000003oool03`3oool003h0oooo00<000000?ooo`3oool06@3oool00`00
00006W[U000000070;V`d08000001@3B][h00`000000e[Rl0=Jh_0040=Jh_0030000003M_KT0gKfi
00<0gKfi00<000000>2m]@3P_KD00P3P_KD00`000000h[fc0>:m/`020>:m/`8000000`3LaL800`00
0000oooo0?ooo`0<0?ooo`L0000000<0dKg70000003C_lL01@3C_lL010000000e<770=C1a`000002
0>S3[`050000003[`j`0jl>/0>_3[00000002`3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000403oool003l0oooo0P00000I0?ooo`<000001@2i/=0200000080^K;C00<000000=:f_P3B][h0
0P3B][h00`000000e[Rl0=Jh_0030=Jh_0030000003I^KX0000000<0gKfi00<000000>2m]@3P_KD0
0P3P_KD00`000000h[fc0>:m/`020>:m/`030000003S_K40hkfa0080000000<0g<G20000003oool0
3P3oool00`000000E9?^05BCkP0205BCkP8000001P3C_lL00`000000e<770=C1a`020=C1a`030000
003X`jl000000080jl>/00<000000?ooo`3oool02`3oool01P000000oooo0?ooo`000000oooo0000
0100oooo00110?ooo`030000003oool0oooo01L0oooo00<00000000`Z`0000000P2i/=02000000@0
^K;C00D000000=:f_P3B][h0d[Jn000000060=Jh_0040000003I^KX0fKVj00000080gKfi00<00000
0>2m]@3P_KD00P3P_KD00`000000h[fc0>:m/`020>:m/`030000003S_K40hkfa0080hkfa00<00000
0?ooo`3oool03`3oool00`000000E9?^05BCkP0305BCkP030000003C_lL0dko70080dko700<00000
0=C1a`3D`LL00`3D`LL2000000<0jl>/00<000000?ooo`3oool02`3oool010000000oooo0?ooo`3o
ool200000100oooo00120?ooo`030000003oool0oooo01L0oooo00@00000000`Z`00000000001`2i
/]<00`000000d[Jn000000060=Jh_0030000003I^KX0fKVj0080fKVj0P0000040>2m]@030000003R
_K<0h[fc0080h[fc00<000000>>m/@3S_K400`3S_K400`000000oooo0?ooo`0@0?ooo`8000000`1D
Tnh00`000000dko70=>oa`020=>oa`030000003D`LL0e<7700@0e<7700D000000>_3[03[`j`0jl>/
0000000>0?ooo`030000003oool0oooo00800000403oool004<0oooo00<000000?ooo`3oool05`3o
ool00`000000032[000000070;Vbd`030000003B][h0000000H0e[Rl00<000000=Vi^P3I^KX00`3I
^KX00`000000h;fe0>2m]@020>2m]@030000003R_K<0h[fc0080h[fc00<000000>>m/@3S_K400P3S
_K400`000000oooo0?ooo`0B0?ooo`<000000P1DTnh010000000dko70=>oa`0000060=C1a`800000
0P3[`j`00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo00000100oooo00140?ooo`800000
603oool00`000000032[000000070;Vbd`030000003F^;`0e[Rl00@0e[Rl00<000000=Vi^P3I^KX0
0`3I^KX00`000000fkZh000000020>2m]@030000003R_K<0h[fc00<0h[fc00<000000>>m/@3S_K40
0P3S_K400`000000oooo0?ooo`0B0?ooo`030000000dP^T0=8;Y00<0000000<0dko70000003D`LL0
1@3D`LL01P000000e/;70=K2a`000000jl>/00000100oooo00@000000?ooo`3oool00000403oool0
04H0oooo00<000000?ooo`3oool05P3oool2000000D0^K;C0P0000000`2g]=L000000=Jh_0030=Jh
_0030000003I^KX0fKVj00@0fKVj00<000000=^j^00000000P3P_KD00`000000h[fc0>:m/`020>:m
/`030000003S_K40hkfa0080hkfa00<000000?ooo`3oool0503oool010000000=8;Y03B2j@0dP^T2
000000H0e<7700@000000=K2a`3F`/L0e/;70P00000B0?ooo`040000003oool0oooo000000l0oooo
00170?ooo`030000003oool0oooo01L0oooo00<000000;Vbd`2i/]<00P0000040;Nde`050000003F
^;`0e[Rl0=Jh_00000001@3I^KX010000000fkZh0=^j^03K^[P2000000D0h[fc00<000000>>m/@3S
_K400P3S_K400`000000oooo0?ooo`0E0?ooo`030000000dP^T0=8;Y0080=8;Y00<000000=C1a`3D
`LL00P3D`LL00`000000e/;70=K2a`030=K2a`030000003oool0oooo0140oooo00<000000?ooo`00
00003`3oool004P0oooo00<000000?ooo`3oool05`3oool2000000H0]kCG00@000000=Jh_03F^;`0
00001P3I^KX00`000000fkZh0=^j^0020=^j^0030000003R_K<0h[fc00<0h[fc00D000000>>m/@3S
_K40hkfa0000000I0?ooo`8000000P0dP^T00`000000e<770=C1a`020=C1a`030000003F`/L0e/;7
0080e/;700<000000?ooo`3oool04`3oool2000000l0oooo00190?ooo`030000003oool0oooo01L0
oooo00<000000;Nde`2g]=L01@2g]=L00`000000e[Rl000000050=Vi^P030000003K^[P0fkZh0080
fkZh00<000000=bk]`0000000`3R_K<00`000000hkfa0>>m/@020>>m/@030000003oool0oooo01L0
oooo00H0000001=^g`000000000003B2j@0000020=C1a`030000003F`/L0e/;70080e/;700<00000
0?ooo`3oool0503oool2000000l0oooo001:0?ooo`8000005`3oool2000000L0]kCG00<000000=Vi
^P3I^KX0103I^KX00`000000fkZh0=^j^0020=^j^0040000003L^kL0g;^g00000080h[fc00<00000
0>>m/@3S_K400P3S_K400`000000oooo0?ooo`0H0?ooo`030000000CK]l04fkO0080000000<0e<77
0000003F`/L0103F`/L00`000000oooo0?ooo`0D0?ooo`8000003`3oool004`0oooo00<000000?oo
o`3oool05@3oool00`000000]kCG0;Nde`030;Nde`80000000<0];KJ0000003I^KX00`3I^KX00`00
0000fkZh0=^j^0020=^j^0030000003L^kL0g;^g0080g;^g0P0000040>>m/@030000003oool0oooo
01X0oooo00D0000001=^g`0CK]l04fkO000000050=K2a`030000003oool0oooo0140oooo1000000A
0?ooo`00C@3oool00`000000oooo0?ooo`0E0?ooo`030000002g]=L0]kCG00800000102d]]X01@00
0000fKVj0=Vi^P3I^KX0000000@0fkZh00<000000=bk]`3L^kL00`3L^kL00`000000hkfa0>>m/@02
0>>m/@030000003oool0oooo01/0oooo0P00000201=^g`050000003F`/L0e/;70=K2a`000000403o
ool4000001D0oooo001>0?ooo`030000003oool0oooo01D0oooo0P0000060;BffP040000003I^KX0
fKVj000000@0fkZh00<000000=bk]`3L^kL00`3L^kL00`000000g[bg000000020>>m/@030000003o
ool0oooo01h0oooo0`0000020=K2a`030000003oool0oooo00/0oooo1000000I0?ooo`00C`3oool2
000001H0oooo00<000000;BffP2d]]X01@2d]]X00`000000fKVj000000040=^j^0030000003L^kL0
g;^g00<0g;^g00<000000=jl]`0000000P3S_K400`000000oooo0?ooo`0P0?ooo`80000000<0e/;7
0000003oool02@3oool3000001d0oooo001A0?ooo`030000003oool0oooo01<0oooo00<000000;Bf
fP2d]]X01@2d]]X2000000@0fkZh00<000000=bk]`3L^kL00`3L^kL010000000g[bg0=jl]`3N_;L2
000002D0oooo00<000000?ooo`3oool01@3oool400000200oooo001B0?ooo`030000003oool0oooo
01<0oooo00<000000;BffP2d]]X00P2d]]X200000080/;SO00D000000=^j^03K^[P0fkZh00000005
0=bk]`030000003N_;L0g[bg0080g[bg00<000000?ooo`3oool09`3oool4000002@0oooo001C0?oo
o`030000003oool0oooo0180oooo00<000000;BffP2d]]X00P0000040;2hg`040000003K^[P0fkZh
000000D0g;^g00<000000=jl]`3N_;L00P3N_;L00`000000oooo0?ooo`0T0?ooo`@00000:03oool0
05@0oooo0P00000B0?ooo`<000001`2`^=l00`000000fkZh000000040=bk]`030000003N_;L0g[bg
00<0g[bg00<000000?ooo`3oool08@3oool3000002`0oooo001F0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`0000001`2`^=l2000000D0g;^g00<000000=jl]`3N_;L00P3N_;L00`000000
oooo0?ooo`0N0?ooo`@00000;`3oool005L0oooo00<000000?ooo`3oool03P3oool010000000oooo
0?ooo`0000060;2hg`800000103L^kL00`000000g[bg0=jl]`030=jl]`030000003oool0oooo01X0
oooo1000000c0?ooo`00F03oool00`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`00
00000P2`^=l300000080Z[SS00D000000=bk]`3L^kL0g;^g000000040=jl]`030000003oool0oooo
01L0oooo1000000g0?ooo`00F@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo0P0000050:Zhh`040000003L^kL0g;^g000000D0g[bg00<000000?ooo`3oool0503oool30000
03/0oooo001J0?ooo`800000303oool00`000000oooo0?ooo`030?ooo`030000002Z^><0Z[SS00@0
Z[SS00<000000=bk]`000000103N_;L00`000000oooo0?ooo`0A0?ooo`@00000?P3oool005`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000002Z^><0Z[SS0080Z[SS
0`0000050=jl]`030000003oool0oooo00d0oooo100000120?ooo`00G@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00D0oooo100000030:>hj0050000003N_;L0g[bg0=jl]`000000
303oool4000004H0oooo001N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000XkSX0:>hj0040:>hj0040000003N_;L0g[bg000000T0oooo0`00001:0?ooo`00G`3o
ool2000000L0oooo00<000000?ooo`3oool01`3oool00`000000XkSX0:>hj0040:>hj08000001P3o
ool4000004d0oooo001Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool0
0`000000XkSX0:>hj0020:>hj0<000000P3oool400000540oooo001R0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02@3oool4000000030?ooo`000000000000800000E@3oool006<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`<00000F@3oool006@0oooo
00D000000?ooo`3oool0oooo000000090?ooo`@00000G03oool006D0oooo0P0000000`3oool00000
0?ooo`040?ooo`@00000H03oool006L0oooo0P0000000`3oool0000000000002000006@0oooo001X
0?ooo`800000J03oool00=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3oool00=80
oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3oool00=80oooo003B0?ooo`00dP3oool0
0=80oooo003B0?ooo`00dP3oool00001\
\>"],
  ImageRangeCache->{{{0, 209.938}, {170.063, 0}} -> {-0.28566, -0.12371, \
0.00636156, 0.00636156}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["Example 4", "Subsubsection",
  Background->None],

Cell["Boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''\)[x] + Pi^2*y[x] \[Equal] Cos[Pi*x], 
        y[0] \[Equal] y[1], \(y'\)[0] \[Equal] \(y'\)[1]}\)], "Input",
  CellLabel->"In[14]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\[Pi]\^2\ y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], 
          "==", \(Cos[\[Pi]\ x]\)}], ",", \(y[0] == y[1]\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "1", "]"}]}]}], "}"}]], "Output",\

  CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
Trying to find polynomial approximation for solution of the BVP.\
\>", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[15]:=",
  Background->None],

Cell[BoxData[
    \(LdeApprox::"nopoly" \(\(:\)\(\ \)\) 
      "\!\(Cos[\(\(\[Pi]\\ x\)\)]\) is not a polynomial on \!\(x\)"\)], \
"Message",
  CellLabel->"From In[15]:="],

Cell[BoxData[
    \($Aborted\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["ToRatCoeffs",
    FontFamily->"Courier New"],
  " function to get rational coefficients of the LDE on interval ",
  StyleBox["[0,1]",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp1 = {ToRatCoeffs[\(y''\)[x] + Pi^2*y[x] \[Equal] Cos[Pi*x], 
          y[x], {x, 0, 1}, 5, 0], 
        y[0] \[Equal] y[1], \(y'\)[0] \[Equal] \(y'\)[1]}\)], "Input",
  CellLabel->"In[16]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\[Pi]\^2\ y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], 
          "==", \(1.0001342309422214318481148464`15.9546 - 
            0.0099145554925265925695493424`15.9546\ x - 
            4.8041073454421110984593134078`15.9546\ x\^2 - 
            0.6871096821507181565414723053`15.9546\ x\^3 + 
            5.8347718686681882173706381565`15.9546\ x\^4 - 
            2.333908747467275232931148412728517`15.9546\ x\^5\)}], 
        ",", \(y[0] == y[1]\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "1", "]"}]}]}], "}"}]], "Output",\

  CellLabel->"Out[16]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp1, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[17]:=",
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 
          2.00453730873679948121230573`14.4231*^-7 - 
            0.2500309408176085757577293556`14.4231\ x + 
            0.5009320863889717789872030318`14.4231\ x\^2 + 
            0.400741462529876925379498237`14.4231\ x\^3 - 
            0.7666197116288223181203298484`14.4231\ x\^4 - 
            0.3642012524584007622323843234`14.4231\ x\^5 + 
            0.6708491371099296845365543562`14.4231\ x\^6 - 
            0.1916711820314084796621108275`14.4231\ x\^7}}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[18]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(\(-2\)\ Cos[\[Pi]\ x] + 2\ Cos[\[Pi]\ x]\^3 - \[Pi]\ \
Sin[\[Pi]\ x] + 2\ \[Pi]\ x\ Sin[\[Pi]\ x] + Sin[\[Pi]\ x]\ Sin[2\ \[Pi]\ \
x]\)\/\(4\ \[Pi]\^2\)}}\)], "Output",
  CellLabel->"Out[18]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr)\), {x, 0, 1}, 
      PlotRange \[Rule] {\(-10^\((\(-6\))\)\), 10^\((\(-6\))\)}]\)], "Input",
  CellLabel->"In[19]:=",
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -39 -6.25 ]
[.01131 0 0 6.25 ]
[.01131 .07725 -51 -6.25 ]
[.01131 .07725 0 6.25 ]
[.01131 .15451 -39 -6.25 ]
[.01131 .15451 0 6.25 ]
[.01131 .23176 -51 -6.25 ]
[.01131 .23176 0 6.25 ]
[.01131 .38627 -45 -6.25 ]
[.01131 .38627 0 6.25 ]
[.01131 .46353 -33 -6.25 ]
[.01131 .46353 0 6.25 ]
[.01131 .54078 -45 -6.25 ]
[.01131 .54078 0 6.25 ]
[.01131 .61803 -33 -6.25 ]
[.01131 .61803 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
gsave
.01131 0 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .07725 m
.03006 .07725 L
s
gsave
.01131 .07725 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .15451 m
.03006 .15451 L
s
gsave
.01131 .15451 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .23176 m
.03006 .23176 L
s
gsave
.01131 .23176 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .38627 m
.03006 .38627 L
s
gsave
.01131 .38627 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .46353 m
.03006 .46353 L
s
gsave
.01131 .46353 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .54078 m
.03006 .54078 L
s
gsave
.01131 .54078 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .61803 m
.03006 .61803 L
s
gsave
.01131 .61803 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .24707 m
.02846 .28724 L
.03279 .31418 L
.03527 .32573 L
.03754 .33404 L
.03879 .33781 L
.04015 .34128 L
.04142 .34398 L
.04262 .34605 L
.04386 .34777 L
.045 .34896 L
.04626 .3499 L
.04696 .35025 L
.04762 .35047 L
.04894 .35063 L
.05016 .35045 L
.05086 .35022 L
.0515 .34992 L
.05293 .34901 L
.05415 .34795 L
.05528 .34678 L
.05783 .3435 L
.06244 .33577 L
.08253 .29232 L
.08803 .28165 L
.09393 .27217 L
.09679 .26846 L
.0995 .26552 L
.10192 .26341 L
.1032 .26248 L
.10458 .26164 L
.10586 .26101 L
.10704 .26056 L
.10816 .26024 L
.10934 .26002 L
.1106 .25992 L
.11176 .25995 L
.11304 .26013 L
.11375 .26029 L
.1144 .26048 L
.11557 .26091 L
.11665 .26141 L
.11908 .26292 L
.12122 .26467 L
.12349 .26696 L
.12855 .2736 L
.13329 .28166 L
.14407 .30595 L
.16435 .36859 L
.18289 .43534 L
Mistroke
.20352 .50752 L
.21356 .5384 L
.22265 .56277 L
.23156 .58276 L
.24118 .59958 L
.24647 .60662 L
.25134 .61168 L
.25599 .61524 L
.25833 .61656 L
.25966 .61717 L
.2609 .61765 L
.2621 .61803 L
Mfstroke
.2621 .61803 m
.26211 .61803 L
s
.27235 .61803 m
.27349 .61768 L
.27564 .61683 L
.27795 .61566 L
.28045 .61408 L
.28574 .60972 L
.29134 .60369 L
.30137 .58958 L
.32099 .55206 L
.33931 .50932 L
.37819 .41534 L
.39798 .375 L
.40842 .35731 L
.41952 .34158 L
.42934 .33039 L
.44019 .32093 L
.44494 .31771 L
.45006 .31483 L
.45454 .31278 L
.45933 .31104 L
.46192 .31028 L
.46428 .3097 L
.46889 .30882 L
.47147 .30847 L
.47283 .30833 L
.47427 .3082 L
.47552 .30811 L
.47691 .30804 L
.47817 .30799 L
.47935 .30795 L
.48065 .30794 L
.48139 .30793 L
.48207 .30794 L
.48332 .30795 L
.48402 .30796 L
.48466 .30798 L
.48586 .30802 L
.48716 .30807 L
.48951 .3082 L
.4952 .30861 L
.50044 .30906 L
.50514 .30946 L
.50773 .30966 L
.51018 .30982 L
.51246 .30994 L
.51367 .31 L
.51494 .31004 L
.51601 .31007 L
.51719 .31009 L
.51827 .3101 L
Mistroke
.51928 .3101 L
.52049 .31008 L
.52181 .31005 L
.52247 .31002 L
.52319 .30999 L
.52447 .30992 L
.52696 .30972 L
.52923 .30948 L
.53187 .30909 L
.53474 .30855 L
.53995 .30722 L
.54484 .30551 L
.54942 .30347 L
.55984 .29708 L
.56999 .28832 L
.58089 .27594 L
.60208 .24294 L
.62218 .20187 L
.66045 .1093 L
.68182 .05995 L
.70116 .02451 L
.71088 .01178 L
.71635 .00643 L
.71895 .00439 L
.72137 .00278 L
.72368 .00152 L
.72578 .00061 L
.7269 .00022 L
Mfstroke
.7269 .00022 m
.72769 0 L
s
.73786 0 m
.73813 7e-005 L
.74037 .00088 L
.74295 .00216 L
.74539 .00372 L
.74995 .00756 L
.75485 .01302 L
.76016 .02049 L
.76974 .03792 L
.77855 .05826 L
.81802 .18602 L
.83787 .25709 L
.85598 .31221 L
.86078 .32396 L
.86599 .33501 L
.8705 .34297 L
.87548 .3499 L
.8782 .35282 L
.88075 .35499 L
.88344 .35667 L
.88495 .35733 L
.88562 .35756 L
.88634 .35777 L
.88755 .358 L
.88868 .35811 L
.88937 .35812 L
.89002 .35808 L
.89124 .35793 L
.89252 .35762 L
.89371 .3572 L
.89501 .35661 L
.89639 .35581 L
.89892 .35395 L
.90132 .35168 L
.90582 .3462 L
.91596 .32879 L
.93427 .28878 L
.93922 .27925 L
.94164 .27531 L
.94387 .27225 L
.94645 .26953 L
.94781 .26851 L
.94849 .26812 L
.94924 .26778 L
.95046 .26745 L
.95176 .26744 L
.95299 .26777 L
.9541 .26837 L
.95525 .2693 L
.95646 .27067 L
Mistroke
.95749 .27216 L
.95863 .27416 L
.96117 .28012 L
.96356 .28776 L
.96786 .30731 L
.97028 .32199 L
.9725 .33806 L
.97619 .37096 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[19]:=",
  ImageSize->{223.188, 137.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003O0000RB000`400?l00000o`00003og`3oool0
0=l0oooo003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3o
ool00=l0oooo000C0?ooo`D0000000<0oooo0000003oool00P3oool00`000000oooo000000040000
0080oooo0P00002g0?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0;@0oooo000E0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0]03oool000d0oooo100000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0]03oool001D0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`00000<0?ooo`800000MP3oool6000002`0oooo000D
0?ooo`8000002P3oool2000000@0oooo0P00000=0?ooo`030000003oool0oooo07D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0Z0?ooo`00<03oool00`30`<00/;2`092@T0020?oo
o`030000003oool0oooo07@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Y0?oo
o`00<03oool00`2PX:00oooo0<30`0020?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0X0?ooo`00:P3oool0103Ph>00P8200820P020P8020?ooo`03
061PH02@T900X:2P0080oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo02L0oooo000`0?ooo`030:2PX03oool0oooo0080oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo000a0?ooo`050:2PX02`
/;00oooo0?ooo`000000L`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo
000e0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0V0?ooo`00=@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool09P3oool003D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02D0oooo00090?ooo`030000003oool0oooo0080oooo0P0000040?ooo`80
00000`3oool01P000000oooo0?ooo`3oool000000?ooo`D000000P3oool2000000d0oooo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02D0oooo00090?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo00000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0U0?ooo`002@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1^0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0903oool000030?ooo`000000
0000008000001@3oool00`000000oooo0?ooo`070?ooo`800000103oool00`000000oooo00000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000KP3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo00070?ooo`040000003oool0
oooo000000T0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo00070?ooo`@00000
2@3oool3000000T0oooo0P0000040?ooo`8000002@3oool01@2`/;00oooo0?ooo`3oool0000006h0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`00<@3oool01@2`/;00oooo
0?ooo`3oool0000006h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0S0?ooo`00
:P3oool0103Ph>00P8200820P020P8030?ooo`050>3Ph030`<00oooo0?ooo`000000K@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo000b0?ooo`040:2PX03oool0oooo0000
06d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0R0?ooo`00;`3oool01030`<00
L71`0820P020P8020?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0R0?ooo`00=@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool08P3oool003D0oooo00<000000?ooo`3oool0JP3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo0280oooo000e0?ooo`030000003oool0oooo06T0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0Q0?ooo`00503oool2000000<0oooo00H00000
0?ooo`3oool0oooo0000003oool500000080oooo0P00000=0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0Q0?ooo`004`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo0240oooo000F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0803oool000d0oooo
100000030?ooo`800000103oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000J@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0200oooo000D0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0P0?oo
o`00503oool3000000T0oooo0P0000040?ooo`8000002@3oool01@2`/;00oooo0?ooo`3oool00000
06T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0O0?ooo`00<@3oool01@2`/;00
oooo0?ooo`3oool0000006P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0O0?oo
o`00:P3oool0103Ph>00P8200820P020P8030?ooo`050>3Ph030`<00oooo0?ooo`000000J03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01l0oooo000b0?ooo`040:2PX03oool0oooo
000006P0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0N0?ooo`00;`3oool01030
`<00L71`0820P020P8020?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0N0?ooo`00=@3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool07P3oool003D0oooo00<000000?ooo`3oool0I03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01d0oooo000e0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0M0?ooo`001`3oool4000000<0oooo0P00
00040?ooo`8000000`3oool01P000000oooo0?ooo`3oool000000?ooo`D000000P3oool2000000d0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01d0
oooo00070?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo06<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0L0?oo
o`00203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0703oool00003
0?ooo`000000000000800000103oool00`000000oooo0?ooo`080?ooo`800000103oool00`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0L0?oo
o`001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`800000H`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01/0oooo0008
0?ooo`8000002P3oool3000000T0oooo0P0000040?ooo`8000003@3oool00`000000oooo0?ooo`1Q
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool00340oooo00D0/;2`0?oo
o`3oool0oooo0000001S0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool06`3oool0
0340oooo00D0/;2`0?ooo`3oool0oooo0000000I0?ooo`800000103oool2000000<0oooo1000000B
0?ooo`800000103oool2000000D0oooo0`00000A0?ooo`800000103oool2000000<0oooo0`00000C
0?ooo`800000103oool2000000@0oooo0P0000020?ooo`030000003oool0oooo01<0oooo1@000002
0?ooo`00:P3oool0103Ph>00P8200820P020P8030?ooo`050>3Ph030`<00oooo0?ooo`000000603o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000A0?ooo`040000003oool0oooo000000P0oooo00H0
00000?ooo`3oool000000?ooo`00000G0?ooo`030000003oool0oooo0080oooo000b0?ooo`040:2P
X03oool0oooo000000`0oooo1@0000070?ooo`040000003oool0oooo000000T0oooo00<000000?oo
o`3oool04@3oool010000000oooo0?ooo`0000080?ooo`D00000403oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000004@3oool010000000oooo
0?ooo`0000080?ooo`060000003oool0oooo0000003oool000005`3oool00`000000oooo0?ooo`02
0?ooo`00;`3oool01030`<00L71`0820P020P8020?ooo`030000003oool0oooo00T0oooo0P000003
0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?oo
o`0@0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000004@3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0`00000B0?ooo`040000003oool0oooo
000000T0oooo0P0000030?ooo`030000003oool0oooo00h0oooo0`0000030?ooo`030000003oool0
oooo0080oooo000e0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000004@3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool000000140oooo00H000000?ooo`3oool0
00000?ooo`0000070?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00h0oooo00@000000?ooo`0000000000
0P3oool00`000000oooo0?ooo`020?ooo`00=@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool2000000X0oooo0P00000C0?ooo`8000002`3o
ool200000180oooo0P0000000`3oool000000?ooo`070?ooo`<000004P3oool2000000X0oooo0P00
00030?ooo`030000003oool0oooo00d0oooo00H000000?ooo`3oool0oooo0000003oool2000000@0
oooo000e0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo000e0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo000e
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo000e0?ooo`8000001`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo04<0oooo0P00000c0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`00<@3ooon^00000000=@3oool2000000H0oooo
00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo0P0000070?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00@0oooo0P0000060?ooo`030000003oool0000000@0oooo000e0?ooo`8000001@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0300oooo0P0000160?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`00=@3oool00`000000oooo
000000040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`00=@3oool00`000000oooo000000030?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`00=@3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`03
0?ooo`00=@3oool010000000oooo0000000000020?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00=@3oool00`000000oooo0?ooo`030000
0140oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00=@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0C`3oool4000000`0
oooo00<000000?ooo`3oool00`3oool003D0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo0540oooo0P00000>0?ooo`030000003oool0oooo0080oooo
00070?ooo`@000000`3oool2000000@0oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000
oooo1@0000020?ooo`8000003@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`020?ooo`001`3oool00`000000oooo
0?ooo`090?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`020?oo
o`00203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0I`3oool000T0
oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000001L0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1X0?ooo`001`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1X0?ooo`00203oool2000000X0oooo0`000009
0?ooo`800000103oool2000000T0oooo00D0/;2`0?ooo`3oool0oooo0000000H0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0J@3oool00340oooo00D0/;2`0?ooo`3oool0oooo0000
000H0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0J@3oool002X0oooo00@0h>3P
0820P020P800P8200`3oool01@3Ph>00`<300?ooo`3oool0000001T0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`1Z0?ooo`00<P3oool0102PX:00oooo0?ooo`00000I0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0JP3oool002l0oooo00@0`<30071`L020P800P820
0P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
JP3oool003D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo06/0oooo000e0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1[0?ooo`00=@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0K03oool003D0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo06`0oooo000D0?ooo`8000000`3oool01P000000oooo
0?ooo`3oool000000?ooo`D000000P3oool2000000d0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo06`0oooo000C0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0K@3oool001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1]0?ooo`00503oool20000
00@0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02P3oool2000001/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1^
0?ooo`00503oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0KP3oool001@0oooo0`000009
0?ooo`800000103oool2000000T0oooo00D0/;2`0?ooo`3oool0oooo0000000L0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool0K`3oool00340oooo00D0/;2`0?ooo`3oool0oooo0000
000M0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0K`3oool002X0oooo00@0h>3P
0820P020P800P8200`3oool01@3Ph>00`<300?ooo`3oool0000001d0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`1_0?ooo`00<P3oool0102PX:00oooo0?ooo`00000M0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0L03oool002l0oooo00@0`<30071`L020P800P820
0P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
L03oool003D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0740oooo000e0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1a0?ooo`00=@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0L@3oool000T0oooo00<000000?ooo`3oool00P3oool2000000@0
oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000oooo1@0000020?ooo`8000003@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0LP3oool0
00T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0780oooo0009
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1c0?ooo`002P3oool0
0`000000oooo0?ooo`070?ooo`800000103oool00`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`8000007`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo07<0oooo00070?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo07@0oooo00070?ooo`@000002@3oool3000000T0oooo
0P0000040?ooo`8000002@3oool01@2`/;00oooo0?ooo`3oool000000200oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`1d0?ooo`00<@3oool01@2`/;00oooo0?ooo`3oool000000240
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1d0?ooo`00:P3oool0103Ph>00P820
0820P020P8030?ooo`050>3Ph030`<00oooo0?ooo`0000008@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo07D0oooo000b0?ooo`040:2PX03oool0oooo00000280oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`1e0?ooo`00;`3oool01030`<00L71`0820P020P8020?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1f0?oo
o`00=@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0MP3oool003D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo07L0oooo000e0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`1g0?ooo`004`3oool5000000030?ooo`000000oooo0080oooo00<00000
0?ooo`000000100000020?ooo`8000003@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0N03oool001D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1i
0?ooo`005@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3oool2
000000D0oooo00<000000?ooo`3oool0NP3oool001D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02D0oooo0P0000000`3oool000000000001m0?ooo`005@3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003o
ool0oooo000000`0oooo0P00000W0?ooo`030000003oool0000007h0oooo000D0?ooo`8000002P3o
ool2000000@0oooo0P00002g0?ooo`00<03oool00`30`<00/;2`092@T02/0?ooo`00<03oool00`2P
X:00oooo0<30`02/0?ooo`00:P3oool0103Ph>00P8200820P020P8020?ooo`03061PH02@T900X:2P
0:`0oooo000`0?ooo`030:2PX03oool0oooo0:`0oooo000a0?ooo`030:2PX02`/;00oooo0:/0oooo
003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3oool00001
\
\>"],
  ImageRangeCache->{{{0, 222.188}, {136.875, 0}} -> {-0.32241, -1.27911*^-06, \
0.00606431, 1.869*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[19]="]
}, Open  ]],

Cell["Example 5", "Subsubsection",
  Background->None],

Cell["Boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''\)[x] - y[x] \[Equal] 2*Sinh[1], y[0] \[Equal] 0, 
        y[1] \[Equal] 0}\)], "Input",
  CellLabel->"In[20]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(-y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], 
          "==", \(2\ Sinh[1]\)}], ",", \(y[0] == 0\), ",", \(y[1] == 0\)}], 
      "}"}]], "Output",
  CellLabel->"Out[20]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[21]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(\(2\ Sinh[
                      1]\)\/1642129\)\) - \(1517568\ x\ Sinh[1]\)\/1642129 + \
\(1640448\ x\^2\ Sinh[1]\)\/1642129 - \(245760\ x\^3\ Sinh[1]\)\/1642129 + \
\(122880\ x\^4\ Sinh[1]\)\/1642129}}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[22]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \((\(-1\) + \[ExponentialE])\)\ \
\[ExponentialE]\^\(\(-1\) - x\)\ \((\[ExponentialE] - \[ExponentialE]\^x + \
\[ExponentialE]\^\(2\ x\) - \[ExponentialE]\^\(1 + x\))\)}}\)], "Output",
  CellLabel->"Out[22]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr)\))\), {x, 0, 
        1}]\)], "Input",
  CellLabel->"In[23]:=",
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.308886 205709 [
[.21429 .29639 -9 -9 ]
[.21429 .29639 9 0 ]
[.40476 .29639 -9 -9 ]
[.40476 .29639 9 0 ]
[.59524 .29639 -9 -9 ]
[.59524 .29639 9 0 ]
[.78571 .29639 -9 -9 ]
[.78571 .29639 9 0 ]
[.97619 .29639 -3 -9 ]
[.97619 .29639 3 0 ]
[.01131 .00032 -51 -6.25 ]
[.01131 .00032 0 6.25 ]
[.01131 .10318 -39 -6.25 ]
[.01131 .10318 0 6.25 ]
[.01131 .20603 -39 -6.25 ]
[.01131 .20603 0 6.25 ]
[.01131 .41174 -33 -6.25 ]
[.01131 .41174 0 6.25 ]
[.01131 .51459 -33 -6.25 ]
[.01131 .51459 0 6.25 ]
[.01131 .61745 -45 -6.25 ]
[.01131 .61745 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30889 m
.21429 .31514 L
s
[(0.2)] .21429 .29639 0 1 Mshowa
.40476 .30889 m
.40476 .31514 L
s
[(0.4)] .40476 .29639 0 1 Mshowa
.59524 .30889 m
.59524 .31514 L
s
[(0.6)] .59524 .29639 0 1 Mshowa
.78571 .30889 m
.78571 .31514 L
s
[(0.8)] .78571 .29639 0 1 Mshowa
.97619 .30889 m
.97619 .31514 L
s
[(1)] .97619 .29639 0 1 Mshowa
.125 Mabswid
.07143 .30889 m
.07143 .31264 L
s
.11905 .30889 m
.11905 .31264 L
s
.16667 .30889 m
.16667 .31264 L
s
.2619 .30889 m
.2619 .31264 L
s
.30952 .30889 m
.30952 .31264 L
s
.35714 .30889 m
.35714 .31264 L
s
.45238 .30889 m
.45238 .31264 L
s
.5 .30889 m
.5 .31264 L
s
.54762 .30889 m
.54762 .31264 L
s
.64286 .30889 m
.64286 .31264 L
s
.69048 .30889 m
.69048 .31264 L
s
.7381 .30889 m
.7381 .31264 L
s
.83333 .30889 m
.83333 .31264 L
s
.88095 .30889 m
.88095 .31264 L
s
.92857 .30889 m
.92857 .31264 L
s
.25 Mabswid
0 .30889 m
1 .30889 L
s
.02381 .00032 m
.03006 .00032 L
s
gsave
.01131 .00032 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .10318 m
.03006 .10318 L
s
gsave
.01131 .10318 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .20603 m
.03006 .20603 L
s
gsave
.01131 .20603 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .41174 m
.03006 .41174 L
s
gsave
.01131 .41174 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .51459 m
.03006 .51459 L
s
gsave
.01131 .51459 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .61745 m
.03006 .61745 L
s
gsave
.01131 .61745 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.02381 .02089 m
.02756 .02089 L
s
.02381 .04146 m
.02756 .04146 L
s
.02381 .06204 m
.02756 .06204 L
s
.02381 .08261 m
.02756 .08261 L
s
.02381 .12375 m
.02756 .12375 L
s
.02381 .14432 m
.02756 .14432 L
s
.02381 .16489 m
.02756 .16489 L
s
.02381 .18546 m
.02756 .18546 L
s
.02381 .2266 m
.02756 .2266 L
s
.02381 .24717 m
.02756 .24717 L
s
.02381 .26774 m
.02756 .26774 L
s
.02381 .28831 m
.02756 .28831 L
s
.02381 .32946 m
.02756 .32946 L
s
.02381 .35003 m
.02756 .35003 L
s
.02381 .3706 m
.02756 .3706 L
s
.02381 .39117 m
.02756 .39117 L
s
.02381 .43231 m
.02756 .43231 L
s
.02381 .45288 m
.02756 .45288 L
s
.02381 .47345 m
.02756 .47345 L
s
.02381 .49402 m
.02756 .49402 L
s
.02381 .53517 m
.02756 .53517 L
s
.02381 .55574 m
.02756 .55574 L
s
.02381 .57631 m
.02756 .57631 L
s
.02381 .59688 m
.02756 .59688 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .42467 L
.04262 .27342 L
.04758 .21283 L
.05288 .15854 L
.05785 .11678 L
.06244 .08545 L
.06788 .05657 L
.07069 .0449 L
.07379 .03443 L
.07647 .02727 L
.07899 .0221 L
.08035 .01989 L
.08165 .01817 L
.08314 .01663 L
.08384 .01606 L
.08451 .01562 L
.08577 .01502 L
.08692 .01474 L
.08815 .01472 L
.08884 .01483 L
.08948 .01501 L
.09055 .01547 L
.09173 .01621 L
.09296 .01724 L
.0941 .01842 L
.09675 .02195 L
.09916 .02609 L
.10458 .03833 L
.11449 .06974 L
.12366 .10693 L
.14443 .20855 L
.18369 .40966 L
.20339 .49206 L
.22144 .54896 L
.23087 .57065 L
.24079 .58728 L
.24595 .59339 L
.25075 .59753 L
.25351 .59924 L
.25602 .60037 L
.25741 .60083 L
.25814 .60102 L
.25891 .60118 L
.25959 .6013 L
.26033 .60139 L
.26165 .60147 L
.26294 .60144 L
.26414 .60132 L
.26546 .60109 L
Mistroke
.26619 .60091 L
.26686 .60072 L
.26941 .59976 L
.27181 .5985 L
.27627 .59525 L
.28109 .59046 L
.28639 .58371 L
.29198 .57498 L
.30199 .5555 L
.32166 .50458 L
.34001 .44538 L
.37897 .30054 L
.42038 .15292 L
.44112 .09377 L
.45023 .07237 L
.46028 .05249 L
.46989 .03736 L
.4789 .02682 L
.48387 .02257 L
.48842 .01966 L
.49081 .01851 L
.49341 .01755 L
.49473 .01719 L
.49545 .01703 L
.49613 .01689 L
.49677 .01679 L
.49746 .0167 L
.49866 .01659 L
.4999 .01655 L
.50103 .01657 L
.50233 .01667 L
.50357 .01684 L
.50471 .01706 L
.50576 .01732 L
.50815 .01809 L
.51055 .01913 L
.5132 .02059 L
.51858 .02452 L
.5238 .02961 L
.52943 .03645 L
.53963 .05234 L
.55965 .09572 L
.58074 .15649 L
.61882 .29212 L
.65935 .44314 L
.67806 .50375 L
.69836 .55625 L
.70945 .57737 L
.71432 .5847 L
.71968 .59131 L
Mistroke
.72211 .59379 L
.72473 .59608 L
.72699 .59774 L
.72946 .59921 L
.7309 .5999 L
.73224 .60043 L
.73351 .60083 L
.73417 .601 L
.73487 .60116 L
.73557 .60128 L
.73621 .60136 L
.73747 .60146 L
.73862 .60146 L
.73982 .60137 L
.74105 .60119 L
.74174 .60105 L
.74237 .60089 L
.74352 .60054 L
.74479 .60005 L
.74698 .59897 L
.74931 .59749 L
.75456 .59287 L
.75948 .58691 L
.7683 .57228 L
.77782 .55087 L
.79787 .48739 L
.81898 .39715 L
.8571 .20058 L
.86805 .14535 L
.87837 .09812 L
.88842 .05944 L
.89283 .04549 L
.89769 .03274 L
.89996 .02782 L
.90239 .02332 L
.9045 .02015 L
.90679 .01748 L
.90814 .01631 L
.90938 .01551 L
.91057 .01499 L
.91183 .01472 L
.91308 .01474 L
.91425 .01502 L
.9153 .01551 L
.91643 .01627 L
.91771 .01745 L
.91889 .01885 L
.92159 .02316 L
.92422 .02894 L
.92702 .03694 L
Mistroke
.93212 .05656 L
.93675 .08062 L
.94152 .11212 L
.94658 .15362 L
.95566 .25124 L
.96543 .39391 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[23]:=",
  ImageSize->{220.75, 136.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003L0000R2000`400?l00000o`00003og03oool0
0=`0oooo003L0?ooo`00g03oool00=`0oooo003L0?ooo`00g03oool00=`0oooo003L0?ooo`00g03o
ool00=`0oooo003L0?ooo`001`3oool500000080oooo0P0000040?ooo`8000000`3oool01P000000
oooo0?ooo`3oool000000?ooo`D000000P3oool200000;@0oooo00090?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2a0?ooo`002@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0/@3oool000030?ooo`000000000000800000103oool0
0`000000oooo0?ooo`080?ooo`800000103oool00`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Y@3oool000T0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`2T0?ooo`00203oool2000000X0oooo0`0000090?ooo`800000103oool2000000P0oooo00<0
`<300;2`/02@T9000P3oool00`000000oooo0?ooo`2T0?ooo`00<03oool00`2PX:00oooo0<30`002
0?ooo`030000003oool0oooo00H0oooo100000120?ooo`D00000@P3oool3000000h0oooo000Z0?oo
o`040>3Ph020P800P8200820P080oooo00<0H61P092@T02PX:000P3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo00000440oooo00<000000?ooo`3oool00P3oool200000440oooo00@0
00000?ooo`3oool000003@3oool00300oooo00<0X:2P0?ooo`3oool00P3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo00000400oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0m0?ooo`050000003oool0oooo0?ooo`0000003@3oool00340oooo00D0X:2P0;2`/03oool0
oooo000000070?ooo`050000003oool0oooo0?ooo`000000?`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`00=@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`00=@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`00=@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`00=@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`00=@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`090?ooo`00=@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00=@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`090?ooo`004`3oool5000000030?ooo`000000oooo0080oooo00<000000?ooo`0000001000
00020?ooo`8000003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`005@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02@3oool001D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo000=0?ooo`@00000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0203oool001D0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00000<0?ooo`80
00000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0203oool001@0oooo0P00000:0?ooo`800000103oool2000000d0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool00300oooo00<0`<300;2`/02@T9000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`00<03oool0
0`2PX:00oooo0<30`0020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo000Z0?ooo`040>3Ph020P800P820
0820P080oooo00<0H61P092@T02PX:000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`00<03oool00`2P
X:00oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0;`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo000a0?ooo`050:2PX02`/;00oooo0?oo
o`000000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool01`3oool003D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
1`3oool003D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool0
03D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool01`3oool003D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool003D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool01P3oool001@0oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000
oooo1@0000020?ooo`8000003@3oool01@000000oooo0?ooo`3oool0000000h0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`060?ooo`004`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo00D000000?ooo`3oool0oooo0000000>0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01P3oool001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`050000003o
ool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo
000=0?ooo`@000000`3oool2000000@0oooo00<000000?ooo`000000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool200000080oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo000D0?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo000D0?ooo`<000002@3oool2000000@0
oooo0P0000090?ooo`050;2`/03oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool00340oooo00D0/;2`0?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`060?ooo`00:P3oool0103Ph>00P8200820P020P8030?ooo`050>3Ph030`<00oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool01@3oool00380oooo00@0X:2P0?ooo`3oool000000`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool002l0oooo00@0`<30071`
L020P800P8200P3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`050?ooo`00=@3oool010000000oooo0?ooo`00000A0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool01@3oool003D0oooo00@000000?ooo`3oool000004@3o
ool010000000oooo0?ooo`3oool2000000@0oooo0P0000030?ooo`@000004P3oool200000080oooo
00@000000?ooo`00000000001@3oool300000100oooo0P0000040?ooo`80000000<0oooo0000003o
ool00`00000C0?ooo`800000103oool2000000@0oooo0P0000030?ooo`030000003oool0oooo0100
oooo1P0000020?ooo`00=@3oool010000000oooo0?ooo`00000B0?ooo`030000003oool000000080
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0B0?ooo`060000003oool0oooo0000
003oool000002@3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo0000
00@0oooo000e0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`0000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo00H000000?ooo`3oool000000?ooo`00
00060?ooo`D000003`3oool010000000oooo0?ooo`0000070?ooo`8000000P3oool00`000000oooo
0?ooo`0?0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool00`00
0000oooo0?ooo`0@0?ooo`040000003oool0oooo000000@0oooo000e0?ooo`040000003oool0oooo
00000180oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool00P0000070?ooo`040000003oool0oooo00000100oooo00@0
00000?ooo`3oool000001`3oool400000180oooo00@000000?ooo`3oool000002@3oool2000000<0
oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000040?ooo`00=@3oool010000000
oooo0?ooo`00000B0?ooo`030000003oool000000080oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`00000A0?ooo`030000003oool0oooo00800000203oool00`000000oooo0000000@
0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`0000004`3oool010000000oooo0?oo
o`0000080?ooo`060000003oool0oooo0000003oool000004`3oool010000000oooo0?ooo`000004
0?ooo`00=@3oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo008000002P3oool2
000001<0oooo0P0000000`3oool000000?ooo`080?ooo`8000004@3oool2000000P0oooo00<00000
0?ooo`0000000P00000B0?ooo`8000002P3oool200000080oooo00<000000?ooo`3oool04@3oool0
10000000oooo0000000000040?ooo`00=@3oool010000000oooo0?ooo`00000C0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool01@3oool003D0oooo00@000000?ooo`3oool000004`3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo000e0?ooo`040000003oool0
oooo000001<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`00=@3oool0
10000000oooo0?ooo`00000C0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool01@3o
ool00340ooooZ`00000003D0oooo00<000000?ooo`0000005@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0180oooo00@000000?ooo`3oool00000103oool003D0oooo00<000000?oo
o`0000005@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00D0oooo000e0?ooo`03
0000003oool0000001D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00
=@3oool00`000000oooo0000000E0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
103oool003D0oooo00<000000?ooo`0000005P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo000e0?ooo`030000003oool0000001H0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`040?ooo`00=@3oool00`000000oooo0000000F0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0103oool003D0oooo00<000000?ooo`0000005P3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo000e0?ooo`030000003oool0000001H0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`00=@3oool00`000000oooo0000
000G0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool003D0oooo00<00000
0?ooo`0000005`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo000e0?oo
o`030000003oool0000001L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`040?oo
o`00=@3oool00`000000oooo0000000G0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0103oool001@0oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000oooo1@0000020?oo
o`8000003@3oool2000001P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`040?oo
o`004`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00000I0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0103oool001H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`8000006@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo000D0?oo
o`800000103oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`8000006@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00@0oooo000D0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`8000006@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo000D0?ooo`<000002@3oool2
000000@0oooo0P0000090?ooo`040;2`/03oool0oooo0?ooo`8000006@3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00@0oooo000a0?ooo`040;2`/03oool0oooo0?ooo`8000006P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00@0oooo000Z0?ooo`040>3Ph020P800
P8200820P0<0oooo00@0h>3P0<30`03oool0oooo0P00000J0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool0103oool00380oooo00<0X:2P0?ooo`3oool00P00000J0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0103oool002l0oooo00@0`<30071`L020P800P8200P3o
ool2000001X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`040?ooo`00=@3oool2
000001X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`00=@3oool20000
01/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`00=@3oool2000001/0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`00=@3oool2000001/0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`00=@3oool2000001/0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`00=@3oool2000001`0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`030?ooo`00=@3oool2000001`0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`030?ooo`00=@3oool2000001`0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`030?ooo`004`3oool5000000030?ooo`000000oooo0080oooo
00<000000?ooo`000000100000020?ooo`8000003@3oool2000001`0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`030?ooo`005@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
0P00000M0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool001D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooo`8000007@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00<0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000001d0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`005@3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo0000
00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00<0oooo000D0?ooo`8000002P3oool2000000@0oooo0P0000080?ooo`030<30`02`/;00T92@0080
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00<0
oooo000`0?ooo`030:2PX03oool0`<300080oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00<0oooo000Z0?ooo`040>3Ph020P800P8200820P080oooo
00<0H61P092@T02PX:000P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool00`3oool00300oooo00<0X:2P0?ooo`3oool00P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool00340oooo00D0X:2P
0;2`/03oool0oooo0000000P0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3o
ool003D0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo0080oooo000e0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`020?ooo`00=@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool00P3oool003D0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo0080oooo000e0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`00=@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00P3oool003D0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04L0oooo0P0000040?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P3oool000L0oooo1@0000020?ooo`80
0000103oool2000000<0oooo00H000000?ooo`3oool0oooo0000003oool500000080oooo0P00000=
0?ooo`030000003oool0oooo02<0oooo0P0000020?ooo`800000B`3oool200000080oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`002@3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0T0?ooo`<00000C`3o
ool3000002H0oooo00<000000?ooo`3oool00P3oool000T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0Y03oool000T0oooo00<00000
0?ooo`3oool0203oool2000000@0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02P3oool200000:D0oooo00090?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
Y03oool000P0oooo0P00000:0?ooo`<000002@3oool2000000@0oooo0P0000080?ooo`030<30`02`
/;00T92@0:T0oooo000`0?ooo`030:2PX03oool0`<300:T0oooo000Z0?ooo`040>3Ph020P800P820
0820P080oooo00<0H61P092@T02PX:00Z@3oool00300oooo00<0X:2P0?ooo`3oool0Z@3oool00340
oooo00<0X:2P0;2`/03oool0Z03oool00=`0oooo003L0?ooo`00g03oool00=`0oooo003L0?ooo`00
g03oool00=`0oooo003L0?ooo`00g03oool00001\
\>"],
  ImageRangeCache->{{{0, 219.75}, {135.375, 0}} -> {-0.326877, -1.92787*^-06, \
0.00615191, 2.84818*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[23]="]
}, Open  ]],

Cell["Example 6", "Subsubsection",
  Background->None],

Cell["Boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {x*\(y''\)[x] + \(y'\)[x] \[Equal] x, y[1] \[Equal] 0, 
        y[E] \[Equal] 0}\)], "Input",
  CellLabel->"In[24]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], "+", 
            RowBox[{"x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], "==", "x"}], 
        ",", \(y[1] == 0\), ",", \(y[\[ExponentialE]] == 0\)}], 
      "}"}]], "Output",
  CellLabel->"Out[24]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 1, E}, 5]\)], "Input",
  CellLabel->"In[25]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(\(5\ \((\(-1\) + \[ExponentialE])\)\^5\ \
\[ExponentialE]\ \((\(-1\) + \[ExponentialE]\^2)\)\)\/\(4\ \((5 + 
                        1458\ \[ExponentialE] + 14603\ \[ExponentialE]\^2 + 
                        29308\ \[ExponentialE]\^3 + 
                        14603\ \[ExponentialE]\^4 + 
                        1458\ \[ExponentialE]\^5 + 
                        5\ \[ExponentialE]\^6)\)\)\)\) - \(\((\(-1\) + \
\[ExponentialE])\)\ \((5 + 1103\ \[ExponentialE] + 12946\ \[ExponentialE]\^2 \
+ 26174\ \[ExponentialE]\^3 + 17017\ \[ExponentialE]\^4 + 4195\ \
\[ExponentialE]\^5)\)\ \((\(-1\) + x)\)\)\/\(2\ \((5 + 1458\ \[ExponentialE] \
+ 14603\ \[ExponentialE]\^2 + 29308\ \[ExponentialE]\^3 + 14603\ \
\[ExponentialE]\^4 + 1458\ \[ExponentialE]\^5 + 5\ \[ExponentialE]\^6)\)\) + \
\(\((5 - 2382\ \[ExponentialE] + 29963\ \[ExponentialE]\^2 + 36988\ \
\[ExponentialE]\^3 + 29963\ \[ExponentialE]\^4 + 28338\ \[ExponentialE]\^5 + \
5\ \[ExponentialE]\^6)\)\ \((\(-1\) + x)\)\^2\)\/\(20 + 5832\ \[ExponentialE] \
+ 58412\ \[ExponentialE]\^2 + 117232\ \[ExponentialE]\^3 + 58412\ \
\[ExponentialE]\^4 + 5832\ \[ExponentialE]\^5 + 20\ \[ExponentialE]\^6\) - \
\(1280\ \[ExponentialE]\ \((3 - 5\ \[ExponentialE] + \[ExponentialE]\^2 + 9\ \
\[ExponentialE]\^3)\)\ \((\(-1\) + x)\)\^3\)\/\(5 + 1458\ \[ExponentialE] + \
14603\ \[ExponentialE]\^2 + 29308\ \[ExponentialE]\^3 + 14603\ \
\[ExponentialE]\^4 + 1458\ \[ExponentialE]\^5 + 5\ \[ExponentialE]\^6\) + \
\(1920\ \[ExponentialE]\ \((\(-3\) + 2\ \[ExponentialE] + 5\ \
\[ExponentialE]\^2)\)\ \((\(-1\) + x)\)\^4\)\/\(5 + 1458\ \[ExponentialE] + \
14603\ \[ExponentialE]\^2 + 29308\ \[ExponentialE]\^3 + 14603\ \
\[ExponentialE]\^4 + 1458\ \[ExponentialE]\^5 + 5\ \[ExponentialE]\^6\) - \
\(3072\ \[ExponentialE]\ \((1 + \[ExponentialE])\)\ \((\(-1\) + \
x)\)\^5\)\/\(5 + 1458\ \[ExponentialE] + 14603\ \[ExponentialE]\^2 + 29308\ \
\[ExponentialE]\^3 + 14603\ \[ExponentialE]\^4 + 1458\ \[ExponentialE]\^5 + 5\
\ \[ExponentialE]\^6\)}}\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[26]:=",
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 
          1\/4\ \((\(-1\) + x\^2 + 
                Log[x] - \[ExponentialE]\^2\ Log[x])\)}}\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr)\))\), {x, 1, 
        E}]\)], "Input",
  CellLabel->"In[27]:=",
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.530454 0.554264 0.298421 1609.23 [
[.16238 .28592 -12 -9 ]
[.16238 .28592 12 0 ]
[.30094 .28592 -9 -9 ]
[.30094 .28592 9 0 ]
[.43951 .28592 -12 -9 ]
[.43951 .28592 12 0 ]
[.57807 .28592 -3 -9 ]
[.57807 .28592 3 0 ]
[.71664 .28592 -12 -9 ]
[.71664 .28592 12 0 ]
[.8552 .28592 -9 -9 ]
[.8552 .28592 9 0 ]
[.99377 .28592 -12 -9 ]
[.99377 .28592 12 0 ]
[.01131 .05704 -48 -4.5 ]
[.01131 .05704 0 4.5 ]
[.01131 .1375 -42 -4.5 ]
[.01131 .1375 0 4.5 ]
[.01131 .21796 -48 -4.5 ]
[.01131 .21796 0 4.5 ]
[.01131 .37888 -42 -4.5 ]
[.01131 .37888 0 4.5 ]
[.01131 .45934 -36 -4.5 ]
[.01131 .45934 0 4.5 ]
[.01131 .53981 -42 -4.5 ]
[.01131 .53981 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16238 .29842 m
.16238 .30467 L
s
[(1.25)] .16238 .28592 0 1 Mshowa
.30094 .29842 m
.30094 .30467 L
s
[(1.5)] .30094 .28592 0 1 Mshowa
.43951 .29842 m
.43951 .30467 L
s
[(1.75)] .43951 .28592 0 1 Mshowa
.57807 .29842 m
.57807 .30467 L
s
[(2)] .57807 .28592 0 1 Mshowa
.71664 .29842 m
.71664 .30467 L
s
[(2.25)] .71664 .28592 0 1 Mshowa
.8552 .29842 m
.8552 .30467 L
s
[(2.5)] .8552 .28592 0 1 Mshowa
.99377 .29842 m
.99377 .30467 L
s
[(2.75)] .99377 .28592 0 1 Mshowa
.125 Mabswid
.05152 .29842 m
.05152 .30217 L
s
.07924 .29842 m
.07924 .30217 L
s
.10695 .29842 m
.10695 .30217 L
s
.13466 .29842 m
.13466 .30217 L
s
.19009 .29842 m
.19009 .30217 L
s
.2178 .29842 m
.2178 .30217 L
s
.24551 .29842 m
.24551 .30217 L
s
.27323 .29842 m
.27323 .30217 L
s
.32865 .29842 m
.32865 .30217 L
s
.35637 .29842 m
.35637 .30217 L
s
.38408 .29842 m
.38408 .30217 L
s
.41179 .29842 m
.41179 .30217 L
s
.46722 .29842 m
.46722 .30217 L
s
.49493 .29842 m
.49493 .30217 L
s
.52265 .29842 m
.52265 .30217 L
s
.55036 .29842 m
.55036 .30217 L
s
.60579 .29842 m
.60579 .30217 L
s
.6335 .29842 m
.6335 .30217 L
s
.66121 .29842 m
.66121 .30217 L
s
.68893 .29842 m
.68893 .30217 L
s
.74435 .29842 m
.74435 .30217 L
s
.77207 .29842 m
.77207 .30217 L
s
.79978 .29842 m
.79978 .30217 L
s
.82749 .29842 m
.82749 .30217 L
s
.88292 .29842 m
.88292 .30217 L
s
.91063 .29842 m
.91063 .30217 L
s
.93834 .29842 m
.93834 .30217 L
s
.96606 .29842 m
.96606 .30217 L
s
.25 Mabswid
0 .29842 m
1 .29842 L
s
.02381 .05704 m
.03006 .05704 L
s
[(-0.00015)] .01131 .05704 1 0 Mshowa
.02381 .1375 m
.03006 .1375 L
s
[(-0.0001)] .01131 .1375 1 0 Mshowa
.02381 .21796 m
.03006 .21796 L
s
[(-0.00005)] .01131 .21796 1 0 Mshowa
.02381 .37888 m
.03006 .37888 L
s
[(0.00005)] .01131 .37888 1 0 Mshowa
.02381 .45934 m
.03006 .45934 L
s
[(0.0001)] .01131 .45934 1 0 Mshowa
.02381 .53981 m
.03006 .53981 L
s
[(0.00015)] .01131 .53981 1 0 Mshowa
.125 Mabswid
.02381 .07313 m
.02756 .07313 L
s
.02381 .08922 m
.02756 .08922 L
s
.02381 .10531 m
.02756 .10531 L
s
.02381 .12141 m
.02756 .12141 L
s
.02381 .15359 m
.02756 .15359 L
s
.02381 .16968 m
.02756 .16968 L
s
.02381 .18577 m
.02756 .18577 L
s
.02381 .20187 m
.02756 .20187 L
s
.02381 .23405 m
.02756 .23405 L
s
.02381 .25014 m
.02756 .25014 L
s
.02381 .26624 m
.02756 .26624 L
s
.02381 .28233 m
.02756 .28233 L
s
.02381 .31451 m
.02756 .31451 L
s
.02381 .33061 m
.02756 .33061 L
s
.02381 .3467 m
.02756 .3467 L
s
.02381 .36279 m
.02756 .36279 L
s
.02381 .39498 m
.02756 .39498 L
s
.02381 .41107 m
.02756 .41107 L
s
.02381 .42716 m
.02756 .42716 L
s
.02381 .44325 m
.02756 .44325 L
s
.02381 .47544 m
.02756 .47544 L
s
.02381 .49153 m
.02756 .49153 L
s
.02381 .50762 m
.02756 .50762 L
s
.02381 .52371 m
.02756 .52371 L
s
.02381 .5559 m
.02756 .5559 L
s
.02381 .57199 m
.02756 .57199 L
s
.02381 .58808 m
.02756 .58808 L
s
.02381 .60418 m
.02756 .60418 L
s
.02381 .04094 m
.02756 .04094 L
s
.02381 .02485 m
.02756 .02485 L
s
.02381 .00876 m
.02756 .00876 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .41986 L
.04262 .2671 L
.04758 .20673 L
.05288 .15312 L
.05785 .11225 L
.06244 .08186 L
.06788 .0541 L
.07075 .04277 L
.07379 .03305 L
.07642 .02642 L
.07889 .02164 L
.08028 .01952 L
.08159 .01788 L
.08312 .01643 L
.08383 .0159 L
.08451 .01549 L
.08577 .01495 L
.08692 .01472 L
.08815 .01472 L
.08884 .01484 L
.08948 .01502 L
.09055 .01547 L
.09173 .01618 L
.09296 .01715 L
.0941 .01826 L
.09675 .02155 L
.09916 .02539 L
.10458 .03663 L
.11449 .06504 L
.12366 .09813 L
.14443 .18648 L
.16468 .27663 L
.18369 .35399 L
.20208 .41605 L
.22144 .46429 L
.23108 .48126 L
.23618 .48832 L
.24162 .49441 L
.24665 .49872 L
.25121 .50156 L
.25341 .50257 L
.25457 .50301 L
.2558 .5034 L
.25687 .50369 L
.25805 .50395 L
.25913 .50412 L
.26013 .50424 L
.26138 .50432 L
.26208 .50434 L
Mistroke
.26271 .50433 L
.26395 .50427 L
.26511 .50415 L
.26577 .50405 L
.26647 .50393 L
.26772 .50366 L
.27054 .5028 L
.27298 .50178 L
.27525 .50061 L
.28042 .49718 L
.28937 .48883 L
.29895 .47679 L
.32023 .44052 L
.34037 .3974 L
.37875 .30518 L
.39817 .25974 L
.41958 .21485 L
.44011 .17947 L
.4589 .15526 L
.46835 .14637 L
.47829 .13951 L
.48346 .13696 L
.48826 .13522 L
.49102 .1345 L
.49353 .13401 L
.49492 .13382 L
.49565 .13373 L
.49643 .13366 L
.4971 .13361 L
.49785 .13357 L
.49916 .13353 L
.50046 .13354 L
.50166 .13358 L
.50298 .13368 L
.50365 .13374 L
.50439 .13382 L
.50694 .13422 L
.50935 .13475 L
.51382 .13612 L
.51864 .13817 L
.52395 .14107 L
.52954 .14485 L
.53955 .15341 L
.55927 .17636 L
.57762 .20383 L
.61664 .27444 L
.6581 .35149 L
.67888 .38414 L
.68801 .39627 L
.69805 .40772 L
Mistroke
.70705 .4161 L
.71671 .42294 L
.72205 .42571 L
.72693 .42758 L
.72927 .42824 L
.73051 .42854 L
.73183 .4288 L
.7331 .42901 L
.73424 .42916 L
.7354 .42928 L
.73649 .42935 L
.73765 .4294 L
.7389 .4294 L
.74007 .42936 L
.74115 .4293 L
.74241 .42918 L
.74377 .42899 L
.74626 .42852 L
.74886 .42784 L
.75162 .42691 L
.75658 .42468 L
.76111 .42202 L
.76537 .419 L
.77506 .4102 L
.7849 .39864 L
.79526 .3838 L
.81377 .35128 L
.85189 .26986 L
.87316 .22589 L
.88321 .20848 L
.89247 .1956 L
.89716 .19056 L
.90212 .18648 L
.90469 .18494 L
.9071 .18387 L
.90848 .18343 L
.90974 .18314 L
.91044 .18303 L
.91119 .18294 L
.91191 .1829 L
.91257 .1829 L
.91377 .18298 L
.91506 .18319 L
.91628 .1835 L
.9174 .1839 L
.91952 .18493 L
.92176 .18644 L
.92418 .18857 L
.92643 .19105 L
.93154 .19852 L
Mistroke
.93657 .20858 L
.94203 .22282 L
.95195 .2585 L
.9616 .30702 L
.97052 .36564 L
.97619 .41059 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[27]:=",
  ImageSize->{244.813, 151.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003d0000Ub000`400?l00000o`00003om03oool0
0?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03o
ool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00
<P3oool00`000000oooo0?ooo`2o0?ooo`00<P3oool200000<00oooo000b0?ooo`030000003oool0
oooo00P0oooo0P00002e0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`80000000<0oooo0000
003oool0/`3oool00380oooo0P0000080?ooo`030000003oool0oooo00800000/`3oool00380oooo
00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool000000;<0oooo000b0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2`0?ooo`00<P3o
ool2000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2`0?ooo`00203oool2
000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000030?ooo`D000000P3oool2
000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0:l0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0:l0oooo00070?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`3oool2000000H0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2_0?ooo`0000<0oooo0000000000000P0000020?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0:h0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2^0?ooo`00203oool2000000X0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000040?ooo`<000000`3oool2000000D0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`2^0?ooo`00<P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0[@3oool00380oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0:d0oooo000b0?ooo`8000001@3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0:d0oooo000b0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`2/0?ooo`00<P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0[03oool00380oooo0P0000040?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0[03oool00380oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:`0oooo000b0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2[0?ooo`00<P3oool2
000000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2[0?ooo`003P3oool20000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000030?ooo`D000000P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0Z`3oool000d0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2[0?ooo`003@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P000003
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0?`3oool7000006D0oooo00070?oo
o`@000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1R0?ooo`003@3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03/0oooo0P0000090?ooo`030000003o
ool0oooo0640oooo000>0?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0:0?ooo`800000H@3oool00380oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`1N0?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo05d0
oooo000b0?ooo`8000000`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1M0?ooo`00<P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo05`0oooo000b0?ooo`050000003oool0oooo0?ooo`0000004@3o
ool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0F`3o
ool00380oooo0P0000020?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03`0oooo1@00000I0?ooo`00<P3oool01@00
0000oooo0?ooo`3oool000000140oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00P3oool2000001P0oooo000b0?oo
o`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01H0oooo000b0?ooo`8000000P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool05@3oool000P0oooo0P0000040?ooo`800000103oool2000000@0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00070?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01@0oooo00070?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`3oool200000080oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00000`3o
ool000000000000200000080oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`800000103oool01@000000oooo0?ooo`3oool0000001<0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool0000001<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0C
0?ooo`00203oool2000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?oo
o`<000000`3oool200000080oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01<0oooo000b0?ooo`040000003oool0oooo000001@0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0C0?ooo`00<P3oool010000000oooo0?ooo`00000;0?oo
o`D000000P3oool2000000030?ooo`000000oooo00@000000`3oool2000000P0oooo1@0000020?oo
o`800000103oool2000000P0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`020?oo
o`8000003P3oool4000000030?ooo`000000oooo00T0oooo100000030?ooo`8000000`3oool40000
00<0oooo0P0000080?ooo`@000000`3oool2000000040?ooo`000000oooo0?ooo`800000203oool4
000000<0oooo0P0000050?ooo`030000003oool0oooo0080oooo0P0000030?ooo`00<P3oool20000
00030?ooo`000000oooo00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000050?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00
00090?ooo`030000003oool0000000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`4000000@3oool1
0?ooo`00<P3oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000001`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01`3oool2000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
000:0?ooo`030000003oool0oooo00@0oooo0@0000010?ooo`40oooo000b0?ooo`040000003oool0
oooo000000d0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000@0oooo
0P00000:0?ooo`030000003oool0oooo00P0oooo0P00000:0?ooo`8000002`3oool010000000oooo
0?ooo`3oool200000100oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000X0oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`3oool2000000X0oooo0P00000;0?ooo`040000003oool0oooo
0?ooo`8000000`3oool00380oooo0P0000000`3oool000000?ooo`0<0?ooo`030000003oool0oooo
00H0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00T0oooo0P0000080?ooo`040000003oool0oooo000000<0oooo00<0
00000?ooo`3oool03@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo0080oooo000b0?ooo`040000003oool0oooo000000`0oooo0P0000080?ooo`040000
003oool00000000000@0oooo0`0000080?ooo`8000002P3oool3000000P0oooo0P0000090?ooo`@0
00000`3oool3000000h0oooo0P0000050?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`80
0000103oool3000000P0oooo0P0000050?ooo`030000003oool0oooo0080oooo0`0000080?ooo`<0
0000203oool4000000<0oooo0`0000020?ooo`00<P3oool010000000oooo0?ooo`00000F0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00380oooo0P0000000`3oool00000
0?ooo`0E0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00380oooo00@0
00000?ooo`3oool000005`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140oooo
000b0?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0A0?ooo`00;@3ooonl000000/0oooo000b0?ooo`060000003oool0oooo0000003oool00000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool2000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo00X0oooo000b0?ooo`04
0000003oool0oooo000001H0oooo00<000000?ooo`0000005`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`00000C
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00380oooo0P0000000`3o
ool000000?ooo`0G0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0403oool00380
oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0100oooo000b0?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0?0?ooo`00<P3oool2000000030?ooo`000000oooo01P0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0?0?ooo`00<P3oool010000000oooo0?ooo`00000I0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00380oooo00@000000?ooo`3oool0
00006@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00l0oooo000b0?ooo`<00000
6P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo000b0?ooo`030000003o
ool0000001/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`00<P3oool0
0`000000oooo0000000K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03P3oool0
0380oooo0`00000K0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03P3oool000P0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0
oooo0P0000040?ooo`030000003oool0000001`0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0>0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000000L0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool03P3oool000L0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`<0
0000703oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00h0oooo00070?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool2000000@0oooo
00<000000?ooo`000000703oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00h0oooo
00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0000001d0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0>0?ooo`00203oool2000000X0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`<000000`3oool3000001d0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0=0?ooo`00<P3oool00`000000oooo0000000M0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool03@3oool00380oooo00<000000?ooo`0000007@3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00d0oooo000b0?ooo`<000007P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00d0oooo000b0?ooo`030000003oool0000001h0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`130?ooo`8000002P3oool00`000000oooo0?oo
o`0d0?ooo`00<P3oool00`000000oooo0000000N0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03@0oooo000b0?oo
o`<000007`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo04H0oooo0P0000050?oo
o`<00000=`3oool00380oooo00<000000?ooo`0000007`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo04P0oooo1@00000j0?ooo`00<P3oool00`000000oooo0000000P0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0R03oool00380oooo0`00000P0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0R03oool000h0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`8000000`3oool500000080oooo00<000000?ooo`0000008@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08T0oooo000=0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000Q0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0R@3oool000d0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`<000008P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo08X0oooo000=0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000R0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0RP3oool000d0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`8000008`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo08/0oooo000>0?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P00000T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0R`3o
ool00380oooo0P00000T0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool0
0380oooo0P00000U0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0S@3oool00380
oooo0P00000V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0S@3oool00380oooo
0P00000W0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0SP3oool00380oooo0P00
000X0?ooo`040000003oool0oooo0?ooo`<00000T@3oool00380oooo0P00000Y0?ooo`@00000T`3o
ool00380oooo0P0000300?ooo`00<P3oool200000<00oooo000b0?ooo`800000`03oool00380oooo
0P0000300?ooo`00203oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00
00030?ooo`D000000P3oool2000000@0oooo0P0000300?ooo`001`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`3o
ool200000<00oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`3oool200000<00oooo00070?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool2000000@0oooo0P0000300?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00`3oool200000<00oooo00080?ooo`8000002P3oool2000000@0oooo0P000004
0?ooo`800000103oool2000000@0oooo0`0000030?ooo`800000`03oool00380oooo00<000000?oo
o`3oool0_`3oool00380oooo00<000000?ooo`3oool0_`3oool00380oooo0P0000300?ooo`00<P3o
ool00`000000oooo0?ooo`2o0?ooo`00<P3oool00`000000oooo0?ooo`2o0?ooo`00<P3oool20000
0<00oooo000b0?ooo`030000003oool0oooo0;l0oooo000b0?ooo`030000003oool0oooo0;l0oooo
000b0?ooo`800000`03oool00380oooo00<000000?ooo`3oool0_`3oool00380oooo00<000000?oo
o`3oool0_`3oool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo
003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0
oooo003d0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 243.813}, {150.25, 0}} -> {0.514558, -0.00024294, \
0.00964334, 3.32144*^-06}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell["Example 7", "Subsubsection",
  Background->None],

Cell["Boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''''\)[x] \[Equal] \[Lambda]*y[x] + 1, 
        y[0] \[Equal] 0, \(y'\)[0] \[Equal] 0, \(y''\)[1] \[Equal] 
          0, \(y'''\)[1] \[Equal] 0}\)], "Input",
  CellLabel->"In[28]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["y", 
              TagBox[\((4)\),
                Derivative],
              MultilineFunction->None], "[", "x", "]"}], 
          "==", \(1 + \[Lambda]\ y[x]\)}], ",", \(y[0] == 0\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", "0"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "1", "]"}], "==", "0"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", 
              TagBox[\((3)\),
                Derivative],
              MultilineFunction->None], "[", "1", "]"}], "==", "0"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[29]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \((3170893824\ x\^5\ \[Lambda]\ \((8218956791808000 - 
                      13207339008000\ \[Lambda] + 446315520\ \[Lambda]\^2 + 
                      15043\ \[Lambda]\^3)\))\)/\((\
22239094895673037648035840000 - 1852120305462278791102464000\ \[Lambda] + 
                  4317678221483936474726400\ \[Lambda]\^2 - 
                  1263588439189157314560\ \[Lambda]\^3 + 
                  70817604823941120\ \[Lambda]\^4 - 
                  856076282880\ \[Lambda]\^5 + 
                  302161\ \[Lambda]\^6)\) + \((8847360\ x\ \[Lambda]\ \
\((19664615138918400 + 158633023242240\ \[Lambda] - 
                      61258914816\ \[Lambda]\^2 + 
                      1602517\ \
\[Lambda]\^3)\))\)/\((22239094895673037648035840000 - 
                  1852120305462278791102464000\ \[Lambda] + 
                  4317678221483936474726400\ \[Lambda]\^2 - 
                  1263588439189157314560\ \[Lambda]\^3 + 
                  70817604823941120\ \[Lambda]\^4 - 
                  856076282880\ \[Lambda]\^5 + 
                  302161\ \[Lambda]\^6)\) + \((23781703680\ x\^3\ \
\((\(-155855773237248000\) + 5613388038144000\ \[Lambda] - 
                      4256114933760\ \[Lambda]\^2 + 33329920\ \[Lambda]\^3 + 
                      5897\ \[Lambda]\^4)\))\)/\((\
22239094895673037648035840000 - 1852120305462278791102464000\ \[Lambda] + 
                  4317678221483936474726400\ \[Lambda]\^2 - 
                  1263588439189157314560\ \[Lambda]\^3 + 
                  70817604823941120\ \[Lambda]\^4 - 
                  856076282880\ \[Lambda]\^5 + 
                  302161\ \[Lambda]\^6)\) - \((495452160\ x\^4\ \
\((\(-1870269278846976000\) + 201420973906329600\ \[Lambda] - 
                      226923034705920\ \[Lambda]\^2 + 
                      5195873280\ \[Lambda]\^3 + 
                      270487\ \
\[Lambda]\^4)\))\)/\((22239094895673037648035840000 - 
                  1852120305462278791102464000\ \[Lambda] + 
                  4317678221483936474726400\ \[Lambda]\^2 - 
                  1263588439189157314560\ \[Lambda]\^3 + 
                  70817604823941120\ \[Lambda]\^4 - 
                  856076282880\ \[Lambda]\^5 + 
                  302161\ \[Lambda]\^6)\) - \((\[Lambda]\ \
\((2306042020818321408000 + 20228835651040051200\ \[Lambda] - 
                      7118085590876160\ \[Lambda]\^2 + 
                      156446008320\ \[Lambda]\^3 + 
                      302161\ \
\[Lambda]\^4)\))\)/\((22239094895673037648035840000 - 
                  1852120305462278791102464000\ \[Lambda] + 
                  4317678221483936474726400\ \[Lambda]\^2 - 
                  1263588439189157314560\ \[Lambda]\^3 + 
                  70817604823941120\ \[Lambda]\^4 - 
                  856076282880\ \[Lambda]\^5 + 
                  302161\ \[Lambda]\^6)\) - \((88473600\ x\^2\ \
\((\(-62841047769258393600\) + 719481389438730240\ \[Lambda] - 
                      345885854662656\ \[Lambda]\^2 - 
                      9509526528\ \[Lambda]\^3 + 
                      757183\ \
\[Lambda]\^4)\))\)/\((22239094895673037648035840000 - 
                  1852120305462278791102464000\ \[Lambda] + 
                  4317678221483936474726400\ \[Lambda]\^2 - 
                  1263588439189157314560\ \[Lambda]\^3 + 
                  70817604823941120\ \[Lambda]\^4 - 
                  856076282880\ \[Lambda]\^5 + 
                  302161\ \[Lambda]\^6)\)}}\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[30]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \((\[ExponentialE]\^\(\(-x\)\ \[Lambda]\^\(1/4\)\)\ \
\((\(-2\)\ \[ExponentialE]\^\(\[Lambda]\^\(1/4\) + x\ \[Lambda]\^\(1/4\)\) - 
                    2\ \[ExponentialE]\^\(2\ \[Lambda]\^\(1/4\) + x\ \
\[Lambda]\^\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)] + \[ExponentialE]\^\(2\ \
\[Lambda]\^\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)] - 
                    2\ \[ExponentialE]\^\(x\ \[Lambda]\^\(1/4\)\)\ Cos[\
\[Lambda]\^\(1/4\)] + \[ExponentialE]\^\(2\ x\ \[Lambda]\^\(1/4\)\)\ Cos[\
\[Lambda]\^\(1/4\)] - 
                    2\ \[ExponentialE]\^\(\[Lambda]\^\(1/4\) + x\ \[Lambda]\^\
\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)]\^2 + \[ExponentialE]\^\(\[Lambda]\^\(1/4\) \
+ 2\ x\ \[Lambda]\^\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)]\^2 + \
\[ExponentialE]\^\(\[Lambda]\^\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)]\^2 + 
                    2\ \[ExponentialE]\^\(\[Lambda]\^\(1/4\) + x\ \[Lambda]\^\
\(1/4\)\)\ Cos[
                        x\ \[Lambda]\^\(1/4\)] + \[ExponentialE]\^\(2\ \
\[Lambda]\^\(1/4\) + x\ \[Lambda]\^\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)]\ Cos[
                        x\ \[Lambda]\^\(1/4\)] + \[ExponentialE]\^\(x\ \
\[Lambda]\^\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)]\ Cos[
                        x\ \[Lambda]\^\(1/4\)] + \[ExponentialE]\^\(2\ \
\[Lambda]\^\(1/4\)\)\ Sin[\[Lambda]\^\(1/4\)] - \[ExponentialE]\^\(2\ x\ \
\[Lambda]\^\(1/4\)\)\ Sin[\[Lambda]\^\(1/4\)] - \[ExponentialE]\^\(2\ \
\[Lambda]\^\(1/4\) + x\ \[Lambda]\^\(1/4\)\)\ Cos[
                        x\ \[Lambda]\^\(1/4\)]\ Sin[\[Lambda]\^\(1/4\)] + \
\[ExponentialE]\^\(x\ \[Lambda]\^\(1/4\)\)\ Cos[
                        x\ \[Lambda]\^\(1/4\)]\ Sin[\[Lambda]\^\(1/4\)] - 
                    2\ \[ExponentialE]\^\(\[Lambda]\^\(1/4\) + x\ \[Lambda]\^\
\(1/4\)\)\ Sin[\[Lambda]\^\(1/4\)]\^2 + \[ExponentialE]\^\(\[Lambda]\^\(1/4\) \
+ 2\ x\ \[Lambda]\^\(1/4\)\)\ Sin[\[Lambda]\^\(1/4\)]\^2 + \
\[ExponentialE]\^\(\[Lambda]\^\(1/4\)\)\ Sin[\[Lambda]\^\(1/4\)]\^2 + \
\[ExponentialE]\^\(2\ \[Lambda]\^\(1/4\) + x\ \[Lambda]\^\(1/4\)\)\ Cos[\
\[Lambda]\^\(1/4\)]\ Sin[
                        x\ \[Lambda]\^\(1/4\)] - \[ExponentialE]\^\(x\ \
\[Lambda]\^\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)]\ Sin[
                        
                        x\ \[Lambda]\^\(1/4\)] + \[ExponentialE]\^\(2\ \
\[Lambda]\^\(1/4\) + x\ \[Lambda]\^\(1/4\)\)\ Sin[\[Lambda]\^\(1/4\)]\ Sin[
                        x\ \[Lambda]\^\(1/4\)] + \[ExponentialE]\^\(x\ \
\[Lambda]\^\(1/4\)\)\ Sin[\[Lambda]\^\(1/4\)]\ Sin[
                        x\ \[Lambda]\^\(1/4\)])\))\)/\((2\ \[Lambda]\ \((\
\[ExponentialE]\^\(\[Lambda]\^\(1/4\)\) + 
                    Cos[\[Lambda]\^\(1/4\)] + \[ExponentialE]\^\(2\ \[Lambda]\
\^\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)] + \
\[ExponentialE]\^\(\[Lambda]\^\(1/4\)\)\ Cos[\[Lambda]\^\(1/4\)]\^2 + \
\[ExponentialE]\^\(\[Lambda]\^\(1/4\)\)\ \
Sin[\[Lambda]\^\(1/4\)]\^2)\))\)}}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\), {x, 0, 
        1}, {\[Lambda], 1/8, 1/4}]\)], "Input",
  CellLabel->"In[31]:=",
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.378e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -16.7601 -9 ]
[.3345 .12542 1.2399 0 ]
[.50253 .05935 -21.0959 -9 ]
[.50253 .05935 2.90415 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.76745 .09703 0 -6.16187 ]
[.76745 .09703 24 2.83813 ]
[.88369 .27502 0 -5.99218 ]
[.88369 .27502 18 3.00782 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 24 3.14607 ]
[.02049 .28782 -39 -3.83541 ]
[.02049 .28782 0 8.66459 ]
[.00725 .37078 -6 -2.83182 ]
[.00725 .37078 0 6.16818 ]
[-0.00671 .45831 -33 -4.03667 ]
[-0.00671 .45831 0 8.46333 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(0.25)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0.5)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.75)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75514 .10158 m
.74899 .10385 L
s
[(0.15)] .76745 .09703 -1 .3693 Mshowa
.87123 .27915 m
.865 .28122 L
s
[(0.2)] .88369 .27502 -1 .3316 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(0.25)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.78003 .13965 m
.77633 .14098 L
s
.80404 .17637 m
.80033 .17768 L
s
.82721 .21182 m
.82349 .21311 L
s
.8496 .24606 m
.84587 .24733 L
s
.89215 .31115 m
.88841 .31237 L
s
.91239 .34211 m
.90864 .34331 L
s
.93198 .37208 m
.92823 .37326 L
s
.95096 .40111 m
.9472 .40226 L
s
.72932 .06208 m
.72564 .06347 L
s
.70252 .02109 m
.69885 .02251 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03273 .28309 m
.03885 .28072 L
s
gsave
.02049 .28782 -39 -1.83541 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.01956 .36622 m
.02571 .36394 L
s
[(0)] .00725 .37078 1 -0.37071 Mshowa
.00566 .45393 m
.01184 .45174 L
s
gsave
-0.00671 .45831 -33 -2.03667 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.125 Mabswid
.0295 .30346 m
.03318 .30206 L
s
.02623 .32411 m
.02991 .32271 L
s
.02292 .34502 m
.0266 .34364 L
s
.01615 .38771 m
.01985 .38635 L
s
.0127 .40948 m
.0164 .40814 L
s
.0092 .43155 m
.01291 .43023 L
s
.03592 .26298 m
.03959 .26155 L
s
.00206 .47662 m
.00578 .47532 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.916 .715 .617 r
.37482 .78279 .39806 .80578 .44189 .59268 .4201 .57538 Metetra
.905 .496 .187 r
.4201 .57538 .44189 .59268 .47781 .68177 .45581 .66131 Metetra
.869 .427 .052 r
.45581 .66131 .47781 .68177 .5165 .76054 .49432 .73708 Metetra
.736 .751 .864 r
.49432 .73708 .5165 .76054 .55688 .73805 .53512 .71464 Metetra
.892 .754 .702 r
.53512 .71464 .55688 .73805 .59622 .64914 .57532 .62776 Metetra
.898 .767 .708 r
.57532 .62776 .59622 .64914 .63449 .56518 .61447 .54559 Metetra
.799 .795 .849 r
.61447 .54559 .63449 .56518 .67392 .53295 .65446 .51363 Metetra
0 .313 .782 r
.65446 .51363 .67392 .53295 .71688 .56131 .69759 .54052 Metetra
.648 .163 0 r
.69759 .54052 .71688 .56131 .76389 .62474 .74452 .60139 Metetra
0 .128 .65 r
.74452 .60139 .76389 .62474 .81205 .67084 .79271 .64538 Metetra
.739 .762 .871 r
.79271 .64538 .81205 .67084 .8557 .64633 .8369 .62089 Metetra
.927 .782 .68 r
.8369 .62089 .8557 .64633 .89171 .54825 .87405 .52502 Metetra
.923 .802 .709 r
.87405 .52502 .89171 .54825 .92809 .46642 .91148 .44483 Metetra
.832 .416 0 r
.91148 .44483 .92809 .46642 .99555 .62094 .97814 .59401 Metetra
.915 .716 .62 r
.351 .75924 .37482 .78279 .4201 .57538 .39771 .5576 Metetra
.899 .484 .168 r
.39771 .5576 .4201 .57538 .45581 .66131 .43322 .6403 Metetra
.858 .408 .025 r
.43322 .6403 .45581 .66131 .49432 .73708 .47157 .71303 Metetra
.733 .75 .866 r
.47157 .71303 .49432 .73708 .53512 .71464 .51279 .69062 Metetra
.89 .755 .707 r
.51279 .69062 .53512 .71464 .57532 .62776 .55386 .60578 Metetra
.896 .768 .713 r
.55386 .60578 .57532 .62776 .61447 .54559 .59388 .52543 Metetra
.795 .795 .851 r
.59388 .52543 .61447 .54559 .65446 .51363 .63444 .49374 Metetra
0 .342 .805 r
.63444 .49374 .65446 .51363 .69759 .54052 .67774 .51912 Metetra
.619 .133 0 r
.67774 .51912 .69759 .54052 .74452 .60139 .72461 .5774 Metetra
0 .16 .678 r
.72461 .5774 .74452 .60139 .79271 .64538 .77284 .61923 Metetra
.737 .761 .873 r
.77284 .61923 .79271 .64538 .8369 .62089 .81759 .59476 Metetra
.924 .783 .686 r
.81759 .59476 .8369 .62089 .87405 .52502 .85588 .50111 Metetra
.919 .802 .715 r
.85588 .50111 .87405 .52502 .91148 .44483 .89436 .42259 Metetra
.822 .402 0 r
.89436 .42259 .91148 .44483 .97814 .59401 .96024 .56633 Metetra
.914 .717 .622 r
.32658 .73509 .351 .75924 .39771 .5576 .37467 .5393 Metetra
.893 .47 .148 r
.37467 .5393 .39771 .5576 .43322 .6403 .41001 .61871 Metetra
.845 .388 0 r
.41001 .61871 .43322 .6403 .47157 .71303 .44822 .68835 Metetra
.731 .75 .868 r
.44822 .68835 .47157 .71303 .51279 .69062 .48988 .66597 Metetra
.887 .756 .712 r
.48988 .66597 .51279 .69062 .55386 .60578 .5318 .5832 Metetra
.893 .769 .718 r
.5318 .5832 .55386 .60578 .59388 .52543 .57269 .50469 Metetra
.792 .795 .854 r
.57269 .50469 .59388 .52543 .63444 .49374 .61382 .47325 Metetra
0 .372 .826 r
.61382 .47325 .63444 .49374 .67774 .51912 .65732 .49709 Metetra
.588 .1 0 r
.65732 .49709 .67774 .51912 .72461 .5774 .70413 .55272 Metetra
0 .193 .706 r
.70413 .55272 .72461 .5774 .77284 .61923 .75242 .59237 Metetra
.734 .76 .874 r
.75242 .59237 .77284 .61923 .81759 .59476 .79773 .56789 Metetra
.921 .784 .692 r
.79773 .56789 .81759 .59476 .85588 .50111 .83717 .4765 Metetra
.916 .803 .721 r
.83717 .4765 .85588 .50111 .89436 .42259 .87671 .39965 Metetra
.811 .387 0 r
.87671 .39965 .89436 .42259 .96024 .56633 .94184 .53785 Metetra
.913 .718 .625 r
.30153 .71034 .32658 .73509 .37467 .5393 .35098 .52046 Metetra
.885 .455 .125 r
.35098 .52046 .37467 .5393 .41001 .61871 .38617 .59654 Metetra
.83 .365 0 r
.38617 .59654 .41001 .61871 .44822 .68835 .42426 .66303 Metetra
.728 .749 .869 r
.42426 .66303 .44822 .68835 .48988 .66597 .46635 .64067 Metetra
.884 .757 .716 r
.46635 .64067 .48988 .66597 .5318 .5832 .50912 .55998 Metetra
.89 .77 .723 r
.50912 .55998 .5318 .5832 .57269 .50469 .55087 .48333 Metetra
.788 .794 .857 r
.55087 .48333 .57269 .50469 .61382 .47325 .59259 .45215 Metetra
0 .4 .846 r
.59259 .45215 .61382 .47325 .65732 .49709 .63629 .47441 Metetra
.553 .065 0 r
.63629 .47441 .65732 .49709 .70413 .55272 .68307 .52734 Metetra
0 .227 .733 r
.68307 .52734 .70413 .55272 .75242 .59237 .73142 .56476 Metetra
.731 .76 .876 r
.73142 .56476 .75242 .59237 .79773 .56789 .77731 .54027 Metetra
.918 .785 .699 r
.77731 .54027 .79773 .56789 .83717 .4765 .81789 .45115 Metetra
.912 .804 .728 r
.81789 .45115 .83717 .4765 .87671 .39965 .85851 .37599 Metetra
.798 .371 0 r
.85851 .37599 .87671 .39965 .94184 .53785 .92289 .50856 Metetra
.912 .719 .629 r
.27583 .68495 .30153 .71034 .35098 .52046 .32659 .50107 Metetra
.876 .438 .099 r
.32659 .50107 .35098 .52046 .38617 .59654 .36166 .57374 Metetra
.812 .34 0 r
.36166 .57374 .38617 .59654 .42426 .66303 .39966 .63703 Metetra
.726 .749 .871 r
.39966 .63703 .42426 .66303 .46635 .64067 .44218 .61469 Metetra
.881 .758 .721 r
.44218 .61469 .46635 .64067 .50912 .55998 .48579 .5361 Metetra
.887 .771 .728 r
.48579 .5361 .50912 .55998 .55087 .48333 .5284 .46132 Metetra
.784 .794 .86 r
.5284 .46132 .55087 .48333 .59259 .45215 .57071 .4304 Metetra
.017 .428 .864 r
.57071 .4304 .59259 .45215 .63629 .47441 .61463 .45105 Metetra
0 0 .485 r
.61463 .45105 .63629 .47441 .68307 .52734 .66139 .50122 Metetra
0 .26 .759 r
.66139 .50122 .68307 .52734 .73142 .56476 .70983 .53636 Metetra
.728 .759 .877 r
.70983 .53636 .73142 .56476 .77731 .54027 .7563 .51185 Metetra
.914 .786 .705 r
.7563 .51185 .77731 .54027 .81789 .45115 .79803 .42503 Metetra
.908 .805 .735 r
.79803 .42503 .81789 .45115 .85851 .37599 .83973 .35158 Metetra
.784 .353 0 r
.83973 .35158 .85851 .37599 .92289 .50856 .90339 .47841 Metetra
.91 .72 .632 r
.24946 .65889 .27583 .68495 .32659 .50107 .30148 .4811 Metetra
.866 .418 .07 r
.30148 .4811 .32659 .50107 .36166 .57374 .33645 .5503 Metetra
.791 .311 0 r
.33645 .5503 .36166 .57374 .39966 .63703 .37439 .61034 Metetra
.723 .748 .872 r
.37439 .61034 .39966 .63703 .44218 .61469 .41735 .58799 Metetra
.878 .759 .727 r
.41735 .58799 .44218 .61469 .48579 .5361 .46178 .51153 Metetra
.883 .772 .734 r
.46178 .51153 .48579 .5361 .5284 .46132 .50525 .43865 Metetra
.78 .793 .863 r
.50525 .43865 .5284 .46132 .57071 .4304 .54815 .40797 Metetra
.057 .456 .881 r
.54815 .40797 .57071 .4304 .61463 .45105 .59231 .42697 Metetra
0 .013 .525 r
.59231 .42697 .61463 .45105 .66139 .50122 .63907 .47433 Metetra
0 .294 .784 r
.63907 .47433 .66139 .50122 .70983 .53636 .68761 .50716 Metetra
.725 .758 .879 r
.68761 .50716 .70983 .53636 .7563 .51185 .73468 .4826 Metetra
.91 .787 .712 r
.73468 .4826 .7563 .51185 .79803 .42503 .77756 .39809 Metetra
.903 .806 .741 r
.77756 .39809 .79803 .42503 .83973 .35158 .82034 .32637 Metetra
.767 .333 0 r
.82034 .32637 .83973 .35158 .90339 .47841 .88331 .44736 Metetra
.909 .721 .636 r
.22238 .63216 .24946 .65889 .30148 .4811 .27562 .46052 Metetra
.853 .396 .038 r
.27562 .46052 .30148 .4811 .33645 .5503 .31052 .52619 Metetra
.766 .278 0 r
.31052 .52619 .33645 .5503 .37439 .61034 .34842 .58292 Metetra
.72 .748 .874 r
.34842 .58292 .37439 .61034 .41735 .58799 .39183 .56056 Metetra
.874 .759 .732 r
.39183 .56056 .41735 .58799 .46178 .51153 .43707 .48623 Metetra
.88 .773 .74 r
.43707 .48623 .46178 .51153 .50525 .43865 .48139 .41527 Metetra
.776 .793 .866 r
.48139 .41527 .50525 .43865 .54815 .40797 .52489 .38483 Metetra
.096 .482 .897 r
.52489 .38483 .54815 .40797 .59231 .42697 .5693 .40214 Metetra
0 .055 .567 r
.5693 .40214 .59231 .42697 .63907 .47433 .61609 .44663 Metetra
0 .327 .808 r
.61609 .44663 .63907 .47433 .68761 .50716 .66475 .4771 Metetra
.722 .757 .88 r
.66475 .4771 .68761 .50716 .73468 .4826 .7124 .45249 Metetra
.906 .788 .719 r
.7124 .45249 .73468 .4826 .77756 .39809 .75644 .37031 Metetra
.898 .806 .749 r
.75644 .37031 .77756 .39809 .82034 .32637 .80032 .30033 Metetra
.749 .31 0 r
.80032 .30033 .82034 .32637 .88331 .44736 .86262 .41538 Metetra
.907 .722 .64 r
.19457 .6047 .22238 .63216 .27562 .46052 .24896 .43931 Metetra
.837 .37 .001 r
.24896 .43931 .27562 .46052 .31052 .52619 .28384 .50137 Metetra
.736 .24 0 r
.28384 .50137 .31052 .52619 .34842 .58292 .32173 .55473 Metetra
.717 .747 .876 r
.32173 .55473 .34842 .58292 .39183 .56056 .36558 .53235 Metetra
.871 .76 .738 r
.36558 .53235 .39183 .56056 .43707 .48623 .41163 .46018 Metetra
.876 .774 .746 r
.41163 .46018 .43707 .48623 .48139 .41527 .45679 .39115 Metetra
.772 .792 .869 r
.45679 .39115 .48139 .41527 .52489 .38483 .50088 .36095 Metetra
.134 .507 .91 r
.50088 .36095 .52489 .38483 .5693 .40214 .54556 .37652 Metetra
0 .099 .61 r
.54556 .37652 .5693 .40214 .61609 .44663 .5924 .4181 Metetra
0 .36 .83 r
.5924 .4181 .61609 .44663 .66475 .4771 .6412 .44615 Metetra
.719 .756 .881 r
.6412 .44615 .66475 .4771 .7124 .45249 .68946 .42147 Metetra
.901 .788 .727 r
.68946 .42147 .7124 .45249 .75644 .37031 .73465 .34165 Metetra
.893 .807 .756 r
.73465 .34165 .75644 .37031 .80032 .30033 .77963 .27341 Metetra
.728 .286 0 r
.77963 .27341 .80032 .30033 .86262 .41538 .84129 .38241 Metetra
.906 .723 .644 r
.166 .5765 .19457 .6047 .24896 .43931 .22148 .41744 Metetra
.818 .34 0 r
.22148 .41744 .24896 .43931 .28384 .50137 .25637 .47582 Metetra
.7 .198 0 r
.25637 .47582 .28384 .50137 .32173 .55473 .29428 .52576 Metetra
.715 .747 .877 r
.29428 .52576 .32173 .55473 .36558 .53235 .33857 .50334 Metetra
.867 .761 .744 r
.33857 .50334 .36558 .53235 .41163 .46018 .38541 .43335 Metetra
.872 .775 .752 r
.38541 .43335 .41163 .46018 .45679 .39115 .4314 .36627 Metetra
.768 .792 .872 r
.4314 .36627 .45679 .39115 .50088 .36095 .4761 .33629 Metetra
.172 .531 .922 r
.4761 .33629 .50088 .36095 .54556 .37652 .52107 .35008 Metetra
0 .146 .652 r
.52107 .35008 .54556 .37652 .5924 .4181 .56798 .38868 Metetra
.022 .392 .85 r
.56798 .38868 .5924 .4181 .6412 .44615 .61694 .41427 Metetra
.716 .755 .883 r
.61694 .41427 .6412 .44615 .68946 .42147 .66582 .3895 Metetra
.896 .789 .734 r
.66582 .3895 .68946 .42147 .73465 .34165 .71215 .31205 Metetra
.888 .807 .763 r
.71215 .31205 .73465 .34165 .77963 .27341 .75824 .24558 Metetra
.703 .258 0 r
.75824 .24558 .77963 .27341 .84129 .38241 .81929 .34842 Metetra
.904 .725 .649 r
.13663 .54753 .166 .5765 .22148 .41744 .19314 .39486 Metetra
.794 .305 0 r
.19314 .39486 .22148 .41744 .25637 .47582 .22807 .4495 Metetra
.658 .15 0 r
.22807 .4495 .25637 .47582 .29428 .52576 .26605 .49596 Metetra
.712 .746 .879 r
.26605 .49596 .29428 .52576 .33857 .50334 .31078 .47349 Metetra
.862 .762 .75 r
.31078 .47349 .33857 .50334 .38541 .43335 .35839 .40569 Metetra
.867 .776 .759 r
.35839 .40569 .38541 .43335 .4314 .36627 .40519 .34058 Metetra
.764 .791 .875 r
.40519 .34058 .4314 .36627 .4761 .33629 .4505 .31081 Metetra
.209 .554 .933 r
.4505 .31081 .4761 .33629 .52107 .35008 .49578 .32279 Metetra
0 .193 .694 r
.49578 .32279 .52107 .35008 .56798 .38868 .54279 .35834 Metetra
.067 .424 .869 r
.54279 .35834 .56798 .38868 .61694 .41427 .59194 .38142 Metetra
.713 .754 .884 r
.59194 .38142 .61694 .41427 .66582 .3895 .64143 .35654 Metetra
.891 .789 .742 r
.64143 .35654 .66582 .3895 .71215 .31205 .68891 .28147 Metetra
.882 .807 .771 r
.68891 .28147 .71215 .31205 .75824 .24558 .73611 .21678 Metetra
.675 .226 0 r
.73611 .21678 .75824 .24558 .81929 .34842 .79659 .31335 Metetra
.902 .726 .654 r
.10644 .51775 .13663 .54753 .19314 .39486 .16388 .37156 Metetra
.765 .265 0 r
.16388 .37156 .19314 .39486 .22807 .4495 .19891 .42239 Metetra
.608 .096 0 r
.19891 .42239 .22807 .4495 .26605 .49596 .23699 .4653 Metetra
.709 .746 .881 r
.23699 .4653 .26605 .49596 .31078 .47349 .28217 .44276 Metetra
.857 .762 .757 r
.28217 .44276 .31078 .47349 .35839 .40569 .33052 .37716 Metetra
.862 .777 .765 r
.33052 .37716 .35839 .40569 .40519 .34058 .37812 .31404 Metetra
.759 .79 .879 r
.37812 .31404 .40519 .34058 .4505 .31081 .42405 .28447 Metetra
.245 .576 .942 r
.42405 .28447 .4505 .31081 .49578 .32279 .46965 .29458 Metetra
0 .242 .735 r
.46965 .29458 .49578 .32279 .54279 .35834 .5168 .32703 Metetra
.112 .454 .885 r
.5168 .32703 .54279 .35834 .59194 .38142 .56616 .34755 Metetra
.71 .753 .886 r
.56616 .34755 .59194 .38142 .64143 .35654 .61628 .32254 Metetra
.885 .79 .75 r
.61628 .32254 .64143 .35654 .68891 .28147 .66489 .24987 Metetra
.876 .808 .779 r
.66489 .24987 .68891 .28147 .73611 .21678 .71321 .18696 Metetra
.643 .191 0 r
.71321 .18696 .73611 .21678 .79659 .31335 .77316 .27716 Metetra
.9 .728 .66 r
.07538 .48712 .10644 .51775 .16388 .37156 .13368 .3475 Metetra
.728 .217 0 r
.13368 .3475 .16388 .37156 .19891 .42239 .16885 .39443 Metetra
.549 .036 0 r
.16885 .39443 .19891 .42239 .23699 .4653 .20707 .43374 Metetra
.706 .745 .882 r
.20707 .43374 .23699 .4653 .28217 .44276 .2527 .41112 Metetra
.852 .763 .763 r
.2527 .41112 .28217 .44276 .33052 .37716 .30177 .34773 Metetra
.857 .778 .772 r
.30177 .34773 .33052 .37716 .37812 .31404 .35015 .28661 Metetra
.755 .79 .882 r
.35015 .28661 .37812 .31404 .42405 .28447 .39669 .25724 Metetra
.279 .596 .95 r
.39669 .25724 .42405 .28447 .46965 .29458 .44265 .26543 Metetra
0 .291 .773 r
.44265 .26543 .46965 .29458 .5168 .32703 .48997 .29471 Metetra
.156 .483 .9 r
.48997 .29471 .5168 .32703 .56616 .34755 .53956 .31261 Metetra
.707 .752 .887 r
.53956 .31261 .56616 .34755 .61628 .32254 .59031 .28746 Metetra
.879 .79 .758 r
.59031 .28746 .61628 .32254 .66489 .24987 .64006 .2172 Metetra
.869 .808 .787 r
.64006 .2172 .66489 .24987 .71321 .18696 .68948 .15608 Metetra
.605 .152 0 r
.68948 .15608 .71321 .18696 .77316 .27716 .74896 .23978 Metetra
.897 .729 .666 r
.04343 .45561 .07538 .48712 .13368 .3475 .10248 .32263 Metetra
.683 .162 0 r
.10248 .32263 .13368 .3475 .16885 .39443 .13785 .36559 Metetra
0 .031 .519 r
.13785 .36559 .16885 .39443 .20707 .43374 .17626 .40124 Metetra
.703 .744 .884 r
.17626 .40124 .20707 .43374 .2527 .41112 .22233 .37851 Metetra
.847 .764 .77 r
.22233 .37851 .2527 .41112 .30177 .34773 .27209 .31735 Metetra
.851 .778 .78 r
.27209 .31735 .30177 .34773 .35015 .28661 .32123 .25825 Metetra
.75 .789 .885 r
.32123 .25825 .35015 .28661 .39669 .25724 .36839 .22905 Metetra
.313 .615 .956 r
.36839 .22905 .39669 .25724 .44265 .26543 .41473 .23528 Metetra
0 .34 .809 r
.41473 .23528 .44265 .26543 .48997 .29471 .46225 .26132 Metetra
.199 .511 .912 r
.46225 .26132 .48997 .29471 .53956 .31261 .51211 .27656 Metetra
.704 .751 .889 r
.51211 .27656 .53956 .31261 .59031 .28746 .5635 .25122 Metetra
.872 .79 .767 r
.5635 .25122 .59031 .28746 .64006 .2172 .61436 .18338 Metetra
.862 .807 .795 r
.61436 .18338 .64006 .2172 .68948 .15608 .6649 .12407 Metetra
.562 .108 0 r
.6649 .12407 .68948 .15608 .74896 .23978 .72395 .20115 Metetra
.894 .731 .672 r
.01053 .42319 .04343 .45561 .10248 .32263 .07023 .29692 Metetra
.627 .098 0 r
.07023 .29692 .10248 .32263 .13785 .36559 .10585 .33584 Metetra
0 .103 .592 r
.10585 .33584 .13785 .36559 .17626 .40124 .1445 .36776 Metetra
.7 .744 .885 r
.1445 .36776 .17626 .40124 .22233 .37851 .19101 .3449 Metetra
.841 .764 .778 r
.19101 .3449 .22233 .37851 .27209 .31735 .24144 .28598 Metetra
.845 .779 .787 r
.24144 .28598 .27209 .31735 .32123 .25825 .29131 .2289 Metetra
.745 .788 .888 r
.29131 .2289 .32123 .25825 .36839 .22905 .3391 .19986 Metetra
.345 .633 .96 r
.3391 .19986 .36839 .22905 .41473 .23528 .38584 .20408 Metetra
0 .388 .842 r
.38584 .20408 .41473 .23528 .46225 .26132 .4336 .22681 Metetra
.241 .537 .923 r
.4336 .22681 .46225 .26132 .51211 .27656 .48376 .23933 Metetra
.701 .75 .89 r
.48376 .23933 .51211 .27656 .5635 .25122 .53579 .21379 Metetra
.865 .79 .775 r
.53579 .21379 .5635 .25122 .61436 .18338 .58776 .14838 Metetra
.854 .807 .803 r
.58776 .14838 .61436 .18338 .6649 .12407 .6394 .09086 Metetra
0 0 .48 r
.6394 .09086 .6649 .12407 .72395 .20115 .6981 .16122 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(0.25)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0.5)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.75)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[31]:=",
  ImageSize->{224.75, 182.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003P0000]R000`400?l00000o`00003oh03oool0
0>00oooo003P0?ooo`00h03oool00>00oooo003P0?ooo`00h03oool00>00oooo003P0?ooo`00h03o
ool00>00oooo003P0?ooo`00h03oool00>00oooo003P0?ooo`00h03oool00>00oooo003P0?ooo`00
h03oool00940oooo1@00001:0?ooo`00T`3oool00`000000oooo0?ooo`1:0?ooo`00T`3oool00`00
0000oooo0?ooo`1:0?ooo`00T`3oool00`000000oooo0?ooo`1:0?ooo`00T`3oool00`000000oooo
0?ooo`1:0?ooo`00TP3oool2000004`0oooo003P0?ooo`00h03oool00>00oooo002E0?ooo`800000
B@3oool009<0oooo0P0000000`3oool00000000000180?ooo`00I03oool2000000@0oooo0P000005
0?ooo`030000003oool0oooo0080oooo0P00000H0?ooo`<000000`3oool2000004P0oooo001S0?oo
o`040000003oool0oooo000000X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo01<0oooo0`0000050?ooo`030000003oool0000004L0oooo001S0?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`<00000203o
ool010000000oooo0000000000160?ooo`00H`3oool010000000oooo0?ooo`00000;0?ooo`040000
003oool0oooo0?ooo`8000004@3oool2000000/0oooo00@000000?ooo`3oool00000AP3oool006<0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00d0oooo0`0000000`3oool000000?ooo`0:0?ooo`050000003oool0oooo0?ooo`000000A@3o
ool006@0oooo0P0000090?ooo`@000000`3oool3000000X0oooo0`00000@0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@P3oool00840oooo0P0000000`3oool000000000000A0?oo
o`050000003oool0oooo0?ooo`000000A03oool007h0oooo0`00000F0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0@@3oool007`0oooo1000000G0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0@03oool007T0oooo0`00000K0?ooo`030000003oool0oooo0080oooo
0P0000120?ooo`00M`3oool2000001h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0o0?ooo`00C03oool2000000@0oooo0P0000040?ooo`8000006P3oool300000080oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo0P000004
0?ooo`8000000`3oool500000080oooo0P00000W0?ooo`00B`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000001L0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000:0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0T0?ooo`00B`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo0180oooo0`0000000`3oool000000?ooo`0R0?ooo`030000003oool0oooo00H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0T0?ooo`00B`3oool010000000oooo0?ooo`0000090?oo
o`8000004`3oool2000001l0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo0P00000W0?ooo`00B`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0
oooo00l0oooo1000000O0?ooo`030000003Jc/d0000000L0oooo00<000000?ooo`3oool01`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0V0?ooo`00C03oool2000000X0oooo0`00000=0?ooo`8000008P3oool0
1@000000f/k=0=[>c@3Jc/d0000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000
00020?ooo`8000002P3oool2000000@0oooo0`00000V0?ooo`00I@3oool400000280oooo00<00000
0=[>c@3Jc/d00P3Jc/d2000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0k
0?ooo`00H`3oool2000002D0oooo00<000000=[>c@3Jc/d0103Jc/d2000000@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0j0?ooo`00H03oool3000002H0oooo00<000000=[>c@3J
c/d01P3Jc/d2000000<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0i0?ooo`00
G@3oool3000002P0oooo00<000000=[>c@3Jc/d01P3Jc/d00`000000g<k;000000040?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0>@3oool005/0oooo0P00000Z0?ooo`030000003J
c/d0f/k=00H0f/k=00<000000=c>b`3Lc//00P0000030?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0>03oool002/0oooo0P0000040?ooo`8000000`3oool4000000<0oooo0P00000I
0?ooo`<000000P3oool00`000000oooo0?ooo`0V0?ooo`030000003Jc/d0f/k=00L0f/k=00@00000
0=c>b`3Lc//0g<k;0P0000020?ooo`030000003oool0oooo00X0oooo0P00000i0?ooo`00:P3oool0
10000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
5P3oool2000002d0oooo00<000000=[>c@3Jc/d01`3Jc/d00`000000g<k;0=c>b`030=c>b`800000
00<0oooo0000003oool0303oool00`000000oooo0?ooo`0g0?ooo`00:P3oool010000000oooo0?oo
o`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3oool3000000030?oo
o`000000oooo02/0oooo00<000000=g:aP0000001`3Jc/d00`000000g<k;0=c>b`040=c>b`@00000
3P3oool00`000000oooo0?ooo`0f0?ooo`00:P3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo0080oooo0P00000B0?ooo`800000<@3oool010000000gL[60=g:aP0000050=[>c@03
0000003Lc//0g<k;00H0g<k;0`00000?0?ooo`030000003oool0oooo03D0oooo000Z0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0>0?oo
o`<0000000<0oooo0000003oool0;`3oool01@000000gL[60=g:aP3Mb/H0000000@0f/k=00<00000
0=c>b`3Lc//01P3Lc//00`000000g/k900000002000000h0oooo00<000000?ooo`3oool0=@3oool0
02/0oooo0P00000:0?ooo`800000103oool3000000`0oooo0P00000d0?ooo`030000003Mb/H0gL[6
00<0gL[600D000000=[>c@3Jc/d0f/k=000000070=c>b`030000003Nc/T0g/k900<000003`3oool0
0`000000oooo0?ooo`0d0?ooo`00B@3oool3000000030?ooo`000000oooo0380oooo00<000000=g:
aP3Mb/H01@3Mb/H00`000000f/k=000000080=c>b`040000003Nc/T0g/k90=k>b@<000003P3oool2
000003D0oooo00170?ooo`800000>03oool00`000000gL[60=g:aP060=g:aP030000003Lc//0g<k;
00H0g<k;00<000000=k>b@3Nc/T00P3Nc/T3000000l0oooo00<000000?ooo`3oool0<`3oool004@0
oooo0`0000000`3oool000000?ooo`0f0?ooo`030000003Mb/H0gL[600H0gL[600<000000=o:a000
00001P3Lc//00`000000g/k90=k>b@030=k>b@040000003Nc/T00000000000l0oooo00<000000?oo
o`3oool0<P3oool00480oooo0P00000k0?ooo`030000003Mb/H0gL[600H0gL[600@000000=o:a03O
b/@000001@3Lc//00`000000g/k90=k>b@040=k>b@@00000403oool00`000000oooo0?ooo`0a0?oo
o`00903oool2000001T0oooo0`0000000`3oool000000?ooo`0G0?ooo`@000007P3oool00`000000
gL[60=g:aP070=g:aP050000003Ob/@0gl[40=o:a00000000`3Lc//00`000000g/k90=k>b@050=k>
b@030000003Pc/L0h<k7008000003`3oool00`000000oooo0?ooo`0a0?ooo`008`3oool010000000
oooo0?ooo`00000F0?ooo`8000006`3oool2000000040;k9h`000000F:;e05RRm@H00000603oool0
0`000000gL[60=g:aP060=g:aP030000003Ob/@0gl[400<0gl[400@000000=c>b`3Lc//000001`3N
c/T010000000h<k70>3>a`3Pc/L2000000l0oooo00<000000?ooo`3oool0<03oool002<0oooo00@0
00000?ooo`3oool000004`3oool4000001/0oooo00<000000;k9h`2nbN<00P2nbN<00`000000F:;e
05RRm@0405RRm@<00000503oool2000000P0gL[600<000000=o:a03Ob/@0103Ob/@00`000000g<k;
000000070=k>b@030000003Pc/L000000080h<k70P00000?0?ooo`030000003oool0oooo0300oooo
000S0?ooo`040000003oool0oooo00000100oooo0`00000M0?ooo`8000001P2nbN<00`000000F:;e
05RRm@0405RRm@0300000000HmL00000008000003`3oool200000080/koS00<000000=g:aP3Mb/H0
103Mb/H00`000000gl[40=o:a0060=o:a0030000003Nc/T0g/k900D0g/k900@000000>3>a`3Pc/L0
00000`3Pc/L2000000l0oooo00<000000?ooo`3oool0;`3oool002<0oooo00@000000?ooo`3oool0
00003P3oool2000000030?ooo`000000oooo01/0oooo0P0000090;k9h`030000001HX_D0F:;e00<0
F:;e00<00000001Se`00HmL00P00HmL3000000X0oooo0P0000040;>oh`030000003Mb/H0gL[600<0
gL[600<000000=o:a03Ob/@01P3Ob/@00`000000hL[2000000050=k>b@050000003Pc/L0h<k70>3>
a`0000000`3Pc/L3000000l0oooo00<000000?ooo`3oool0;P3oool002@0oooo0P00000<0?ooo`<0
00007`3oool00`000000_/WS0;k9h`0:0;k9h`@000000P1HX_D00`00000006?G001Se`03001Se`D0
0000103oool2000000L0/koS00D000000=g:aP3Mb/H0gL[6000000090=o:a0040000003Qb/80hL[2
000000<0g/k900<000000>3>a`3Pc/L00P3Pc/L01P000000h<k70>3>a`3Pc/L000000>7>a@800000
3P3oool00`000000oooo0?ooo`0^0?ooo`00<03oool200000080oooo00<000000?ooo`3oool0703o
ool00`000000f<O9000000090;k9h`80000000@0_lWR0000001@WO@0D9gd10000004001Se`030000
000mRN`0?HW/0080?HW/1000000:0;>oh`040000003Mb/H0gL[6000000P0gl[400D000000>7:`P3Q
b/80hL[2000000030=k>b@030000003Pc/L0h<k70080h<k700@000000>3>a`3Pc/L000000P3Qc/D2
000000l0oooo00<000000?ooo`3oool0;@3oool002d0oooo0`00000R0?ooo`050000003HalT0f<O9
0=S7b@0000001`2nbN<00`000000_lWR0;o9hP020;o9hP030000001@WO@0D9gd00<0D9gd0P000003
001Se`030000000mRN`0?HW/00@0?HW/00<000000;>oh`2c_n<0202c_n<00`000000gL[600000008
0=o:a0030000003Qb/80hL[200<0hL[200<000000=k>b@0000001@3Pc/L00`000000h<k700000004
0>7>a@8000003`3oool00`000000oooo0?ooo`0/0?ooo`00:`3oool200000080oooo00<000000?oo
o`3oool07`3oool00`000000f<O90=S7b@030=S7b@030000002nbN<0_/WS0080_/WS0P0000060;o9
hP030000001@WO@0D9gd00<0D9gd0`000002001Se`030000000mRN`0?HW/00<0?HW/00<000000;>o
h`2c_n<02@2c_n<00`000000gl[40=o:a0070=o:a0030000003Qb/80hL[200@0hL[200<000000>3>
a`3Pc/L00`3Pc/L3000000H0hLk50P00000>0?ooo`030000003oool0oooo02`0oooo000Y0?ooo`80
00009@3oool00`000000f<O90=S7b@050=S7b@040000002nbN<00000000000T0_lWR0P000004052M
m00300000000Ell00000008000001P0mRN`00`000000/koS0;>oh`060;>oh`80000000<0]<3S0000
003Ob/@01P3Ob/@00`000000hL[20>7:`P040>7:`P040000003Rb[l000000>3>a`<000000P3Pc/L0
0`000000hLk50>7>a@040>7>a@<000003P3oool00`000000oooo0?ooo`040?ooo`800000103oool2
000000<0oooo1000000H0?ooo`00:@3oool2000002@0oooo00<000000=S7b@3HalT01`3HalT00`00
0000_lWR0;o9hP070;o9hP80000000<0`L[Q0000000000000`000000101@WO@00000001Gc`00Ell3
000000D0?HW/00<000000;>oh`2c_n<0102c_n<01@000000]<3S0;C0h`2d`><0000000H0gl[400<0
00000>7:`P3Qb/801@3Qb/84000000@0h<k70P0000060>7>a@<000003`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3oool06@3oool002T0oooo00<0
00000?ooo`0000008P3oool00`000000f<O90=S7b@070=S7b@030000003IalL0000000L0_lWR00<0
00000<7:h@31b^400P31b^4010000000AiSc04NHl`17V?<3000000<005O?1000000303f9k0040000
002c_n<0/koS0;>oh`8000001@2d`><00`000000gl[40=o:a0030=o:a0030000003Qb/80hL[200<0
hL[20`0000020>;:_`050000003Pc/L0h<k70>3>a`0000000P3Qc/D00`000000hLk50>7>a@020>7>
a@030000003Sc/<0hlk3008000003P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`3oool0603oool002T0oooo00@000000?ooo`3oool00000803oool0
0`000000f<O90=S7b@070=S7b@040000003IalL0fLO70=W7a`800000102obN800`000000`L[Q0<7:
h@040<7:h@0300000017V?<0AiSc00<0AiSc0P000002001Gc`030000000bP^T0<X;Y00@0000000<0
/koS000000000000202d`><01@000000gl[40=o:a03Ob/@0000000<0hL[2100000050>;:_`030000
003Pc/L0000000@0hLk500@000000>7>a@3Qc/D000000`3Sc/<3000000h0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool002P0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003HalT0f<O900P0
f<O900<000000=W7a`3IalL00`3IalL010000000_lWR0000000000080<7:h@0300000017V?<0AiSc
00<0AiSc0P0000000`00Ell0000003:2j@0403:2j@8000002`2d`><010000000gl[40000003Qb/83
000000<0hL[200<000000>;:_`3Rb[l00`3Rb[l00`000000h<k7000000050>7>a@8000001@3Sc/<3
000000d0oooo0P0000020?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
603oool000L0oooo100000020?ooo`060000003oool0oooo0?ooo`000000oooo1@0000020?ooo`80
0000303oool2000000@0oooo00<000000?ooo`3oool06P3oool00`000000f<O90=S7b@080=S7b@03
0000003IalL0fLO700D0fLO700<000000<7:h@31b^402@31b^42000000@0AiSc1000000603:2j@03
0000002d`><0]<3S00P0]<3S100000050>7:`P030000003Rb[l0h/Zo00D0h/Zo00<000000>7>a@3Q
c/D0103Qc/D2000000D0hlk31000000=0?ooo`040000003oool0oooo0?ooo`8000002P3oool20000
01T0oooo00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo01P0oooo00<000000=O3a`000000203HalT00`000000fLO70=W7a`050=W7
a`030000003KalD0000000P0`L[Q0P0000000`32b^400000000000030000000304NHl`00000004[5
008000001@0bP^T00`000000]<3S0;C0h`060;C0h`@000001P3Qb/800`000000h/Zo0>;:_`050>;:
_`030000003TbKd0000000D0hLk50P0000040>?>``030000003Tc/400000008000003P3oool00`00
0000oooo0?ooo`0W0?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0103oool3000001L0oooo00D000000=O3a`3G`lL0el?7000000060=S7b@030000003IalL0
fLO700H0fLO700@000000=_7a@3KalD000001P31b^400`000000`/[Q0<;:h@020<;:h@040000000n
To40?Y?a03jCl@<000000P00B/D2000000@0<X;Y00<000000;C0h`2d`><00P2d`><500000080]<3S
00<000000>7:`P3Qb/800`3Qb/800`000000h/Zo0>;:_`050>;:_`040000003TbKd0i<Vm000000<0
hLk500@000000>?>``3Sc/<000000`3Sc/<00`000000i<k10>C>`@03000000h0oooo00<000000?oo
o`3oool09P3oool000030?ooo`000000000000800000103oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00T0oooo0P0000050?ooo`80000000<0oooo0000003oool05@3oool00`000000el?70=O3a`020=O3
a`030000003HalT0f<O90080f<O900<000000=W7a`3IalL01P3IalL01@000000flO50=_7a@3KalD0
000000@0`L[Q0P0000060<;:h@030000000nTo40?Y?a00<0?Y?a0P0000001000B/D0000000000000
000303:2j@@0000000<0]<3S0000000000001@2d`><01@000000hL[20>7:`P3Qb/80000000L0h/Zo
00D000000>C9_@3TbKd0i<Vm000000020>7>a@050000003Sc/<0hlk30>?>``0000000P3Sc/<00`00
0000i<k10>C>`@020>C>`@<000003@3oool00`000000oooo0?ooo`0V0?ooo`001`3oool010000000
oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003T
^j`0i;^/00<00000503oool00`000000el?70=O3a`040=O3a`050000003HalT0f<O90=S7b@000000
1`3IalL00`000000flO50=_7a@030=_7a@0400000031b^400000000000T0`/[Q0P00000403jCl@80
000000<004[50000000WNnH0100000020;C0h`8000001`2d`><010000000hL[20>7:`P0000070>;:
_`030000003TbKd0i<Vm00<0i<Vm00<000000>7>a@000000103Sc/<2000000D0i<k11000000=0?oo
o`030000003oool0oooo02D0oooo00080?ooo`8000002P3oool2000000@0oooo0P0000080?ooo`04
092@T030`<00X:2P000000H0oooo00@000000>Bk[03T^j`0i;^/0`00000B0?ooo`030000003G`lL0
el?700H0el?700<000000=S7b@0000001`3IalL00`000000flO50=_7a@050=_7a@0300000032b^40
`/[Q00L0`/[Q0P0000000`33b]l00000000000030000000303jCl@000000000000@0000000@09g_V
00000000000000002P2d`><00`000000hL[2000000070>;:_`030000003TbKd0i<Vm00@0i<Vm00<0
00000>?>``3Sc/<0103Sc/<00`000000i<k10>C>`@040>C>`@<000003@3oool2000002H0oooo000T
0?ooo`030;2`/03oool0X:2P00800000103oool00`000000i;^/0>Bk[0020>Bk[0040000002P6@00
000000000100oooo00<000000=O3a`3G`lL0203G`lL00`000000fLO70=W7a`060=W7a`030000003K
alD0flO500@0flO500<000000=c6``0000001`32b^400`000000`l[O0<?:g`020<?:g`040000000e
SNh0=Hg^03F=kPD000001@0WNnH00`000000]<3S0;C0h`090;C0h`030000003Rb[l0h/Zo00D0h/Zo
00<000000>C9_@3TbKd0103TbKd00`000000iLVk000000040>?>``030000003Tc/40000000@0i<k1
00<000000>G>_`0000000P00000=0?ooo`030000003oool0oooo02@0oooo000N0?ooo`040>3Ph020
P800P8200820P080oooo00@0P820092@T02`/;0000001@3oool00`000000i;^/0>Bk[0030>Bk[004
0000002P6@000000000000h0oooo00<000000=O3a`3G`lL0203G`lL00`000000f<?5000000060=W7
a`030000003KalD0flO500D0flO500<000000=c6``3La/<00P0000040<;:h@0300000033b]l0`l[O
00@0`l[O1000000203F=kP0400000000?K`00000000000@09g_V00<000000;C0h`2d`><01P2d`><2
000000030;G0hP000000h/Zo00@0h/Zo00<000000>C9_@3TbKd01@3TbKd010000000iLVk0>G9^`00
00030>?>``030000003Tc/40000000<0i<k100<000000>G>_`3Uc[l01000000=0?ooo`030000003o
ool0oooo02<0oooo000T0?ooo`040;2`/03oool0/;2`000000@0oooo00<000000>Bk[03T^j`0103T
^j`5000000d0oooo00<000000=O3a`3G`lL01`3G`lL01@000000f<?50=S3a@3H`lD0000000@0fLO7
00<000000=_7a@3KalD01@3KalD00`000000g<K30=c6``030=c6``0400000032b^400000000000D0
`l[O1000000503F=kPD000000P0WNnH00`000000]<3S0;C0h`050;C0h`050000002e`>80]L3R0;G0
hP0000001@3Rb[l00`000000i<Vm0>C9_@040>C9_@050000003UbK/0iLVk0>G9^`0000000P3Sc/<0
1@000000i<k10>C>`@3Tc/4000000080i<k100@000000>G>_`3Uc[l0iLjo1000000=0?ooo`030000
003oool0oooo0280oooo000T0?ooo`040:2PX02`/;00/;2`000000@0oooo00<000000>Bk[03T^j`0
103T^j`00`000000iKZZ00000003000000/0oooo00<000000=O3a`3G`lL01`3G`lL00`000000f<?5
0=S3a@030=S3a@040000003IalL0fLO7000000L0flO500<000000=c6``3La/<01@3La/<00`000000
`l[O0<?:g`020<?:g`<000001033b]l2000000<0=Hg^00D00000000a/@000000000001adhP020000
000302MkiP000000]<3S00<0]<3S0P0000050;G0hP050000003Rb[l0h/Zo0>;:_`0000001`3TbKd0
0`000000iLVk0>G9^`020>G9^`030000003Sc/<0000000@0i<k10P0000050>G>_`<000003@3oool0
0`000000oooo0?ooo`0R0?ooo`009`3oool200000080oooo00<000000>Bk[03T^j`0103T^j`01000
0000iKZZ0>FjZP3U^ZX4000000T0oooo00<000000=O3a`3G`lL01`3G`lL00`000000f<?50=S3a@05
0=S3a@030000003IalL0000000H0flO500<000000=c6``3La/<01@3La/<00`000000gLK200000003
000000D0`l[O0P0000000`34b]l000000000000400000003000a/@0000000000008077CR0`000000
0`2d`><00000000000080;G0hP030000003Rb[l0000000L0i<Vm00<000000>G9^`3UbK/0103UbK/0
0`000000i<k10>C>`@040>C>`@030000003Uc[l0iLjo0080iLjo1@00000<0?ooo`8000008`3oool0
02L0oooo00D000000?ooo`3oool0oooo000000060>Bk[0030000003U^ZX0iKZZ0080iKZZ10000006
0?ooo`80000000<0/kkR0000003G`lL01P3G`lL00`000000f<?50=S3a@070=S3a@030000003KalD0
flO500D0flO500<000000=c6``3La/<01@3La/<4000000H0`l[O00<000000<C:g`34b]l00P34b]l0
10000000;8O/02b7k00/Qn`200000003000a/@000000000000<077CR0P00000:0;G0hP030000003R
b[l0000000H0i<Vm00<000000>G9^`3UbK/0103UbK/00`000000i/Vj000000040>C>`@800000103U
c[l00`000000iljm00000003000000d0oooo00<000000?ooo`3oool0803oool002H0oooo00D00000
0?ooo`3oool0oooo000000060>Bk[0030000003U^ZX0iKZZ00@0iKZZ100000030?ooo`800000102c
_^800`000000el?70=O3a`040=O3a`030000003H`lD0f<?500H0f<?500<000000=[3``0000001@3K
alD00`000000g<K30=c6``030=c6``<000000`3Ma/800`000000`l[O0<?:g`020<?:g`8000001P34
b]l00`000000;8O/02b7k00202b7k00400000000<K40036a000000@077CR00<000000;G0hP2e`>80
202e`>800`000000i<Vm0>C9_@050>C9_@030000003UbK/0iLVk00@0iLVk00@000000>K9^P3VbKX0
00000P3Tc/4010000000iLjo0>G>_`0000020>G>_`040000003Wc[d0iljm0>O>_@@00000303oool0
0`000000oooo0?ooo`0P0?ooo`009P3oool200000080oooo00<000000>Bk[03T^j`0103T^j`00`00
0000iKZZ0>FjZP040>FjZPL000001P2c_^800`000000el?70=O3a`030=O3a`030000003H`lD0f<?5
00H0f<?500D000000=[3``3J`l<0f/?3000000030=_7a@040000003La/<0g<K30=c6``<0000000<0
g<K30000003Ma/80103Ma/8010000000`l[O0000000000090<C:g`8000000`0/Qn`200000003000a
/@000000000000<077CR00<000000;G0hP2e`>801@2e`>82000000030;K1hP000000i<Vm00@0i<Vm
00<000000>G9^`3UbK/0103UbK/00`000000i/Vj0>K9^P020>K9^P030000003Tc/40000000<0iLjo
0P0000050>O>_@@00000303oool00`000000oooo0?ooo`0O0?ooo`009P3oool010000000oooo0?oo
o`0000070>Bk[0030000003U^ZX0iKZZ00@0iKZZ00<000000>JjZ00000000P0000090;>nhP050000
003G`lL0el?70=O3a`000000203H`lD00`000000f/?30=[3``020=[3``050000003KalD0flO50000
003La/<00`0000030=c6``030000003Ma/80gLK200D0gLK200<000000<C:g`34b]l01`34b]l20000
00030<G:gP000000000000D0000000H0036a000000000000000001adhP0000050;G0hP8000000`2f
`N800`000000i<Vm0>C9_@020>C9_@030000003UbK/0iLVk00D0iLVk00<000000>K9^P3VbKX00`3V
bKX00`000000iLjo0>G>_`020>G>_`8000001@3Wc[d5000000/0oooo00<000000?ooo`3oool07`3o
ool00200oooo0P0000040?ooo`040000003oool0oooo000000H0i;^/00<000000>FjZP3U^ZX0103U
^ZX010000000i[ZX0>JjZ03V^ZP2000000X0/kkR00<000000=O3a`000000203H`lD00`000000f/?3
0=[3``040=[3``@000001P3La/<00`000000gLK20=g6`P040=g6`P030000003Oa/00000000L0a<[O
00<000000<G:gP35b]h00P35b]h0100000008X7X02:1j00RPNP4000000804FcN0`0000020;G0hP80
00001P2f`N801@000000i<Vm0>C9_@3TbKd0000000H0iLVk00<000000>K9^P3VbKX00`3VbKX00`00
0000ilVh000000030>G>_`800000103Wc[d00`000000j<jl00000002000000030<QJ00000000oooo
00T0oooo0P00000P0?ooo`007`3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00L0i;^/00<000000>FjZP3U^ZX0103U^ZX00`000000i[ZX0>JjZ0020>JjZ08000002P2c_^800`00
0000f<?50=S3a@060=S3a@030000003J`l<0f/?300<0f/?3100000070=c6``030000003Ma/80gLK2
00D0gLK200@000000=o6`03Oa/0000001034b]l2000000H0aL[N00<0000002:1j00RPNP00P0RPNP3
000000<04FcN0`0000090;K1hP030000003TbKd0000000H0iLVk00<000000>K9^P3VbKX0103VbKX0
0`000000ilVh000000030>G>_`030000003Wc[d0000000<0iljm00<000000>S>_03Xc[`01@00000;
0?ooo`030000003oool0oooo01d0oooo000O0?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`0000001P3T^j`00`000000iKZZ0>FjZP050>FjZP030000003V^ZP0i[ZX00<0i[ZX0P000007
0;>nhP80000000<0/kkR0000003H`lD01P3H`lD00`000000f/?30=[3``0300000080f/?300<00000
0=_3`@0000001@3La/<00`000000gLK20=g6`P050=g6`P030000003Oa/00glK00080glK000@00000
0<C:g`00000000002@35b]h2000000<08X7X00<00000000UYP000000100AK=h00`000000]/7R0;K1
hP070;K1hP030000003TbKd0000000H0iLVk00<000000>K9^P3VbKX00`3VbKX01`000000ilVh0>O9
^03WbKP000000>G>_`0000000`3Wc[d00`000000iljm000000030>S>_0<0000000<0b5X00000003o
ool02P3oool00`000000oooo0?ooo`0M0?ooo`007`3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0000000L0i;^/00<000000>FjZP3U^ZX0103U^ZX00`000000i[ZX0>JjZ0040>JjZ003
0000003V^JL0000000@0/kkR0P0000040;>nhP030000003H`lD0f<?500<0f<?5100000050=[3``03
0000003K`l40fl?1008000000P3La/<00`000000gLK20=g6`P050=g6`P030000003Oa/00glK000@0
glK000<000000<G:gP35b]h01`35b]h2000000050<K;g@00000000000000000RPNP00P0000000`00
9JH0000000000002015/gP030000002f`N80]/7R00P0]/7R00<000000>G9^`3UbK/0103UbK/00`00
0000i/Vj0>K9^P040>K9^P070000003WbKP0ilVh0>O9^0000000iLjo000000030>O>_@030000003W
c[d0000000@0j<jl1@00000;0?ooo`030000003oool0oooo01`0oooo000O0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`0000001P3T^j`00`000000iKZZ0>FjZP050>FjZP030000003V
^ZP0i[ZX00<0i[ZX00H000000>JiY`3V^JL0i[VW0000002c_^82000000L0/kkR00<000000=S3a@3H
`lD00`0000070=[3``030000003K`l40fl?100<0fl?100<000000=c6``0000001`3Ma/800`000000
glK00=o6`0030=o6`0030000003Pa[h0000000L0aL[N00<000000<K;g@36bmd00P36bmd00`000000
67_U00000006000000804FcN00<000000;K1hP2f`N801@2f`N82000000030;O1hP000000iLVk00<0
iLVk00<000000>K9^P3VbKX0103VbKX00`000000ilVh0>O9^0030>O9^0030000003Wc[d0iljm00<0
iljm00<000000>S>_03Xc[`00`3Xc[`010000000_dl000000038FP02000000/0oooo00<000000?oo
o`3oool06`3oool00200oooo0P0000030?ooo`8000001`3T^j`00`000000iKZZ0>FjZP040>FjZP03
0000003V^ZP0i[ZX00@0i[ZX00<000000>JiY`3V^JL00P3V^JL00`000000/kkR0;>nhP070;>nhP@0
0000203J`l<00`000000fl?10=_3`@050=_3`@030000003Ma/80gLK200D0gLK200<000000=o6`03O
a/00103Oa/000`000000h<Jn0>36_P02000000@0aL[N00<000000<K;g@36bmd01036bmd00`000000
67_U01Qki@0200000003000IW00000001FCI0080000000<04FcN0000002f`N800`2f`N82000000@0
]l7R00D000000>G9^`3UbK/0iLVk000000060>K9^P030000003WbKP0ilVh0080ilVh00<000000>S9
]P000000103Wc[d2000000<0j<jl00<000000>W=^P0000001@0000090?ooo`8000001P3oool20000
00@0oooo0P0000030?ooo`@000000`3oool2000000<0oooo000U0?ooo`8000001P3T^j`00`000000
iKZZ0>FjZP050>FjZP030000003V^ZP0i[ZX00@0i[ZX00<000000>JiY`3V^JL00`3V^JL00`000000
/kkR0;>nhP030;>nhP<000000P2c_^800`000000f/?30=[3``060=[3``030000003K`l40fl?100D0
fl?100<000000=c3_`0000001P3Ma/800`000000glK00=o6`0030=o6`0030000003Pa[h0h<Jn00<0
h<Jn00@000000<G:gP00000000002036bmd20000008067_U00<00000000IW00000000P05I=T20000
0080]/7R0P0000060;O1hP040000003UbK/0iLVk000000H0i/Vj00<000000>O9^03WbKP00`3WbKP0
10000000j<Vf0>S9]P0000020>O>_@030000003Xc[`0000000<0j<jl00H000000>W=^P000000_dl0
00000038FP02000000/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000080?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool002D0oooo00<000000>Bk
[03T^j`01@3T^j`00`000000iKZZ0>FjZP050>FjZP030000003V^ZP0i[ZX00<0i[ZX00<000000>Ji
Y`3V^JL0103V^JL2000000040;>nhP0000000000000000<0/kkR0P0000000`2d_^4000000=[3``06
0=[3``030000003K`l40fl?100D0fl?100@000000=c3_`3L`kl00000103Ma/800`000000glK00=o6
`0030=o6`0030000003Pa[h0h<Jn00D0h<Jn00<000000<K;g@36bmd01P36bmd2000000080<O;g000
000000000000000HNnD00000000IW000000300ETf@8000002@2g`N800`000000iLVk000000050>K9
^P030000003WbKP0ilVh00<0ilVh00D000000>S9]P3XbKH0j<Vf000000020>O>_@060000003Xc[`0
j<jl0000003Xc[`000000`3YcKX6000000/0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool100000040oooo0@3oool002D0oooo
00<000000>Bk[03T^j`01@3T^j`00`000000iKZZ0>FjZP040>FjZP030000003V^ZP0i[ZX00@0i[ZX
00<000000>JiY`3V^JL0103V^JL3000000@0/kkR0P0000040;Bnh@030000003J`l<0f/?300<0f/?3
00<000000=_3`@3K`l401@3K`l400`000000g<>o0=c3_`020=c3_`040000003Ma/80gLK2000000H0
glK000<000000>36_P3Pa[h0103Pa[h00`000000hLFm000000060<K;g@0300000037bm`0al_L0080
al_L00<0000000idh@0000000P0000000`006I`000000000000200ETf@030000002g`N80]l7R00P0
]l7R00<000000>K9^P3VbKX0103VbKX00`000000ilVh0>O9^0030>O9^0030000003XbKH0j<Vf0080
j<Vf0P0000040>S>_0800000103YcKX3000000030<aN00000000000000X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool20000
00<0oooo000U0?ooo`8000001@3T^j`00`000000iKZZ0>FjZP050>FjZP030000003V^ZP0i[ZX00@0
i[ZX00<000000>JiY`3V^JL00P3V^JL2000000<0ikVV00@000000;>nhP00000000001P2d_^400`00
0000f/?30=[3``020=[3``030000003K`l40fl?100D0fl?100<000000=c3_`3L`kl0103L`kl00`00
0000gLK2000000050=o6`0030000003Pa[h0h<Jn00D0h<Jn00@000000>75_@3QaKd000001036bmd0
0`000000al_L0<O;g0040<O;g0030000000>M>403WCQ00D000000P05I=T00`000000]l7R0;O1hP05
0;O1hP80000000<0^<7Q0000003VbKX00`3VbKX00`000000ilVh0>O9^0030>O9^0030000003XbKH0
j<Vf00@0j<Vf00<000000>S>_03Xc[`00P3Xc[`2000000<0jLfj00<000000>[=^00000001000000:
0?ooo`8000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00P3oool002@0oooo0P0000000`3oool000000>Bk[0030>Bk[0030000003U
^ZX0iKZZ00D0iKZZ00<000000>JjZ03V^ZP00`3V^ZP00`000000i[VW0>JiY`03000000030>JiY`00
0000ikVV00<0ikVV00<000000;Bnh@2d_^401`2d_^4010000000f/?30=[3``0000080=_3`@030000
003L`kl0g<>o00D0g<>o00<000000=o6`03Oa/00103Oa/000`000000h<Jn0>36_P040>36_P030000
003QaKd0hLFm0080hLFm00@000000<K;g@00000000001P37bm`010000000b<_L00000000000200id
h@80000000@005cD00000000000000001@2g`N82000000@0^<7Q00D000000>K9^P3VbKX0i/Vj0000
00050>O9^0030000003XbKH0j<Vf00<0j<Vf00<000000>W9]00000000`3Xc[`2000000<0jLfj00<0
00000>[=^00000000P0000000`3<GP000000000000060?ooo`D000000`3oool2000000X0oooo0P00
00040?ooo`<000000P3oool002@0oooo00@000000?ooo`3oool000000`3T^j`00`000000iKZZ0>Fj
ZP050>FjZP030000003V^ZP0i[ZX00@0i[ZX0`0000030>JiY`030000003W^JH0ikVV00@0ikVV00<0
00000;Bnh@2d_^401`2d_^400`000000f/?3000000070=_3`@030000003L`kl0g<>o00D0g<>o00<0
00000=g2_P000000103Oa/000`000000h<Jn0>36_P040>36_P030000003QaKd0hLFm00@0hLFm00<0
00000<O;g037bm`01@37bm`010000000b<_L0<S;g038bm`30000000300idh@0000000000008005cD
0P0000020;O1hP8000001P2h`N4010000000i/Vj0>K9^P0000050>O9^0030000003XbKH0j<Vf00@0
j<Vf00<000000>W9]00000000P3Xc[`01P000000jLfj0>W=^P000000jLfj000000<0j/fh1@000002
0?ooo`@00000103oool00`000000oooo0?ooo`0H0?ooo`00903oool01@000000oooo0?ooo`3oool0
00000080i;^/00<000000>FjZP3U^ZX01@3U^ZX010000000i[ZX0>JjZ03V^ZP3000000H0i[VW00<0
00000>NiYP3W^JH00`3W^JH00`000000ikVT000000080;Bnh@8000001`3K`l400`000000g<>o0=c3
_`060=c3_`040000003M`[h0gL:n00000080glK000<000000>36_P3Pa[h01@3Pa[h00`000000hLFm
0>75_@030>75_@030000003RaK/0000000@0al_L0P0000050<S;g00300000004KMd0000000<00000
0`00G=@2000000T0^<7Q00<000000>K9^P0000001@3WbKP00`000000j<Vf0>S9]P030>S9]P070000
003YbK@0jLVd0>W9]0000000j<jl000000030>W=^P800000103ZcKP2000000040<aN000000000000
000000P0oooo00<000000?ooo`3oool0603oool00080oooo100000020?ooo`060000003oool0oooo
0?ooo`000000oooo1@0000020?ooo`8000003@3oool2000000<0oooo0P0000070>FjZP030000003V
^ZP00000008000000P3V^ZP00`000000i[VW0>JiY`040>JiY`030000003W^JH0ikVV00<0ikVV00@0
00000>NiY03W^J@000001@2d_^4200000080]KkQ00<000000=_3`@3K`l40103K`l400`000000g<>o
0=c3_`050=c3_`030000003M`[h0gL:n0080gL:n00<000000=o6`00000001P3Pa[h00`000000hLFm
0>75_@040>75_@030000003RaK/0000000<0al_L00<000000<S;g038bm`01P38bm`00`00000016gM
00A]g@040000008005cD00<000000;S1h@2h`N40202h`N400`000000ilVh0>O9^0030>O9^0030000
003XbKH0j<Vf00@0j<Vf00<000000>W9]03YbK@00P3YbK@00`000000jLfj0>W=^P020>W=^P030000
003ZcKP0j/fh0080j/fh00<000000>_=]`000000100000090?ooo`030000003oool0oooo01L0oooo
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000
003U^ZX0iKZZ00@0iKZZ0`0000050>JjZ0030000003V^JL0i[VW00<0i[VW00<000000>NiYP3W^JH0
103W^JH01@000000ikVT0>NiY03W^J@000000080];kQ0P0000050;Fnh@030000003K`l40fl?10080
fl?100<000000=c3_`3L`kl01@3L`kl00`000000gL:n0=g2_P040=g2_P030000003Pa[h0h<Jn00@0
h<Jn00<000000>75_@3QaKd0103QaKd01`000000h/Fk0>;5^`3RaK/000000<O;g00000001`38bm`2
000000030<W;f`0000000000008016gM0`000002001Le0030000002h`N40^<7Q00D0^<7Q0P000000
0`2h`N4000000>O9^0030>O9^0030000003XbKH0j<Vf00<0j<Vf00<000000>W9]03YbK@00`3YbK@2
000000<0jLfj0P0000030>[=^0050000003[cKL000000000003<GP000`0000080?ooo`030000003o
ool0oooo01L0oooo00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`040?ooo`030000003U^ZX0iKZZ00<0000000<0iKZZ0000003V^ZP0103V^ZP00`000000i[VW0>Ji
Y`040>JiY`030000003W^JH0ikVV00<0ikVV00<000000>NiY03W^J@00`3W^J@2000000P0]KkQ00@0
00000=_3`@3K`l400000203L`kl00`000000gL:n0=g2_P030=g2_P030000003N`[`0000000D0h<Jn
00<000000>75_@3QaKd00`3QaKd00`000000h/Fk0>;5^`030>;5^`0300000038bm`0b<_L00D0b<_L
00<000000<W;f`39bm/00P39bm/500000004001CcP0000000000000000D0^<7Q0P0000040;S1h@04
0000003WbKP0ilVh000000H0j<Vf00<000000>W9]03YbK@00P3YbK@00`000000jlRb000000020>W=
^P060000003ZcKP0j/fh0000003ZcKP000000`3[cKL4000000030=AZ00000000oooo00H0oooo00<0
00000?ooo`3oool05`3oool000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo00000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00D0oooo0`0000030>FjZP030000003V^ZP0i[ZX00@0i[ZX00<000000>JiY`3V^JL0103V
^JL00`000000ikVV0>NiYP030>NiYP030000003W^J@0ikVT00<0ikVT0P0000090;Fnh@030000003K
`l40000000L0g<>o00<000000=g2_P3M`[h0103M`[h010000000g/:l0=k2_00000030>36_P030000
003QaKd0hLFm00@0hLFm00<000000>;5^`3RaK/00P3RaK/00`000000hlFj000000050<S;g0030000
0039bm/0bL_K00@0bL_K00<00000001Vf00000000P000002001CcP8000000P2h`N42000000H0^<7Q
00@000000>O9^03WbKP000001@3XbKH00`000000jLVd0>W9]0030>W9]0060000003[b;80jlRb0000
003YcKX000000`3ZcKP2000000<0jlfg0P000000103<GP0000000000000000070?ooo`030000003o
ool0oooo01L0oooo00020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`80
00000`3oool300000080oooo0P0000020>FjZP030000003V^ZP0i[ZX00@0i[ZX00<000000>JiY`3V
^JL00`3V^JL00`000000ikVV0>NiYP040>NiYP030000003W^J@0ikVT00<0ikVT00<000000>RhX`00
0000202e_^42000000L0g<>o00<000000=g2_P3M`[h0103M`[h01@000000g/:l0=k2_03N`[`00000
0080h<Jn00<000000>75_@3QaKd0103QaKd00`000000h/Fk0>;5^`030>;5^`030000003SaKX0hlFj
0080000000<0b<_L0000000000002039bm/00`00000006KH001Vf002000000<005?>0P0000090;S1
h@8000001P3XbKH00`000000jLVd0>W9]0020>W9]0030000003[b;80jlRb0080jlRb00<000000>[=
^03ZcKP00P3ZcKP00`000000jlfg0>_=]`020>_=]`80000000D0c5h0000000000000e6X000000006
0?ooo`030000003oool0oooo01L0oooo00030?ooo`8000002P3oool2000000@0oooo0P0000080?oo
o`06092@T030`<00X:2P0?ooo`000000oooo0`0000070?ooo`8000001P3V^ZP00`000000i[VW0>Ji
Y`040>JiY`030000003W^JH0ikVV00<0ikVV00<000000>NiY03W^J@0103W^J@010000000j;RS0>Rh
X`0000050;Fnh@8000000P2f_^400`000000g<>o0=c3_`040=c3_`030000003M`[h0gL:n00<0gL:n
00<000000=k2_03N`[`00`3N`[`00`000000h<Jn000000050>75_@030000003RaK/0h/Fk00<0h/Fk
00<000000>?5^P3SaKX00`3SaKX00`000000bL_K0<W;f`060<W;f`80000000@0b/_J000000000000
06KH0`000002001CcP030000002h`N40^<7Q00P0^<7Q00<000000>S9]P3XbKH00`3XbKH00`000000
jLVd0>W9]0030>W9]0030000003[b;80jlRb0080jlRb0P0000030>[=^08000000P3[cKL01@000000
k<fe000000000000c5h000<000001P3oool00`000000oooo0?ooo`0G0?ooo`007`3oool0102`/;00
oooo0:2PX03oool2000000/0oooo00<000000>JjZ03V^ZP0103V^ZP00`000000i[VW0>JiY`040>Ji
Y`030000003W^JH0ikVV00<0ikVV00<000000>NiY03W^J@00`3W^J@00`000000j;RS0>RhX`020>Rh
X`030000002e_^40]KkQ008000001@2f_^400`000000g<>o0=c3_`020=c3_`030000003M`[h0gL:n
00@0gL:n00<000000=k2_03N`[`0103N`[`00`000000hLFm0>75_@040>75_@030000003RaK/0h/Fk
00<0h/Fk00<000000>?5^P3SaKX00P3SaKX00`000000hlFi000000060<W;f`030000003:bmX0b/_J
0080b/_J1P000002001CcP030000002h`N40^<7Q00D0^<7Q0P0000000`2i`^4000000>S9]P030>S9
]P030000003YbK@0jLVd0080jLVd00<000000>_8/P3[b;800P3[b;800`000000jlRa000000020>[=
^0060000003[cKL0jlfg0000003[cKL000000P3/cKD01P000000c5h0000000000000e6X0000000D0
oooo00<000000?ooo`3oool05`3oool001T0oooo00@0h>3P0820P020P800P8200P3oool00`20P800
T92@0;2`/0020?ooo`030000003oool0oooo00X0oooo00<000000>JjZ03V^ZP00P3V^ZP00`000000
i[VW0>JiY`040>JiY`030000003W^JH0ikVV00@0ikVV00<000000>NiY03W^J@00`3W^J@00`000000
j;RS0>RhX`020>RhX`<00000202f_^4010000000g<>o0=c3_`0000060=g2_P030000003N`[`0g/:l
00@0g/:l00<000000=o2^`000000103QaKd00`000000h/Fk0>;5^`030>;5^`030000003SaKX0hlFj
00<0hlFj00@000000>?5^@3SaKT000001039bm/00`000000b/_J0<[;fP040<[;fP0300000000Gm<0
000000D000001@2h`N42000000@0^L;Q00@000000>S9]P3XbKH000001@3YbK@00`000000jlRb0>_8
/P020>_8/P060000003[b;40jlRa0000003ZcKP000000`3[cKL010000000k<fe0>c=]@3/cKD20000
00040<aN000000000000000000D0oooo00<000000?ooo`3oool05`3oool001l0oooo00<0/;2`0?oo
o`2`/;000`3oool2000000/0oooo00D000000>JjZ03V^ZP0i[ZX000000060>JiY`030000003W^JH0
ikVV00<0ikVV00<000000>NiY03W^J@0103W^J@00`000000j;RS0>RhX`020>RhX`030000003X^:80
000000T0][kQ00<000000=c3_`0000001@3M`[h00`000000g/:l0=k2_0050=k2_0040000003O`[/0
gl:k00000080hLFm00<000000>;5^`3RaK/00`3RaK/00`000000hlFj0>?5^P030>?5^P030000003S
aKT0hlFi0080hlFi00@000000<W;f`00000000001@3:bmX2000000040<_;f@0000000000001Od`80
000000<004_80000000000000P2h`N42000000H0^L;Q00@000000>S9]P3XbKH00000103YbK@00`00
0000jlRb0>_8/P020>_8/P030000003[b;40jlRa0080jlRa00<000000>_=]`3[cKL00P3[cKL01000
0000k<fe0>c=]@3/cKD2000000050<aN0000000000000=AZ000000001@3oool00`000000oooo0?oo
o`0F0?ooo`007`3oool00`2PX:00/;2`0;2`/0050?ooo`030000003oool0oooo00T0oooo00@00000
0>JjZ03V^ZP000001P3V^JL00`000000ikVV0>NiYP030>NiYP030000003W^J@0ikVT00<0ikVT00<0
00000>RhX`3X^:<00`3X^:<010000000j;RR0>RhXP0000080;Jnh@8000001P3M`[h00`000000g/:l
0=k2_0040=k2_0030000003O`[/0gl:k0080gl:k00<000000>75_@0000001@3RaK/00`000000hlFj
0>?5^P030>?5^P030000003SaKT0hlFi00<0hlFi00<000000<[;fP3:bmX0103:bmX00`000000bl_I
0<_;f@020<_;f@<0000000@0001l00000000BlP004_80P0000090;W2h@8000001@3YbK@00`000000
jlRb0>_8/P020>_8/P030000003[b;40jlRa0080jlRa0P0000020>_=]`030000003/cKD000000080
k<fe0`000000103<GP0000000000000000050?ooo`030000003oool0oooo01H0oooo000X0?ooo`03
0000003oool0oooo00T0oooo0P0000060>JiY`030000003W^JH0ikVV00@0ikVV00<000000>NiY03W
^J@00`3W^J@00`000000j;RS0>RhX`020>RhX`050000003X^:80j;RR0>RhXP0000001P2f_^420000
0080]koP00<000000=g2_P3M`[h00P3M`[h00`000000g/:l0=k2_0050=k2_0030000003O`[/0gl:k
00<0gl:k00<000000>;5^`3RaK/00`3RaK/00`000000hlFj0>?5^P030>?5^P030000003SaKT0hlFi
00<0hlFi00<000000>C4]`000000103:bmX00`000000bl_I0<_;f@050<_;f@D0000000<004_80000
002i`^402@2i`^400`000000jLVd0>W9]0020>W9]0030000003[b;80jlRb0080jlRb00<000000>_8
/@3[b;400P3[b;400`000000k<R_000000020>_=]`090000003/cKD0k<fe0000003/cKD000000?oo
o`000000c5h00080000000<0e6X00000003oool00`3oool00`000000oooo0?ooo`0F0?ooo`00:@3o
ool00`000000oooo0?ooo`090?ooo`030000003V^JL0i[VW00@0i[VW00<000000>NiYP3W^JH00`3W
^JH00`000000ikVT0>NiY0040>NiY0030000003X^:<0j;RS0080j;RS00<000000>RhXP3X^:800P3X
^:800`000000][kQ0;Jnh@03000000D0]koP00@000000=g2_P3M`[h000001`3N`[`00`000000gl:k
0=o2^`030=o2^`030000003P`[X0000000@0h/Fk00<000000>?5^P3SaKX00`3SaKX00`000000hlFi
0>?5^@030>?5^@050000003Ta;L0i<Bg0000003:bmX00P0000070<_;f@030000003<bmT000000080
000000@004;200000000BlP000001`2i`^42000000030;[2h0000000jLVd0080jLVd00<000000>_8
/P3[b;800P3[b;800`000000jlRa0>_8/@020>_8/@030000003/b:l0k<R_008000000`3/cKD20000
00<0oooo00<000000<aN000000000P0000040?ooo`030000003oool0oooo01H0oooo000Z0?ooo`80
00002P3oool00`000000i[VW0>JiY`020>JiY`030000003W^JH0ikVV00@0ikVV00<000000>NiY03W
^J@00`3W^J@00`000000j;RS0>RhX`030>RhX`030000003X^:80j;RR0080j;RR0`0000090;Noh003
0000003M`[h0000000H0g/:l00<000000=o2^`3O`[/0103O`[/010000000h<:j0>32^P0000020>;5
^`030000003SaKX0hlFj00<0hlFj00<000000>?5^@3SaKT00`3SaKT00`000000i<Bg0>C4]`020>C4
]`030000003;bmT0bl_I00H0bl_I00H000000<c;f@3<bmT00000001@b00000020012`P8000001@2i
`^42000000<0^/;P00@000000>W9]03YbK@00000103[b;800`000000jlRa0>_8/@020>_8/@030000
003/b:l0k<R_0080k<R_00<000000>c=]@3/cKD00P3/cKD00`000000oooo0?ooo`020?ooo`<00000
00<0e6X00000003oool00P3oool00`000000oooo0?ooo`0F0?ooo`00;03oool00`000000oooo0?oo
o`080?ooo`050000003V^JL0i[VW0>JiY`0000001P3W^JH00`000000ikVT0>NiY0030>NiY0030000
003X^:<0j;RS0080j;RS00<000000>RhXP3X^:800`3X^:800`000000j;RQ0000000:0;Noh0030000
003N`[`0g/:l00D0g/:l00<000000=o2^`3O`[/00`3O`[/00`000000h<:j0>32^P020>32^P030000
003RaK/0000000D0hlFj00<000000>?5^@3SaKT00`3SaKT00`000000i<Bg0>C4]`020>C4]`800000
1@3;bmT2000000@0c<_I00<00000001@b00000000P00@/8200000080^L;Q0P0000060;[2h0030000
003YbK@0000000@0jlRb00<000000>_8/@3[b;400P3[b;400`000000k<R_0>c8[`020>c8[`800000
0P3/cKD00`000000oooo000000040?ooo`@000000`3oool00`000000oooo0?ooo`0F0?ooo`00;@3o
ool00`000000oooo0?ooo`080?ooo`040000003V^JL0i[VW000000D0ikVV00<000000>NiY03W^J@0
103W^J@00`000000j;RS0>RhX`020>RhX`030000003X^:80j;RR00<0j;RR00@000000>RhX@3X^:40
00001`2g_n02000000030;Noh0000000g/:l00@0g/:l00<000000=o2^`3O`[/0103O`[/00`000000
h<:j0>32^P030>32^P030000003SaKX0hlFj00<0hlFj00<000000>?5^@3SaKT00`3SaKT00`000000
i<Bg0>C4]`020>C4]`040000003Ua;H0iLBf000000<0bl_I00<000000<c;f@3<bmT01@3<bmT00`00
00000538000000030012`P800000202j`^02000000@0jlRb00<000000>_8/@3[b;400`3[b;401`00
0000k<R_0>c8[`3/b:l000000>g8[P0000000P3/cKD010000000oooo0?ooo`0000040?ooo`800000
00D0e6X00000003oool0oooo0000000H0?ooo`00;P3oool00`000000oooo0?ooo`080?ooo`800000
1P3W^JH00`000000ikVT0>NiY0040>NiY0030000003X^:<0j;RS0080j;RS00<000000>RhXP3X^:80
0P3X^:800`000000j;RQ0>RhX@020>RhX@030000002g_n00]koP0080]koP0P0000040;Noh0030000
003N`[`0g/:l0080g/:l00<000000=o2^`3O`[/00`3O`[/00`000000h<:j0>32^P030>32^P030000
003Q`[P0000000@0hlFj00<000000>?5^@3SaKT00`3SaKT00`000000i<Bg0>C4]`020>C4]`070000
003Ua;H0iLBf0>G4]P000000bl_I000000060<c;f@80000000<0oooo0000000000000P0000020012
`P030000002j`^00^/;P00L0^/;P00<000000>_8/P3[b;800P3[b;800`000000jlRa0>_8/@020>_8
/@030000003/b:l0k<R_0080k<R_00<000000>g8[P3]b:h00P0000030?ooo`030000003oool0oooo
00<0oooo0`0000020?ooo`030000003oool0oooo01H0oooo000_0?ooo`8000002@3oool00`000000
ikVV0>NiYP040>NiYP030000003W^J@0ikVT00<0ikVT00<000000>RhX`3X^:<00P3X^:<00`000000
j;RR0>RhXP030>RhXP030000003X^:40j;RQ00<0j;RQ00@000000;Noh000000000001`2g_n001000
0000g/:l0=k2_00000060=o2^`030000003P`[X0h<:j00<0h<:j00@000000>72^03Q`[P000000P3S
aKX00`000000hlFi0>?5^@030>?5^@030000003Ta;L0i<Bg0080i<Bg00<000000>G4]P3Ua;H00`3U
a;H00`000000c<_I0<c;f@040<c;f@030000003oool0oooo00<0oooo0`0000000`00@/8000000;[2
h0060;[2h080000000D0^l;P0000003[b;80jlRb000000050>_8/@050000003/b:l0k<R_0>c8[`00
0000103]b:h00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo0`0000030?ooo`03
0000003oool0oooo01D0oooo000a0?ooo`030000003oool0oooo00L0oooo00<000000>NiYP3W^JH0
0P3W^JH00`000000ikVT0>NiY0040>NiY0030000003X^:<0j;RS0080j;RS00<000000>RhXP3X^:80
0`3X^:800`000000j;RQ0>RhX@020>RhX@030000003Y^:40000000X0]koP00<000000=k2_0000000
1@3O`[/00`000000h<:j0>32^P030>32^P030000003Q`[P0hL:h0080hL:h00<000000>?5^P000000
1@3SaKT00`000000i<Bg0>C4]`020>C4]`030000003Ua;H0iLBf0080iLBf00<000000>G4]@000000
103<bmT00`000000oooo0?ooo`060?ooo`80000000<004;20000002j`^000`2j`^02000000<0^l;P
00@000000>_8/P3[b;8000001@3[b;401@000000k<R_0>c8[`3/b:l0000000@0kLR^00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`<000000P3oool00`000000oooo0?ooo`0E0?oo
o`00<P3oool00`000000oooo0?ooo`070?ooo`050000003W^JH0ikVV0>NiYP0000001P3W^J@00`00
0000j;RS0>RhX`020>RhX`030000003X^:80j;RR00<0j;RR00<000000>RhX@3X^:400P3X^:401000
0000jKRQ0>VhX@00000:0;Noh0030000003O`[/0gl:k00@0gl:k00<000000>32^P3P`[X00`3P`[X0
0`000000hL:h0>72^0030>72^0030000003SaKT0hlFi00<0hlFi00<000000>C4]`3Ta;L00P3Ta;L0
0`000000iLBf0>G4]P030>G4]P050000003Ua;D0iLBe0000003<bmT00P00000:0?ooo`<000000P2j
`^02000000H0^l;P0P0000050>_8/@030000003/b:l0k<R_0080k<R_00D000000>g8[P3]b:h0kLR^
000000060?ooo`030000003oool0oooo0080oooo0`0000020?ooo`030000003oool0oooo01D0oooo
000c0?ooo`030000003oool0oooo00L0oooo00@000000>NiYP3W^JH000001@3W^J@00`000000j;RS
0>RhX`020>RhX`030000003X^:80j;RR00<0j;RR00<000000>RhX@3X^:400`3X^:401@000000jKRQ
0>VhX@3Y^:40000000L0]koP0P0000000`2h_ml000000=o2^`030=o2^`030000003P`[X0h<:j00<0
h<:j00<000000>72^03Q`[P00`3Q`[P00`000000h/6g000000040>?5^@030000003Ta;L0i<Bg0080
i<Bg00<000000>G4]P3Ua;H00P3Ua;H00`000000iLBe0>G4]@020>G4]@030000003oool0oooo00X0
oooo0P0000000`00>[/00000000000090;_2h0030000003[b;40jlRa00<0jlRa00D000000>c8[`3/
b:l0k<R_000000040>g8[P030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool30000
00030?ooo`000000oooo01H0oooo000d0?ooo`030000003oool0oooo00L0oooo0P0000060>NiY003
0000003X^:<0j;RS0080j;RS00<000000>RhXP3X^:800`3X^:800`000000j;RQ0>RhX@030>RhX@05
0000003Y^:40jKRQ0>VhX@0000001@2g_n02000000@0^;oO00D000000=o2^`3O`[/0gl:k00000005
0>32^P030000003Q`[P0hL:h00<0hL:h00@000000>;1]`3R`KL000000P3SaKT00`000000i<Bg0>C4
]`030>C4]`030000003Ua;H0iLBf0080iLBf00<000000>G4]@3Ua;D00P3Ua;D00`000000oooo0?oo
o`0;0?ooo`80000000<003Zk0000002k`^001P2k`^02000000030;_2g`000000jlRa0080jlRa00<0
00000>c8[`3/b:l00P3/b:l00`000000kLR^0>g8[P020>g8[P030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool2000000030?ooo`000000oooo01H0oooo000e0?ooo`800000203oool0
0`000000ikVT0>NiY0040>NiY0030000003X^:<0j;RS0080j;RS00<000000>RhXP3X^:800`3X^:80
0`000000j;RQ0>RhX@020>RhX@030000003Y^:40jKRQ0080jKRQ0P0000020;Noh08000001P2h_ml0
10000000gl:k0=o2^`0000050>32^P030000003Q`[P0hL:h00<0hL:h00<000000>;1]`3R`KL00P3R
`KL00`000000hlFi000000040>C4]`030000003Ua;H0iLBf0080iLBf00<000000>G4]@3Ua;D00P3U
a;D00`000000oooo0?ooo`0=0?ooo`@000001@2k`^000`000000^l;O0;_2g`020;_2g`040000003[
b;40jlRa000000@0k<R_00D000000>g8[P3]b:h0kLR^0000000:0?ooo`040000003oool0oooo0?oo
o`@000005`3oool003L0oooo00<000000?ooo`3oool01P3oool00`000000ikVT0>NiY0020>NiY003
0000003X^:<0j;RS0080j;RS00<000000>RhXP3X^:800`3X^:800`000000j;RQ0>RhX@030>RhX@03
0000003Y^:40jKRQ0080jKRQ00@000000>VgW`00000000002@2h_ml00`000000gl:k000000050>32
^P030000003Q`[P0hL:h00<0hL:h00<000000>;1]`3R`KL00`3R`KL00`000000i<Bg0>C4]`030>C4
]`030000003Ua;H0iLBf0080iLBf00<000000>G4]@3Ua;D00P3Ua;D00`000000oooo0?ooo`0>0?oo
o`0300000000<K@0000000@0^l;P00<000000;_2g`2k`]l00`2k`]l010000000jlRa0>_8/@000003
0>c8[`030000003]b:h0kLR^0080kLR^00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`<000005`3oool003P0oooo00<000000?ooo`3oool01P3oool01@000000ikVT0>NiY03W^J@0
000000@0j;RS00<000000>RhXP3X^:800`3X^:800`000000j;RQ0>RhX@030>RhX@030000003Y^:40
jKRQ0080jKRQ00@000000>VgW`3Y]il000002P2h_ml00`000000h<:j0>32^P030>32^P030000003Q
`[P0hL:h00<0hL:h00<000000>;1]`3R`KL00`3R`KL00`000000hl6f000000030>C4]`030000003U
a;H0iLBf0080iLBf00<000000>G4]@3Ua;D00P3Ua;D00`000000oooo0?ooo`0@0?ooo`0400000000
<K@000000;_2h08000001`2k`]l2000000@0k<R_00<000000>g8[P3]b:h00P3]b:h00`000000oooo
0?ooo`090?ooo`040000003oool0oooo0?ooo`@000005P3oool003T0oooo00<000000?ooo`3oool0
1P3oool010000000ikVT0>NiY00000040>RhX`030000003X^:80j;RR00<0j;RR00<000000>RhX@3X
^:400P3X^:400`000000jKRQ0>VhX@030>VhX@050000003Y]il0jKNO0>VgW`0000001`2h_ml20000
00030;Vog`000000h<:j00<0h<:j00<000000>72^03Q`[P00`3Q`[P00`000000h/6g0>;1]`030>;1
]`040000003S`KH0hl6f00000080i<Bg00<000000>G4]P3Ua;H00P3Ua;H00`000000iLBe0>G4]@02
0>G4]@030000003oool0oooo0140oooo00<00000000a]00000002P2k`]l01@000000k<R_0>c8[`3/
b:l0000000@0kLR^00<000000?ooo`3oool02`3oool010000000oooo0?ooo`3oool3000001H0oooo
000j0?ooo`8000001`3oool2000000D0j;RS00<000000>RhXP3X^:800`3X^:800`000000j;RQ0>Rh
X@020>RhX@030000003Y^:40jKRQ0080jKRQ00<000000>VgW`3Y]il00P3Y]il2000000@0^;oO0P00
00040;Vog`040000003P`[X0h<:j000000D0hL:h00<000000>;1]`3R`KL00`3R`KL00`000000hl6f
0>?1]P020>?1]P800000103Ua;H00`000000iLBe0>G4]@020>G4]@030000003oool0oooo01<0oooo
0`0000070;_2g`80000000D0_<;O0000003/b:l0k<R_000000040>g8[P030000003oool0oooo00`0
oooo00@000000?ooo`3oool0oooo0P00000F0?ooo`00?03oool00`000000oooo0?ooo`050?ooo`03
0000003X^:<0j;RS0080j;RS00<000000>RhXP3X^:800`3X^:800`000000j;RQ0>RhX@030>RhX@03
0000003Y^:40jKRQ0080jKRQ00<000000>VgW`3Y]il00P3Y]il010000000jKNO0000002h_ml20000
00L0^KoO00<000000>32^P0000001@3Q`[P00`000000h/6g0>;1]`030>;1]`030000003S`KH0hl6f
00<0hl6f00<000000>G4]P3Ua;H00P3Ua;H00`000000iLBe0>G4]@020>G4]@030000003oool0oooo
01@0oooo0P0000050;_2g`8000000`2l`]l010000000k<R_0>c8[`0000030>g8[P030000003oool0
oooo00d0oooo00@000000?ooo`3oool0oooo0P00000F0?ooo`00?@3oool00`000000oooo0?ooo`05
0?ooo`050000003X^:<0j;RS0>RhX`0000001@3X^:800`000000j;RQ0>RhX@020>RhX@030000003Y
^:40jKRQ00<0jKRQ00<000000>VgW`3Y]il00P3Y]il010000000jKNO0>VgW`00000:0;Vog`030000
003Q`[P0hL:h00<0hL:h00<000000>;1]`3R`KL00`3R`KL00`000000hl6f0>?1]P030>?1]P030000
003S`K@000000080iLBf00<000000>G4]@3Ua;D00`3Ua;D00`000000oooo0?ooo`0D0?ooo`<00000
0P2k`]l2000000H0_<;O0P0000040>g8[P030000003oool0oooo00h0oooo00@000000?ooo`3oool0
oooo0P00000E0?ooo`00?P3oool00`000000oooo0?ooo`050?ooo`040000003X^:<0j;RS000000D0
j;RR00<000000>RhX@3X^:400P3X^:400`000000jKRQ0>VhX@020>VhX@030000003Y]il0jKNO00<0
jKNO00D000000>VgW`3Y]il0jKNO000000070;Vog`80000000<0^KoN0000003Q`[P00`3Q`[P00`00
0000h/6g0>;1]`030>;1]`030000003S`KH0hl6f00<0hl6f00H000000>?1]03S`K@000000>G4]P00
00040>G4]@030000003oool0oooo01H0oooo100000090;c2g`030000003]b:h0kLR^0080kLR^00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`02000001D0oooo000o0?ooo`8000001P3oool2
000000H0j;RR00<000000>RhX@3X^:400P3X^:400`000000jKRQ0>VhX@020>VhX@030000003Y]il0
jKNO0080jKNO00<000000>VgW`3Y]il00P3Y]il2000000@0^KoO0P0000040;VogP040000003Q`[P0
hL:h000000D0h/6g00<000000>?1]P3S`KH00`3S`KH00`000000hl6d0>?1]0020>?1]0030000003U
a;D0iLBe00<0iLBe00<000000?ooo`3oool05`3oool3000000L0_<;O0P0000001@2m`mh000000>g8
[P3]b:h000000180oooo00@000000?ooo`3oool000005P3oool00440oooo00<000000?ooo`3oool0
103oool00`000000j;RR0>RhXP030>RhXP030000003X^:40j;RQ00<0j;RQ00<000000>VhX@3Y^:40
0P3Y^:400`000000jKNO0>VgW`020>VgW`030000003Y]il0jKNO0080jKNO00@000000>ZgWP000000
^KoO0P0000060;VogP040000003Q`[P0hL:h000000D0h/6g00<000000>?1]P3S`KH00`3S`KH00`00
0000hl6d0>?1]0020>?1]08000000`3Ua;D00`000000oooo0?ooo`0I0?ooo`03000000008:H00000
00@0_<;O0P0000030;g3gP040000003]b:h0kLR^000001<0oooo00<000000?ooo`0000005P3oool0
0480oooo00<000000?ooo`3oool0103oool00`000000j;RR0>RhXP020>RhXP030000003X^:40j;RQ
0080j;RQ00<000000>VhX@3Y^:400P3Y^:400`000000jKNO0>VgW`030>VgW`030000003Y]il0jKNO
0080jKNO00@000000>ZgWP3Z]ih000002@2i_mh2000000D0h/6g00<000000>?1]P3S`KH00`3S`KH0
0`000000hl6d0>?1]0020>?1]0040000003T`K<0i<6c00000080iLBe00<000000?ooo`3oool06P3o
ool010000000022V0000002l`]l2000000H0_L?N00<000000>g8[P000000503oool00`000000oooo
0000000E0?ooo`00@`3oool00`000000oooo0?ooo`040?ooo`050000003X^:80j;RR0>RhXP000000
103X^:400`000000jKRQ0>VhX@020>VhX@030000003Y]il0jKNO00<0jKNO00<000000>VgW`3Y]il0
0P3Y]il01@000000j[NN0>ZgWP3Z]ih0000000P0^KoN0P0000050>;1]`030000003S`KH0hl6f00<0
hl6f00<000000>?1]03S`K@00P3S`K@010000000i<6c0>C1/`3T`K<2000001h0oooo00<00000000P
YP000000202m`mh2000001H0oooo0P00000E0?ooo`00A03oool2000000D0oooo00@000000>RhXP3X
^:800000103X^:400`000000jKRQ0>VhX@020>VhX@030000003Y]il0jKNO0080jKNO00<000000>Vg
W`3Y]il00P3Y]il00`000000j[NN0>ZgWP020>ZgWP8000001@2i_mh200000080^[oN00D000000>;1
]`3R`KL0h/6g000000050>?1]P030000003S`K@0hl6d0080hl6d00<000000>C1/`3T`K<00`3T`K<0
0`000000oooo0?ooo`0M0?ooo`03000000008:H0000000P0_L?N00<000000?ooo`3oool0503oool2
000001D0oooo00160?ooo`030000003oool0oooo00<0oooo0P0000040>RhX@030000003Y^:40jKRQ
00<0jKRQ00<000000>VgW`3Y]il00P3Y]il00`000000jKNO0>VgW`020>VgW`050000003Z]ih0j[NN
0>ZgWP0000000P3Z]id00`000000^KoN0;VogP02000000D0^[oN00@000000>;1]`3R`KL000001@3S
`KH00`000000hl6d0>?1]0020>?1]0030000003T`K<0i<6c00<0i<6c00<000000?ooo`3oool07P3o
ool2000000H0_L?N0P00000G0?ooo`8000005@3oool004L0oooo00<000000?ooo`3oool00`3oool0
0`000000j;RQ0>RhX@020>RhX@030000003Y^:40jKRQ0080jKRQ00<000000>VgW`3Y]il00`3Y]il0
0`000000jKNO0>VgW`020>VgW`050000003Z]ih0j[NN0>ZgWP0000000`3Z]id2000000P0^[oN0P00
00050>?1]P030000003S`K@0hl6d00<0hl6d00<000000>C1/`3T`K<00P3T`K<00`000000oooo0?oo
o`0P0?ooo`8000000`2m`mh2000001D0oooo1000000G0?ooo`00B03oool00`000000oooo0?ooo`03
0?ooo`050000003X^:40j;RQ0>RhX@000000103Y^:400`000000jKNO0>VgW`030>VgW`030000003Y
]il0jKNO0080jKNO00D000000>ZgWP3Z]ih0j[NN000000040>ZgW@030000002j_mh0^[oN00L0^[oN
00<000000>?1]P3S`KH00`3S`KH00`000000hl6d0>?1]0020>?1]0030000003T`K<0i<6c00<0i<6c
00<000000?ooo`3oool08@3oool010000000_L?N00000000000C0?ooo`@000006`3oool004T0oooo
0P0000040?ooo`040000003X^:40j;RQ000000@0jKRQ00<000000>VgW`3Y]il00P3Y]il00`000000
jKNO0>VgW`020>VgW`030000003Z]ih0j[NN0080j[NN00L000000>ZgW@3Z]id0j[NM0000003oool0
000000H0^[oN0P0000000`2k_mh000000>?1]P020>?1]P030000003S`K@0hl6d00<0hl6d00<00000
0>C1/`3T`K<00P3T`K<00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0oooo1000000O
0?ooo`00B`3oool00`000000oooo0?ooo`020?ooo`800000103Y^:400`000000jKNO0>VgW`030>Vg
W`030000003Y]il0jKNO0080jKNO00D000000>ZgWP3Z]ih0j[NN000000040>ZgW@030000003oool0
000000@0^[oN0P0000040;^ogP040000003S`KH0hl6f000000@0hl6d00<000000>C1/`3T`K<00`3T
`K<00`000000oooo0?ooo`0a0?ooo`@000008`3oool004`0oooo00<000000?ooo`3oool00P3oool0
0`000000jKRQ0>VhX@020>VhX@030000003Y]il0jKNO00<0jKNO00<000000>VgW`3Y]il00P3Y]il0
1@000000j[NN0>ZgWP3Z]ih0000000@0j[NM00D000000?ooo`3oool000000;ZogP02000000L0^koN
0P0000050>?1]0030000003T`K<0i<6c0080i<6c00<000000?ooo`3oool0;P3oool4000002L0oooo
001=0?ooo`030000003oool0oooo0080oooo00D000000>VhX@3Y^:40jKRQ000000050>VgW`030000
003Y]il0jKNO0080jKNO00D000000>ZgWP3Z]ih0j[NN000000040>ZgW@050000003oool0oooo0?oo
o`0000002P2k_mh00`000000hl6d0>?1]0030>?1]0030000003T`K<0i<6c0080i<6c00<000000?oo
o`3oool0:`3oool3000002/0oooo001>0?ooo`8000000`3oool010000000jKRQ0>VhX@0000040>Vg
W`030000003Y]il0jKNO0080jKNO00<000000>ZgWP3Z]ih00P3Z]ih00`000000j[NM0>ZgW@020>Zg
W@030000003oool0oooo0080oooo00<000000;^ogP2k_mh01@2k_mh2000000030;^og@000000hl6d
0080hl6d00<000000>C1/`3T`K<00P3T`K<00`000000oooo0?ooo`0X0?ooo`@00000;P3oool00500
oooo00@000000?ooo`3oool0oooo0P0000050>VgW`030000003Y]il0jKNO0080jKNO00<000000>Zg
WP3Z]ih00P3Z]ih01@000000j[NM0>ZgW@3Z]id0000000H0oooo00<000000;^ogP2k_mh00P2k_mh2
000000@0^koM00@000000>?1]03S`K@00000103T`K<00`000000oooo0?ooo`0T0?ooo`@00000<P3o
ool00540oooo00D000000?ooo`3oool0oooo000000050>VgW`030000003Y]il0jKNO0080jKNO00D0
00000>ZgWP3Z]ih0j[NN000000040>ZgW@030000003oool0oooo00D0oooo00@000000;^ogP000000
00001`2k_md2000000@0i<6c00<000000?ooo`3oool08@3oool4000003H0oooo001B0?ooo`050000
003oool0oooo0?ooo`000000103Y]il00`000000jKNO0>VgW`020>VgW`050000003Z]ih0j[NN0>Zg
WP000000103Z]id00`000000oooo0?ooo`060?ooo`030000002k_md0^koM00P0^koM00<000000>C1
/`3T`K<00P3T`K<00`000000oooo0?ooo`0M0?ooo`@00000>P3oool005<0oooo0P0000020?ooo`80
000000<0jKNO0000003Y]il00`3Y]il00`000000j[NN0>ZgWP020>ZgWP030000003Z]id0j[NM0080
j[NM00<000000?ooo`3oool01`3oool00`000000^koM0;^og@050;^og@80000000D0_<3M0000003T
`K<0i<6c0000000L0?ooo`@00000?P3oool005D0oooo00@000000?ooo`3oool0oooo0P0000040>Vg
W`030000003Z]ih0j[NN0080j[NN00<000000>ZgW@3Z]id00P3Z]id00`000000oooo0?ooo`080?oo
o`030000002k_md0^koM0080^koM0P0000030;c0g@040000003T`K<0i<6c000001P0oooo10000012
0?ooo`00EP3oool01@000000oooo0?ooo`3oool0000000@0jKNO00<000000>ZgWP3Z]ih00P3Z]ih0
1@000000j[NM0>ZgW@3Z]id0000000`0oooo00@000000;^og@00000000001P2l`=d2000001H0oooo
0`0000160?ooo`00E`3oool01@000000oooo0?ooo`3oool0000000<0jKNO00D000000>ZgWP3Z]ih0
j[NN000000040>ZgW@030000003oool0oooo00/0oooo00<000000;c0g@2l`=d01`2l`=d00`000000
oooo0?ooo`0@0?ooo`@00000B@3oool005P0oooo00L000000?ooo`3oool0oooo0000003Y]il00000
00@0j[NN00<000000>ZgW@3Z]id00P3Z]id00`000000oooo0?ooo`0<0?ooo`030000002l`=d0_<3M
00@0_<3M0P00000?0?ooo`@00000C@3oool005T0oooo0P0000020?ooo`800000103Z]ih00`000000
j[NM0>ZgW@020>ZgW@030000003oool0oooo00`0oooo00<000000;c0g@2l`=d00P2l`=d2000000d0
oooo1000001A0?ooo`00F`3oool010000000oooo0?ooo`0000040>ZgWP030000003Z]id0j[NM0080
j[NM00<000000?ooo`3oool03@3oool010000000_<3M00000000000;0?ooo`@00000E@3oool005`0
oooo00@000000?ooo`3oool000000`3Z]ih01@000000j[NM0>ZgW@3Z]id000000140oooo00<00000
0?ooo`3oool01`3oool4000005T0oooo001M0?ooo`060000003oool0oooo0000003Z]ih00000103Z
]id00`000000oooo0?ooo`0F0?ooo`<00000G@3oool005h0oooo0P0000000`3oool0000000000004
0>ZgW@030000003oool0oooo0180oooo1000001P0?ooo`00H03oool00`000000oooo000000040>Zg
W@030000003oool0oooo00h0oooo1000001T0?ooo`00H@3oool00`000000oooo000000030>ZgW@03
0000003oool0oooo00X0oooo1000001X0?ooo`00HP3oool01@000000oooo0000003Z]id0000000T0
oooo1000001/0?ooo`00H`3oool4000000D0oooo1000001`0?ooo`00I@3oool2000000030?ooo`00
0000000000800000M03oool006H0oooo0P00001h0?ooo`00h03oool00>00oooo003P0?ooo`00h03o
ool00>00oooo003P0?ooo`00h03oool00>00oooo003P0?ooo`00h03oool00>00oooo003P0?ooo`00
h03oool00>00oooo003P0?ooo`00h03oool00>00oooo0000\
\>"],
  ImageRangeCache->{{{0, 223.75}, {181.25, 0}} -> {-0.202682, -0.0961109, \
0.00569734, 0.00569734}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[31]="]
}, Open  ]],

Cell["Example 8", "Subsubsection",
  Background->None],

Cell["Boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''''\)[x] \[Equal] 1, 
        y[0] \[Equal] 0, \(y'\)[0] \[Equal] 0, \(y''\)[1] \[Equal] 
          0, \(y'''\)[1] \[Equal] 0}\)], "Input",
  CellLabel->"In[32]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["y", 
              TagBox[\((4)\),
                Derivative],
              MultilineFunction->None], "[", "x", "]"}], "==", "1"}], 
        ",", \(y[0] == 0\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", "0"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "1", "]"}], "==", "0"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", 
              TagBox[\((3)\),
                Derivative],
              MultilineFunction->None], "[", "1", "]"}], "==", "0"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[33]:=",
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] x\^2\/4 - x\^3\/6 + x\^4\/24}}\)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[34]:=",
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 1\/24\ \((6\ x\^2 - 4\ x\^3 + x\^4)\)}}\)], "Output",
  CellLabel->"Out[34]="]
}, Open  ]],

Cell["Comparing exact and approximate results.", "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
              apr)\))\)]\)], "Input",
  CellLabel->"In[35]:=",
  Background->None],

Cell[BoxData[
    \({0}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell["Example 9", "Subsubsection",
  Background->None],

Cell[TextData[{
  "Polynomial approximation of solution of boundary value problem ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"x", " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}]}], "+", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
          ",", \(y[0] == 0\), ",", 
          RowBox[{\(y[1]\), "==", 
            RowBox[{"\[Alpha]", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "1", "]"}]}]}]}], "}"}]]],
  "."
}], "Text",
  Background->None],

Cell["The boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''\)[x] + x*\(y'\)[x] \[Equal] 0, y[0] \[Equal] 0, 
        y[1] \[Equal] \[Alpha]*\(y'\)[1]}\)], "Input",
  CellLabel->"In[36]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{"x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
        ",", \(y[0] == 0\), ",", 
        RowBox[{\(y[1]\), "==", 
          RowBox[{"\[Alpha]", " ", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "1", "]"}]}]}]}], 
      "}"}]], "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 11]\)], "Input",
  CellLabel->"In[37]:=",
  Background->None],

Cell[BoxData[
    \(LdeApprox::"noegvar" \(\(:\)\(\ \)\) 
      "no eigenvalue variable specified. Trying to determine ..."\)], \
"Message",
  CellLabel->"From In[37]:="],

Cell[BoxData[
    \(LdeApprox::"fxegvar" \(\(:\)\(\ \)\) 
      "\!\(\[Alpha]\) - is the eigenvalue variable."\)], "Message",
  CellLabel->"From In[37]:="],

Cell[BoxData[
    \({{\[Alpha] \[Rule] 
          54902566175591439582499388\/38919051394453247480231153, 
        y[x] \[Rule] \((\(-\(112592366095\/166666669790924395558908\)\) + \
\(1068376088611317781408\ x\)\/1068376088403361509993 - \(84767915840\ x\^2\)\
\/9131419559003089829 - \(178062496184180467712\ \
x\^3\)\/1068376088403361509993 - \(137391230525440\ \
x\^4\)\/82182776031027808461 + \(14844196976699211776\ \
x\^5\)\/593542271335200838885 - \(936354855059456\ \
x\^6\)\/27394258677009269487 - \(7218188544151912448\ \
x\^7\)\/2492877539607843523317 - \(14975139910778880\ \
x\^8\)\/118708454267040167777 + \(1338888529280761856\ \
x\^9\)\/3205128265210084529979 - \(85092039619772416\ \
x\^10\)\/1068376088403361509993 + \(16303992678121472\ \
x\^11\)\/19586894954061627683205)\)\ C[1]}}\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
  "Finding normalized polynomial approximation for solution of the BVP on \
interval ",
  StyleBox["[0,1]",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr1 = Normalize[apr, {x, 0, 1}]\)], "Input",
  CellLabel->"In[38]:=",
  Background->None],

Cell[BoxData[
    \({{\[Alpha] \[Rule] 
          54902566175591439582499388\/38919051394453247480231153, 
        y[x] \[Rule] 
          64166667869505892290179580\ \
\@\(7429\/8453561983383027371203598281276839108377559442395565541\)\ \
\((\(-\(112592366095\/166666669790924395558908\)\) + \(1068376088611317781408\
\ x\)\/1068376088403361509993 - \(84767915840\ x\^2\)\/9131419559003089829 - \
\(178062496184180467712\ x\^3\)\/1068376088403361509993 - \(137391230525440\ \
x\^4\)\/82182776031027808461 + \(14844196976699211776\ \
x\^5\)\/593542271335200838885 - \(936354855059456\ \
x\^6\)\/27394258677009269487 - \(7218188544151912448\ \
x\^7\)\/2492877539607843523317 - \(14975139910778880\ \
x\^8\)\/118708454267040167777 + \(1338888529280761856\ \
x\^9\)\/3205128265210084529979 - \(85092039619772416\ \
x\^10\)\/1068376088403361509993 + \(16303992678121472\ \
x\^11\)\/19586894954061627683205)\)}}\)], "Output",
  CellLabel->"Out[38]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Unfortunately ",
    FontColor->RGBColor[0, 0, 0.500008]],
  StyleBox["DSolve",
    FontFamily->"Courier New",
    FontColor->RGBColor[0, 0, 0.500008]],
  StyleBox[" can not find exact solution of the BVP because it contains \
parameter ",
    FontColor->RGBColor[0, 0, 0.500008]],
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  StyleBox[". ",
    FontColor->RGBColor[0, 0, 0.500008]]
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[39]:=",
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 0}}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[TextData[{
  "As the BVP is homogeneous one then to get the exact solution we can use \
the following technic. First of all we find exact solution for the following \
problem ",
  Cell[BoxData[
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"x", " ", 
                RowBox[{
                  SuperscriptBox["y", "\[Prime]",
                    MultilineFunction->None], "[", "x", "]"}]}], "+", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
          ",", \(y[0] == 0\)}], "}"}]]],
  ". After that we find constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". And finally we normalize the result to get exact solution of the initial \
BVP. "
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = 
      DSolve[{\(y''\)[x] + x*\(y'\)[x] \[Equal] 0, y[0] \[Equal] 0}, y[x], 
        x]\)], "Input",
  CellLabel->"In[40]:=",
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] \@\(\[Pi]\/2\)\ C[1]\ Erf[x\/\@2]}}\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[TextData[{
  "Finding constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " using the exact solution."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sub1 = Flatten[{sol, D[sol, x]} /. x \[Rule] 1]\)], "Input",
  CellLabel->"In[41]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(y[1] \[Rule] \@\(\[Pi]\/2\)\ C[1]\ Erf[1\/\@2]\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "1", "]"}], 
          "\[Rule]", \(C[1]\/\@\[ExponentialE]\)}]}], "}"}]], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sub2 = 
      Solve[y[1] \[Equal] \[Alpha]*\(y'\)[1] /. sub1, \[Alpha]]\)], "Input",
  CellLabel->"In[42]:=",
  Background->None],

Cell[BoxData[
    \({{\[Alpha] \[Rule] \@\(\(\[ExponentialE]\ \[Pi]\)\/2\)\ Erf[
              1\/\@2]}}\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Subscript[\[Delta], \[Alpha]] \[Rule] 
      N[\((\[Alpha] /. sub2)\) - \((\[Alpha] /. apr)\)]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(\[Delta]\_\[Alpha] \[Rule] {1.532107773982716`*^-14}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[TextData[{
  "Finding normalized exact solution of the BVP on interval ",
  StyleBox["[0,1]",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol1 = Normalize[sol, {x, 0, 1}]\)], "Input",
  CellLabel->"In[44]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(\((\[ExponentialE]\ \[Pi])\)\^\(1/4\)\ Erf[x\/\@2]\)\
\/\@\(\(-2\)\ \@\[ExponentialE]\ Erf[1] + 2\ \@2\ Erf[1\/\@2] + \@\(\
\[ExponentialE]\ \[Pi]\)\ Erf[1\/\@2]\^2\)}}\)], "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[TextData[{
  "Comparing normalized exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\((y[x] /. sol1[\([1]\)])\) - \((y[x] /. 
              apr1[\([1]\)])\))\), {x, 0, 1}]\)], "Input",
  CellLabel->"In[45]:=",
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.307845 2.28289e+011 [
[.21429 .29534 -9 -9 ]
[.21429 .29534 9 0 ]
[.40476 .29534 -9 -9 ]
[.40476 .29534 9 0 ]
[.59524 .29534 -9 -9 ]
[.59524 .29534 9 0 ]
[.78571 .29534 -9 -9 ]
[.78571 .29534 9 0 ]
[.97619 .29534 -3 -9 ]
[.97619 .29534 3 0 ]
[.01131 .07956 -43.5 -6.25 ]
[.01131 .07956 0 6.25 ]
[.01131 .1937 -43.5 -6.25 ]
[.01131 .1937 0 6.25 ]
[.01131 .42199 -37.5 -6.25 ]
[.01131 .42199 0 6.25 ]
[.01131 .53613 -37.5 -6.25 ]
[.01131 .53613 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30784 m
.21429 .31409 L
s
[(0.2)] .21429 .29534 0 1 Mshowa
.40476 .30784 m
.40476 .31409 L
s
[(0.4)] .40476 .29534 0 1 Mshowa
.59524 .30784 m
.59524 .31409 L
s
[(0.6)] .59524 .29534 0 1 Mshowa
.78571 .30784 m
.78571 .31409 L
s
[(0.8)] .78571 .29534 0 1 Mshowa
.97619 .30784 m
.97619 .31409 L
s
[(1)] .97619 .29534 0 1 Mshowa
.125 Mabswid
.07143 .30784 m
.07143 .31159 L
s
.11905 .30784 m
.11905 .31159 L
s
.16667 .30784 m
.16667 .31159 L
s
.2619 .30784 m
.2619 .31159 L
s
.30952 .30784 m
.30952 .31159 L
s
.35714 .30784 m
.35714 .31159 L
s
.45238 .30784 m
.45238 .31159 L
s
.5 .30784 m
.5 .31159 L
s
.54762 .30784 m
.54762 .31159 L
s
.64286 .30784 m
.64286 .31159 L
s
.69048 .30784 m
.69048 .31159 L
s
.7381 .30784 m
.7381 .31159 L
s
.83333 .30784 m
.83333 .31159 L
s
.88095 .30784 m
.88095 .31159 L
s
.92857 .30784 m
.92857 .31159 L
s
.25 Mabswid
0 .30784 m
1 .30784 L
s
.02381 .07956 m
.03006 .07956 L
s
gsave
.01131 .07956 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-12) show
grestore
.02381 .1937 m
.03006 .1937 L
s
gsave
.01131 .1937 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.02381 .42199 m
.03006 .42199 L
s
gsave
.01131 .42199 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-13) show
grestore
.02381 .53613 m
.03006 .53613 L
s
gsave
.01131 .53613 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-12) show
grestore
.125 Mabswid
.02381 .10238 m
.02756 .10238 L
s
.02381 .12521 m
.02756 .12521 L
s
.02381 .14804 m
.02756 .14804 L
s
.02381 .17087 m
.02756 .17087 L
s
.02381 .21653 m
.02756 .21653 L
s
.02381 .23936 m
.02756 .23936 L
s
.02381 .26219 m
.02756 .26219 L
s
.02381 .28502 m
.02756 .28502 L
s
.02381 .33067 m
.02756 .33067 L
s
.02381 .3535 m
.02756 .3535 L
s
.02381 .37633 m
.02756 .37633 L
s
.02381 .39916 m
.02756 .39916 L
s
.02381 .44482 m
.02756 .44482 L
s
.02381 .46765 m
.02756 .46765 L
s
.02381 .49048 m
.02756 .49048 L
s
.02381 .5133 m
.02756 .5133 L
s
.02381 .05673 m
.02756 .05673 L
s
.02381 .0339 m
.02756 .0339 L
s
.02381 .01107 m
.02756 .01107 L
s
.02381 .55896 m
.02756 .55896 L
s
.02381 .58179 m
.02756 .58179 L
s
.02381 .60462 m
.02756 .60462 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .6012 m
.02605 .42338 L
.02846 .27642 L
.03072 .1732 L
.03279 .10508 L
.03405 .07409 L
.03521 .0519 L
.03649 .034 L
.03713 .02733 L
.03784 .02171 L
.03903 .01603 L
.04031 .01472 L
.04151 .01755 L
.04262 .02325 L
.04384 .0326 L
.04514 .04569 L
.04748 .076 L
.05278 .16637 L
.06244 .35354 L
.06791 .44704 L
.07079 .48866 L
.07382 .52591 L
.07649 .55251 L
.0779 .56424 L
.07941 .575 L
.0808 .58321 L
.08206 .58933 L
.08334 .59415 L
.08454 .59752 L
.08569 .59967 L
.08696 .60085 L
.0876 .60098 L
.08828 .60078 L
.08953 .59956 L
.0907 .5974 L
.09193 .59408 L
.09414 .58568 L
.09672 .57206 L
.09913 .55604 L
.10458 .5096 L
.12332 .29371 L
.13318 .18146 L
.14363 .08782 L
.14891 .0541 L
.15192 .03953 L
.15473 .02902 L
.15605 .02514 L
.15731 .02207 L
.15845 .0198 L
.15967 .01795 L
Mistroke
.16098 .01657 L
.1622 .01587 L
.16295 .01573 L
.16366 .01578 L
.16497 .01639 L
.16614 .01743 L
.16743 .01919 L
.16877 .02161 L
.17002 .02443 L
.17226 .03085 L
.17466 .03952 L
.18014 .06581 L
.18512 .09677 L
.20586 .27113 L
.22502 .4422 L
.23463 .5119 L
.24364 .56076 L
.24817 .57834 L
.25071 .58598 L
.25304 .59161 L
.25546 .59598 L
.25682 .59787 L
.25809 .59914 L
.25879 .59966 L
.25944 .60007 L
.26066 .60056 L
.26198 .60062 L
.26272 .60049 L
.2634 .60021 L
.26466 .59944 L
.26585 .59833 L
.26809 .59539 L
.26934 .59319 L
.2705 .59085 L
.27312 .58436 L
.27752 .57007 L
.2822 .55047 L
.29202 .49656 L
.30286 .42144 L
.32381 .25693 L
.33298 .18801 L
.34303 .12156 L
.34774 .095 L
.35277 .07041 L
.35713 .05272 L
.36185 .03731 L
.36463 .03026 L
.36719 .02512 L
.36964 .02134 L
.37088 .0199 L
Mistroke
.37224 .01868 L
.37347 .0179 L
.37459 .01747 L
.37588 .01719 L
.37712 .01734 L
.37825 .01769 L
.3793 .01828 L
.38045 .01914 L
.38168 .02033 L
.38429 .0239 L
.38705 .0291 L
.39198 .04185 L
.39729 .06043 L
.40311 .0863 L
.42329 .20872 L
.44445 .36373 L
.46373 .49198 L
.47331 .54117 L
.47836 .5617 L
.48373 .57909 L
.4884 .59022 L
.48968 .59262 L
.49106 .59488 L
.49226 .59645 L
.49356 .59795 L
.49476 .59909 L
.49587 .5998 L
.49705 .60035 L
.49831 .60076 L
.49948 .60081 L
.50059 .60053 L
.50158 .60025 L
.50266 .59957 L
.50502 .59749 L
.50634 .59592 L
.50755 .59409 L
.51213 .5851 L
.51469 .57843 L
.51748 .56984 L
.52255 .55108 L
.53347 .49755 L
.5436 .43503 L
.56245 .29973 L
.5828 .15633 L
.59399 .09236 L
.59889 .06965 L
.60427 .04907 L
.60672 .04121 L
.60935 .03417 L
.61162 .029 L
Mistroke
.61409 .02459 L
.61554 .02246 L
.61618 .02165 L
.61688 .02073 L
.61816 .01972 L
.61887 .01921 L
.61952 .01891 L
.62074 .01845 L
.62206 .0181 L
.62329 .01825 L
.62445 .01866 L
.6257 .01942 L
.62635 .01982 L
.62704 .02043 L
.62831 .02185 L
.62948 .02347 L
.63403 .03204 L
.63655 .03858 L
.6389 .04572 L
.64425 .0659 L
.65312 .10985 L
.66263 .16981 L
.68244 .31996 L
.69288 .40198 L
.70398 .48161 L
.71381 .5392 L
.71941 .56474 L
.72197 .57453 L
.72467 .58304 L
.72696 .58928 L
.72947 .59465 L
.73058 .59643 L
.73176 .5982 L
.73287 .59952 L
.73388 .60033 L
.73516 .60099 L
.73633 .60149 L
.73762 .6016 L
.73827 .60144 L
.73899 .60104 L
.74019 .60053 L
.74148 .59916 L
.74268 .59769 L
.74382 .59602 L
.74515 .59343 L
.74636 .5909 L
.74907 .5838 L
.75394 .56652 L
.75925 .54143 L
.76498 .50726 L
Mistroke
.78508 .34566 L
.80466 .1687 L
.81002 .12592 L
.81576 .08618 L
.82115 .05596 L
.82612 .03513 L
.82859 .02763 L
.82984 .02469 L
.83122 .02205 L
.83259 .02008 L
.83336 .01921 L
.83407 .01876 L
.83538 .01805 L
.83603 .01805 L
.83675 .0181 L
.83807 .01886 L
.83927 .02018 L
.83994 .02099 L
.84066 .02215 L
.84196 .02484 L
.84449 .03173 L
.84681 .0402 L
.85117 .06164 L
.85597 .09312 L
.86565 .1796 L
.88676 .42494 L
.89161 .47887 L
.89676 .52931 L
.90117 .56378 L
.90367 .57899 L
.90603 .59029 L
.9072 .5946 L
.90842 .5982 L
.90947 .60028 L
.91062 .60205 L
.91186 .60281 L
.91256 .60261 L
.91319 .6022 L
.91442 .60048 L
.91558 .5979 L
.91684 .59379 L
.91817 .58801 L
.92056 .57422 L
.92314 .55415 L
.92598 .52586 L
.93068 .46519 L
.93574 .38307 L
.94489 .2091 L
.94861 .1396 L
.95257 .07553 L
Mistroke
.95484 .04699 L
.95592 .03625 L
.95691 .02844 L
.95791 .02236 L
.95898 .01866 L
.95994 .01764 L
.96094 .01932 L
.96189 .02373 L
.96276 .03016 L
.96375 .04111 L
.9647 .05475 L
.96638 .08846 L
.96821 .14006 L
.97022 .21696 L
.97236 .32569 L
.97418 .44339 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{222.375, 137.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003N0000RB000`400?l00000o`00003ogP3oool0
0=h0oooo003N0?ooo`00gP3oool00=h0oooo003N0?ooo`00gP3oool00=h0oooo003N0?ooo`00gP3o
ool00=h0oooo003N0?ooo`00gP3oool002d0oooo00<000000?ooo`3oool0[P3oool002d0oooo00<0
00000?ooo`3oool0[P3oool002d0oooo0P0000000`3oool000000?ooo`2/0?ooo`00;@3oool01000
0000oooo0?ooo`00000D0?ooo`<00000903oool3000002T0oooo0`00000T0?ooo`800000503oool2
000000L0oooo000]0?ooo`030000003oool0oooo008000004`3oool010000000oooo00000000000R
0?ooo`040000003oool0oooo000002P0oooo0P0000000`3oool000000?ooo`0R0?ooo`<00000503o
ool2000000L0oooo000]0?ooo`030000003oool0oooo008000004`3oool010000000oooo0?ooo`00
000R0?ooo`050000003oool0oooo0?ooo`0000009`3oool01@000000oooo0?ooo`3oool000000280
oooo00@000000?ooo`3oool000004`3oool2000000L0oooo000]0?ooo`80000000<0oooo00000000
00004P3oool01@000000oooo0?ooo`3oool000000240oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`0000008P3oool010000000oooo0?ooo`00
000C0?ooo`8000001`3oool002d0oooo00<000000?ooo`3oool00P00000B0?ooo`050000003oool0
oooo0?ooo`0000008@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`040000003oool0oooo000001<0oooo
0P0000070?ooo`00;@3oool01@000000oooo0000003oool000000180oooo00D000000?ooo`3oool0
oooo0000000P0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo00D000000?ooo`3oool0oooo0000000C0?oo
o`8000001`3oool002d0oooo00D000000?ooo`000000oooo0000000B0?ooo`050000003oool0oooo
0?ooo`000000803oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?ooo`050000003oool0oooo0?ooo`0000004`3o
ool00`000000oooo000000060?ooo`00;@3oool3000000030?ooo`000000oooo0140oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0000000H0oooo00070?oo
o`D0000000<0oooo0000003oool00P3oool00`000000oooo0000000400000080oooo0P00000A0?oo
o`030000003oool000000080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00l0oooo00@000000?ooo`3oool000001P3oool000T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool000000080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool000001P3o
ool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool000001P3oool000030?ooo`000000000000800000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00h0oooo0`0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000H0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool00000403oool00`000000oooo000000020?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000H0oooo0008
0?ooo`8000002P3oool2000000@0oooo0P0000080?ooo`0<0<30`02@T900`<300?ooo`3@d=00T92@
0<30`02`/;00oooo0000003oool000000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000060?ooo`009@3oool0
1P30`<00oooo0?ooo`3oool0d=3@0>3Ph080oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool010000000oooo
0?ooo`0000060?ooo`007P3oool0103Ph>00P8200820P020P8030?ooo`030<30`03oool0oooo0080
oooo00<0d=3@0>3Ph03oool00`0000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000H0oooo000U0?ooo`03
0<30`03oool0oooo00<0oooo00D0/;2`0?ooo`000000oooo000000020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo
000000H0oooo000T0?ooo`80/;2`0`3oool01`2@T900/;2`0<30`03oool000000?ooo`0000000P3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03P3o
ool010000000oooo0?ooo`0000060?ooo`00;@3oool00`000000oooo000000020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0oooo000000H0oooo000]0?ooo`<000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000060?ooo`00;@3o
ool00`000000oooo000000020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000H0oooo000]0?ooo`030000003o
ool000000080oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool000001P3oool002d0oooo0P0000030?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0oooo000000H0oooo000]0?ooo`8000000`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000060?ooo`00;@3o
ool2000000<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`3oool000001P3oool002d0oooo0P0000030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`040000003o
ool0oooo000000H0oooo000]0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`0000060?ooo`00;@3o
ool2000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00`0oooo00@000000?ooo`3oool000001P3oool000P0oooo0P0000030?ooo`060000003o
ool0oooo0?ooo`000000oooo1@0000020?ooo`8000004@3oool2000000<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3o
ool0oooo000000060?ooo`001`3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo0P000003
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;
0?ooo`050000003oool0oooo0?ooo`0000001P3oool000X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0>0?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0000
0`3oool0000000000002000000<0oooo0P0000040?ooo`030000003oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo0P0000030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool000P0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00h0oooo0P0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0`3oool000P0oooo0`0000090?ooo`800000103oool200000140oooo0P0000030?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool002@0oooo00<0`<30092@T030`<000P3oool0
102`/;00`<30092@T03oool2000000<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`030?ooo`009@3oool00`30`<00oooo0?ooo`030?ooo`040;2`/03oool00000000000<0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`007P3oool0103Ph>00P8200820P020
P8030?ooo`030<30`03oool0oooo0080oooo0P2@T9000`3oool00000000000040?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00`3oool002D0oooo00<0`<300?ooo`3oool00`3oool0
102`/;00oooo0000000000040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool002@0oooo0P2`/;030?ooo`040:2PX02`/;00/;2`0?ooo`800000103oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo000]0?ooo`800000103oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo000]0?ooo`800000103oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00<0oooo000]0?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00<0oooo000]0?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00H0oooo0P0000030?ooo`<000000`3oool4000000/0oooo00<000000?ooo`3oool0
1@3oool2000000@0oooo0P0000030?ooo`030000003oool00000008000004P3oool3000000<0oooo
0P0000030?ooo`<000001`3oool00`000000oooo0?ooo`0:0?ooo`800000103oool2000000040?oo
o`000000oooo0?ooo`8000002@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo1@0000020?ooo`00;@3oool2000000@0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`050?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000B0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool2000000@0oooo000]0?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`0000080?oo
o`D000004@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000L0oooo00<0
00000?ooo`3oool0203oool010000000oooo0?ooo`0000060?ooo`030000003oool000000080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
0P0000040?ooo`00;@3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000203oool200000003
0?ooo`000000oooo0140oooo00@000000?ooo`3oool00000203oool3000000P0oooo00<000000?oo
o`3oool0203oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo008000002@3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`00;@3oool20000
00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000000B0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool2000000@0oooo000]0?ooo`80
0000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`03
0000003oool0oooo00@0oooo0P00000;0?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`<0
00004`3oool3000000T0oooo0`0000070?ooo`030000003oool0oooo00T0oooo0P0000060?ooo`04
0000003oool0oooo0?ooo`8000002P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`00;@3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`00;@3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`00;@3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`00;@3oool2000000@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`00:@3ooone00000000;@3oool2000000D0oooo00<000000?ooo`0000001`3oool2000000L0
oooo00<000000?ooo`3oool01@3oool2000000L0oooo00<000000?ooo`3oool01P3oool2000000H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000P0
oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool2000000P0oooo00<000000?ooo`3oool01@3oool20000
00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool00000
00D0oooo0P0000040?ooo`00;@3oool2000000D0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`030?ooo`00;@3oool2000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`00;@3oool2000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`00;@3oool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`00;@3oool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?oo
o`00;@3oool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00
;@3oool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00;@3o
ool2000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00;@3oool2
000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00;@3oool20000
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00;@3oool2000000D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00;@3oool2000000D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00;@3oool2000000D0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00;@3oool2000000D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`00;@3oool2000000D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`00203oool2000000<0oooo00H000000?ooo`3o
ool0oooo0000003oool500000080oooo0P00000A0?ooo`8000001P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00070?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03P3o
ool2000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`002P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00h0oooo0P0000060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool000P0oooo0P0000040?ooo`030000003oool0000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo0P0000060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool000P0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00h0oooo0P0000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0`3oool000P0oooo0`0000090?ooo`800000103oool200000140oooo0P0000060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool002@0oooo00<0`<30092@T030`<000P3oool0
102`/;00`<30092@T03oool2000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`030?ooo`009@3oool00`30`<00oooo0?ooo`030?ooo`040;2`/03oool00000000000H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`007P3oool0103Ph>00P8200820P020
P8030?ooo`030<30`03oool0oooo0080oooo0P2@T9000`3oool00000000000060?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00`3oool002D0oooo00<0`<300?ooo`3oool00`3oool0
102`/;00oooo0000000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool002@0oooo0P2`/;030?ooo`040:2PX02`/;00/;2`0?ooo`8000001P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo000]0?ooo`8000001P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00<0oooo000]0?ooo`8000001P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo000]0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00<0oooo000]0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00<0oooo000]0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo000]0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo000]0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00<0oooo000]0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0
oooo000]0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
000]0?ooo`8000001`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo0007
0?ooo`D0000000<0oooo0000003oool00P3oool00`000000oooo0000000400000080oooo0P00000A
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`03
0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00090?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`8000001`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00090?ooo`050000003oool0oooo
0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000
403oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`000000603oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool000P0oooo
0P00000:0?ooo`800000103oool2000000P0oooo00X0`<30092@T030`<00oooo0=3@d02@T900`<30
0;2`/03oool000002@3oool01@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo000U0?ooo`060<30`03o
ool0oooo0?ooo`3@d=00h>3P0P3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?oo
o`0000006@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool05P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool00P3oool0
01h0oooo00@0h>3P0820P020P800P8200`3oool00`30`<00oooo0?ooo`020?ooo`030=3@d03Ph>00
oooo00800000203oool01@000000oooo0?ooo`3oool0000001T0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0oooo
000000090?ooo`030000003oool0oooo0080oooo000U0?ooo`030<30`03oool0oooo00<0oooo00<0
/;2`0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000001T0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo00D000000?ooo`3oool0
oooo000000090?ooo`030000003oool0oooo0080oooo000T0?ooo`80/;2`0`3oool01@2@T900/;2`
0<30`03oool0000000T0oooo00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0
000000T0oooo00<000000?ooo`3oool00P3oool002d0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`00000K0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3o
ool002d0oooo0P0000080?ooo`040000003oool0oooo000001/0oooo00D000000?ooo`3oool0oooo
0000000U0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01T0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`020?ooo`00;@3oool00`000000oooo0?ooo`080?ooo`030000003oool0000001/0oooo
00D000000?ooo`3oool0oooo0000000U0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo00<000000?ooo`00
00002P3oool00`000000oooo0?ooo`020?ooo`00;@3oool00`000000oooo0?ooo`080?ooo`030000
003oool0000001/0oooo00<000000?ooo`3oool00P00000V0?ooo`040000003oool0oooo000002L0
oooo00@000000?ooo`3oool00000703oool00`000000oooo0000000:0?ooo`030000003oool0oooo
0080oooo000]0?ooo`030000003oool0oooo00P0oooo0`00000L0?ooo`030000003oool0000002L0
oooo0P0000000`3oool000000?ooo`0V0?ooo`80000000<0oooo0000003oool06`3oool00`000000
oooo0000000:0?ooo`030000003oool0oooo0080oooo000]0?ooo`8000002@3oool2000001d0oooo
0`00000X0?ooo`800000:@3oool2000001h0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`00;@3oool00`000000oooo0?ooo`2^0?ooo`00;@3oool00`000000oooo0?ooo`2^
0?ooo`00;@3oool00`000000oooo0?ooo`2^0?ooo`00gP3oool00=h0oooo003N0?ooo`00gP3oool0
0=h0oooo003N0?ooo`00gP3oool00=h0oooo003N0?ooo`00gP3oool00=h0oooo003N0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 221.375}, {136.375, 0}} -> {-0.267009, \
-1.65511*^-12, 0.00583632, 2.43481*^-14}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[45]="]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
ScreenStyleEnvironment->"Brackets",
WindowToolbars->{},
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->False,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 185, 7, 39, "Subsection"],
Cell[1893, 59, 381, 12, 22, "SmallText"],
Cell[2277, 73, 205, 6, 25, "Text"],
Cell[2485, 81, 66, 1, 31, "MathCaption"],
Cell[2554, 84, 112, 3, 29, "Input"],
Cell[2669, 89, 114, 3, 35, "Subsubsection"],
Cell[2786, 94, 86, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2897, 100, 203, 5, 29, "Input"],
Cell[3103, 107, 678, 19, 23, "Output"]
}, Open  ]],
Cell[3796, 129, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3943, 136, 137, 4, 29, "Input"],
Cell[4083, 142, 881, 13, 121, "Output"]
}, Open  ]],
Cell[4979, 158, 246, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[5250, 172, 123, 4, 29, "Input"],
Cell[5376, 178, 285, 6, 23, "Output"]
}, Open  ]],
Cell[5676, 187, 280, 12, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[5981, 203, 174, 4, 29, "Input"],
Cell[6158, 209, 26084, 671, 144, 6347, 422, "GraphicsData", "PostScript", \
"Graphics"],
Cell[32245, 882, 154, 4, 23, "Output"]
}, Open  ]],
Cell[32414, 889, 54, 1, 35, "Subsubsection"],
Cell[32471, 892, 86, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[32582, 898, 163, 4, 29, "Input"],
Cell[32748, 904, 365, 10, 34, "Output"]
}, Open  ]],
Cell[33128, 917, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[33275, 924, 120, 3, 29, "Input"],
Cell[33398, 929, 1026, 16, 119, "Output"]
}, Open  ]],
Cell[34439, 948, 246, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[34710, 962, 103, 3, 29, "Input"],
Cell[34816, 967, 189, 4, 36, "Output"]
}, Open  ]],
Cell[35020, 974, 253, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[35298, 988, 186, 4, 29, "Input"],
Cell[35487, 994, 65036, 1312, 178, 20487, 757, "GraphicsData", "PostScript", \
"Graphics"],
Cell[100526, 2308, 161, 4, 23, "Output"]
}, Open  ]],
Cell[100702, 2315, 54, 1, 35, "Subsubsection"],
Cell[100759, 2318, 86, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[100870, 2324, 200, 4, 29, "Input"],
Cell[101073, 2330, 674, 19, 23, "Output"]
}, Open  ]],
Cell[101762, 2352, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[101909, 2359, 118, 3, 29, "Input"],
Cell[102030, 2364, 1697, 27, 224, "Output"]
}, Open  ]],
Cell[103742, 2394, 246, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[104013, 2408, 104, 3, 29, "Input"],
Cell[104120, 2413, 4957, 70, 242, "Output"]
}, Open  ]],
Cell[109092, 2486, 253, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[109370, 2500, 220, 6, 29, "Input"],
Cell[109593, 2508, 61113, 1296, 178, 21110, 797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[170709, 3806, 162, 4, 23, "Output"]
}, Open  ]],
Cell[170886, 3813, 54, 1, 35, "Subsubsection"],
Cell[170943, 3816, 86, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[171054, 3822, 186, 4, 29, "Input"],
Cell[171243, 3828, 623, 17, 23, "Output"]
}, Open  ]],
Cell[171881, 3848, 135, 4, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[172041, 3856, 118, 3, 29, "Input"],
Cell[172162, 3861, 171, 4, 23, "Message"],
Cell[172336, 3867, 67, 2, 23, "Output"]
}, Open  ]],
Cell[172418, 3872, 270, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[172713, 3886, 234, 5, 29, "Input"],
Cell[172950, 3893, 959, 23, 42, "Output"]
}, Open  ]],
Cell[173924, 3919, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[174071, 3926, 119, 3, 29, "Input"],
Cell[174193, 3931, 543, 10, 42, "Output"]
}, Open  ]],
Cell[174751, 3944, 246, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[175022, 3958, 104, 3, 29, "Input"],
Cell[175129, 3963, 243, 5, 39, "Output"]
}, Open  ]],
Cell[175387, 3971, 231, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[175643, 3984, 207, 4, 29, "Input"],
Cell[175853, 3990, 28587, 822, 144, 9023, 575, "GraphicsData", "PostScript", \
"Graphics"],
Cell[204443, 4814, 155, 4, 23, "Output"]
}, Open  ]],
Cell[204613, 4821, 54, 1, 35, "Subsubsection"],
Cell[204670, 4824, 86, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[204781, 4830, 165, 4, 29, "Input"],
Cell[204949, 4836, 361, 10, 23, "Output"]
}, Open  ]],
Cell[205325, 4849, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[205472, 4856, 118, 3, 29, "Input"],
Cell[205593, 4861, 295, 6, 39, "Output"]
}, Open  ]],
Cell[205903, 4870, 246, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[206174, 4884, 104, 3, 29, "Input"],
Cell[206281, 4889, 257, 5, 23, "Output"]
}, Open  ]],
Cell[206553, 4897, 231, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[206809, 4910, 156, 4, 29, "Input"],
Cell[206968, 4916, 31468, 769, 143, 7327, 466, "GraphicsData", "PostScript", \
"Graphics"],
Cell[238439, 5687, 155, 4, 23, "Output"]
}, Open  ]],
Cell[238609, 5694, 54, 1, 35, "Subsubsection"],
Cell[238666, 5697, 86, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[238777, 5703, 164, 4, 29, "Input"],
Cell[238944, 5709, 517, 14, 23, "Output"]
}, Open  ]],
Cell[239476, 5726, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[239623, 5733, 118, 3, 29, "Input"],
Cell[239744, 5738, 2080, 31, 116, "Output"]
}, Open  ]],
Cell[241839, 5772, 246, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[242110, 5786, 104, 3, 29, "Input"],
Cell[242217, 5791, 167, 4, 36, "Output"]
}, Open  ]],
Cell[242399, 5798, 231, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[242655, 5811, 156, 4, 29, "Input"],
Cell[242814, 5817, 27851, 731, 158, 6734, 465, "GraphicsData", "PostScript", \
"Graphics"],
Cell[270668, 6550, 155, 4, 23, "Output"]
}, Open  ]],
Cell[270838, 6557, 54, 1, 35, "Subsubsection"],
Cell[270895, 6560, 86, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[271006, 6566, 232, 5, 29, "Input"],
Cell[271241, 6573, 871, 25, 23, "Output"]
}, Open  ]],
Cell[272127, 6601, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[272274, 6608, 118, 3, 29, "Input"],
Cell[272395, 6613, 3511, 63, 333, "Output"]
}, Open  ]],
Cell[275921, 6679, 246, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[276192, 6693, 104, 3, 29, "Input"],
Cell[276299, 6698, 2916, 47, 154, "Output"]
}, Open  ]],
Cell[279230, 6748, 253, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[279508, 6762, 184, 4, 29, "Input"],
Cell[279695, 6768, 71844, 1418, 189, 20972, 785, "GraphicsData", \
"PostScript", "Graphics"],
Cell[351542, 8188, 162, 4, 23, "Output"]
}, Open  ]],
Cell[351719, 8195, 54, 1, 35, "Subsubsection"],
Cell[351776, 8198, 86, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[351887, 8204, 215, 5, 29, "Input"],
Cell[352105, 8211, 849, 25, 23, "Output"]
}, Open  ]],
Cell[352969, 8239, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[353116, 8246, 118, 3, 29, "Input"],
Cell[353237, 8251, 104, 2, 39, "Output"]
}, Open  ]],
Cell[353356, 8256, 246, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[353627, 8270, 104, 3, 29, "Input"],
Cell[353734, 8275, 113, 2, 36, "Output"]
}, Open  ]],
Cell[353862, 8280, 83, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[353970, 8285, 155, 4, 29, "Input"],
Cell[354128, 8291, 62, 2, 23, "Output"]
}, Open  ]],
Cell[354205, 8296, 54, 1, 35, "Subsubsection"],
Cell[354262, 8299, 806, 22, 25, "Text"],
Cell[355071, 8323, 90, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[355186, 8329, 181, 4, 29, "Input"],
Cell[355370, 8335, 688, 19, 23, "Output"]
}, Open  ]],
Cell[356073, 8357, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[356220, 8364, 119, 3, 29, "Input"],
Cell[356342, 8369, 170, 4, 23, "Message"],
Cell[356515, 8375, 155, 3, 23, "Message"],
Cell[356673, 8380, 841, 15, 148, "Output"]
}, Open  ]],
Cell[357529, 8398, 220, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[357774, 8410, 110, 3, 29, "Input"],
Cell[357887, 8415, 945, 17, 158, "Output"]
}, Open  ]],
Cell[358847, 8435, 461, 14, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[359333, 8453, 104, 3, 29, "Input"],
Cell[359440, 8458, 77, 2, 23, "Output"]
}, Open  ]],
Cell[359532, 8463, 888, 24, 48, "MathCaption"],

Cell[CellGroupData[{
Cell[360445, 8491, 171, 5, 29, "Input"],
Cell[360619, 8498, 109, 2, 46, "Output"]
}, Open  ]],
Cell[360743, 8503, 143, 5, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[360911, 8512, 125, 3, 29, "Input"],
Cell[361039, 8517, 338, 8, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[361414, 8530, 149, 4, 29, "Input"],
Cell[361566, 8536, 143, 3, 46, "Output"]
}, Open  ]],
Cell[361724, 8542, 154, 5, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[361903, 8551, 152, 3, 29, "Input"],
Cell[362058, 8556, 111, 2, 23, "Output"]
}, Open  ]],
Cell[362184, 8561, 195, 7, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[362404, 8572, 110, 3, 29, "Input"],
Cell[362517, 8577, 257, 5, 79, "Output"]
}, Open  ]],
Cell[362789, 8585, 242, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[363056, 8598, 173, 4, 29, "Input"],
Cell[363232, 8604, 45176, 996, 144, 8280, 536, "GraphicsData", "PostScript", \
"Graphics"],
Cell[408411, 9602, 155, 4, 23, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

