(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    100907,       3254]*)
(*NotebookOutlinePosition[    101653,       3279]*)
(*  CellTagsIndexPosition[    101609,       3275]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Modified a-method examples of the ",
  StyleBox["DifferentialEquations`LdeApprox`",
    FontSlant->"Italic"],
  " package"
}], "Subsection"],

Cell[TextData[{
  StyleBox["Copyright \[Copyright] 2003-2005 ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Graph Tree Ltd",
    ButtonData:>{
      URL[ "http://www.mathshop.digi-area.com/"], None},
    Active->True,
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[". All rights reserved.",
    FontSlant->"Italic"]
}], "SmallText",
  TextAlignment->Right],

Cell[TextData[{
  "This notebook illustrates ",
  StyleBox["DifferentialEquations`LdeApprox`",
    FontFamily->"Courier New"],
  " package capability of doing polynomial approximation of an LDE solution \
using modified a-method. "
}], "Text"],

Cell["This loads the package.", "MathCaption"],

Cell[BoxData[
    \(<< DifferentialEquations`LdeApprox`\)], "Input",
  CellLabel->"In[76]:="],

Cell["\<\
This loads Graphics`Legend package (just for best presentation of the \
results).\
\>", "MathCaption"],

Cell[BoxData[
    \(<< Graphics`Legend`\)], "Input",
  CellLabel->"In[77]:="],

Cell["Example 1", "Subsubsection"],

Cell["Initial value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\((x^2 + 1)\)*\(y'\)[x] \[Equal] 1, y[0] == 0}\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\((1 + x\^2)\), " ", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", "1"}], 
        ",", \(y[0] == 0\)}], "}"}]], "Output",
  CellLabel->"Out[78]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr0 = ApproxSol[ivp, y[x], {x, \(-1\), 1}, 5]\)], "Input",
  CellLabel->"In[79]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(168\ x\)\/169 - \(48\ x\^3\)\/169 + \(64\ \
x\^5\)\/845}}\)], "Output",
  CellLabel->"Out[79]="]
}, Open  ]],

Cell["\<\
Finding polynomial approximation for solution of the IVP using modified \
method with k = 1.\
\>", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr1 = 
      ApproxSol[ivp, y[x], {x, \(-1\), 1}, 5, 
        Method \[Rule] Modified[1]]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(\((658 + 518\ \@2)\)\ x\)\/\(664 + 519\ \@2\) - \(16\
\ \((34 + 29\ \@2)\)\ x\^3\)\/\(3\ \((664 + 519\ \@2)\)\) + \(224\ \((1 + \
\@2)\)\ x\^5\)\/\(5\ \((664 + 519\ \@2)\)\)}}\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]],

Cell["\<\
Finding polynomial approximation for solution of the IVP using modified \
method with k = 2.\
\>", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr2 = 
      ApproxSol[ivp, y[x], {x, \(-1\), 1}, 5, 
        Method \[Rule] Modified[2]]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(\((821 + 582\ \@2)\)\ x\)\/\(826 + 584\ \@2\) + \
\(\((358 + 252\ \@2)\)\ x\^3\)\/\(\(-1239\) - 876\ \@2\) + \(56\ \((3 + 2\ \
\@2)\)\ x\^5\)\/\(5\ \((413 + 292\ \@2)\)\)}}\)], "Output",
  CellLabel->"Out[81]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " tot find exact solution of the IVP."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[82]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] ArcTan[x]}}\)], "Output",
  CellLabel->"Out[82]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  ". In this case modified method (for k=2) gives more uniform and pricise \
appoximation."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\[IndentingNewLine]\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
              apr0[\([1]\)])\), \[IndentingNewLine]\((y[x] /. 
              sol[\([1]\)])\) - \((y[x] /. 
              apr1[\([1]\)])\), \[IndentingNewLine]\((y[x] /. 
              sol[\([1]\)])\) - \((y[x] /. apr2[\([1]\)])\)}, {x, \(-1\), 
        1}, \[IndentingNewLine]PlotStyle \[Rule] {{RGBColor[0, 0, 1], 
            AbsoluteThickness[2]}, {RGBColor[0, 1, 0], 
            AbsoluteThickness[2]}, {RGBColor[1, 0, 0], 
            AbsoluteThickness[
              3]}}, \[IndentingNewLine]PlotLegend \[Rule] {"\<k=0\>", \
"\<k=1\>", "\<k=2\>"}, LegendPosition \[Rule] {1.1, \(- .7\)}]\)], "Input",
  CellLabel->"In[83]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47494 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.354447 0.330638 0.259287 0.330638 [
[ 0 0 0 0 ]
[ 1 .47494 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0549411 0.685085 0.463632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309015 351.428 [
[.02381 .29651 -6 -9 ]
[.02381 .29651 6 0 ]
[.2619 .29651 -12 -9 ]
[.2619 .29651 12 0 ]
[.7381 .29651 -9 -9 ]
[.7381 .29651 9 0 ]
[.97619 .29651 -3 -9 ]
[.97619 .29651 3 0 ]
[.4875 .04544 -48 -4.5 ]
[.4875 .04544 0 4.5 ]
[.4875 .1333 -42 -4.5 ]
[.4875 .1333 0 4.5 ]
[.4875 .22116 -48 -4.5 ]
[.4875 .22116 0 4.5 ]
[.4875 .39687 -42 -4.5 ]
[.4875 .39687 0 4.5 ]
[.4875 .48473 -36 -4.5 ]
[.4875 .48473 0 4.5 ]
[.4875 .57259 -42 -4.5 ]
[.4875 .57259 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30901 m
.02381 .31526 L
s
[(-1)] .02381 .29651 0 1 Mshowa
.2619 .30901 m
.2619 .31526 L
s
[(-0.5)] .2619 .29651 0 1 Mshowa
.7381 .30901 m
.7381 .31526 L
s
[(0.5)] .7381 .29651 0 1 Mshowa
.97619 .30901 m
.97619 .31526 L
s
[(1)] .97619 .29651 0 1 Mshowa
.125 Mabswid
.07143 .30901 m
.07143 .31276 L
s
.11905 .30901 m
.11905 .31276 L
s
.16667 .30901 m
.16667 .31276 L
s
.21429 .30901 m
.21429 .31276 L
s
.30952 .30901 m
.30952 .31276 L
s
.35714 .30901 m
.35714 .31276 L
s
.40476 .30901 m
.40476 .31276 L
s
.45238 .30901 m
.45238 .31276 L
s
.54762 .30901 m
.54762 .31276 L
s
.59524 .30901 m
.59524 .31276 L
s
.64286 .30901 m
.64286 .31276 L
s
.69048 .30901 m
.69048 .31276 L
s
.78571 .30901 m
.78571 .31276 L
s
.83333 .30901 m
.83333 .31276 L
s
.88095 .30901 m
.88095 .31276 L
s
.92857 .30901 m
.92857 .31276 L
s
.25 Mabswid
0 .30901 m
1 .30901 L
s
.5 .04544 m
.50625 .04544 L
s
[(-0.00075)] .4875 .04544 1 0 Mshowa
.5 .1333 m
.50625 .1333 L
s
[(-0.0005)] .4875 .1333 1 0 Mshowa
.5 .22116 m
.50625 .22116 L
s
[(-0.00025)] .4875 .22116 1 0 Mshowa
.5 .39687 m
.50625 .39687 L
s
[(0.00025)] .4875 .39687 1 0 Mshowa
.5 .48473 m
.50625 .48473 L
s
[(0.0005)] .4875 .48473 1 0 Mshowa
.5 .57259 m
.50625 .57259 L
s
[(0.00075)] .4875 .57259 1 0 Mshowa
.125 Mabswid
.5 .06302 m
.50375 .06302 L
s
.5 .08059 m
.50375 .08059 L
s
.5 .09816 m
.50375 .09816 L
s
.5 .11573 m
.50375 .11573 L
s
.5 .15087 m
.50375 .15087 L
s
.5 .16844 m
.50375 .16844 L
s
.5 .18602 m
.50375 .18602 L
s
.5 .20359 m
.50375 .20359 L
s
.5 .23873 m
.50375 .23873 L
s
.5 .2563 m
.50375 .2563 L
s
.5 .27387 m
.50375 .27387 L
s
.5 .29144 m
.50375 .29144 L
s
.5 .32659 m
.50375 .32659 L
s
.5 .34416 m
.50375 .34416 L
s
.5 .36173 m
.50375 .36173 L
s
.5 .3793 m
.50375 .3793 L
s
.5 .41444 m
.50375 .41444 L
s
.5 .43201 m
.50375 .43201 L
s
.5 .44959 m
.50375 .44959 L
s
.5 .46716 m
.50375 .46716 L
s
.5 .5023 m
.50375 .5023 L
s
.5 .51987 m
.50375 .51987 L
s
.5 .53744 m
.50375 .53744 L
s
.5 .55501 m
.50375 .55501 L
s
.5 .02787 m
.50375 .02787 L
s
.5 .0103 m
.50375 .0103 L
s
.5 .59016 m
.50375 .59016 L
s
.5 .60773 m
.50375 .60773 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
.02381 .44981 m
.03279 .33112 L
.04262 .23938 L
.04758 .20631 L
.05288 .17956 L
.05546 .16953 L
.05789 .1617 L
.06024 .15558 L
.06244 .15107 L
.06487 .1474 L
.06616 .14599 L
.06754 .14486 L
.06824 .14444 L
.06899 .14409 L
.0697 .14387 L
.07037 .14375 L
.07162 .14376 L
.07232 .14389 L
.07295 .14408 L
.0742 .14468 L
.07535 .14546 L
.07661 .14657 L
.07794 .14803 L
.08265 .1553 L
.08526 .16065 L
.08806 .16732 L
.0931 .18152 L
.10458 .22187 L
.12439 .30545 L
.14594 .39555 L
.15598 .43177 L
.16664 .46408 L
.17574 .48577 L
.18054 .49483 L
.18579 .50279 L
.1907 .50836 L
.19338 .51062 L
.19588 .51223 L
.19708 .51284 L
.19822 .51331 L
.19925 .51365 L
.20035 .51393 L
.20156 .51412 L
.20284 .51421 L
.20393 .51419 L
.20513 .51406 L
.2058 .51394 L
.20653 .51377 L
.20785 .51336 L
.20913 .51284 L
Mistroke
.21033 .51225 L
.21303 .51052 L
.21591 .5081 L
.2212 .50212 L
.22599 .49504 L
.23604 .47537 L
.24527 .45206 L
.26611 .3846 L
.30565 .22779 L
.32555 .15134 L
.34367 .09199 L
.35304 .06683 L
.36322 .04462 L
.36881 .03488 L
.37397 .02753 L
.37891 .02203 L
.38146 .01977 L
.38415 .01784 L
.38649 .01654 L
.38773 .01599 L
.38905 .01551 L
.39027 .01516 L
.39138 .01493 L
.39249 .01478 L
.39354 .01472 L
.39477 .01472 L
.39607 .01484 L
.39718 .01503 L
.3984 .01532 L
.39971 .01574 L
.40112 .01632 L
.40366 .01768 L
.40601 .01931 L
.40857 .02148 L
.41322 .02649 L
.42195 .03948 L
.43133 .05846 L
.4417 .08505 L
.4627 .15433 L
.50287 .32155 L
.54153 .47908 L
.56154 .5419 L
.57161 .56607 L
.57728 .57719 L
.58263 .58595 L
.58755 .59247 L
.59015 .5953 L
.59289 .59784 L
.5952 .5996 L
.59774 .60115 L
Mistroke
.59886 .6017 L
.60006 .6022 L
.6011 .60256 L
.60222 .60287 L
.60295 .60303 L
.60361 .60314 L
.6049 .60329 L
.60563 .60332 L
.60641 .60332 L
.60715 .60328 L
.60783 .60321 L
.60907 .60301 L
.60977 .60286 L
.61042 .60268 L
.61183 .60222 L
.61316 .60166 L
.61569 .60029 L
.61799 .59869 L
.62316 .59387 L
.62776 .58821 L
.63283 .58049 L
.64309 .56031 L
.66151 .51038 L
.70174 .36032 L
.74044 .21034 L
.7605 .15085 L
.77058 .12899 L
.77629 .11943 L
.7816 .1125 L
.78406 .10996 L
.78666 .10774 L
.78802 .10677 L
.78951 .10587 L
.79088 .10518 L
.79214 .10467 L
.79341 .10428 L
.79461 .10402 L
.79589 .10386 L
.79661 .10382 L
.79727 .10382 L
.79849 .10391 L
.7996 .10409 L
.80088 .10442 L
.80208 .10483 L
.80434 .10592 L
.80674 .1075 L
.81102 .11141 L
.81562 .11717 L
.82067 .12532 L
.83091 .14754 L
Mistroke
.84023 .17397 L
.86116 .25082 L
.88192 .34005 L
.89104 .37864 L
.90108 .41725 L
.90572 .43283 L
.9107 .44746 L
.91501 .45797 L
.91972 .46679 L
.92105 .46871 L
.92246 .47047 L
.92369 .47174 L
.92501 .47284 L
.92572 .4733 L
.92637 .47366 L
.92765 .47413 L
.92881 .47431 L
.93004 .47421 L
.93116 .47388 L
.93237 .47323 L
.9335 .47236 L
.93454 .47132 L
.93708 .46778 L
.93948 .46308 L
.94175 .45736 L
.94388 .4508 L
.94873 .43125 L
.95345 .40553 L
.95855 .36966 L
.96775 .28082 L
.97619 .16821 L
Mfstroke
0 1 0 r
.02381 .48144 m
.03279 .34873 L
.04262 .24422 L
.04758 .20565 L
.05288 .17368 L
.05546 .16136 L
.05789 .15149 L
.06244 .1374 L
.06487 .13206 L
.06754 .12781 L
.06889 .12629 L
.06963 .12562 L
.07034 .12509 L
.07099 .12469 L
.0717 .12436 L
.07295 .12403 L
.07423 .124 L
.07538 .12425 L
.07603 .1245 L
.07672 .12484 L
.07798 .1257 L
.07916 .12674 L
.08041 .12811 L
.08265 .13117 L
.08806 .14159 L
.0931 .15471 L
.10458 .19393 L
.14349 .36476 L
.1633 .44108 L
.17449 .47448 L
.17983 .48744 L
.18485 .49775 L
.18964 .50586 L
.19403 .51178 L
.19891 .51663 L
.20147 .51845 L
.20289 .51925 L
.20417 .51983 L
.20543 .52029 L
.20662 .52061 L
.20788 .52084 L
.20859 .52091 L
.20925 .52094 L
.21034 .52093 L
.21154 .52081 L
.2128 .52057 L
.21397 .52024 L
.21536 .51973 L
.21667 .51911 L
.21914 .51761 L
Mistroke
.2218 .51551 L
.22469 .51266 L
.23002 .50592 L
.23504 .49789 L
.24441 .47879 L
.26539 .41965 L
.304 .27726 L
.32358 .20394 L
.34505 .13424 L
.35493 .10811 L
.36551 .08531 L
.37064 .07637 L
.3755 .06925 L
.38019 .06364 L
.38459 .05955 L
.38699 .05781 L
.38919 .05651 L
.39164 .05541 L
.39292 .05497 L
.39363 .05478 L
.39427 .05463 L
.3955 .0544 L
.39681 .05427 L
.39803 .05423 L
.39918 .05429 L
.39983 .05435 L
.40052 .05445 L
.40175 .05469 L
.40308 .05505 L
.40454 .05558 L
.40694 .05672 L
.40914 .05806 L
.41407 .06213 L
.41864 .06716 L
.42297 .07304 L
.43261 .08983 L
.44286 .11294 L
.46127 .16619 L
.49899 .30505 L
.51994 .38583 L
.53916 .45323 L
.55798 .50717 L
.56745 .52831 L
.57278 .5382 L
.57781 .54613 L
.58273 .55251 L
.58533 .5553 L
.58807 .55784 L
.59038 .55963 L
.59292 .56124 L
Mistroke
.59524 .56236 L
.59636 .56279 L
.5974 .56312 L
.59869 .56344 L
.59938 .56357 L
.6001 .56367 L
.6008 .56374 L
.60145 .56378 L
.60267 .56379 L
.60388 .5637 L
.60499 .56355 L
.60621 .56329 L
.60749 .56293 L
.61017 .56184 L
.61267 .56044 L
.61541 .55848 L
.61834 .55588 L
.62363 .54992 L
.62853 .54298 L
.6396 .52242 L
.65972 .46968 L
.69901 .32916 L
.73678 .19138 L
.75614 .13798 L
.76145 .1267 L
.76703 .11663 L
.77226 .10899 L
.777 .10363 L
.77936 .10154 L
.78192 .09972 L
.78309 .09905 L
.78433 .09844 L
.7855 .09797 L
.78656 .09762 L
.78777 .09734 L
.78907 .09715 L
.79027 .09708 L
.79142 .09712 L
.79206 .09719 L
.79274 .09729 L
.79397 .09756 L
.79473 .09779 L
.79544 .09804 L
.79676 .09861 L
.799 .09988 L
.80136 .10163 L
.80559 .10582 L
.81015 .11185 L
.81513 .12025 L
.82537 .1432 L
Mistroke
.83469 .17038 L
.85563 .2495 L
.87638 .34231 L
.89555 .42459 L
.90517 .45817 L
.90987 .47142 L
.91418 .48124 L
.91635 .48524 L
.91871 .48882 L
.92001 .49041 L
.92121 .49164 L
.92236 .49259 L
.92359 .49335 L
.92429 .49366 L
.92493 .49387 L
.92564 .49401 L
.92638 .49405 L
.92764 .49388 L
.92835 .49365 L
.92902 .49333 L
.93026 .4925 L
.9314 .49145 L
.93271 .48989 L
.93395 .48805 L
.93631 .48355 L
.93853 .47807 L
.9436 .46072 L
.94853 .43674 L
.95385 .4022 L
.96345 .31397 L
.97226 .19938 L
.97619 .13659 L
Mfstroke
1 0 0 r
3 Mabswid
.02381 .51638 m
.03279 .36832 L
.04262 .24972 L
.04758 .20503 L
.05288 .16722 L
.05789 .14014 L
.06244 .12209 L
.06507 .11433 L
.06785 .10804 L
.07022 .10416 L
.07157 .10255 L
.07283 .1014 L
.07353 .10092 L
.07428 .10051 L
.075 .10023 L
.07567 .10007 L
.07692 .10001 L
.07763 .10012 L
.07826 .10029 L
.07901 .1006 L
.07971 .10097 L
.08127 .10214 L
.08265 .10352 L
.0841 .10533 L
.08915 .11416 L
.09387 .12563 L
.10458 .1609 L
.14349 .33661 L
.1633 .41998 L
.17375 .45586 L
.18485 .48619 L
.19469 .50568 L
.20029 .51354 L
.20285 .51635 L
.20555 .51877 L
.20784 .5204 L
.20906 .5211 L
.21035 .52172 L
.21155 .52218 L
.21264 .52251 L
.21373 .52276 L
.21476 .52291 L
.21597 .52298 L
.21724 .52294 L
.21833 .52281 L
.21953 .52258 L
.22081 .5222 L
.2222 .52167 L
.22469 .52037 L
.22724 .51859 L
Mistroke
.22995 .51621 L
.23483 .51069 L
.24062 .50216 L
.24587 .49268 L
.26597 .44309 L
.30609 .30593 L
.34469 .17613 L
.36467 .12717 L
.37473 .10957 L
.38043 .10192 L
.38575 .09638 L
.39077 .09259 L
.39361 .09107 L
.39496 .09051 L
.39623 .09008 L
.39742 .08975 L
.39851 .08953 L
.39973 .08936 L
.40104 .08926 L
.40223 .08927 L
.40352 .08936 L
.40418 .08944 L
.40488 .08956 L
.40614 .08984 L
.40739 .0902 L
.40855 .09062 L
.41115 .09183 L
.41345 .09321 L
.41588 .09499 L
.42471 .10416 L
.42966 .11109 L
.43417 .11849 L
.44432 .13867 L
.46265 .18589 L
.50246 .31762 L
.54076 .44184 L
.56051 .48956 L
.57049 .50716 L
.57617 .51497 L
.58151 .52076 L
.58619 .52458 L
.58885 .5262 L
.59132 .52736 L
.59267 .52785 L
.59394 .52821 L
.59508 .52846 L
.59632 .52865 L
.59696 .52872 L
.59767 .52876 L
.59841 .52877 L
Mistroke
.5991 .52876 L
.60034 .52867 L
.60103 .52858 L
.60167 .52847 L
.60281 .52822 L
.60402 .52788 L
.6062 .52704 L
.6088 .5257 L
.61115 .52416 L
.61579 .5202 L
.62016 .51539 L
.62994 .50093 L
.64026 .48041 L
.65873 .43189 L
.69673 .30182 L
.71789 .22634 L
.73717 .16598 L
.74675 .14128 L
.75717 .11967 L
.76194 .11185 L
.767 .10508 L
.77133 .10063 L
.77379 .09867 L
.7761 .0972 L
.77728 .09659 L
.77854 .09606 L
.77962 .09569 L
.7808 .09538 L
.78152 .09524 L
.78219 .09514 L
.78349 .09505 L
.78468 .09508 L
.78594 .09522 L
.78717 .09547 L
.78849 .09586 L
.78974 .09635 L
.79087 .0969 L
.79366 .09865 L
.7963 .10085 L
.80089 .10595 L
.80515 .1121 L
.81481 .13104 L
.82541 .15958 L
.83538 .19318 L
.85401 .27005 L
.87244 .35626 L
.88289 .40474 L
.89263 .4463 L
.89801 .46666 L
.9031 .48358 L
Mistroke
.90805 .49741 L
.91262 .50741 L
.91499 .51141 L
.91751 .51468 L
.91881 .51596 L
.92003 .51689 L
.92073 .5173 L
.92137 .5176 L
.92211 .51785 L
.92281 .51799 L
.92412 .51799 L
.92485 .51784 L
.92551 .51761 L
.9268 .5169 L
.92802 .5159 L
.92944 .51432 L
.93075 .51245 L
.93371 .50672 L
.93616 .50029 L
.9384 .49303 L
.94344 .47149 L
.9481 .44454 L
.95252 .4122 L
.96242 .31287 L
.96801 .23825 L
.97318 .15588 L
.97619 .10165 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
0 g
.73468 .01131 m
.73468 .27582 L
.97619 .27582 L
.97619 .01131 L
F
1 g
.71815 .02784 m
.71815 .29235 L
.95966 .29235 L
.95966 .02784 L
F
0 g
.001 w
[ ] 0 setdash
.71815 .02784 m
.95966 .02784 L
.95966 .29235 L
.71815 .29235 L
.71815 .02784 L
s
% Start of sub-graphic
p
0.718149 0.02784 0.959659 0.29235 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 1.09524 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.09524 L
0 1.09524 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
3 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.744048 0.35119 1.04167 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .89286 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .47494 L
0 .47494 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[83]:=",
  ImageSize->{327, 155.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000570000Vb000`400?l00000o`00003oo`3ooom8
0?ooo`00o`3ooom80?ooo`00o`3ooom80?ooo`00o`3ooom80?ooo`00o`3ooom80?ooo`00k`3ooom>
000000X0oooo003_0?ooodh000002P3oool00>l0ooooCP00000:0?ooo`00k`3ooom>000000X0oooo
003Y0?oooe@000002P3oool00>T0oooo00<000000?ooo`3oool0C03oool5000000X0oooo003Y0?oo
o`030000003oool0oooo04`0oooo1@00000:0?ooo`00j@3oool00`000000oooo0?ooo`1<0?ooo`D0
00002P3oool00>T0oooo00<000000?ooo`3oool0C03oool5000000X0oooo003Y0?ooo`030000003o
ool0oooo04`0oooo1@00000:0?ooo`00j@3oool00`000000oooo0?ooo`1<0?ooo`D000002P3oool0
0>T0oooo00<000000?ooo`3oool0C03oool5000000X0oooo003Y0?ooo`030000003oool0oooo04`0
oooo1@00000:0?ooo`00M03oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04`0oooo
1@00000:0?ooo`00M03oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04`0oooo1@00
000:0?ooo`00M03oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04`0oooo1@00000:
0?ooo`00M03oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04`0oooo1@00000:0?oo
o`00FP3oool70000oa<0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1<0?ooo`D0
00002P3oool005T0oooo2@000?lB0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0
C03oool5000000X0oooo001I0?ooo`80003o1@3oool20000oa80oooo00<000000?ooo`3oool0LP3o
ool010000000oooo0?ooo`3ooolI0?l000@0oooo0P0000000`3oool00000000000020?ooo`@00000
0P3oool4000001d0oooo1@00000:0?ooo`00F03oool20000o`L0oooo0P000?lA0?ooo`030000003o
ool0oooo0780oooo00@000000?ooo`3oool0oooo6@3o00050?ooo`030000003oool0000000T0oooo
00<000000?ooo`3oool07P3oool5000000X0oooo00190?ooo`800000103oool2000000@0oooo0P00
00020000o`80oooo0P0000040?ooo`03000000000?l0003o00@0oooo00<000000?ooo`3oool00P3o
ool2000000D0oooo00<000000?ooo`3oool0LP3oool010000000oooo0?ooo`3ooolI0?l000D0oooo
0`0000030?ooo`@000000`3oool00`000000oooo0?ooo`0M0?ooo`D000002P3oool004P0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0000o`020000o`050?ooo`000000oooo0?ooo`00
00000P3oool010000000oooo0?ooo`000?l40?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool07`3oool0
10000000oooo00000000000:0?ooo`030000003oool0oooo01`0oooo1@00000:0?ooo`00B03oool0
10000000oooo0?ooo`0000080?ooo`04000000000?l0003o0000o`80oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`020000o`<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`800000L`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0
oooo00@000000?ooo`3oool000007@3oool5000000X0oooo00120?ooo`@000000P3oool010000000
oooo0?ooo`0000080?ooo`04000000000?l0003o00000080oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0?ooo`000000003o00@0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool07P3oool2000000`0oooo0P00000N0?ooo`D0
00002P3oool004P0oooo00@000000?ooo`3oool00000203oool30000o`040000003oool0oooo0000
00H00?l00P3oool010000000003o0000o`0000020?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04`0oooo1@00000:0?ooo`00B@3oool2
000000T0oooo0P000?l010000000oooo0?ooo`3oool8003o00040000003oool0oooo0000o`@00000
0`3oool3000000@0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1<0?ooo`D00000
2P3oool005@0oooo0P000?l30?ooo`@00?l00`3oool3003o0080oooo0P000?l=0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0C03oool5000000X0oooo001C0?ooo`<0003o0`3oool2
003o00H0oooo0`00o`000`3oool0003o0000o`0=0?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool0C03oool5000000X0oooo001C0?ooo`80003o0`3oool2003o00P0oooo0P00o`00103o
ool0003o0000o`000?l<0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0C03oool5
000000X0oooo001B0?ooo`<0003o0`3oool00`00o`00oooo0?ooo`080?ooo`800?l000<0oooo0000
o`000?l0303oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04`0oooo1@00000:0?oo
o`00DP3oool20000o`<0oooo0P00o`0;0?ooo`04003o003oool0003o0000o``0oooo00<000000?oo
o`3oool0LP3oool00`000000oooo0?ooo`1<0?ooo`D000002P3oool00580oooo0P000?l30?ooo`04
003o003oool0oooo0?ooo`L0o`000P3oool2003o00<0003o2`3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo04`0oooo1@00000:0?ooo`00D@3oool30000o`80oooo0P00o`020?ooo`T0
o`000P3oool01000o`00oooo0000o`000?l;0?ooo`030000003oool0oooo03L0oooo1P3o000e0?oo
o`030000003oool0oooo04`0oooo1@00000:0?ooo`005`3oool50?l003D0oooo0P000?l30?ooo`80
0?l000<0oooo0?l0003o00002@3o00000`3oool00?l0003o00020000o`/0oooo00<000000?ooo`3o
ool0=P3oool70?l002@0oooo0`3o000>0?ooo`030000003oool0oooo04`0oooo1@00000:0?ooo`00
5`3oool60?l003@0oooo0P000?l20?ooo`800?l00P3oool30?l000D0oooo103o0002003o00<0003o
2P3oool00`000000oooo0?ooo`0e0?ooo`T0o`0000<00?l00?ooo`3oool0803oool30?l000h0oooo
00<000000?ooo`3oool0C03oool5000000X0oooo000F0?ooo`L0o`00<`3oool30000o`80oooo0P00
o`000`3oool0o`000?l000020?l000H0oooo103o0002003o0080003o2P3oool00`000000oooo0?oo
o`0d0?ooo`@0o`000P00o`050?l00003003o003oool0oooo01l0oooo0`3o000>0?ooo`030000003o
ool0oooo04`0oooo1@00000:0?ooo`005P3oool80?l00380oooo0P000?l20?ooo`<00?l000@0oooo
0?l0003o0000o`00203oool40?l00003003o00000?l0003o00X0oooo00<000000?ooo`3oool0=03o
ool30?l000800?l00`000?l40?l000030000o`3oool0oooo01h0oooo0`3o000>0?ooo`030000003o
ool0oooo04`0oooo1@00000:0?ooo`005P3oool30?l00080oooo0`3o000b0?ooo`80003o0P3oool2
003o00030?ooo`3o0000o`000080o`002@3oool40?l00003003o00000?l0003o00T0oooo00<00000
0?ooo`3oool0<`3oool40?l00003003o00000?l0003o00<0oooo103o000P0?ooo`<0o`003P3oool0
0`000000oooo0?ooo`1<0?ooo`D000002P3oool001D0oooo103o00020?ooo`@0o`00<03oool30000
o`050?ooo`00o`000?l0003o003oool00`3o000;0?ooo`<0o`0000<00?l00000o`000?l02@3oool0
0`000000oooo0?ooo`0c0?ooo`<0o`0000<00?l00?ooo`000?l01@3oool30?l000030000o`3oool0
oooo01d0oooo0`3o000>0?ooo`030000003oool0oooo04`0oooo1@00000:0?ooo`005@3oool30?l0
00<00?l000@0oooo0?l0003o0000o`00<03oool20000o`80oooo0P00o`000`000000o`000?l00002
0?l000030?ooo`000000000000@0oooo0P0000020?ooo`@0o`000`000?l00`3oool0000000000005
0?ooo`030000003oool0oooo0380oooo103o00000`00o`00003o0000o`050?ooo`@0o`007`3oool3
0?l000h0oooo00<000000?ooo`3oool0C03oool5000000X0oooo000D0?ooo`@0o`000`00o`00103o
ool0o`000?l0003o000_0?ooo`05000000000?l0003o0000003oool00P00o`001P3oool0o`000?l0
003o0000oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`030?l0
0004003o00000?l0003o00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0a
0?ooo`@0o`000P00o`000`000?l0oooo0?ooo`050?ooo`<0o`0000<0003o0?ooo`3oool0703oool3
0?l000h0oooo00<000000?ooo`3oool0C03oool5000000X0oooo000D0?ooo`<0o`0000<00?l00?oo
o`3oool00P00o`040?l002h0oooo00@000000000o`000?l000000`00o`040?l000050?ooo`000000
oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000020?ooo`@0o`000P000?l30?ooo`030000
003oool0oooo0080oooo0P00000b0?ooo`<0o`000P00o`020000o`L0oooo0`3o00000`00o`00oooo
0?ooo`0L0?ooo`<0o`003P3oool00`000000oooo0?ooo`1<0?ooo`D000002P3oool001@0oooo0`3o
00001000o`00oooo0?ooo`3oool2003o00<0o`00:03oool400000080oooo0`000?l0100000000?l0
003o003oool30?l00080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003o0000o`000?l000<0003o0P0000050?ooo`030000003oool0oooo0300oooo103o
00000`00o`00003o0000o`080?ooo`@0o`0000<0003o0?ooo`3oool06`3oool30?l000h0oooo00<0
00000?ooo`3oool0C03oool5000000X0oooo000D0?ooo`<0o`000`000?l20?ooo`04003o003o0000
o`000?l002h0oooo0P000?l0103oool00000003o0000o`040?l00080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003o0000o`000080o`000P000?l00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0300oooo0`3o00000`00o`00oooo0000o`0:0?oo
o`<0o`0000<00?l00?ooo`3oool06`3oool30?l000h0oooo00<000000?ooo`3oool0C03oool50000
00X0oooo000D0?ooo`<0o`000`000?l20?ooo`04003o003o0000o`000?l002h0oooo0P000?l01000
00000?l0003o0000o`030?l000@0oooo0P0000040?ooo`800000103oool010000000o`000?l0003o
00020000o`<00000103oool00`000000oooo0?ooo`0_0?ooo`@0o`0000<00?l00000o`000?l02P3o
ool30?l00003003o00000?l0oooo01/0oooo0`3o000>0?ooo`030000003oool0oooo04`0oooo1@00
000:0?ooo`004`3oool30?l00003003o00000?l0oooo0080003o00<0oooo003o003o00000`3o000/
0?ooo`<0003o00<0oooo003o0000o`00103o000A0?ooo`<0o`0000<00?l00000o`000?l01P3oool0
0`000000oooo0?ooo`0_0?ooo`<0o`000P00o`000`000?l0oooo0?ooo`090?ooo`@0o`0000<0003o
0?ooo`3oool06P3oool30?l000h0oooo00<000000?ooo`3oool07P3oool2000000030?ooo`000000
00000080oooo100000020?ooo`D00000703oool5000000X0oooo000C0?ooo`<0o`0000@0003o0?oo
o`3oool0oooo0P000?l2003o00<0o`00;03oool20000o`80oooo0P00o`030?l00180oooo103o0002
0000o`H0oooo00<000000?ooo`3oool0;`3oool30?l00003003o00000?l0003o00`0oooo0`3o0000
0`00o`00oooo0?ooo`0J0?ooo`<0o`003P3oool010000000oooo0?ooo`3ooolH003o00H0oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0L0?ooo`D000002P3oool001<0oooo0`3o0000
10000?l0oooo0?ooo`3oool30000o`04003o003o0000o`000?l002`0oooo0P000?l00`3oool00?l0
003o00040?l001<0oooo0`3o00020000o`H0oooo00<000000?ooo`3oool0;P3oool40?l00003003o
00000?l0003o00`0oooo0`3o00000`00o`00003o0?ooo`0J0?ooo`<0o`003P3oool010000000oooo
0?ooo`3ooolH003o00H0oooo0`0000030?ooo`@00000103oool00`000000oooo0?ooo`0L0?ooo`D0
00002P3oool001<0oooo0`3o00050?ooo`80003o00@00?l00?l0003o0000o`00;03oool20000o`03
0?ooo`00o`000?l000<0o`00503oool40?l000030000o`3oool0oooo00@0oooo00<000000?ooo`3o
ool0;P3oool30?l00004003o00000?l0003o0000o``0oooo0`3o00000`00o`00003o0?ooo`0J0?oo
o`<0o`003P3oool00`000000oooo0?ooo`0O0?ooo`040000003oool00000000000X0oooo00<00000
0?ooo`3oool0703oool5000000X0oooo000C0?ooo`<0o`001P3oool00`000?l00?l00?l000020?l0
02/0oooo0`000?l00`3oool00?l00?l000030?l001D0oooo0`3o00000`000?l0oooo0?ooo`040?oo
o`030000003oool0oooo02h0oooo0`3o00000`00o`00003o0000o`0=0?ooo`@0o`0000<00?l00?oo
o`3oool06@3oool30?l000h0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo01`0oooo1@00000:0?ooo`004`3oool30?l000H0oooo00<0003o003o0000
o`000`3o000Z0?ooo`80003o00<0oooo003o0000o`000`3o000F0?ooo`<0o`000P000?l50?ooo`03
0000003oool0oooo02d0oooo103o00000`00o`00003o0000o`0>0?ooo`<0o`0000<00?l00000o`3o
ool06@3oool30?l000h0oooo00<000000?ooo`3oool07P3oool2000000`0oooo0P00000N0?ooo`D0
00002P3oool001<0oooo0`3o00060?ooo`80003o00@00?l00?l0003o0000o`00:P3oool20000o`03
0?ooo`00o`000?l000<0o`005P3oool40?l000030000o`3oool0oooo00<0oooo00<000000?ooo`3o
ool0;@3oool30?l00004003o00000?l0003o0000o`h0oooo0`3o00000`00o`00003o0?ooo`0I0?oo
o`<0o`003P3oool00`000000oooo0?ooo`1<0?ooo`D000002P3oool00180oooo0`3o00080?ooo`03
0000o`00o`00o`000080o`00:P3oool20000o`030?ooo`00o`00o`0000<0o`005`3oool30?l00003
0000o`3oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool30?l00003003o00000?l0003o00l0
oooo103o00000`00o`00oooo0?ooo`0H0?ooo`<0o`003P3oool00`000000oooo0?ooo`1<0?ooo`D0
00002P3oool00180oooo0`3o00080?ooo`030000o`00o`00o`000080o`00:@3oool30000o`800?l0
0`3o000H0?ooo`<0o`0000<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`@0o`00
00<00?l00000o`000?l0403oool30?l00003003o00000?l0oooo01P0oooo0`3o000>0?ooo`030000
003oool0oooo04`0oooo1@00000:0?ooo`004P3oool30?l000P0oooo00<0003o003o0000o`000`3o
000X0?ooo`80003o00<0oooo003o0000o`000`3o000H0?ooo`@0o`0000<0003o0?ooo`3oool00P3o
ool00`000000oooo0?ooo`0/0?ooo`<0o`0000@00?l00000o`000?l0003o403oool30?l00003003o
00000?l0oooo01P0oooo0`3o000>0?ooo`030000003oool0oooo04`0oooo1@00000:0?ooo`004P3o
ool30?l000P0oooo0P000?l01000o`00o`000?l0003o000X0?ooo`80003o00<0oooo003o003o0000
0`3o000I0?ooo`<0o`0000<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`0/0?ooo`<0o`00
00<00?l00000o`000?l04@3oool30?l00003003o00000?l0oooo01L0oooo0`3o000?0?ooo`030000
003oool0oooo04`0oooo1@00000:0?ooo`004P3oool30?l000P0oooo0P000?l01000o`00o`000?l0
003o000X0?ooo`80003o0P00o`030?l001X0oooo0`3o00000`000?l0oooo0?ooo`020?ooo`030000
003oool0oooo02/0oooo103o00000`00o`00003o0000o`0A0?ooo`@0o`0000<00?l00000o`3oool0
5P3oool30?l000l0oooo00<000000?ooo`3oool0C03oool5000000X0oooo000B0?ooo`<0o`002@3o
ool00`000?l00?l00?l000020?l002L0oooo0`000?l2003o00<0o`006P3oool40?l000@0oooo00<0
00000?ooo`3oool0:`3oool30?l000800?l00P000?lB0?ooo`<0o`0000<00?l00000o`3oool05P3o
ool30?l000l0oooo00<000000?ooo`3oool0C03oool5000000X0oooo000B0?ooo`<0o`002@3oool0
0`000?l00?l00?l000020?l002H0oooo00@000000000o`000?l0oooo0P00o`030?l000<0oooo0P00
00040?ooo`800000103oool2000000<0oooo100000030?ooo`<0o`00103oool00`000000oooo0?oo
o`0[0?ooo`<0o`0000<00?l00000o`000?l04`3oool30?l00003003o00000?l0oooo01H0oooo0`3o
000?0?ooo`030000003oool0oooo04`0oooo1@00000:0?ooo`004P3oool30?l000T0oooo00<0003o
003o0000o`000`3o000T0?ooo`060000003oool0003o0000o`3oool00?l0103o00020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`030000003oool0oooo00<0oooo00D000000?l0003o0000o`000000o`030?ooo`030000003o
ool0oooo02X0oooo103o00000`00o`00003o0000o`0C0?ooo`<0o`000P00o`0G0?ooo`<0o`003`3o
ool00`000000oooo0?ooo`1<0?ooo`D000002P3oool00180oooo0`3o00090?ooo`80003o00@00?l0
0?l0003o0000o`00903oool010000000oooo0000o`000?l2003o00<0o`000`3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`030?ooo`<0o`0000@0003o0?ooo`3oool0oooo0P00000[0?ooo`<0o`000P00
o`020000oa<0oooo103o00000`00o`00003o0?ooo`0E0?ooo`<0o`003`3oool00`000000oooo0?oo
o`1<0?ooo`D000002P3oool00140oooo0`3o000;0?ooo`030000o`00o`00o`000080o`007P3oool4
00000080oooo00@000000000o`000?l0003o0P00o`030?l000<0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool40?l000<0oooo00<000000?ooo`3oool0:P3oool30?l00004003o00000?l0003o
0000oa@0oooo0`3o00000`00o`00003o0?ooo`0E0?ooo`<0o`003`3oool00`000000oooo0?ooo`1<
0?ooo`D000002P3oool00140oooo0`3o000;0?ooo`030000o`00o`00o`000080o`00903oool01@00
0000003o0000o`0000000?l000@0o`000`3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`040000003o0000o`000?l000<0oooo00<000000?ooo`3oool0:P3oool30?l00003003o00000?l0
003o01D0oooo0`3o00000`00o`00003o0?ooo`0E0?ooo`<0o`003`3oool00`000000oooo0?ooo`1<
0?ooo`D000002P3oool00140oooo0`3o000;0?ooo`030000o`00o`00o`000080o`009@3oool20000
o`030?ooo`00o`00o`000080o`001@3oool2000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo00D000000?l0003o0000o`000000o`020?ooo`030000003oool0oooo02T0oooo103o0000
0`00o`00003o0000o`0E0?ooo`<0o`000P00o`000`000?l0oooo0?ooo`0C0?ooo`<0o`003`3oool0
0`000000oooo0?ooo`1<0?ooo`D000002P3oool00140oooo0`3o000;0?ooo`80003o00@00?l00?l0
003o0000o`00903oool20000o`800?l00`3o000N0?ooo`@0o`000P3oool00`000000oooo0?ooo`0Y
0?ooo`<0o`000P00o`020000oaD0oooo103o00000`00o`00003o0?ooo`0D0?ooo`<0o`003`3oool0
0`000000oooo0?ooo`1<0?ooo`D000002P3oool00140oooo0`3o000;0?ooo`80003o00@00?l00?l0
003o0000o`008`3oool30000o`800?l00`3o000O0?ooo`<0o`000P3oool00`000000oooo0?ooo`0Y
0?ooo`<0o`0000@00?l00000o`000?l0003o5P3oool30?l00003003o00000?l0oooo01@0oooo0`3o
000?0?ooo`030000003oool0oooo04`0oooo1@00000:0?ooo`004@3oool30?l000`0oooo00<0003o
003o003o00000P3o000S0?ooo`80003o00<0oooo003o003o00000`3o000O0?ooo`<0o`000P3oool0
0`000000oooo0?ooo`0Y0?ooo`<0o`0000<00?l00000o`000?l05`3oool30?l00003003o00000?l0
oooo01@0oooo0`3o000?0?ooo`030000003oool0oooo04`0oooo1@00000:0?ooo`004@3oool30?l0
00`0oooo00<0003o003o003o00000P3o000S0?ooo`80003o00<0oooo003o003o00000P3o000P0?oo
o`<0o`000P3oool00`000000oooo0?ooo`0X0?ooo`@0o`0000<00?l00000o`000?l05`3oool30?l0
00800?l000<0003o0?ooo`3oool04P3oool30?l000l0oooo00<000000?ooo`3oool0C03oool50000
00X0oooo000?0?ooo`8000000`3o000<0?ooo`030000o`00o`000?l000<0o`005`3oool2000000@0
oooo0P0000030?ooo`80003o0P00o`030?l00200oooo103o00000`3oool000000?ooo`0Y0?ooo`<0
o`000P00o`020000o`800000103oool2000000l0oooo103o00000`00o`00003o0?ooo`0C0?ooo`<0
o`000P00000=0?ooo`030000003oool0oooo04`0oooo1@00000:0?ooo`004@3oool30?l000`0oooo
0P000?l01000o`00o`000?l0003o000F0?ooo`040000003oool0oooo000000L0oooo0`000?l00`00
o`00o`000?l000020?l00240oooo0`3o00000`3oool000000?ooo`0Y0?ooo`<0o`0000@00?l00000
o`000?l0003o1@3oool010000000oooo0?ooo`00000?0?ooo`<0o`0000<00?l00000o`3oool04`3o
ool30?l000l0oooo00<000000?ooo`3oool0C03oool5000000X0oooo000A0?ooo`<0o`003@3oool0
0`000?l00?l00?l000020?l001H0oooo00@000000?ooo`3oool000001`3oool20000o`030?ooo`00
o`00o`000080o`008P3oool30?l000030?ooo`000000oooo02T0oooo0`3o00000`00o`00003o0000
o`090?ooo`030000003oool0oooo00d0oooo0`3o00000`00o`00003o0?ooo`0C0?ooo`<0o`003`3o
ool00`000000oooo0?ooo`1<0?ooo`D000002P3oool000T0oooo100000040?ooo`<0o`003@3oool0
0`000?l00?l00?l000020?l00100oooo100000020?ooo`040000003oool0oooo000000L0oooo0P00
0?l00`0000000?l00?l000020?l00280oooo103o00000`000000oooo0?ooo`0W0?ooo`@0o`0000<0
0?l00000o`000?l01`3oool200000100oooo0`3o00000`00o`00003o0000o`0B0?ooo`<0o`0000<0
003o0?ooo`3oool03@3oool00`000000oooo0?ooo`1<0?ooo`D000002P3oool00140oooo0`3o000=
0?ooo`030000o`00o`00o`000080o`005P3oool010000000oooo0?ooo`0000070?ooo`80003o0P00
o`030?l002<0oooo0`3o00000`000000oooo0?ooo`0W0?ooo`<0o`000P00o`020000o`L0oooo00<0
00000?ooo`3oool03`3oool30?l000800?l000<0003o0?ooo`3oool0403oool30?l000030000003o
ool0oooo00d0oooo00<000000?ooo`3oool07P3oool2000000030?ooo`00000000000080oooo1000
00030?ooo`8000007P3oool5000000X0oooo000@0?ooo`<0o`003P3oool20000o`04003o003o0000
o`000?l001H0oooo0P0000080?ooo`80003o00<00?l00?l0003o00000P3o000S0?ooo`<0o`0000<0
00000?ooo`3oool09`3oool30?l00004003o00000?l0003o0000o`L0oooo0`00000@0?ooo`<0o`00
00<00?l00000o`3oool04@3oool30?l000030000003oool0oooo00d0oooo00@000000?ooo`3oool0
oooo60000?l60?ooo`030000003oool0000000T0oooo00@000000?ooo`3oool000007@3oool50000
00X0oooo000@0?ooo`<0o`003P3oool20000o`04003o003o0000o`000?l001l0oooo0`000?l01000
o`00o`000?l0003o000T0?ooo`<0o`0000<000000?ooo`3oool09`3oool30?l00003003o00000?l0
003o01/0oooo0`3o00000`00o`00003o0?ooo`0A0?ooo`<0o`00403oool010000000oooo0?ooo`3o
oolH0000o`H0oooo0`0000030?ooo`@000000P3oool010000000oooo0?ooo`00000M0?ooo`D00000
2P3oool00100oooo0`3o000?0?ooo`030000o`00o`00o`000080o`007`3oool20000o`800?l00`3o
000T0?ooo`@0o`00:03oool40?l00003003o00000?l0003o01/0oooo0`3o00000`00o`00003o0?oo
o`0A0?ooo`<0o`00403oool00`000000oooo0?ooo`0O0?ooo`040000003oool00000000000P0oooo
00@000000?ooo`3oool000007@3oool5000000X0oooo000@0?ooo`<0o`003`3oool00`000?l00?l0
0?l000020?l001l0oooo0P000?l00`00o`00o`000?l000020?l002D0oooo0`3o000X0?ooo`<0o`00
00@00?l00?ooo`000?l0003o6`3oool30?l00003003o00000?l0003o0140oooo0`3o000@0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00000M0?oo
o`D000002P3oool00100oooo0`3o000?0?ooo`030000o`00o`00o`000080o`007`3oool20000o`04
003o003o0000o`000?l002H0oooo0`3o000X0?ooo`<0o`0000@00?l00000o`000?l0003o6`3oool3
0?l000800?l000<0003o0?ooo`3oool03`3oool30?l00100oooo00<000000?ooo`3oool07P3oool2
000000`0oooo0P00000N0?ooo`D000002P3oool000T0oooo1`0000030?l000l000000P000?l01000
o`00o`000?l0003o000M000000<0003o00@00?l00?l0003o0000o`009P0000040?l002L000000`3o
00000`00o`00003o0000o`0M000000<0o`0000<00?l00000o`000000400000030?l000L000002@3o
ool00`000000oooo0?ooo`1<0?ooo`D000002P3oool000h0oooo00<000000?ooo`3o00000P3o0005
0?ooo`030000003oool0oooo00L0oooo00<000000000o`00o`000`3o00040?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`3oool20000o`800?l00`3o
00090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`<0o`00203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01`3oool40?l00003003o00000?l0003o00@0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0`3o00000`00o`00003o0000
00090?ooo`030000003oool0oooo00@0oooo0`3o00000`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo04`0oooo1@00000:0?ooo`003P3oool00`000000oooo0?l000020?l00100oooo00<0003o
003o003o00000P3o000I0?ooo`040000003oool0oooo0?ooo`80003o00<00?l00?l0003o00000P3o
000W0?ooo`<0o`009P3oool30?l00004003o003oool0003o0000o`@0oooo00<000000?ooo`3oool0
5P3oool30?l00003003o00000?l0oooo0100oooo0`3o00000`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo04`0oooo1@00000:0?ooo`00403oool30?l00100oooo00<0003o003o003o00000P3o
000M0?ooo`80003o00@00?l00?l0003o0000o`00:03oool30?l002H0oooo0`3o00001000o`00003o
0000o`000?lM0?ooo`<0o`0000<00?l00000o`000?l0403oool30?l00100oooo00<000000?ooo`3o
ool0C03oool5000000X0oooo000@0?ooo`<0o`00403oool20000o`04003o003o0000o`000?l001/0
oooo0P000?l2003o00<0o`00:03oool40?l002@0oooo103o00000`00o`00003o0000o`0O0?ooo`<0
o`0000<00?l00000o`3oool03`3oool30?l00100oooo00<000000?ooo`3oool0C03oool5000000X0
oooo000?0?ooo`040000o`3o0000o`000?l00140oooo00<0003o003o003o00000P3o000K0?ooo`80
003o00<00?l00?l0003o00000P3o000Y0?ooo`<0o`00903oool30?l000800?l00P000?lO0?ooo`<0
o`0000<00?l00000o`3oool03P3oool30?l00140oooo00<000000?ooo`3oool0C03oool5000000X0
oooo000?0?ooo`040000o`3o0000o`000?l00140oooo00<0003o003o003o00000P3o000K0?ooo`80
003o00@00?l00?l0003o0000o`00:P3oool30?l002@0oooo0`3o00001000o`00oooo0000o`000?lO
0?ooo`<0o`0000<00?l00000o`3oool03P3oool30?l00140oooo00<000000?ooo`3oool0C03oool5
000000X0oooo000?0?ooo`<0o`004P3oool00`000?l00?l00?l000020?l001/0oooo00<0003o003o
0000o`000`3o000Z0?ooo`@0o`008`3oool30?l00004003o00000?l0003o0000oal0oooo0`3o0000
0`00o`00003o0000o`0>0?ooo`<0o`004@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo00`0oooo000?0?ooo`<0o`004P3oool00`000?l00?l00?l000030?l001T0oooo0P000?l2003o
00<0o`00:P3oool010000000o`000?l0003o000R0?ooo`@0o`0000<00?l00000o`000?l0803oool3
0?l000800?l000<0003o0?ooo`3oool0303oool30?l00140oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0<0?ooo`003`3oool30?l001<0oooo00<0003o003o003o00000P3o000I0?oo
o`80003o00<00?l00?l0003o00000P3o000Z0?ooo`040000003o0000o`000?l00280oooo0`3o0002
003o0080003o8@3oool30?l00003003o00000?l0oooo00d0oooo0`3o000A0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0303oool000l0oooo0`3o000C0?ooo`030000o`00o`00o`00
0080o`006@3oool20000o`04003o003o0000o`000?l002/0oooo00<000000?l0003o00000P3o000Q
0?ooo`<0o`0000@00?l00?ooo`000?l0003o8@3oool30?l00003003o00000?l0oooo00d0oooo0`3o
000A0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0303oool000l0oooo0`3o000C
0?ooo`030000o`00o`00o`0000<0o`00603oool00`000?l00?l0003o00030?l002/0oooo00<00000
0000o`3o00000P3o000P0?ooo`@0o`0000@00?l00000o`000?l0003o8@3oool30?l00003003o0000
0?l0003o00d0oooo0`3o000A0?oooe0000003P3oool000l0oooo0`3o000D0?ooo`800?l00`3o000H
0?ooo`030000o`00o`000?l000<0o`00:`3oool00`000000oooo0?l000020?l00200oooo0`3o0002
003o0080003o8P3oool30?l000800?l000<0003o0?ooo`3oool02P3oool30?l000030000o`3oool0
oooo06d0oooo000?0?ooo`<0o`00503oool00`000?l00?l00?l000020?l001L0oooo0P000?l00`00
o`00o`000?l000020?l002/0oooo00<000000?ooo`3o00000P3o000P0?ooo`<0o`0000@00?l00?oo
o`000?l0003o8P3oool40?l00003003o00000?l0oooo00/0oooo0`3o001`0?ooo`003`3oool30?l0
01@0oooo00<0003o003o003o00000P3o000G0?ooo`030000o`00o`000?l000<0o`00;03oool00`00
0000oooo0?l000030?l001l0oooo0`3o00001000o`00oooo0000o`000?lS0?ooo`<0o`0000<00?l0
0000o`3oool02`3oool30?l00700oooo000?0?ooo`<0o`00503oool00`000?l00?l00?l000030?l0
01H0oooo00<0003o003o0000o`000`3o000/0?ooo`030000003oool0oooo00<0o`007P3oool40?l0
0004003o00000?l0003o0000ob<0oooo0`3o00000`00o`00003o0000o`0;0?ooo`<0o`00L03oool0
00l0oooo0`3o000E0?ooo`030000o`00o`00o`000080o`005P3oool00`000?l00?l00?l000030?l0
02`0oooo00<000000?ooo`3oool00`3o000N0?ooo`<0o`000P00o`020000ob@0oooo103o00020000
o`/0oooo0`3o001`0?ooo`003`3oool30?l001D0oooo00<0003o003o003o00000P3o000E0?ooo`03
0000o`00o`000?l000<0o`000P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0
oooo0P0000030?ooo`@000000`3oool2000000D0oooo00<000000?ooo`3oool0103o000M0?ooo`<0
o`0000@00?l00?ooo`000?l0003o9@3oool30?l00003003o00000?l0oooo00X0oooo0`3o001`0?oo
o`003`3oool30?l001D0oooo00<0003o003o003o00000P3o000E0?ooo`030000o`00o`000?l000<0
o`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`000?l30?l001`0oooo103o00001000
o`00003o0000o`000?lU0?ooo`<0o`0000<00?l00000o`3oool02P3oool30?l00700oooo000>0?oo
o`040000o`3o0000o`000?l001D0oooo00<0003o003o003o00000`3o000D0?ooo`030000o`00o`00
0?l000<0o`0000D0oooo0000003oool0oooo000000080?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool200000080oooo0`3o000L0?ooo`<0o`000P00o`020000
obH0oooo103o00000`000?l0oooo0?ooo`090?ooo`<0o`00L03oool000h0oooo00@0003o0?l0003o
0000o`005P3oool00`000?l00?l00?l000020?l001<0oooo0P000?l00`00o`00o`000?l000020?l0
00050?ooo`000000oooo0?ooo`000000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`80
00001@3oool010000000oooo0?ooo`3oool30?l001`0oooo0`3o0002003o0080003o9`3oool30?l0
0080003o2@3oool30?l000030000o`3oool0oooo06h0oooo000>0?ooo`040000o`3o0000o`000?l0
01H0oooo00<0003o003o003o00000P3o000C0?ooo`030000o`00o`000?l000<0o`000P3oool01000
0000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0103oool010000000oooo0?ooo`3oool40?l001/0oooo0`3o00001000o`00oooo0000o`00
0?lW0?ooo`<0o`0000<00?l00000o`3oool0203oool30?l00740oooo000>0?ooo`<0o`005`3oool0
0`000?l00?l00?l000030?l00180oooo00<0003o003o0000o`000`3o00030?ooo`8000002P3oool2
000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0`0000040?ooo`050000003oool0
oooo0?ooo`000?l00`3o000J0?ooo`@0o`0000@00?l00000o`000?l0003o9`3oool30?l00003003o
00000?l0oooo00P0oooo0`3o001a0?ooo`003P3oool30?l001L0oooo0P000?l01000o`00o`000?l0
003o000A0?ooo`80003o0P00o`030?l002h0oooo00<000000?ooo`3oool00P3oool30?l001X0oooo
0`3o0002003o0080003o:03oool40?l000030000o`3oool0oooo00L0oooo0`3o001a0?ooo`003P3o
ool30?l001P0oooo00<0003o003o003o00000P3o000A0?ooo`030000o`00o`000?l000@0o`00;P3o
ool00`000000oooo0?ooo`020?ooo`@0o`006@3oool30?l000800?l00P000?lY0?ooo`<0o`000P00
0?l80?ooo`<0o`00L@3oool000h0oooo0`3o000H0?ooo`030000o`00o`00o`000080o`00403oool2
0000o`800?l00`3o000_0?ooo`030000003oool0oooo0080oooo00@0003o0?l0003o0000o`00603o
ool40?l00004003o003oool0003o0000obT0oooo0`3o00000`00o`00003o0?ooo`070?ooo`<0o`00
L@3oool000h0oooo0`3o000H0?ooo`030000o`00o`00o`0000<0o`003`3oool20000o`800?l00`3o
000_0?ooo`030000003oool0oooo0080oooo00@0003o0?l0003o0000o`00603oool30?l000800?l0
0`000?lY0?ooo`<0o`0000<00?l00000o`3oool01P3oool30?l00003003o003oool0oooo06l0oooo
000>0?ooo`<0o`00603oool20000o`04003o003o0000o`000?l000l0oooo00<0003o003o0000o`00
103o000_0?ooo`030000003oool0oooo00<0oooo103o000G0?ooo`<0o`000P00o`020000obX0oooo
0`3o00000`00o`00003o0000o`060?ooo`<0o`0000<00?l00?ooo`3oool0K`3oool000h0oooo0`3o
000I0?ooo`030000o`00o`00o`000080o`003P3oool20000o`800?l00`3o000`0?ooo`030000003o
ool0oooo00<0oooo00@00?l00?l0003o0000o`005P3oool40?l00004003o003oool0003o0000obX0
oooo103o00020000o`H0oooo0`3o001b0?ooo`003P3oool30?l001T0oooo00<0003o003o003o0000
0P3o000>0?ooo`80003o0P00o`030?l00300oooo00<000000?ooo`3oool00`3oool010000?l0o`00
0?l0003o000F0?ooo`<0o`000P00o`030000ob/0oooo0`3o00000`00o`00003o0?ooo`050?ooo`<0
o`00LP3oool000h0oooo0`3o000I0?ooo`80003o103o000=0?ooo`030000o`00o`000?l000@0o`00
<03oool00`000000oooo0?ooo`040?ooo`@0o`005@3oool30?l000800?l00P000?l/0?ooo`<0o`00
00<00?l00000o`3oool01@3oool30?l00780oooo000>0?ooo`<0o`006@3oool20000o`04003o003o
0000o`000?l000`0oooo0P000?l2003o00<0o`00<@3oool00`000000oooo0?ooo`040?ooo`04003o
003o0000o`000?l001@0oooo103o0002003o0080003o;03oool30?l00003003o00000?l0003o00D0
oooo0`3o001b0?ooo`003@3oool010000?l0o`000?l0003o000J0?ooo`030000o`00o`00o`000080
o`00303oool20000o`03003o003o0000o`000080o`00<@3oool00`000000oooo0?ooo`040?ooo`03
0000o`3o0000o`000080o`004`3oool30?l000800?l000<0oooo0000o`000?l0;03oool40?l00003
003o00000?l0oooo00<0oooo0`3o00000`00o`00oooo0?ooo`1`0?ooo`003P3oool30?l001X0oooo
00<0003o003o003o00000P3o000;0?ooo`<0003o00@00?l00?l0003o0000o`00<P3oool00`000000
oooo0?ooo`040?ooo`030000o`00o`00o`000080o`004P3oool40?l000800?l00`000?l]0?ooo`<0
o`0000<00?l00000o`000?l00`3oool30?l007<0oooo000>0?ooo`<0o`006`3oool00`000?l0o`00
0?l000020?l000X0oooo0P000?l00`00o`00o`000?l000020?l00380oooo00<000000?ooo`3oool0
1@3oool00`00o`00o`000?l000020?l00140oooo0`3o00000`3oool00?l0003o00020000obh0oooo
0`3o00001P00o`00oooo0000o`000?l0oooo0000o`<0o`00L`3oool000h0oooo0`3o000K0?ooo`03
0000o`00o`00o`000080o`002P3oool20000o`04003o003o0000o`000?l003<0oooo00<000000?oo
o`3oool01@3oool00`000?l00?l00?l000020?l00140oooo0`3o00000`3oool00?l00?ooo`020000
obh0oooo0`3o00000`00o`00oooo0000o`030000o`<0o`00L`3oool000h0oooo0`3o000L0?ooo`04
003o003o0000o`000?l000X0oooo00<0003o0?ooo`00o`000`3o000>0?ooo`800000103oool20000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000050?ooo`030000003oool0oooo
00D0oooo00<0003o003o003o00000`3o000?0?ooo`@0o`000P00o`000`3oool0003o0000o`0^0?oo
o`@0o`0000<00?l00?ooo`000?l00P000?l30?l007<0oooo000>0?ooo`<0o`00703oool00`000?l0
o`000?l000020?l000P0oooo0P000?l00`3oool0o`000?l000020?l000d0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0
oooo00<0003o003o0000o`000`3o000?0?ooo`<0o`0000<0oooo003o003oool00`000?l_0?ooo`<0
o`000P00o`000`3oool0003o0000o`030?l007<0oooo000=0?ooo`<0o`007P3oool01000o`00o`00
0?l0003o00080?ooo`030000o`3oool00?l000<0o`003P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo0080oooo0P0000070?ooo`030000o`00o`00o`0000<0o`00
3@3oool40?l000800?l000<0oooo0000o`000?l0<03oool30?l000800?l00P3oool30?l007@0oooo
000=0?ooo`<0o`007P3oool00`000?l0o`000?l000020?l000H0oooo0P000?l00`3oool0o`000?l0
00020?l000h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool2000000D0oooo00<00000
0?ooo`3oool01P3oool00`000?l00?l0003o00030?l000`0oooo103o0000103oool00?l00?ooo`3o
ool20000oc00oooo0`3o0004003o00<0o`00M03oool000d0oooo0`3o000O0?ooo`04003o003o0000
o`000?l000H0oooo00<0003o0?ooo`00o`000`3o000?0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000o`00o`00
0?l000@0o`002`3oool30?l000040?ooo`00o`000?l00?ooo`<0003o<03oool40?l000<00?l00`3o
001d0?ooo`003@3oool30?l001l0oooo00@0003o0?l0003o0000o`001@3oool20000o`030?ooo`3o
0000o`000080o`00403oool2000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo0`00
00040?ooo`030000003oool0oooo00L0oooo00<0003o003o0000o`000`3o000:0?ooo`@0o`0000@0
oooo003o003oool0oooo0P000?lb0?ooo`<0o`0000<0oooo003o0000o`000`3o001d0?ooo`003@3o
ool30?l00200oooo103o00030?ooo`80003o00<0oooo003o003o00000P3o000f0?ooo`030000003o
ool0oooo00L0oooo00<0003o003o0000o`00103o00090?ooo`<0o`000P3oool00`00o`00oooo0?oo
o`020000oc80oooo103o00000`3oool0o`000?l000020?l007@0oooo000=0?ooo`<0o`00803oool0
0`000?l0o`000?l000030?l000<0003o00<00?l00?l0003o00000P3o000f0?ooo`030000003oool0
oooo00L0oooo0P000?l00`00o`00oooo0?l000020?l000P0oooo103o00000`3oool00?l0003o0002
0?ooo`80003o<`3oool70?l007D0oooo000=0?ooo`<0o`008@3oool60?l000030000o`3o0000o`00
00<0o`00=`3oool00`000000oooo0?ooo`070?ooo`80003o0P00o`040?l000H0oooo103o00020?oo
o`03003o003oool0oooo00<0003o<`3oool70?l007D0oooo000=0?ooo`<0o`008@3oool00`000?l0
0?l00?l000080?l003P0oooo00<000000?ooo`3oool0203oool20000o`03003o003oool0o`000080
o`001@3oool40?l00080oooo0P00o`020?ooo`80003o=03oool70?l007D0oooo000=0?ooo`<0o`00
8`3oool80?l003T0oooo00<000000?ooo`3oool0203oool20000o`800?l02`3o00020?ooo`800?l0
0P3oool30000ocD0oooo1@3o001f0?ooo`00<`3oool00`00o`00o`000?l000050?l003T0oooo00<0
00000?ooo`3oool0203oool30000o`03003o003oool0o`0000P0o`000`3oool2003o0080oooo0P00
0?na0?ooo`00M03oool00`000000oooo0?ooo`090?ooo`80003o0P00o`000`3oool0o`000?l00005
0?l000<0oooo0`00o`020?ooo`80003o/@3oool007@0oooo00<000000?ooo`3oool02@3oool20000
o`800?l02`3oool2003o0080oooo0`000?na0?ooo`00M03oool00`000000oooo0?ooo`090?ooo`80
003o0`00o`0:0?ooo`800?l00P3oool20000ok80oooo001d0?ooo`030000003oool0oooo00X0oooo
0P000?l2003o00T0oooo0`00o`00103oool0003o0000o`000?nb0?ooo`00M03oool00`000000oooo
0?ooo`0:0?ooo`80003o00<0oooo003o0000o`001`3oool3003o0080oooo0P000?nc0?ooo`00M03o
ool00`000000oooo0?ooo`0:0?ooo`<0003o00<0oooo003o0000o`001@3oool3003o00<0oooo0P00
0?nc0?ooo`00M03oool00`000000oooo0?ooo`0;0?ooo`80003o00<0oooo003o0000o`000P00o`02
0?ooo`<00?l00`3oool30000ok<0oooo00190?ooo`800000103oool2000000@0oooo0P0000040?oo
o`800000103oool2000000D0oooo00<000000?ooo`3oool00P3oool2000000D0oooo00<000000?oo
o`3oool02`3oool30000o`P00?l0103oool20000ok@0oooo00180?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0303oool20000o`80oooo1@00o`040?ooo`<0003o]03oool004P0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo0P00000=0?ooo`80003o2`3oool20000okD0oooo00180?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000D0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`030000003oool0
oooo00d0oooo00<0003o0?ooo`3oool02@3oool20000okD0oooo00180?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00d0oooo0P000?l90?ooo`<0003o]@3oool004T0oooo0P00000:0?ooo`80
0000103oool2000000@0oooo0P0000030?ooo`@000000`3oool3000000@0oooo00<000000?ooo`3o
ool03P3oool20000o`L0oooo0`000?nf0?ooo`00M03oool00`000000oooo0?ooo`0>0?ooo`<0003o
1@3oool30000okL0oooo001d0?ooo`030000003oool0oooo00l0oooo0`000?l30?ooo`<0003o^03o
ool007@0oooo00<000000?ooo`3oool0403oool70000okT0oooo001d0?ooo`030000003oool0oooo
0100oooo1P000?nj0?ooo`00M03oool00`000000oooo0?ooo`3@0?ooo`00M03oool00`000000oooo
0?ooo`3@0?ooo`00M03oool00`000000oooo0?ooo`3@0?ooo`00o`3ooom80?ooo`00o`3ooom80?oo
o`00o`3ooom80?ooo`00\
\>"],
  ImageRangeCache->{{{0, 326}, {154.25, 0}} -> {-1.07771, -0.784209, \
0.00931248, 0.00931248}, {{8.3125, 223.063}, {136.375, 3.625}} -> {-1.14056, \
-0.0011211, 0.00982044, 1.33069*^-05}, {{233.813, 312.25}, {145.188, 59.25}} -> \
{-10.1159, -0.488864, 0.0428371, 0.0428371}, {{238, 261.313}, {140.938, \
117.625}} -> {-10.7447, -3.63932, 0.0450407, 0.145755}, {{238, 261.313}, \
{113.875, 90.5}} -> {-10.7447, -7.58836, 0.0450407, 0.145755}, {{238, \
261.313}, {86.8125, 63.4375}} -> {-10.7447, -11.5328, 0.0450407, 0.145755}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[83]="]
}, Open  ]],

Cell["Example 2", "Subsubsection"],

Cell["Initial value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\((x^2 + 2*x + 1)\)*\(y'\)[x] + \((x - 1)\)*y[x] \[Equal] x, 
        y[0] \[Equal] 0}\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\((\(-1\) + x)\)\ y[x]\), "+", 
            RowBox[{\((1 + 2\ x + x\^2)\), " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], "==", "x"}], 
        ",", \(y[0] == 0\)}], "}"}]], "Output",
  CellLabel->"Out[84]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr0 = ApproxSol[ivp, y[x], {x, \(-1\), 1}, 5]\)], "Input",
  CellLabel->"In[85]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(87\/14333\)\) - \(456\ x\)\/14333 + \(9004\ \
x\^2\)\/14333 - \(5748\ x\^3\)\/14333 - \(3744\ x\^4\)\/14333 + \(3936\ \
x\^5\)\/14333}}\)], "Output",
  CellLabel->"Out[85]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr1 = 
      ApproxSol[ivp, y[x], {x, \(-1\), 1}, 5, 
        Method \[Rule] Modified[1]]\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(1341\/162718\)\) - \(5187\ x\)\/162718 + \(53128\ \
x\^2\)\/81359 - \(34320\ x\^3\)\/81359 - \(24120\ x\^4\)\/81359 + \(25032\ \
x\^5\)\/81359}}\)], "Output",
  CellLabel->"Out[86]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr2 = 
      ApproxSol[ivp, y[x], {x, \(-1\), 1}, 5, 
        Method \[Rule] Modified[2]]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(761\/15560\)\) - \(2973\ x\)\/15560 + \(6797\ \
x\^2\)\/7780 + \(1317\ x\^3\)\/7780 - \(996\ x\^4\)\/1945 - \(322\ \
x\^5\)\/1945}}\)], "Output",
  CellLabel->"Out[87]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " tot find exact solution of the IVP."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[88]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(\[ExponentialE]\^\(-\(2\/\(1 + x\)\)\)\ \((\(-\
\[ExponentialE]\^2\) + \[ExponentialE]\^\(2\/\(1 + x\)\) + \
\[ExponentialE]\^\(2\/\(1 + x\)\)\ x + ExpIntegralEi[2] - \
ExpIntegralEi[2\/\(1 + x\)])\)\)\/\(1 + x\)}}\)], "Output",
  CellLabel->"Out[88]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  ". In this case modified method gives quite bad appoximation."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[{\[IndentingNewLine]\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
              apr0[\([1]\)])\), \[IndentingNewLine]\((y[x] /. 
              sol[\([1]\)])\) - \((y[x] /. 
              apr1[\([1]\)])\), \[IndentingNewLine]\((y[x] /. 
              sol[\([1]\)])\) - \((y[x] /. apr2[\([1]\)])\)}, {x, \(-1\), 1}, 
      PlotRange \[Rule] {\(-0.03\), 
          0.07}, \[IndentingNewLine]PlotStyle \[Rule] {{RGBColor[0, 0, 1], 
            AbsoluteThickness[2]}, {RGBColor[0, 1, 0], 
            AbsoluteThickness[2]}, {RGBColor[1, 0, 0], 
            AbsoluteThickness[
              3]}}, \[IndentingNewLine]PlotLegend \[Rule] {"\<k=0\>", \
"\<k=1\>", "\<k=2\>"}, LegendPosition \[Rule] {1.1, \(- .7\)}]\)], "Input",
  CellLabel->"In[89]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .47494 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.354447 0.330638 0.259287 0.330638 [
[ 0 0 0 0 ]
[ 1 .47494 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0549411 0.685085 0.463632 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.18541 6.18034 [
[.02381 .17291 -6 -9 ]
[.02381 .17291 6 0 ]
[.2619 .17291 -12 -9 ]
[.2619 .17291 12 0 ]
[.7381 .17291 -9 -9 ]
[.7381 .17291 9 0 ]
[.97619 .17291 -3 -9 ]
[.97619 .17291 3 0 ]
[.4875 .0618 -30 -4.5 ]
[.4875 .0618 0 4.5 ]
[.4875 .30902 -24 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .43262 -24 -4.5 ]
[.4875 .43262 0 4.5 ]
[.4875 .55623 -24 -4.5 ]
[.4875 .55623 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .18541 m
.02381 .19166 L
s
[(-1)] .02381 .17291 0 1 Mshowa
.2619 .18541 m
.2619 .19166 L
s
[(-0.5)] .2619 .17291 0 1 Mshowa
.7381 .18541 m
.7381 .19166 L
s
[(0.5)] .7381 .17291 0 1 Mshowa
.97619 .18541 m
.97619 .19166 L
s
[(1)] .97619 .17291 0 1 Mshowa
.125 Mabswid
.07143 .18541 m
.07143 .18916 L
s
.11905 .18541 m
.11905 .18916 L
s
.16667 .18541 m
.16667 .18916 L
s
.21429 .18541 m
.21429 .18916 L
s
.30952 .18541 m
.30952 .18916 L
s
.35714 .18541 m
.35714 .18916 L
s
.40476 .18541 m
.40476 .18916 L
s
.45238 .18541 m
.45238 .18916 L
s
.54762 .18541 m
.54762 .18916 L
s
.59524 .18541 m
.59524 .18916 L
s
.64286 .18541 m
.64286 .18916 L
s
.69048 .18541 m
.69048 .18916 L
s
.78571 .18541 m
.78571 .18916 L
s
.83333 .18541 m
.83333 .18916 L
s
.88095 .18541 m
.88095 .18916 L
s
.92857 .18541 m
.92857 .18916 L
s
.25 Mabswid
0 .18541 m
1 .18541 L
s
.5 .0618 m
.50625 .0618 L
s
[(-0.02)] .4875 .0618 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.02)] .4875 .30902 1 0 Mshowa
.5 .43262 m
.50625 .43262 L
s
[(0.04)] .4875 .43262 1 0 Mshowa
.5 .55623 m
.50625 .55623 L
s
[(0.06)] .4875 .55623 1 0 Mshowa
.125 Mabswid
.5 .09271 m
.50375 .09271 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .61803 m
.50375 .61803 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
.02381 .06705 m
.02846 .05769 L
.03279 .05122 L
.03527 .04844 L
.03754 .04649 L
.03879 .04564 L
.04015 .0449 L
.04143 .04438 L
.04262 .04404 L
.04376 .04384 L
.04498 .04376 L
.04614 .04382 L
.0472 .04399 L
.04843 .04431 L
.04913 .04455 L
.04978 .04482 L
.05224 .04616 L
.05483 .04814 L
.05718 .0504 L
.06244 .05705 L
.06787 .06601 L
.07287 .07596 L
.08414 .10354 L
.10458 .16503 L
.125 .22662 L
.13497 .25155 L
.14407 .26965 L
.14857 .27678 L
.15348 .28309 L
.15811 .28766 L
.16239 .29069 L
.16473 .29187 L
.16692 .29268 L
.16818 .29302 L
.16933 .29325 L
.17059 .29342 L
.17122 .29347 L
.17192 .2935 L
.1726 .2935 L
.17325 .29348 L
.17445 .29338 L
.17575 .29318 L
.17649 .29303 L
.17716 .29287 L
.17953 .29212 L
.18204 .29103 L
.18697 .28804 L
.19148 .28442 L
.20161 .27365 L
.21993 .24781 L
Mistroke
.24056 .21487 L
.25969 .18598 L
.27939 .16151 L
.28905 .15208 L
.29793 .14505 L
.30782 .13909 L
.31301 .13673 L
.31849 .13481 L
.32071 .1342 L
.32309 .13364 L
.32515 .13324 L
.32738 .1329 L
.32874 .13273 L
.33 .13261 L
.3312 .13251 L
.33247 .13244 L
.33361 .1324 L
.33468 .13238 L
.33585 .13238 L
.33711 .13241 L
.33838 .13246 L
.33952 .13253 L
.34084 .13264 L
.34209 .13277 L
.34431 .13305 L
.34671 .13344 L
.35217 .13464 L
.35719 .13609 L
.36746 .14003 L
.37831 .14541 L
.41625 .17035 L
.45664 .19914 L
.47525 .21067 L
.49551 .221 L
.50653 .22547 L
.51673 .22883 L
.52648 .23133 L
.53188 .23242 L
.53684 .23322 L
.5414 .2338 L
.5462 .23425 L
.54869 .23442 L
.55102 .23454 L
.55235 .23459 L
.55356 .23462 L
.55424 .23464 L
.55497 .23465 L
.55565 .23466 L
.55629 .23467 L
.55734 .23467 L
Mistroke
.55847 .23466 L
.55954 .23465 L
.56051 .23463 L
.56165 .2346 L
.5629 .23456 L
.56516 .23446 L
.56752 .23432 L
.57004 .23413 L
.57456 .23369 L
.57992 .23301 L
.58486 .23223 L
.59599 .23002 L
.61616 .22458 L
.65567 .21066 L
.69366 .19694 L
.71482 .19072 L
.72484 .18837 L
.73411 .18661 L
.74369 .18523 L
.74874 .18469 L
.75132 .18448 L
.7541 .18428 L
.75653 .18415 L
.75875 .18405 L
.75985 .18402 L
.76087 .18399 L
.76194 .18397 L
.7631 .18395 L
.7644 .18394 L
.76562 .18394 L
.76672 .18395 L
.76791 .18396 L
.7692 .18399 L
.77058 .18403 L
.77304 .18412 L
.77557 .18426 L
.77797 .18442 L
.78248 .18481 L
.78734 .18536 L
.79262 .18611 L
.80213 .18785 L
.81094 .18986 L
.85014 .20252 L
.87017 .20998 L
.8807 .21366 L
.8918 .21708 L
.90178 .2195 L
.90452 .22002 L
.90745 .22051 L
.90997 .22086 L
Mistroke
.91272 .22116 L
.91403 .22127 L
.91541 .22137 L
.91659 .22144 L
.91789 .22149 L
.91911 .22152 L
.92042 .22153 L
.92165 .22152 L
.92278 .22149 L
.92394 .22144 L
.92503 .22138 L
.92621 .22129 L
.92747 .22117 L
.92981 .22089 L
.93194 .22055 L
.93681 .21948 L
.93926 .21877 L
.94196 .21786 L
.95117 .21357 L
.95637 .21028 L
.96194 .20597 L
.97199 .19594 L
.97619 .19081 L
Mfstroke
0 1 0 r
.02381 .22039 m
.02846 .19958 L
.03279 .18292 L
.03793 .16635 L
.04262 .15419 L
.04754 .14423 L
.0522 .13734 L
.05475 .13454 L
.05711 .13255 L
.05845 .13168 L
.0597 .13101 L
.06101 .13048 L
.0617 .13026 L
.06244 .13008 L
.06315 .12995 L
.0638 .12987 L
.06454 .12983 L
.06524 .12983 L
.06649 .12995 L
.06719 .13007 L
.06784 .13023 L
.0692 .13066 L
.0707 .13131 L
.07373 .13317 L
.0764 .1354 L
.07927 .13834 L
.08445 .14502 L
.09498 .16306 L
.10458 .18305 L
.12528 .22809 L
.13438 .24499 L
.13921 .25259 L
.14443 .25954 L
.14943 .26491 L
.15401 .26866 L
.15628 .2701 L
.15839 .27119 L
.1606 .27207 L
.16176 .27244 L
.16301 .27274 L
.16366 .27287 L
.16434 .27298 L
.16556 .27312 L
.16688 .27319 L
.16763 .27318 L
.16833 .27316 L
.1696 .27304 L
.17075 .27287 L
.17209 .2726 L
.17336 .27226 L
Mistroke
.17569 .27143 L
.17785 .27045 L
.18275 .2675 L
.18785 .26343 L
.19335 .25804 L
.20332 .24612 L
.22194 .2192 L
.24152 .18935 L
.26299 .16044 L
.27287 .14959 L
.28345 .14006 L
.29344 .13317 L
.30253 .12871 L
.30735 .12703 L
.31 .12631 L
.31247 .12576 L
.31457 .12539 L
.31684 .12509 L
.31806 .12497 L
.31935 .12487 L
.32045 .12481 L
.32165 .12477 L
.32233 .12476 L
.32306 .12476 L
.32375 .12477 L
.32439 .12478 L
.32559 .12483 L
.32686 .12491 L
.32823 .12502 L
.32951 .12516 L
.33242 .12558 L
.33495 .12606 L
.33725 .12659 L
.34243 .12807 L
.35233 .132 L
.36149 .13675 L
.38224 .15062 L
.42148 .18296 L
.45919 .21301 L
.48014 .22653 L
.48932 .23146 L
.49937 .23608 L
.50846 .23954 L
.51819 .24247 L
.52357 .24374 L
.52846 .24468 L
.53337 .24542 L
.53577 .24571 L
.53802 .24593 L
.54043 .24613 L
Mistroke
.54264 .24626 L
.5439 .24632 L
.54509 .24637 L
.54635 .2464 L
.54706 .24642 L
.54773 .24643 L
.54837 .24643 L
.54907 .24644 L
.55034 .24643 L
.55157 .24641 L
.5527 .24639 L
.55394 .24635 L
.55529 .24629 L
.55801 .24613 L
.56042 .24595 L
.56262 .24574 L
.56755 .24515 L
.57645 .24365 L
.58638 .24138 L
.59555 .23877 L
.61632 .23137 L
.65561 .21407 L
.69338 .1976 L
.71274 .19076 L
.7227 .18791 L
.7336 .1854 L
.73863 .18447 L
.74399 .18365 L
.74906 .18305 L
.75366 .18264 L
.75637 .18247 L
.75887 .18235 L
.76017 .1823 L
.76161 .18227 L
.76233 .18225 L
.76311 .18224 L
.76384 .18224 L
.76451 .18224 L
.76582 .18224 L
.76703 .18226 L
.76773 .18227 L
.76836 .18228 L
.76977 .18233 L
.77101 .18237 L
.77234 .18244 L
.77476 .18258 L
.7797 .183 L
.7843 .18354 L
.79475 .18528 L
.80494 .18763 L
Mistroke
.81584 .19082 L
.85727 .20734 L
.87802 .21628 L
.88714 .2198 L
.89719 .2231 L
.90182 .22436 L
.90681 .22548 L
.90922 .22592 L
.91151 .22628 L
.91377 .22657 L
.91582 .22677 L
.91704 .22687 L
.91819 .22694 L
.91941 .22699 L
.92072 .22702 L
.92187 .22702 L
.92309 .22701 L
.92413 .22697 L
.92527 .22692 L
.92596 .22687 L
.92662 .22682 L
.92785 .22671 L
.93061 .22635 L
.93299 .22592 L
.93559 .22533 L
.94041 .22386 L
.94494 .222 L
.94991 .21938 L
.95527 .21582 L
.96618 .20595 L
.97619 .19337 L
Mfstroke
1 0 0 r
3 Mabswid
.02381 .18541 m
.02605 .18435 L
.02846 .18346 L
.02962 .18312 L
.03072 .18284 L
.0317 .18264 L
.03279 .18247 L
.03398 .18233 L
.03524 .18224 L
.03641 .18222 L
.0375 .18225 L
.03879 .18234 L
.03997 .18248 L
.04132 .18271 L
.04262 .18299 L
.045 .18366 L
.04753 .18461 L
.0521 .18688 L
.05752 .19046 L
.06244 .1945 L
.08414 .21941 L
.10458 .24781 L
.11434 .25977 L
.11968 .26511 L
.12466 .26906 L
.12891 .27153 L
.13129 .27251 L
.13234 .27285 L
.13346 .27314 L
.1347 .27339 L
.13584 .27354 L
.13707 .27362 L
.13777 .27362 L
.13843 .2736 L
.13961 .2735 L
.14069 .27334 L
.14188 .27309 L
.14313 .27273 L
.1457 .2717 L
.14813 .27037 L
.15268 .26695 L
.15757 .26193 L
.16287 .25498 L
.17243 .23887 L
.18124 .2205 L
.22064 .11824 L
.24044 .06941 L
.25853 .0341 L
.26851 .01968 L
.27798 .00971 L
Mistroke
.28316 .00584 L
.28564 .0044 L
.28797 .00329 L
.2893 .00276 L
.29074 .00227 L
.29194 .00193 L
.29325 .00163 L
.29468 .00139 L
.29545 .00129 L
.29618 .00123 L
.29748 .00117 L
.29821 .00116 L
.29887 .00118 L
.30005 .00126 L
.30116 .00139 L
.30238 .00159 L
.30369 .00187 L
.30636 .00268 L
.30881 .00367 L
.31329 .00614 L
.31799 .00962 L
.32792 .01982 L
.33877 .03517 L
.35842 .07295 L
.37938 .12494 L
.42093 .25023 L
.46096 .37784 L
.49948 .48639 L
.51901 .53088 L
.52935 .55079 L
.54045 .56904 L
.55112 .58335 L
.56085 .59353 L
.56553 .59741 L
.57063 .60088 L
.57545 .60343 L
.57991 .60514 L
.58232 .60581 L
.58453 .60626 L
.58569 .60643 L
.58696 .60657 L
.5876 .60663 L
.58829 .60667 L
.58952 .60671 L
.59069 .6067 L
.59195 .60664 L
.59315 .60654 L
.59425 .60641 L
.59634 .60606 L
.59855 .60553 L
Mistroke
.60099 .60477 L
.60361 .60374 L
.60835 .60133 L
.61399 .59756 L
.61914 .59323 L
.629 .58269 L
.63814 .57029 L
.65887 .53328 L
.69802 .43398 L
.73962 .29972 L
.77971 .16449 L
.7981 .1084 L
.81828 .05658 L
.82791 .03681 L
.83823 .02009 L
.84394 .01309 L
.84913 .00825 L
.85164 .00647 L
.85296 .00568 L
.85436 .00496 L
.85558 .00444 L
.85693 .00396 L
.85815 .00363 L
.8593 .00341 L
.86048 .00328 L
.86174 .00323 L
.86293 .00329 L
.864 .00343 L
.86527 .00369 L
.86599 .00389 L
.86665 .00411 L
.86914 .00521 L
.87154 .00669 L
.87418 .00883 L
.8795 .01481 L
.88411 .02187 L
.88907 .03149 L
.89801 .05457 L
.90815 .09029 L
.9192 .14188 L
.93931 .27388 L
.95718 .43818 L
Mfstroke
.95718 .43818 m
.972 .61803 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.73468 .01131 m
.73468 .27582 L
.97619 .27582 L
.97619 .01131 L
F
1 g
.71815 .02784 m
.71815 .29235 L
.95966 .29235 L
.95966 .02784 L
F
0 g
.001 w
[ ] 0 setdash
.71815 .02784 m
.95966 .02784 L
.95966 .29235 L
.71815 .29235 L
.71815 .02784 L
s
% Start of sub-graphic
p
0.718149 0.02784 0.959659 0.29235 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0297619 0.297619 [
[ 0 0 0 0 ]
[ 1 1.09524 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.09524 L
0 1.09524 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0535714 0.35119 0.35119 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
3 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .20238 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.39881 0.35119 0.696429 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .54762 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.744048 0.35119 1.04167 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
2 Mabswid
[ ] 0 setdash
.02381 .30902 m
.97619 .30902 L
s
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .89286 -61 -10.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .47494 L
0 .47494 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[89]:=",
  ImageSize->{288, 136.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000R2000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00dP3ooom5000000T0oooo003B
0?ooodD000002@3oool00=80ooooA@0000090?ooo`00dP3ooom5000000T0oooo003=0?ooodX00000
2@3oool00<d0oooo00<000000?ooo`3oool0@P3oool5000000T0oooo003=0?ooo`030000003oool0
oooo0480oooo1@0000090?ooo`00c@3oool00`000000oooo0?ooo`120?ooo`D000002@3oool00<d0
oooo00<000000?ooo`3oool0@P3oool5000000T0oooo003=0?ooo`030000003oool0oooo0480oooo
1@0000090?ooo`00c@3oool00`000000oooo0?ooo`120?ooo`D000002@3oool003h0oooo1P3o0029
0?ooo`030000003oool0oooo0480oooo1@0000090?ooo`00?03oool80?l00280oooo00<000000?oo
o`3oool0?P3oool70?l001l0oooo00<000000?ooo`3oool0@P3oool5000000T0oooo000l0?ooo`T0
o`008@3oool00`000000oooo0?ooo`0m0?ooo`P0o`007`3oool00`000000oooo0?ooo`120?ooo`D0
00002@3oool003/0oooo103o00020?ooo`D0o`00803oool00`000000oooo0?ooo`0m0?ooo`P0o`00
7`3oool00`000000oooo0?ooo`120?ooo`D000002@3oool003X0oooo1@3o00040?ooo`@0o`007`3o
ool00`000000oooo0?ooo`0l0?ooo`D0o`0000<0oooo0?l0003o00000P3o000N0?ooo`030000003o
ool0oooo0480oooo1@0000090?ooo`00>@3oool40?l000L0oooo103o000N0?ooo`030000003oool0
oooo03`0oooo0`3o00040?ooo`@0o`007@3oool00`000000oooo0?ooo`0J0?ooo`80000000<0oooo
0000000000000P3oool400000080oooo1000000G0?ooo`D000002@3oool003P0oooo103o00090?oo
o`@0o`007@3oool00`000000oooo0?ooo`0k0?ooo`@0o`001@3oool40?l001`0oooo00<000000?oo
o`3oool05`3o00040?ooo`030000003oool0000000T0oooo00<000000?ooo`3oool0603oool50000
00T0oooo000h0?ooo`<0o`002`3oool40?l001`0oooo0P00000k0?ooo`@0o`001`3oool30?l001`0
oooo00<000000?ooo`3oool05`3o00040?ooo`<000000`3oool4000000<0oooo00<000000?ooo`3o
ool05`3oool5000000T0oooo000g0?ooo`@0o`00303oool30?l001`0oooo00<000000?ooo`3oool0
>P3oool30?l000P0oooo103o000K0?ooo`030000003oool0oooo01L0o`00103oool010000000oooo
00000000000:0?ooo`030000003oool0oooo01H0oooo1@0000090?ooo`003`3oool40000ob@0oooo
0`3o000=0?ooo`@0o`006`3oool00`000000oooo0?ooo`0i0?ooo`@0o`002@3oool30?l001/0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000001L0
oooo1@0000090?ooo`003P3oool60000ob80oooo103o000>0?ooo`<0o`006`3oool00`000000oooo
0?ooo`0i0?ooo`<0o`002P3oool40?l001X0oooo00<000000?ooo`3oool06P3oool2000000`0oooo
0P00000H0?ooo`D000002@3oool000h0oooo1`000?lP0?ooo`@0o`003`3oool40?l00080oooo0P00
00040?ooo`800000103oool2000000<0oooo100000030?ooo`030000003oool0oooo03P0oooo103o
000;0?ooo`<0o`006P3oool00`000000oooo0?ooo`120?ooo`D000002@3oool000h0oooo0P000?l4
0?ooo`80003o7`3oool30?l00140oooo103o000010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0h0?ooo`<0o`00
303oool30?l001X0oooo00<000000?ooo`3oool0@P3oool5000000T0oooo000=0?ooo`80003o1@3o
ool20000oah0oooo103o000B0?ooo`<0o`0000@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00<0oooo0P00000h0?ooo`@0o`00303oool40?l001T0
oooo00<000000?ooo`3oool0@P3oool5000000T0oooo000=0?ooo`030000o`3oool0oooo00D0oooo
0P000?lM0?ooo`<0o`00403oool3000000@0o`000P3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0g0?ooo`<0
o`003P3oool30?l001T0oooo00<000000?ooo`3oool0@P3oool5000000T0oooo000=0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool06P3oool40?l001@0oooo0`3o00020?ooo`030000
003oool0oooo00H0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo03H0oooo103o000>0?ooo`<0o`006@3oool00`000000oooo0?ooo`120?oo
o`D000002@3oool001H0oooo0P000?lK0?ooo`<0o`005@3oool40?l000030000003oool0oooo00P0
oooo0P0000040?ooo`800000103oool00`000000oooo0?ooo`0f0?ooo`<0o`003`3oool40?l001P0
oooo00<000000?ooo`3oool0@P3oool5000000T0oooo000F0?ooo`80003o6`3oool30?l001H0oooo
0`3o000G0?ooo`030000003oool0oooo03H0oooo0`3o000@0?ooo`<0o`00603oool00`000000oooo
0?ooo`120?ooo`D000002@3oool001H0oooo0`000?lI0?ooo`@0o`005P3oool40?l001H0oooo0P00
000f0?ooo`@0o`00403oool30?l001P0oooo00<000000?ooo`3oool0@P3oool5000000T0oooo000G
0?ooo`80003o6@3oool30?l001P0oooo0`3o000F0?ooo`030000003oool0oooo03D0oooo0`3o000A
0?ooo`<0o`00603oool00`000000oooo0?ooo`120?ooo`D000002@3oool001L0oooo0`000?lH0?oo
o`<0o`00603oool30?l001H0oooo00<000000?ooo`3oool0=03oool40?l00140oooo0`3o000H0?oo
o`030000003oool0oooo0480oooo1@0000090?ooo`00603oool20000oaL0oooo103o000H0?ooo`@0
o`005@3oool00`000000oooo0?ooo`0d0?ooo`<0o`004`3oool30?l001L0oooo00<000000?ooo`3o
ool0@P3oool5000000T0oooo000H0?ooo`80003o5`3oool30?l001X0oooo0`3o000E0?ooo`030000
003oool0oooo03@0oooo0`3o000C0?ooo`<0o`005`3oool00`000000oooo0?ooo`120?ooo`D00000
2@3oool001P0oooo0`000?lF0?ooo`<0o`006P3oool40?l001@0oooo00<000000?ooo`3oool0<`3o
ool40?l001<0oooo0`3o000G0?ooo`030000003oool0oooo0480oooo1@0000090?ooo`006@3oool2
0000oaD0oooo103o000>0?ooo`H00?l01`3oool30?l001@0oooo0P00000d0?ooo`<0o`00503oool3
0?l001L0oooo00<000000?ooo`3oool0@P3oool5000000T0oooo000>0?ooo`D000001000o`020?oo
o`80003o5@3oool30?l000<0oooo0P0000040?ooo`80000000<0oooo003o0000o`002P00o`040?oo
o`<0o`00503oool00`000000oooo0?ooo`0S0?ooo`800000103oool2000000@0oooo0P0000020?oo
o`<0o`00503oool30?l000L0oooo1@00000;0?ooo`030000003oool0oooo0480oooo1@0000090?oo
o`00403oool00`000000oooo003o0005003o00040?ooo`000?l0003o0000oa@0oooo0`3o00020?oo
o`040000003oool0oooo000000D0oooo1P00o`030000o`H00?l000<0003o0?ooo`3o00000`3o000C
0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000040?l001D0oooo0`3o00080?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
@P3oool5000000T0oooo000@0?ooo`0300000000o`000?l000800?l000D0oooo003o0000o`000?l0
0?ooo`020000oa<0oooo103o00020?ooo`040000003oool0oooo000000@0oooo0`00o`0:0000o`D0
0?l000@0003o0?l0003o0000o`004`3oool00`000000oooo0?ooo`0R0?ooo`040000003oool0oooo
000000/0oooo00@000000?l0003o0000o`005P3oool30?l000P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`120?ooo`D000002@3oool000P0oooo100000040?ooo`0300000000o`00
0?l000@0oooo0P00o`000`3oool0003o0000o`0C0?ooo`<0o`0000@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`3oool3003o00D0003o203oool4003o00<0o`004`3oool00`000000oooo
0?ooo`0R0?ooo`040000003oool0oooo000000T0oooo0P000000103oool0o`000?l0003o000F0?oo
o`<0o`00203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo1@0000090?oo
o`00403oool2003o00H0oooo0P00o`030000oa40oooo103o00030?ooo`040000003oool0oooo0000
0080oooo0`00o`030000o`030?ooo`000000oooo00X0oooo0P00o`040?l00180oooo00<000000?oo
o`3oool08P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00<0o`005P3oool3
0?l000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`80000000<0oooo
0000000000000P3oool400000080oooo1@00000F0?ooo`D000002@3oool000l0oooo00<00000003o
003oool01`3oool01000o`00oooo0000o`000?lA0?ooo`<0o`001@3oool200000080oooo0`00o`03
0000o`80oooo0`00000;0?ooo`04003o003o0000o`000?l00180oooo0P00000T0?ooo`8000002P3o
ool2000000@0o`005P3oool30?l000L0oooo0P00000=0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0F0?ooo`D000002@3oool000l0oooo0P00o`08
0?ooo`800?l00P000?l@0?ooo`@0o`00203oool3003o00<0003o4P3oool30?l00080003o403oool0
0`000000oooo0?ooo`0a0?ooo`<0o`005`3oool30?l001H0oooo00<000000?ooo`3oool05P00o`05
0?ooo`<000000`3oool4000000@0oooo00<000000?ooo`3oool05P3oool5000000T0oooo000?0?oo
o`800?l02@3oool01000o`00003o0000o`000?l?0?ooo`<0o`00203oool3003o00<0003o4`3oool3
0?l000800?l000<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`0a0?ooo`<0o`005`3oool3
0?l001H0oooo00<000000?ooo`3oool05P00o`050?ooo`040000003oool00000000000X0oooo00<0
00000?ooo`3oool05P3oool5000000T0oooo000?0?ooo`800?l02@3oool2003o0080003o3`3oool3
0?l000P0oooo0P00o`000`3oool0003o0000o`0D0?ooo`@0o`000P00o`020000o`d0oooo00<00000
0?ooo`3oool0<@3oool30?l001P0oooo0`3o000E0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?ooo`D000002@3oool000d0oooo1P3o00080?oo
o`800?l000<0003o0?ooo`3oool0303oool40?l000L0oooo0P00o`000`3oool0003o0000o`0F0?oo
o`<0o`000`00o`020000o``0oooo00<000000?ooo`3oool0<03oool40?l001P0oooo0`3o000E0?oo
o`030000003oool0oooo01X0oooo0P00000<0?ooo`800000603oool5000000T0oooo000<0?ooo`L0
o`002@3oool00`00o`00003o0000o`0=0?ooo`<0o`001`3oool3003o00<0003o5P3oool30?l00004
0?ooo`00o`000?l0003o00<0003o2P3oool00`000000oooo0?ooo`0Z0?ooo`H00?l00`3o0002003o
00030?ooo`00o`00oooo01@0oooo0`3o000E0?ooo`030000003oool0oooo0480oooo1@0000090?oo
o`00203oool3000000X0o`001`000002003o00030000o`000000000000X00000103o000700000080
0?l000<000000000o`000?l05`0000040?l0000400000000o`000?l0003o00<0003o<@00000;003o
00<0o`001P00o`0C000000<0o`001`0000000`00o`00000000000003000000P0oooo00<000000?oo
o`3oool0@P3oool5000000T0oooo000<0?ooo`80o`000P00o`060?l000L0oooo00<00?l00000o`3o
ool02`3oool30?l000L0oooo0P00o`00103oool0003o0000o`00000H0?ooo`<0o`000P3oool3003o
00@0003o1`3oool00`000000oooo0?ooo`0Q0?ooo`X00?l00`000?l00`3oool0o`000?l000020?l0
00030000o`00o`000?l000H00?l0403oool30?l000H0oooo0`00o`0<0?ooo`030000003oool0oooo
0480oooo1@0000090?ooo`003@3oool3003o0080oooo1@3o00060?ooo`800?l000<0003o0?ooo`3o
ool0203oool40?l000H0oooo0P00o`000`3oool0003o0000o`0J0?ooo`<0o`000`3oool4003o00@0
003o1@3oool00`000000oooo0?ooo`0N0?ooo`030000o`00o`000?l000@00?l02P3oool30?l000D0
oooo00<0003o003o0000o`001000o`000`000?l0oooo0?ooo`0;0?ooo`<0o`001P3oool2003o00d0
oooo00<000000?ooo`3oool0@P3oool5000000T0oooo000=0?ooo`800?l01@3oool40?l000H0oooo
00<00?l00000o`3oool02@3oool30?l000L0oooo00@00?l00?ooo`3oool0003o6`3oool40?l000<0
oooo1000o`050000o`<0oooo00<000000?ooo`3oool06P3oool20000o`H00?l03@3oool30?l000T0
oooo1P00o`020000o`T0oooo0`3o00050?ooo`030000o`00o`000?l000d0oooo00<000000?ooo`3o
ool0@P3oool5000000T0oooo000=0?ooo`800?l01P3oool40?l000D0oooo00<00?l00000o`000?l0
2@3oool30?l000H0oooo0P00o`000`3oool0003o0000o`0L0?ooo`<0o`001@3oool3003o00030?oo
o`000?l0003o0080003o0P3oool00`000000oooo0?ooo`0H0?ooo`80003o1P00o`0>0?ooo`@0o`00
2`3oool6003o00<0003o1P3oool30?l000<0oooo1@00o`0=0?ooo`030000003oool0oooo0480oooo
1@0000090?ooo`003@3oool2003o00L0oooo0`3o00050?ooo`800?l000<0003o0?ooo`3oool01P3o
ool40?l000D0oooo0P00o`020?ooo`030000o`3oool0oooo01/0oooo0`3o00060?ooo`@00?l000<0
oooo0000o`000?l00P000?l00`000000oooo0?ooo`0E0?ooo`<0003o1@00o`0A0?ooo`<0o`003`3o
ool5003o00<0003o1@3oool30?l000030000o`00o`000?l000<00?l03P3oool00`000000oooo0?oo
o`120?ooo`D000002@3oool000`0oooo0`00o`080?ooo`<0o`001@3oool00`00o`00003o0?ooo`07
0?ooo`<0o`001P3oool00`00o`00oooo0?ooo`020000oad0oooo0`3o00070?ooo`D00?l01@000?lD
0?ooo`80003o1P00o`0C0?ooo`<0o`004@3oool7003o00@0003o0`3o0003003o0140oooo00<00000
0?ooo`3oool0@P3oool5000000T0oooo000=0?ooo`03003o003oool0oooo00L0oooo103o00040?oo
o`800?l000<0003o0?ooo`3oool01@3oool30?l000D0oooo0P00o`000`3oool0003o0000o`0N0?oo
o`@0o`00203oool5003o00D0003o3P3oool40000o`H00?l0503oool40?l001<0oooo2@00o`030?l0
00800?l04P3oool00`000000oooo0?ooo`120?ooo`D000002@3oool001P0oooo103o00040?ooo`03
003o00000?l0oooo00D0oooo103o00040?ooo`800?l00P3oool00`000?l0oooo0?ooo`0N0?ooo`<0
o`002P3oool5003o00H0003o2@3oool40000o`D00?l05`3oool30?l001P0oooo1@00o`030?l00080
0?l04P3oool00`000000oooo0?ooo`120?ooo`D000002@3oool001T0oooo103o00030?ooo`800?l0
1P3oool30?l000D0oooo00<00?l00?ooo`3oool00P000?lP0?ooo`<0o`00303oool5003o00l0003o
1@00o`0I0?ooo`<0o`006P3oool3003o00<0o`00503oool00`000000oooo0?ooo`120?ooo`D00000
2@3oool001X0oooo0`3o00030?ooo`030000o`00o`000?l000D0oooo0`3o00040?ooo`800?l000<0
oooo0000o`000?l08@3oool40?l000d0oooo1P00o`080000o`L00?l06P3oool40?l001d0oooo0`3o
000D0?ooo`030000003oool0oooo0480oooo1@0000090?ooo`006`3oool30?l000<0oooo00<0003o
003o0000o`000`3oool40?l000<0oooo0P00o`000`3oool0003o0000o`0S0?ooo`<0o`003@3oool2
000001400?l0703oool30?l001h0oooo0`3o000D0?ooo`030000003oool0oooo0480oooo1@000009
0?ooo`006`3oool40?l00080oooo00<0003o003o0000o`000P3oool40?l000<0oooo0`00o`030000
ob<0oooo0`3o000=0?ooo`030000003oool0oooo0080oooo2P00o`0P0?ooo`<0o`007P3oool30?l0
01@0oooo00<000000?ooo`3oool0@P3oool5000000T0oooo000L0?ooo`@0o`000P3oool2003o0003
0?ooo`3o0000o`000080o`000`3oool3003o00030?ooo`000?l0003o02@0oooo0`3o000=0?ooo`03
0000003oool0oooo02/0oooo103o000O0?ooo`<0o`004`3oool00`000000oooo0?ooo`120?ooo`D0
00002@3oool001d0oooo103o00000`3oool00?l0003o00040?l000<0oooo0`00o`000`3oool0003o
0000o`0U0?ooo`@0o`00303oool00`000000oooo0?ooo`0[0?ooo`<0o`00803oool30?l001<0oooo
00<000000?ooo`3oool0@P3oool5000000T0oooo000M0?ooo`X0o`000`3oool3003o00040?ooo`00
0?l0003o0000obH0oooo0`3o000<0?ooo`030000003oool0oooo02/0oooo0`3o000P0?ooo`<0o`00
4`3oool00`000000oooo0?ooo`120?ooo`D000002@3oool001h0oooo203o0006003o00040?ooo`00
0?l0003o0000obL0oooo0`3o000<0?ooo`030000003oool0oooo02X0oooo103o000P0?ooo`<0o`00
4`3oool00`000000oooo0?ooo`120?ooo`D000002@3oool00200oooo1@3o00000`000?l00?l0003o
0003003o00040?ooo`000?l0003o0000obP0oooo103o000;0?ooo`800000:`3oool30?l00240oooo
0`3o000C0?ooo`030000003oool0oooo01X0oooo0P0000000`3oool00000000000020?ooo`@00000
0`3oool2000001P0oooo1@0000090?ooo`00903oool30000o`@0oooo0`000?lZ0?ooo`<0o`002`3o
ool00`000000oooo0?ooo`0Z0?ooo`<0o`008@3oool30?l001<0oooo00<000000?ooo`3oool05P00
0?l50?ooo`030000003oool0000000T0oooo00@000000?ooo`3oool000005`3oool5000000T0oooo
000U0?ooo`<0003o0P3oool30000ob/0oooo0`3o000;0?ooo`030000003oool0oooo02T0oooo103o
000Q0?ooo`<0o`004`3oool00`000000oooo0?ooo`0F0000o`D0oooo0`0000030?ooo`@000000P3o
ool010000000oooo0?ooo`00000G0?ooo`D000002@3oool002H0oooo1P000?l/0?ooo`@0o`002P3o
ool00`000000oooo0?ooo`0Y0?ooo`<0o`008`3oool30?l00180oooo00<000000?ooo`3oool06`3o
ool010000000oooo0000000000080?ooo`040000003oool0oooo000001L0oooo1@0000090?ooo`00
9P3oool60000ob80oooo0P0000040?ooo`8000000`3oool30?l000<0oooo100000030?ooo`030000
003oool0oooo02T0oooo0`3o000S0?ooo`<0o`004P3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00T0oooo00@000000?ooo`3oool000005`3oool5000000T0oooo001=0?ooo`040000
003oool0oooo000000P0oooo0`3o000010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
02T0oooo0`3o000S0?ooo`<0o`004P3oool00`000000oooo0?ooo`0J0?ooo`800000303oool20000
01P0oooo1@0000090?ooo`00C@3oool010000000oooo0?ooo`0000080?ooo`@0o`000`3oool00`00
0000oooo0?ooo`030?ooo`800000:@3oool40?l002<0oooo0`3o000B0?ooo`030000003oool0oooo
0480oooo1@0000090?ooo`00C@3oool010000000oooo0?ooo`0000080?ooo`040000003o0000o`00
0?l000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0X0?ooo`<0o`00903oool3
0?l00180oooo00<000000?ooo`3oool0@P3oool5000000T0oooo001=0?ooo`040000003oool0oooo
000000P0oooo00@000000?l0003o0000o`000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0oooo02P0oooo0`3o000T0?ooo`<0o`004P3oool00`000000oooo0?ooo`120?ooo`D00000
2@3oool004h0oooo0P00000:0?ooo`@0o`000P3oool2000000@0oooo00<000000?ooo`3oool09`3o
ool40?l002@0oooo0`3o000B0?ooo`030000003oool0oooo0480oooo1@0000090?ooo`00F`3oool3
0?l000P0oooo00<000000?ooo`3oool09`3oool30?l002D0oooo0`3o000B0?ooo`030000003oool0
oooo0480oooo1@0000090?ooo`00F`3oool30?l000P0oooo00<000000?ooo`3oool09`3oool30?l0
02H0oooo0`3o000A0?ooo`030000003oool0oooo0480oooo1@0000090?ooo`00F`3oool40?l000L0
oooo0P00000W0?ooo`@0o`009P3oool30?l00140oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0;0?ooo`00G03oool30?l000L0oooo00<000000?ooo`3oool09P3oool30?l002L0oooo
0`3o000A0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool02`3oool005`0oooo0`3o
00070?ooo`030000003oool0oooo02H0oooo0`3o000W0?ooo`<0o`004@3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00/0oooo001L0?ooo`@0o`001P3oool00`000000oooo0?ooo`0U
0?ooo`@0o`009`3oool30?l00140ooooAP00000=0?ooo`00G@3oool30?l000H0oooo00<000000?oo
o`3oool09@3oool30?l002P0oooo0`3o001T0?ooo`00G@3oool30?l000H0oooo0P00000V0?ooo`<0
o`00:03oool30?l006@0oooo001M0?ooo`@0o`001@3oool00`000000oooo0?ooo`0T0?ooo`@0o`00
:03oool30?l006@0oooo001N0?ooo`<0o`001@3oool00`000000oooo0?ooo`0T0?ooo`<0o`00:P3o
ool30?l006<0oooo001N0?ooo`@0o`00103oool00`000000oooo0?ooo`0T0?ooo`<0o`00:P3oool3
0?l006<0oooo001O0?ooo`<0o`00103oool00`000000oooo0?ooo`0S0?ooo`@0o`00:P3oool30?l0
06<0oooo001O0?ooo`<0o`00103oool00`000000oooo0?ooo`0S0?ooo`<0o`00:`3oool30?l006<0
oooo001O0?ooo`@0o`000`3oool2000002@0oooo0`3o000[0?ooo`<0o`00H`3oool00600oooo0`3o
00030?ooo`030000003oool0oooo0280oooo103o000[0?ooo`<0o`00H`3oool00600oooo0`3o0003
0?ooo`030000003oool0oooo0280oooo0`3o000/0?ooo`<0o`00H`3oool00600oooo103o00020?oo
o`030000003oool0oooo0280oooo0`3o000/0?ooo`<0o`00H`3oool004h0oooo0P0000040?ooo`80
0000103oool2000000D0oooo0`3o00020?ooo`030000003oool0oooo0240oooo103o000]0?ooo`<0
o`00HP3oool004d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?oo
o`<0o`000P3oool00`000000oooo0?ooo`0Q0?ooo`<0o`00;P3oool30?l00680oooo001=0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool2000000@0o`0000<0oooo
0000000000008P3oool30?l002h0oooo0`3o001R0?ooo`00C@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3o00000`3oool000000?oo
o`0Q0?ooo`@0o`00;P3oool30?l00680oooo001=0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?l000020?l000030?ooo`000000oooo0240oooo
0`3o000_0?ooo`<0o`00HP3oool004h0oooo0P00000:0?ooo`8000001@3oool00`000000o`000?l0
00020?l000030000003oool0oooo0200oooo0`3o000_0?ooo`<0o`00HP3oool006<0oooo0`3o0000
0`000000oooo0?ooo`0O0?ooo`@0o`00;`3oool30?l00680oooo001S0?ooo`<0o`0000<000000?oo
o`3oool07`3oool30?l00300oooo0`3o001R0?ooo`00H`3oool40?l000030000003oool0oooo01h0
oooo0`3o000`0?ooo`<0o`00HP3oool006@0oooo0`3o000P0?ooo`@0o`00<@3oool30?l00640oooo
001T0?ooo`<0o`00803oool30?l00380oooo0`3o001Q0?ooo`00I03oool40?l001h0oooo103o000b
0?ooo`<0o`00H@3oool006D0oooo0`3o000N0?ooo`<0o`00<`3oool30?l00640oooo001U0?ooo`@0
o`007@3oool30?l003<0oooo0`3o001Q0?ooo`00IP3oool30?l001`0oooo103o000c0?ooo`<0o`00
H@3oool006H0oooo103o000K0?ooo`<0o`00=03oool30?l00640oooo001V0?ooo`040000003o0000
o`000?l001/0oooo0`3o000d0?ooo`<0o`00H@3oool006H0oooo00<000000?l0003o00000P3o000I
0?ooo`@0o`00=03oool30?l00640oooo001V0?ooo`030000003oool0o`000080o`006@3oool30?l0
03D0oooo0`3o001Q0?ooo`00IP3oool2000000@0o`00603oool30?l003D0oooo0`3o001Q0?ooo`00
IP3oool00`000000oooo0?ooo`030?l001L0oooo103o000e0?ooo`<0o`00H@3oool006H0oooo00<0
00000?ooo`3oool0103o000F0?ooo`<0o`00=`3oool30?l00600oooo001V0?ooo`040000003oool0
oooo0?ooo`<0o`005@3oool40?l003L0oooo0`3o001P0?ooo`00CP3oool2000000@0oooo0P000004
0?ooo`8000000`3oool3000000@0oooo00@000000?ooo`3oool0oooo103o000D0?ooo`<0o`00>03o
ool30?l00600oooo001=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo0`3o000C0?ooo`@0
o`00>03oool30?l00600oooo001=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`8000000`3oool40?l00140oooo103o000i
0?ooo`<0o`00H03oool004d0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`<00000103oool00`000000oooo0?ooo`030?ooo`<0o`004@3oool30?l003X0oooo0`3o
001P0?ooo`00C@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`@0o`003`3oool40?l003X0oooo
0`3o001P0?ooo`00CP3oool2000000X0oooo0P0000040?ooo`<000000`3oool00`000000oooo0?oo
o`040?ooo`<0o`003P3oool40?l003/0oooo0`3o001P0?ooo`00IP3oool00`000000oooo0?ooo`04
0?ooo`@0o`00303oool40?l003`0oooo0`3o001P0?ooo`00IP3oool00`000000oooo0?ooo`050?oo
o`@0o`002P3oool40?l003d0oooo0`3o001P0?ooo`00IP3oool2000000L0oooo103o00080?ooo`@0
o`00?P3oool30?l00600oooo001V0?ooo`030000003oool0oooo00L0oooo103o00050?ooo`030?l0
003oool0o`000080o`00@03oool30?l005l0oooo001V0?ooo`030000003oool0oooo00P0oooo1@3o
00020?ooo`H0o`00@03oool30?l005l0oooo001V0?ooo`030000003oool0oooo00P0oooo3@3o0010
0?ooo`<0o`00G`3oool006H0oooo00<000000?ooo`3oool02@3oool:0?l00480oooo0`3o001O0?oo
o`00IP3oool00`000000oooo0?ooo`0<0?ooo`@0o`00A@3oool30?l005l0oooo001V0?ooo`800000
EP3oool30?l005l0oooo002n0?ooo`<0o`00G`3oool00?l0oooo8@3oool00?l0oooo8@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {135.75, 0}} -> {-1.07824, -0.784209, \
0.0105816, 0.0105816}, {{7.375, 196.375}, {120, 3.1875}} -> {-1.14984, \
-0.0440066, 0.0112023, 0.000863128}, {{205.813, 274.875}, {127.75, 52.1875}} -> \
{-10.1252, -0.489634, 0.048702, 0.048702}, {{209.5, 230.063}, {124, 103.5}} -> \
{-10.723, -3.63545, 0.0510643, 0.165248}, {{209.5, 230.063}, {100.188, \
79.6875}} -> {-10.723, -7.57041, 0.0510643, 0.165248}, {{209.5, 230.063}, \
{76.375, 55.875}} -> {-10.723, -11.5054, 0.0510643, 0.165248}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[89]="]
}, Open  ]],

Cell["Example 3", "Subsubsection"],

Cell["Initial value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\((x - 1/2)\)*\(y'\)[x] \[Equal] y[x], 
        y[0] \[Equal] 1}\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\((\(-\(1\/2\)\) + x)\), " ", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", \(y[x]\)}],
         ",", \(y[0] == 1\)}], "}"}]], "Output",
  CellLabel->"Out[90]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr0 = ApproxSol[ivp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[91]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 1 - 2\ x}}\)], "Output",
  CellLabel->"Out[91]="]
}, Open  ]],

Cell["\<\
Modified method is not avilable if leading polynom (coefficient of higher \
derivative) has zeros on the interval of approximation.\
\>", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr1 = 
      ApproxSol[ivp, y[x], {x, 0, 1}, 5, 
        Method \[Rule] Modified[1]]\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(LdeApprox::"zeros" \(\(:\)\(\ \)\) 
      "Leading polynom has zeros on the given interval"\)], "Message",
  CellLabel->"From In[92]:="],

Cell[BoxData[
    \($Aborted\)], "Output",
  CellLabel->"Out[92]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " tot find exact solution of the IVP."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[93]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 1 - 2\ x}}\)], "Output",
  CellLabel->"Out[93]="]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->False,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 159, 5, 39, "Subsection"],
Cell[1867, 57, 381, 12, 22, "SmallText"],
Cell[2251, 71, 243, 6, 25, "Text"],
Cell[2497, 79, 46, 0, 31, "MathCaption"],
Cell[2546, 81, 93, 2, 29, "Input"],
Cell[2642, 85, 112, 3, 31, "MathCaption"],
Cell[2757, 90, 77, 2, 29, "Input"],
Cell[2837, 94, 34, 0, 35, "Subsubsection"],
Cell[2874, 96, 85, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2984, 102, 111, 2, 29, "Input"],
Cell[3098, 106, 318, 9, 23, "Output"]
}, Open  ]],
Cell[3431, 118, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3578, 125, 144, 4, 29, "Input"],
Cell[3725, 131, 146, 4, 39, "Output"]
}, Open  ]],
Cell[3886, 138, 163, 5, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[4074, 147, 148, 4, 29, "Input"],
Cell[4225, 153, 264, 5, 51, "Output"]
}, Open  ]],
Cell[4504, 161, 163, 5, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[4692, 170, 148, 4, 29, "Input"],
Cell[4843, 176, 261, 5, 51, "Output"]
}, Open  ]],
Cell[5119, 184, 228, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[5372, 197, 124, 4, 29, "Input"],
Cell[5499, 203, 85, 2, 23, "Output"]
}, Open  ]],
Cell[5599, 208, 317, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[5941, 222, 717, 12, 149, "Input"],
Cell[6661, 236, 51597, 1519, 162, 17743, 1096, "GraphicsData", "PostScript", \
"Graphics"],
Cell[58261, 1757, 155, 4, 23, "Output"]
}, Open  ]],
Cell[58431, 1764, 34, 0, 35, "Subsubsection"],
Cell[58468, 1766, 85, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[58578, 1772, 151, 3, 29, "Input"],
Cell[58732, 1777, 387, 10, 23, "Output"]
}, Open  ]],
Cell[59134, 1790, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[59281, 1797, 144, 4, 29, "Input"],
Cell[59428, 1803, 227, 5, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59692, 1813, 148, 4, 29, "Input"],
Cell[59843, 1819, 236, 5, 39, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60116, 1829, 148, 4, 29, "Input"],
Cell[60267, 1835, 223, 5, 39, "Output"]
}, Open  ]],
Cell[60505, 1843, 228, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[60758, 1856, 124, 4, 29, "Input"],
Cell[60885, 1862, 303, 6, 55, "Output"]
}, Open  ]],
Cell[61203, 1871, 290, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[61518, 1884, 763, 13, 149, "Input"],
Cell[62284, 1899, 36342, 1254, 143, 16450, 1003, "GraphicsData", \
"PostScript", "Graphics"],
Cell[98629, 3155, 155, 4, 23, "Output"]
}, Open  ]],
Cell[98799, 3162, 34, 0, 35, "Subsubsection"],
Cell[98836, 3164, 85, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[98946, 3170, 129, 3, 29, "Input"],
Cell[99078, 3175, 332, 9, 36, "Output"]
}, Open  ]],
Cell[99425, 3187, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[99572, 3194, 139, 4, 29, "Input"],
Cell[99714, 3200, 84, 2, 23, "Output"]
}, Open  ]],
Cell[99813, 3205, 202, 5, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[100040, 3214, 143, 4, 29, "Input"],
Cell[100186, 3220, 156, 3, 23, "Message"],
Cell[100345, 3225, 67, 2, 23, "Output"]
}, Open  ]],
Cell[100427, 3230, 228, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[100680, 3243, 124, 4, 29, "Input"],
Cell[100807, 3249, 84, 2, 23, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

