(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    206709,       5410]*)
(*NotebookOutlinePosition[    207455,       5435]*)
(*  CellTagsIndexPosition[    207411,       5431]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Numerical",
  " examples of the ",
  StyleBox["DifferentialEquations`LdeApprox`",
    FontSlant->"Italic"],
  " package"
}], "Subsection"],

Cell[TextData[{
  StyleBox["Copyright \[Copyright] 2003-2005 ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Graph Tree Ltd",
    ButtonData:>{
      URL[ "http://www.mathshop.digi-area.com/"], None},
    Active->True,
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[". All rights reserved.",
    FontSlant->"Italic"]
}], "SmallText",
  TextAlignment->Right],

Cell[TextData[{
  "This notebook illustrates ",
  StyleBox["DifferentialEquations`LdeApprox`",
    FontFamily->"Courier New"],
  " package capability of doing numerical polynomial approximation of an LDE \
solution. "
}], "Text"],

Cell["This loads the package.", "MathCaption"],

Cell[BoxData[
    \(<< DifferentialEquations`LdeApprox`\)], "Input",
  CellLabel->"In[94]:="],

Cell["Example 1", "Subsubsection"],

Cell["Initial value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\((x^2 + 2*x + 1)\)*\(y'\)[x] + \((x - 1)\)*y[x] \[Equal] x, 
        y[0] == 0}\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\((\(-1\) + x)\)\ y[x]\), "+", 
            RowBox[{\((1 + 2\ x + x\^2)\), " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], "==", "x"}], 
        ",", \(y[0] == 0\)}], "}"}]], "Output",
  CellLabel->"Out[95]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[ivp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[96]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(1485255\/106143742177\)\) + \(90129264\ \
x\)\/106143742177 + \(52209002432\ x\^2\)\/106143742177 - \(50378475072\ x\^3\
\)\/106143742177 + \(25318969344\ x\^4\)\/106143742177 - \(5632886784\ x\^5\)\
\/106143742177}}\)], "Output",
  CellLabel->"Out[96]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " tot find exact solution of the IVP."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[97]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(\[ExponentialE]\^\(-\(2\/\(1 + x\)\)\)\ \((\(-\
\[ExponentialE]\^2\) + \[ExponentialE]\^\(2\/\(1 + x\)\) + \
\[ExponentialE]\^\(2\/\(1 + x\)\)\ x + ExpIntegralEi[2] - \
ExpIntegralEi[2\/\(1 + x\)])\)\)\/\(1 + x\)}}\)], "Output",
  CellLabel->"Out[97]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\), {x, 0, 
        1}]\)], "Input",
  CellLabel->"In[98]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.310788 20905.8 [
[.21429 .29829 -9 -9 ]
[.21429 .29829 9 0 ]
[.40476 .29829 -9 -9 ]
[.40476 .29829 9 0 ]
[.59524 .29829 -9 -9 ]
[.59524 .29829 9 0 ]
[.78571 .29829 -9 -9 ]
[.78571 .29829 9 0 ]
[.97619 .29829 -3 -9 ]
[.97619 .29829 3 0 ]
[.01131 .10173 -48 -4.5 ]
[.01131 .10173 0 4.5 ]
[.01131 .20626 -39 -6.25 ]
[.01131 .20626 0 6.25 ]
[.01131 .41532 -33 -6.25 ]
[.01131 .41532 0 6.25 ]
[.01131 .51985 -42 -4.5 ]
[.01131 .51985 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .31079 m
.21429 .31704 L
s
[(0.2)] .21429 .29829 0 1 Mshowa
.40476 .31079 m
.40476 .31704 L
s
[(0.4)] .40476 .29829 0 1 Mshowa
.59524 .31079 m
.59524 .31704 L
s
[(0.6)] .59524 .29829 0 1 Mshowa
.78571 .31079 m
.78571 .31704 L
s
[(0.8)] .78571 .29829 0 1 Mshowa
.97619 .31079 m
.97619 .31704 L
s
[(1)] .97619 .29829 0 1 Mshowa
.125 Mabswid
.07143 .31079 m
.07143 .31454 L
s
.11905 .31079 m
.11905 .31454 L
s
.16667 .31079 m
.16667 .31454 L
s
.2619 .31079 m
.2619 .31454 L
s
.30952 .31079 m
.30952 .31454 L
s
.35714 .31079 m
.35714 .31454 L
s
.45238 .31079 m
.45238 .31454 L
s
.5 .31079 m
.5 .31454 L
s
.54762 .31079 m
.54762 .31454 L
s
.64286 .31079 m
.64286 .31454 L
s
.69048 .31079 m
.69048 .31454 L
s
.7381 .31079 m
.7381 .31454 L
s
.83333 .31079 m
.83333 .31454 L
s
.88095 .31079 m
.88095 .31454 L
s
.92857 .31079 m
.92857 .31454 L
s
.25 Mabswid
0 .31079 m
1 .31079 L
s
.02381 .10173 m
.03006 .10173 L
s
[(-0.00001)] .01131 .10173 1 0 Mshowa
.02381 .20626 m
.03006 .20626 L
s
gsave
.01131 .20626 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .41532 m
.03006 .41532 L
s
gsave
.01131 .41532 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .51985 m
.03006 .51985 L
s
[(0.00001)] .01131 .51985 1 0 Mshowa
.125 Mabswid
.02381 .01811 m
.02756 .01811 L
s
.02381 .03901 m
.02756 .03901 L
s
.02381 .05992 m
.02756 .05992 L
s
.02381 .08082 m
.02756 .08082 L
s
.02381 .12264 m
.02756 .12264 L
s
.02381 .14354 m
.02756 .14354 L
s
.02381 .16445 m
.02756 .16445 L
s
.02381 .18535 m
.02756 .18535 L
s
.02381 .22716 m
.02756 .22716 L
s
.02381 .24807 m
.02756 .24807 L
s
.02381 .26898 m
.02756 .26898 L
s
.02381 .28988 m
.02756 .28988 L
s
.02381 .33169 m
.02756 .33169 L
s
.02381 .3526 m
.02756 .3526 L
s
.02381 .37351 m
.02756 .37351 L
s
.02381 .39441 m
.02756 .39441 L
s
.02381 .43622 m
.02756 .43622 L
s
.02381 .45713 m
.02756 .45713 L
s
.02381 .47803 m
.02756 .47803 L
s
.02381 .49894 m
.02756 .49894 L
s
.02381 .54075 m
.02756 .54075 L
s
.02381 .56166 m
.02756 .56166 L
s
.02381 .58256 m
.02756 .58256 L
s
.02381 .60347 m
.02756 .60347 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.03279 .45067 L
.04262 .31499 L
.05288 .20497 L
.06244 .12832 L
.06792 .09448 L
.0731 .06866 L
.07775 .05022 L
.0828 .03492 L
.08542 .0288 L
.0883 .02341 L
.08975 .02122 L
.09131 .01923 L
.09265 .01781 L
.09413 .01658 L
.09483 .0161 L
.09558 .01567 L
.09622 .01537 L
.09692 .0151 L
.09764 .0149 L
.09832 .01478 L
.09959 .01472 L
.10085 .01486 L
.10149 .01502 L
.10219 .01525 L
.10342 .0158 L
.10458 .01649 L
.10718 .01862 L
.10959 .02128 L
.11503 .02956 L
.11983 .03923 L
.12493 .05165 L
.14349 .11126 L
.18124 .26488 L
.20221 .34767 L
.22144 .41261 L
.24029 .46205 L
.24976 .48087 L
.2551 .48961 L
.26013 .49662 L
.26506 .5023 L
.2704 .50717 L
.27276 .50888 L
.27526 .51041 L
.2776 .51158 L
.27974 .51243 L
.28093 .51281 L
.28222 .51315 L
.28294 .51331 L
.28359 .51343 L
Mistroke
.28489 .51361 L
.28612 .51372 L
.28723 .51375 L
.28851 .51372 L
.28972 .51363 L
.29035 .51356 L
.29105 .51345 L
.29247 .51318 L
.29377 .51285 L
.29499 .51248 L
.29774 .51141 L
.30069 .5099 L
.30599 .5063 L
.31089 .50199 L
.32197 .48895 L
.33174 .474 L
.3421 .45503 L
.37991 .36661 L
.42016 .26058 L
.4589 .1726 L
.47898 .13919 L
.48907 .12641 L
.49474 .1205 L
.50009 .11579 L
.50504 .11219 L
.51039 .10913 L
.51276 .10806 L
.51526 .10711 L
.5176 .1064 L
.51974 .10589 L
.52102 .10566 L
.52223 .10548 L
.52351 .10534 L
.52424 .10529 L
.52491 .10525 L
.52602 .10522 L
.52725 .10523 L
.52853 .10529 L
.52973 .10539 L
.53037 .10546 L
.53107 .10555 L
.53249 .10578 L
.53501 .10635 L
.53796 .10725 L
.54071 .10832 L
.54575 .11087 L
.55121 .11447 L
.56114 .12314 L
.5708 .13411 L
.57972 .14629 L
Mistroke
.61909 .21872 L
.65695 .3031 L
.678 .34842 L
.69725 .38471 L
.70677 .39993 L
.71715 .414 L
.72695 .42453 L
.73169 .42857 L
.73604 .43166 L
.74113 .43446 L
.7438 .43558 L
.74662 .43649 L
.74781 .43679 L
.74908 .43706 L
.75028 .43725 L
.75137 .43739 L
.75265 .43749 L
.75338 .43753 L
.75405 .43754 L
.75528 .43752 L
.75658 .43744 L
.75773 .43732 L
.75878 .43717 L
.75993 .43695 L
.76115 .43667 L
.76319 .43608 L
.76543 .43525 L
.77049 .43268 L
.77519 .42944 L
.78573 .41919 L
.79567 .40583 L
.81426 .37188 L
.85275 .2749 L
.87225 .22222 L
.88258 .19697 L
.89368 .17417 L
.89915 .16523 L
.90433 .1585 L
.90659 .15617 L
.90899 .15413 L
.91037 .15317 L
.91162 .15244 L
.91278 .15189 L
.91406 .15142 L
.91525 .15112 L
.91652 .15095 L
.91769 .15094 L
.91878 .15105 L
.92007 .15134 L
.92124 .15176 L
Mistroke
.92259 .15244 L
.92388 .15327 L
.92618 .15523 L
.9283 .15762 L
.93311 .16518 L
.93776 .17557 L
.94277 .19043 L
.95182 .22813 L
.95734 .25875 L
.96259 .29382 L
.97245 .37711 L
.97619 .41529 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[98]:=",
  ImageSize->{214.375, 132.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003F0000Q2000`400?l00000o`00003oeP3oool0
0=H0oooo003F0?ooo`00eP3oool00=H0oooo003F0?ooo`00eP3oool00=H0oooo003F0?ooo`00eP3o
ool00=H0oooo003F0?ooo`00eP3oool00=H0oooo000b0?ooo`030000003oool0oooo0:40oooo000b
0?ooo`030000003oool0oooo0:40oooo000b0?ooo`030000003oool0oooo0:40oooo000b0?ooo`03
0000003oool0oooo00P0oooo1000002E0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`800000
0P3oool00`000000oooo0?ooo`2C0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0TP3oool00380oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0980oooo000b0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2A0?ooo`00<P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T@3oool00380oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0900oooo
000b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2@0?ooo`00<P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0S`3oool00380oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo08l0oooo000b0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`2?0?ooo`00<P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0S`3oool000P0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000<0oooo1@0000020?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2>0?ooo`001`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0SP3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0SP3oool000030?ooo`0000000000008000000P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0>P3oool6000004d0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0h0?ooo`8000001P3oool2000004/0oooo
00080?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0B@3oool00380oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`180?ooo`00<P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo04L0oooo000b0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0AP3oool00380oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`150?ooo`00<P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03@0oooo0`00000=0?ooo`00<P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03<0oooo0P0000000`3oool000000000000<
0?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0380oooo00D000000?oo
o`3oool0oooo0000000<0?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`00<P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`090?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`004@3oool2000000<0oooo00H0
00000?ooo`3oool0oooo0000003oool500000080oooo0P00000=0?ooo`050000003oool0oooo0?oo
o`0000004P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo000@0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool000000180oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`004`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000B0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0203oool000X0oooo100000030?ooo`800000103oool00`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`050000
003oool0oooo0?ooo`0000004`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0
oooo000A0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`8000000P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool00140
oooo0`0000090?ooo`800000103oool2000000d0oooo00D000000?ooo`3oool0oooo0000000C0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3oool002d0oooo00<0`<300;2`/02@
T9000P3oool01@000000oooo0?ooo`3oool0000001<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`060?ooo`00;@3oool00`2PX:00oooo0<30`0020?ooo`050000003oool0oooo0?oo
o`000000503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo000W0?ooo`04
0>3Ph020P800P8200820P080oooo00<0H61P092@T02PX:000P3oool01@000000oooo0?ooo`3oool0
000001@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`00;@3oool00`2P
X:00oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000503oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00H0oooo000^0?ooo`050:2PX02`/;00oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool0
0380oooo00D000000?ooo`3oool0oooo0000000C0?ooo`<000000`3oool2000000<0oooo1000000A
0?ooo`800000103oool2000000<0oooo00<000000?ooo`0000000P00000@0?ooo`800000103oool2
000000<0oooo0`00000B0?ooo`800000103oool2000000@0oooo0P0000060?ooo`030000003oool0
oooo00d0oooo1P0000020?ooo`00<P3oool01@000000oooo0?ooo`3oool000000180oooo00@00000
0?ooo`3oool00000203oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000L0oooo
00D000000?ooo`3oool0oooo0000000@0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool00000403oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000040?ooo`00<P3oool010000000oooo
0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0403oool01000
0000oooo0?ooo`0000070?ooo`H000003`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000100oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000103oool00380oooo00@000000?oo
o`3oool000004`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00l0oooo00@0
00000?ooo`3oool000001`3oool200000080oooo00<000000?ooo`3oool03P3oool010000000oooo
0?ooo`0000080?ooo`@00000403oool010000000oooo0?ooo`0000090?ooo`800000103oool00`00
0000oooo0?ooo`0?0?ooo`040000003oool0oooo000000@0oooo000b0?ooo`040000003oool0oooo
000001<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000@0?ooo`040000
003oool0oooo000000H0oooo00H000000?ooo`3oool000000?ooo`00000@0?ooo`040000003oool0
oooo000000T0oooo00@000000?ooo`3oool000003`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`000004
0?ooo`00<P3oool010000000oooo0?ooo`00000D0?ooo`80000000<0oooo0000003oool01`3oool2
00000180oooo0P0000070?ooo`040000003oool0oooo0?ooo`8000004@3oool2000000X0oooo1000
000@0?ooo`8000002P3oool2000000@0oooo00<000000?ooo`3oool0403oool3000000@0oooo000b
0?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`00<P3oool010000000oooo0?ooo`00000G0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0103oool00380oooo00@000000?ooo`3oool000005`3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo000b0?ooo`040000003oool0oooo000001L0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00;P3ooonX00000000<P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0P0000070?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000040?ooo`00<P3o
ool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
103oool00380oooo00@000000?ooo`3oool00000603oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00@0oooo000b0?ooo`040000003oool0oooo000001T0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`040?ooo`00<P3oool010000000oooo0?ooo`00000I0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00380oooo00@000000?ooo`3oool00000
6@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo000b0?ooo`030000003o
ool0000001X0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`030?ooo`00<P3oool0
0`000000oooo0000000K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00`3oool0
0380oooo00<000000?ooo`0000006`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00<0oooo000b0?ooo`030000003oool0000001/0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`030?ooo`00<P3oool00`000000oooo0000000L0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool00`3oool00380oooo00<000000?ooo`000000703oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00<0oooo000b0?ooo`030000003oool0000001d0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`004@3oool2000000<0oooo00H000000?oo
o`3oool0oooo0000003oool500000080oooo0P00000=0?ooo`030000003oool0000001d0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`00403oool010000000oooo0?ooo`00
00030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`0000007@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0080oooo000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0000000N0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00P3oool00140oooo0P00
00040?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`0000007P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0080oooo000A0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
00007`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo000A0?ooo`<00000
2@3oool2000000@0oooo0P00000=0?ooo`800000803oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0S0?ooo`00;@3o
ool00`30`<00/;2`092@T0020?ooo`800000803oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo03`0oooo0P0000040?ooo`8000009P3oool002d0oooo00<0X:2P0?ooo`30`<000P3oool2
00000200oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0o0?ooo`D000009`3oool0
02L0oooo00@0h>3P0820P020P800P8200P3oool00`1PH600T92@0:2PX0020?ooo`8000008@3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06/0oooo000]0?ooo`030:2PX03oool0oooo
0080oooo0P00000Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0K03oool002h0
oooo00@0X:2P0;2`/03oool0oooo0P00000R0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0K03oool00380oooo0P00000R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0K@3oool00380oooo0P00000R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
K@3oool00380oooo0P00000R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0KP3o
ool00380oooo0P00000S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K`3oool0
0380oooo0P00000S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K`3oool00380
oooo0P00000T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0L03oool00380oooo
0P00000U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0L@3oool00380oooo0P00
000V0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0L@3oool000P0oooo0P000004
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000<0oooo1@000002
0?ooo`8000009`3oool2000000<0oooo0P00001d0?ooo`001`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool20000
02P0oooo1000001f0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool200000:80oooo00070?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0:40oooo00070?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0:40oooo00080?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000040?ooo`030000003oool0oooo0:40oooo000b0?ooo`030000003oool0oooo
0:40oooo000b0?ooo`030000003oool0oooo0:40oooo000b0?ooo`030000003oool0oooo0:40oooo
000b0?ooo`030000003oool0oooo0:40oooo000b0?ooo`030000003oool0oooo0:40oooo000b0?oo
o`030000003oool0oooo0:40oooo000b0?ooo`030000003oool0oooo0:40oooo000b0?ooo`030000
003oool0oooo0:40oooo000b0?ooo`030000003oool0oooo0:40oooo000b0?ooo`030000003oool0
oooo0:40oooo000b0?ooo`030000003oool0oooo0:40oooo000b0?ooo`030000003oool0oooo0:40
oooo000b0?ooo`030000003oool0oooo0:40oooo003F0?ooo`00eP3oool00=H0oooo003F0?ooo`00
eP3oool00=H0oooo003F0?ooo`00eP3oool00=H0oooo003F0?ooo`00eP3oool00=H0oooo003F0?oo
o`00eP3oool00001\
\>"],
  ImageRangeCache->{{{0, 213.375}, {131.438, 0}} -> {-0.314448, \
-1.88787*^-05, 0.00627746, 2.85975*^-07}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[98]="]
}, Open  ]],

Cell["Example 2", "Subsubsection"],

Cell["Initial value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\(y''\)[x] + x*y[x] \[Equal] 0, 
        y[0] == 0, \(y'\)[0] \[Equal] 1}\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(x\ y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
        ",", \(y[0] == 0\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", "1"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[99]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[ivp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[100]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(10537801240512\/3531436486369238983\)\) + \
\(3532176207081672192\ x\)\/3531436486369238983 - \(8313823559408640\ \
x\^2\)\/3531436486369238983 + \(33399696230584320\ \
x\^3\)\/3531436486369238983 - \(351864057725214720\ \
x\^4\)\/3531436486369238983 + \(38680198375669760\ \
x\^5\)\/3531436486369238983}}\)], "Output",
  CellLabel->"Out[100]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " tot find exact solution of the IVP."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[101]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 
          1\/6\ \((3\ \((\(-1\))\)\^\(2/3\)\ 3\^\(1/3\)\ \
AiryAi[\((\(-1\))\)\^\(1/3\)\ x]\ Gamma[
                    1\/3] - \((\(-1\))\)\^\(2/3\)\ 3\^\(5/6\)\ AiryBi[\((\(-1\
\))\)\^\(1/3\)\ x]\ Gamma[1\/3])\)}}\)], "Output",
  CellLabel->"Out[101]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Chop[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\)], {x, 0, 
        1}]\)], "Input",
  CellLabel->"In[102]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.308612 87517.9 [
[.21429 .29611 -9 -9 ]
[.21429 .29611 9 0 ]
[.40476 .29611 -9 -9 ]
[.40476 .29611 9 0 ]
[.59524 .29611 -9 -9 ]
[.59524 .29611 9 0 ]
[.78571 .29611 -9 -9 ]
[.78571 .29611 9 0 ]
[.97619 .29611 -3 -9 ]
[.97619 .29611 3 0 ]
[.01131 .04606 -39 -6.25 ]
[.01131 .04606 0 6.25 ]
[.01131 .13358 -39 -6.25 ]
[.01131 .13358 0 6.25 ]
[.01131 .22109 -39 -6.25 ]
[.01131 .22109 0 6.25 ]
[.01131 .39613 -33 -6.25 ]
[.01131 .39613 0 6.25 ]
[.01131 .48365 -33 -6.25 ]
[.01131 .48365 0 6.25 ]
[.01131 .57117 -33 -6.25 ]
[.01131 .57117 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30861 m
.21429 .31486 L
s
[(0.2)] .21429 .29611 0 1 Mshowa
.40476 .30861 m
.40476 .31486 L
s
[(0.4)] .40476 .29611 0 1 Mshowa
.59524 .30861 m
.59524 .31486 L
s
[(0.6)] .59524 .29611 0 1 Mshowa
.78571 .30861 m
.78571 .31486 L
s
[(0.8)] .78571 .29611 0 1 Mshowa
.97619 .30861 m
.97619 .31486 L
s
[(1)] .97619 .29611 0 1 Mshowa
.125 Mabswid
.07143 .30861 m
.07143 .31236 L
s
.11905 .30861 m
.11905 .31236 L
s
.16667 .30861 m
.16667 .31236 L
s
.2619 .30861 m
.2619 .31236 L
s
.30952 .30861 m
.30952 .31236 L
s
.35714 .30861 m
.35714 .31236 L
s
.45238 .30861 m
.45238 .31236 L
s
.5 .30861 m
.5 .31236 L
s
.54762 .30861 m
.54762 .31236 L
s
.64286 .30861 m
.64286 .31236 L
s
.69048 .30861 m
.69048 .31236 L
s
.7381 .30861 m
.7381 .31236 L
s
.83333 .30861 m
.83333 .31236 L
s
.88095 .30861 m
.88095 .31236 L
s
.92857 .30861 m
.92857 .31236 L
s
.25 Mabswid
0 .30861 m
1 .30861 L
s
.02381 .04606 m
.03006 .04606 L
s
gsave
.01131 .04606 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .13358 m
.03006 .13358 L
s
gsave
.01131 .13358 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .22109 m
.03006 .22109 L
s
gsave
.01131 .22109 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .39613 m
.03006 .39613 L
s
gsave
.01131 .39613 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .48365 m
.03006 .48365 L
s
gsave
.01131 .48365 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .57117 m
.03006 .57117 L
s
gsave
.01131 .57117 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.02381 .06356 m
.02756 .06356 L
s
.02381 .08106 m
.02756 .08106 L
s
.02381 .09857 m
.02756 .09857 L
s
.02381 .11607 m
.02756 .11607 L
s
.02381 .15108 m
.02756 .15108 L
s
.02381 .16858 m
.02756 .16858 L
s
.02381 .18609 m
.02756 .18609 L
s
.02381 .20359 m
.02756 .20359 L
s
.02381 .2386 m
.02756 .2386 L
s
.02381 .2561 m
.02756 .2561 L
s
.02381 .2736 m
.02756 .2736 L
s
.02381 .29111 m
.02756 .29111 L
s
.02381 .32612 m
.02756 .32612 L
s
.02381 .34362 m
.02756 .34362 L
s
.02381 .36112 m
.02756 .36112 L
s
.02381 .37863 m
.02756 .37863 L
s
.02381 .41363 m
.02756 .41363 L
s
.02381 .43114 m
.02756 .43114 L
s
.02381 .44864 m
.02756 .44864 L
s
.02381 .46614 m
.02756 .46614 L
s
.02381 .50115 m
.02756 .50115 L
s
.02381 .51865 m
.02756 .51865 L
s
.02381 .53616 m
.02756 .53616 L
s
.02381 .55366 m
.02756 .55366 L
s
.02381 .02855 m
.02756 .02855 L
s
.02381 .01105 m
.02756 .01105 L
s
.02381 .58867 m
.02756 .58867 L
s
.02381 .60617 m
.02756 .60617 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .56976 m
.03279 .41461 L
.04262 .28193 L
.04758 .22827 L
.05288 .17982 L
.06244 .11366 L
.06788 .08696 L
.07075 .07578 L
.07379 .06597 L
.07644 .05904 L
.07936 .05307 L
.08064 .05099 L
.08202 .0491 L
.08322 .04773 L
.08451 .04656 L
.08521 .04605 L
.08584 .04566 L
.08708 .04509 L
.08777 .04489 L
.08852 .04475 L
.08923 .04471 L
.08988 .04475 L
.09107 .04498 L
.09236 .04549 L
.09302 .04584 L
.09372 .04628 L
.09499 .04727 L
.09757 .04997 L
.10001 .05335 L
.10458 .06168 L
.10917 .07241 L
.11423 .08668 L
.12449 .12206 L
.14291 .20036 L
.18311 .38643 L
.20159 .45983 L
.21206 .49482 L
.2218 .52235 L
.2323 .5462 L
.24184 .5624 L
.24709 .56906 L
.25204 .57386 L
.25476 .57589 L
.25727 .57739 L
.26002 .57861 L
.26141 .57906 L
.26215 .57925 L
.26294 .57943 L
.26423 .57963 L
.26543 .57974 L
Mistroke
.26617 .57977 L
.26686 .57976 L
.26815 .57969 L
.26939 .57952 L
.27053 .5793 L
.27178 .57897 L
.2731 .57853 L
.27539 .57754 L
.27753 .57636 L
.28239 .57277 L
.28767 .56749 L
.29248 .56146 L
.30328 .54394 L
.3224 .50089 L
.34318 .44029 L
.38401 .29869 L
.42333 .16543 L
.44306 .1102 L
.46113 .07038 L
.47058 .05435 L
.48052 .04139 L
.48569 .03628 L
.49049 .03256 L
.49321 .03091 L
.49576 .02965 L
.49718 .02908 L
.49871 .02856 L
.50011 .02817 L
.50139 .0279 L
.5026 .02771 L
.50375 .02758 L
.50497 .02752 L
.50566 .02751 L
.50629 .02752 L
.50735 .02758 L
.50852 .02771 L
.50973 .0279 L
.51088 .02814 L
.51349 .02892 L
.51589 .0299 L
.51853 .03127 L
.5213 .03305 L
.52651 .03731 L
.53135 .04233 L
.54236 .05747 L
.55287 .07657 L
.56279 .09851 L
.58137 .14869 L
.61981 .27971 L
.66069 .43058 L
Mistroke
.68103 .49698 L
.69097 .52501 L
.70006 .54737 L
.70879 .56544 L
.71831 .58094 L
.72352 .58742 L
.72836 .59207 L
.73075 .59386 L
.73299 .59525 L
.73423 .59589 L
.73557 .59647 L
.73678 .5969 L
.73792 .59723 L
.73916 .5975 L
.74029 .59766 L
.74151 .59774 L
.7422 .59774 L
.74284 .59772 L
.7439 .59763 L
.74507 .59745 L
.74629 .59716 L
.74743 .59681 L
.75006 .59568 L
.75246 .59426 L
.7551 .59227 L
.75787 .58968 L
.76309 .58344 L
.76794 .57603 L
.77894 .55344 L
.78947 .52446 L
.79941 .49082 L
.81801 .41323 L
.85649 .21499 L
.87599 .11689 L
.88633 .07312 L
.89203 .05298 L
.89743 .03716 L
.90253 .02568 L
.90541 .02086 L
.90679 .01902 L
.90808 .01757 L
.90927 .01649 L
.91055 .01561 L
.91172 .01506 L
.91279 .01478 L
.91396 .01472 L
.91523 .01495 L
.91587 .0152 L
.91656 .01555 L
.9178 .01643 L
Mistroke
.91908 .01769 L
.92026 .01916 L
.92293 .02364 L
.92528 .02899 L
.92778 .03616 L
.9321 .05243 L
.93685 .07647 L
.94193 .10978 L
.94675 .14948 L
.9558 .24753 L
.96555 .39202 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[102]:=",
  ImageSize->{209.813, 129.625},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003A0000PB000`400?l00000o`00003od@3oool0
0=40oooo003A0?ooo`00d@3oool00=40oooo003A0?ooo`00d@3oool00=40oooo003A0?ooo`00d@3o
ool00=40oooo000Y0?ooo`030000003oool0oooo0:D0oooo000Y0?ooo`030000003oool0oooo0:D0
oooo000Y0?ooo`030000003oool0oooo0:D0oooo000Y0?ooo`030000003oool0oooo09@0oooo1000
000=0?ooo`00:@3oool00`000000oooo0?ooo`2D0?ooo`040000003oool0oooo000000d0oooo0008
0?ooo`8000000`3oool01P000000oooo0?ooo`3oool000000?ooo`D000000P3oool2000000d0oooo
00<000000?ooo`3oool0C@3oool600000440oooo00@000000?ooo`3oool000003@3oool000L0oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04`0oooo0P0000040?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?oo
o`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`050?ooo`800000?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00000`3oool0000000000002000000D0oooo00L000000?ooo`3oool0oooo0000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00
00080?ooo`<00000@03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`001`3oool010000000oooo0?ooo`00
00020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo00000000
0000?P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`00203oool2000000X0oooo0P0000040?ooo`800000
203oool00`30`<00/;2`092@T0020?ooo`030000003oool0oooo00H0oooo00D000000?ooo`3oool0
oooo0000000n0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo000T0?ooo`030:2PX03oool0`<300080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool001h0oooo00@0h>3P0820P020P800P8200P3oool00`1PH600T92@
0:2PX0020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00T0oooo000T0?ooo`030:2PX03oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool002D0oooo00D0X:2P0;2`/03oool0oooo000000060?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`00:@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`090?ooo`00:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`00:@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`080?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`00:@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`080?ooo`001`3oool400000080oooo00H000000?ooo`3oool0oooo0000003oool500000080oooo
0P00000=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00070?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`080?ooo`00203oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0203oool000030?ooo`000000000000800000103oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P0000040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`070?ooo`001`3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000X0oooo0P0000040?ooo`80
0000203oool00`30`<00/;2`092@T0020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo000T0?ooo`030:2P
X03oool0`<300080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool01`3oool001h0oooo00@0h>3P0820P020P800P820
0P3oool00`1PH600T92@0:2PX0020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo000T0?ooo`030:2PX03o
ool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool01`3oool002D0oooo00D0X:2P0;2`/03oool0oooo0000
00040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`070?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`070?ooo`00:@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?oo
o`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`060?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`00:@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`060?ooo`001`3oool5000000030?ooo`000000oooo0080oooo00<00000
0?ooo`000000100000020?ooo`8000003@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`002@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool01P3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`050000
003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0
oooo00000`3oool0000000000002000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
00000P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01P3oool000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`00000<0?ooo`050000003oool0oooo0?ooo`000000403o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00080?ooo`8000002P3oool2
000000@0oooo0P0000080?ooo`030<30`02`/;00T92@0080oooo00D000000?ooo`3oool0oooo0000
000@0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool002@0oooo00<0X:2P
0?ooo`30`<000P3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`050?ooo`007P3oool0103Ph>00P8200820P020P8020?ooo`03061PH02@
T900X:2P0080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01@3oool002@0oooo00<0X:2P0?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool000000140oooo00<000000?ooo`3oool00P0000040?ooo`8000000`3oool400000180oooo
0P0000040?ooo`8000001@3oool300000140oooo0P0000040?ooo`80000000<0oooo0000003oool0
0`00000C0?ooo`800000103oool2000000@0oooo0P0000040?ooo`030000003oool0oooo00l0oooo
1P0000020?ooo`009@3oool01@2PX:00/;2`0?ooo`3oool000000080oooo00<000000?ooo`3oool0
403oool00`000000oooo000000020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
4P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`0000070?ooo`8000000P3oool00`000000oooo0?ooo`0?0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`0?0?ooo`040000003oool0oooo000000@0oooo000Y0?ooo`040000003oool0oooo00000180oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0140oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`D00000403oool010000000
oooo0?ooo`0000070?ooo`8000000P3oool00`000000oooo0?ooo`0?0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0@0?ooo`040000003o
ool0oooo000000@0oooo000Y0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo00000140oooo00@000000?oo
o`3oool000001`3oool400000180oooo00@000000?ooo`3oool000002@3oool2000000<0oooo00<0
00000?ooo`3oool0403oool010000000oooo0?ooo`0000040?ooo`00:@3oool010000000oooo0?oo
o`00000C0?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000140
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool00000
0140oooo00@000000?ooo`3oool00000203oool2000001<0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
0000103oool002T0oooo00@000000?ooo`3oool000004`3oool010000000oooo00000000000:0?oo
o`8000004`3oool2000000<0oooo00<000000?ooo`3oool01@3oool200000180oooo0P0000090?oo
o`@000004P3oool2000000X0oooo0P0000030?ooo`030000003oool0oooo0100oooo00@000000?oo
o`0000000000103oool002T0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00D0oooo000Y0?ooo`040000003oool0oooo000001<0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`00:@3oool010000000oooo0?ooo`00000D
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01@3oool002T0oooo00@000000?oo
o`3oool00000503oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00D0oooo000U0?oo
oj`00000000Y0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo00000007
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000@0oooo000Y0?ooo`030000003oool0000001H0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`050?ooo`00:@3oool00`000000oooo0000000F0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool002T0oooo00<000000?ooo`00
00005P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000Y0?ooo`030000
003oool0000001H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00:@3o
ool00`000000oooo0000000F0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool002T0oooo00<000000?ooo`0000005`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00@0oooo000Y0?ooo`030000003oool0000001L0oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`040?ooo`00:@3oool00`000000oooo0000000G0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool0103oool002T0oooo00<000000?ooo`0000005`3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000Y0?ooo`030000003oool0000001P0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`001`3oool5000000030?ooo`000000
oooo0080oooo00<000000?ooo`000000100000020?ooo`8000003@3oool00`000000oooo0000000H
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool000T0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`8000006@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00@0oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000001T0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`040?ooo`002@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P00000I0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool0
00T0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`00000<0?ooo`8000006P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00@0oooo00080?ooo`8000002P3oool2000000@0oooo0P0000080?ooo`030<30`02`
/;00T92@0080oooo0P00000J0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103o
ool002@0oooo00<0X:2P0?ooo`30`<000P3oool2000001X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`040?ooo`007P3oool0103Ph>00P8200820P020P8020?ooo`03061PH02@T900
X:2P0080oooo0P00000J0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103oool0
02@0oooo00<0X:2P0?ooo`3oool00P3oool2000001/0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`040?ooo`009@3oool0102PX:00/;2`0?ooo`3oool2000001/0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`040?ooo`00:@3oool2000001/0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`040?ooo`00:@3oool2000001/0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`040?ooo`00:@3oool2000001`0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`030?ooo`00:@3oool2000001`0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`030?ooo`00:@3oool2000001`0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`030?ooo`001`3oool400000080oooo00H000000?ooo`3oool0oooo0000003oool5
00000080oooo0P00000=0?ooo`800000703oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00<0oooo00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000001d0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`00203oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P00000M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool0
00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`8000007@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00<0oooo00070?ooo`040000003oool0oooo00000080oooo00D00000
0?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`8000007P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo
00080?ooo`8000002P3oool2000000@0oooo0P0000080?ooo`030<30`02`/;00T92@0080oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo000T
0?ooo`030:2PX03oool0`<300080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00<0oooo000N0?ooo`040>3Ph020P800P8200820P080oooo00<0H61P
092@T02PX:000P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool00`3oool002@0oooo00<0X:2P0?ooo`3oool00P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool002D0oooo00D0X:2P0;2`/03o
ool0oooo0000000Q0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool002T0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0
oooo000Y0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`030?ooo`00:@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool00`3oool002T0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00<0oooo000Y0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`030?ooo`00203oool2000000<0oooo00H000000?ooo`3o
ool0oooo0000003oool500000080oooo0P00000=0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`001`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo0080oooo00090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool000X0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P00000T0?ooo`030000003oool0oooo00<0oooo0P0000180?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`020?ooo`00
1`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0T
0?ooo`80000000<0oooo000000000000BP3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool00P3oool000P0oooo0P00000:0?ooo`800000103oool20000
00P0oooo00<0`<300;2`/02@T9000P3oool00`000000oooo0?ooo`0U0?ooo`<00000C03oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool002@0
oooo00<0X:2P0?ooo`30`<000P3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`020?ooo`007P3oool0103Ph>00P820
0820P020P8020?ooo`03061PH02@T900X:2P0080oooo00<000000?ooo`3oool0MP3oool200000003
0?ooo`000000000002D0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0X:2P0?ooo`3oool0
0P3oool00`000000oooo0?ooo`1g0?ooo`<000009P3oool00`000000oooo0?ooo`020?ooo`009@3o
ool01@2PX:00/;2`0?ooo`3oool000000:80oooo00<000000?ooo`3oool00P3oool002T0oooo00<0
00000?ooo`3oool0Y@3oool002T0oooo00<000000?ooo`3oool0Y@3oool00=40oooo003A0?ooo`00
d@3oool00=40oooo003A0?ooo`00d@3oool00=40oooo003A0?ooo`00d@3oool00=40oooo003A0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 208.813}, {128.625, 0}} -> {-0.251553, \
-4.27391*^-06, 0.00611342, 6.6527*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[102]="]
}, Open  ]],

Cell["Example 3", "Subsubsection"],

Cell["Initial value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''\)[x] + x*\(y'\)[x] + y[x] \[Equal] 0, y[0] == 0, 
        y[1] \[Equal] 1}\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(y[x]\), "+", 
            RowBox[{"x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
        ",", \(y[0] == 0\), ",", \(y[1] == 1\)}], "}"}]], "Output",
  CellLabel->"Out[103]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 9]\)], "Input",
  CellLabel->"In[104]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 
          15428981768\/20377475263803637153 + \(28115450694469140528\ \
x\)\/20377475263803637153 + \(101679678790656\ x\^2\)\/20377475263803637153 - \
\(9373117230590176000\ x\^3\)\/20377475263803637153 + \(8416159083952128\ \
x\^4\)\/20377475263803637153 + \(108421228927434752\ \
x\^5\)\/1198675015517861009 + \(69935513300107264\ \
x\^6\)\/20377475263803637153 - \(363298934512484352\ \
x\^7\)\/20377475263803637153 + \(75748806327009280\ \
x\^8\)\/20377475263803637153 + \(1077684374339584\ \
x\^9\)\/20377475263803637153}}\)], "Output",
  CellLabel->"Out[104]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " tot find exact solution of the BVP."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[105]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(\[ExponentialE]\^\(1\/2 - x\^2\/2\)\ \
Erfi[x\/\@2]\)\/Erfi[1\/\@2]}}\)], "Output",
  CellLabel->"Out[105]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\), {x, 0, 
        1}]\)], "Input",
  CellLabel->"In[106]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.307633 3.84539e+008 [
[.21429 .29513 -9 -9 ]
[.21429 .29513 9 0 ]
[.40476 .29513 -9 -9 ]
[.40476 .29513 9 0 ]
[.59524 .29513 -9 -9 ]
[.59524 .29513 9 0 ]
[.78571 .29513 -9 -9 ]
[.78571 .29513 9 0 ]
[.97619 .29513 -3 -9 ]
[.97619 .29513 3 0 ]
[.01131 .01923 -55.5 -6.25 ]
[.01131 .01923 0 6.25 ]
[.01131 .11536 -43.5 -6.25 ]
[.01131 .11536 0 6.25 ]
[.01131 .2115 -55.5 -6.25 ]
[.01131 .2115 0 6.25 ]
[.01131 .40377 -49.5 -6.25 ]
[.01131 .40377 0 6.25 ]
[.01131 .4999 -37.5 -6.25 ]
[.01131 .4999 0 6.25 ]
[.01131 .59604 -49.5 -6.25 ]
[.01131 .59604 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30763 m
.21429 .31388 L
s
[(0.2)] .21429 .29513 0 1 Mshowa
.40476 .30763 m
.40476 .31388 L
s
[(0.4)] .40476 .29513 0 1 Mshowa
.59524 .30763 m
.59524 .31388 L
s
[(0.6)] .59524 .29513 0 1 Mshowa
.78571 .30763 m
.78571 .31388 L
s
[(0.8)] .78571 .29513 0 1 Mshowa
.97619 .30763 m
.97619 .31388 L
s
[(1)] .97619 .29513 0 1 Mshowa
.125 Mabswid
.07143 .30763 m
.07143 .31138 L
s
.11905 .30763 m
.11905 .31138 L
s
.16667 .30763 m
.16667 .31138 L
s
.2619 .30763 m
.2619 .31138 L
s
.30952 .30763 m
.30952 .31138 L
s
.35714 .30763 m
.35714 .31138 L
s
.45238 .30763 m
.45238 .31138 L
s
.5 .30763 m
.5 .31138 L
s
.54762 .30763 m
.54762 .31138 L
s
.64286 .30763 m
.64286 .31138 L
s
.69048 .30763 m
.69048 .31138 L
s
.7381 .30763 m
.7381 .31138 L
s
.83333 .30763 m
.83333 .31138 L
s
.88095 .30763 m
.88095 .31138 L
s
.92857 .30763 m
.92857 .31138 L
s
.25 Mabswid
0 .30763 m
1 .30763 L
s
.02381 .01923 m
.03006 .01923 L
s
gsave
.01131 .01923 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.02381 .11536 m
.03006 .11536 L
s
gsave
.01131 .11536 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.02381 .2115 m
.03006 .2115 L
s
gsave
.01131 .2115 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.02381 .40377 m
.03006 .40377 L
s
gsave
.01131 .40377 -49.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.02381 .4999 m
.03006 .4999 L
s
gsave
.01131 .4999 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.02381 .59604 m
.03006 .59604 L
s
gsave
.01131 .59604 -49.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(7.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.125 Mabswid
.02381 .03846 m
.02756 .03846 L
s
.02381 .05768 m
.02756 .05768 L
s
.02381 .07691 m
.02756 .07691 L
s
.02381 .09614 m
.02756 .09614 L
s
.02381 .13459 m
.02756 .13459 L
s
.02381 .15382 m
.02756 .15382 L
s
.02381 .17304 m
.02756 .17304 L
s
.02381 .19227 m
.02756 .19227 L
s
.02381 .23073 m
.02756 .23073 L
s
.02381 .24995 m
.02756 .24995 L
s
.02381 .26918 m
.02756 .26918 L
s
.02381 .28841 m
.02756 .28841 L
s
.02381 .32686 m
.02756 .32686 L
s
.02381 .34609 m
.02756 .34609 L
s
.02381 .36531 m
.02756 .36531 L
s
.02381 .38454 m
.02756 .38454 L
s
.02381 .42299 m
.02756 .42299 L
s
.02381 .44222 m
.02756 .44222 L
s
.02381 .46145 m
.02756 .46145 L
s
.02381 .48068 m
.02756 .48068 L
s
.02381 .51913 m
.02756 .51913 L
s
.02381 .53836 m
.02756 .53836 L
s
.02381 .55758 m
.02756 .55758 L
s
.02381 .57681 m
.02756 .57681 L
s
.02381 0 m
.02756 0 L
s
.02381 .61526 m
.02756 .61526 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01648 m
.02605 .14333 L
.02846 .25751 L
.03279 .41385 L
.03543 .48212 L
.03793 .53023 L
.04018 .56139 L
.04145 .57444 L
.04262 .58382 L
.04376 .59063 L
.04498 .59559 L
.04614 .59815 L
.0472 .59882 L
.04843 .5977 L
.04913 .59623 L
.04978 .59434 L
.05097 .58966 L
.05224 .58304 L
.055 .56361 L
.05759 .53996 L
.06244 .48553 L
.07312 .34318 L
.08439 .19806 L
.09401 .10176 L
.09665 .08134 L
.09948 .06253 L
.10213 .04786 L
.10458 .03684 L
.10698 .02841 L
.10821 .025 L
.10954 .02201 L
.11086 .01971 L
.1121 .01818 L
.11282 .01757 L
.11358 .01713 L
.11423 .01694 L
.11494 .0169 L
.11622 .0173 L
.11739 .0182 L
.11804 .0189 L
.11874 .01983 L
.12002 .02196 L
.12248 .0276 L
.12474 .03454 L
.129 .05167 L
.13368 .07611 L
.14313 .13979 L
.16421 .31675 L
.18347 .469 L
.193 .52689 L
Mistroke
.19803 .55112 L
.20339 .57164 L
.20604 .57972 L
.20854 .58603 L
.21097 .59097 L
.2132 .59446 L
.21533 .59686 L
.2164 .59772 L
.21757 .59839 L
.21875 .5988 L
.22002 .59893 L
.22121 .59876 L
.22229 .59837 L
.22348 .59768 L
.22459 .59678 L
.22581 .59553 L
.22712 .59388 L
.22979 .58952 L
.23223 .5844 L
.23671 .57234 L
.24142 .55613 L
.25135 .5115 L
.26219 .44982 L
.28348 .3078 L
.30281 .18093 L
.31247 .1264 L
.32293 .07795 L
.32773 .06005 L
.33281 .04437 L
.33714 .03375 L
.3419 .0251 L
.34441 .02185 L
.34573 .02049 L
.34713 .01932 L
.34836 .01853 L
.34901 .0182 L
.34971 .01791 L
.35094 .01757 L
.35209 .01746 L
.35322 .01752 L
.35445 .0178 L
.35574 .01833 L
.35694 .01902 L
.35909 .02078 L
.36139 .02337 L
.36409 .02734 L
.36702 .03275 L
.37234 .04543 L
.38229 .07841 L
.39174 .11947 L
Mistroke
.40215 .17344 L
.42318 .29922 L
.44424 .42612 L
.46349 .52204 L
.473 .55725 L
.47839 .57282 L
.48338 .58422 L
.48585 .58873 L
.48818 .59229 L
.4903 .59494 L
.49253 .59711 L
.49369 .59799 L
.49497 .59876 L
.49613 .59927 L
.49722 .5996 L
.49849 .59978 L
.49966 .59977 L
.50031 .59969 L
.50101 .59954 L
.50228 .5991 L
.5035 .59849 L
.50462 .59776 L
.50713 .59552 L
.50935 .59289 L
.51169 .58945 L
.51665 .57989 L
.52207 .56606 L
.53296 .52834 L
.54308 .48278 L
.58215 .25394 L
.60207 .14018 L
.61256 .09105 L
.6183 .06865 L
.62367 .05101 L
.62885 .03725 L
.63358 .02769 L
.63628 .02357 L
.63884 .02058 L
.64024 .01933 L
.64154 .01841 L
.64227 .018 L
.64297 .01768 L
.64376 .01739 L
.64448 .01721 L
.6456 .01708 L
.64682 .01714 L
.6481 .01743 L
.64929 .01791 L
.65041 .01854 L
.65142 .01927 L
Mistroke
.65371 .02145 L
.65616 .02463 L
.65883 .02904 L
.66367 .03961 L
.66854 .05348 L
.6731 .06931 L
.6835 .11485 L
.70452 .23865 L
.72305 .36493 L
.74328 .49285 L
.74858 .52079 L
.75423 .54683 L
.75912 .56577 L
.76441 .58208 L
.76723 .58888 L
.76983 .5939 L
.77231 .59754 L
.77357 .59895 L
.77494 .60015 L
.77619 .60092 L
.77732 .60137 L
.77864 .60157 L
.77988 .60145 L
.78103 .60107 L
.78209 .60048 L
.78325 .59958 L
.78449 .59833 L
.78687 .59505 L
.78938 .59038 L
.79386 .57888 L
.79868 .56206 L
.80395 .53855 L
.81342 .48397 L
.82223 .42095 L
.84096 .26371 L
.85082 .17991 L
.86126 .1016 L
.86655 .06921 L
.86935 .05462 L
.87236 .04123 L
.87513 .03122 L
.87765 .02412 L
.87887 .02144 L
.88019 .01907 L
.88144 .0174 L
.8826 .01633 L
.88387 .01572 L
.88458 .01564 L
.88524 .01572 L
.88645 .01631 L
Mistroke
.88772 .01752 L
.88887 .01915 L
.88993 .02113 L
.89236 .0273 L
.89498 .03664 L
.89738 .04758 L
.90275 .08063 L
.90757 .12 L
.91268 .17117 L
.92186 .28278 L
.93186 .41897 L
.93711 .4874 L
.94263 .54887 L
.94472 .5676 L
.94695 .58392 L
.94824 .59132 L
.9494 .59662 L
.95057 .60048 L
.95167 .60266 L
.95268 .60332 L
.95374 .60254 L
.95465 .60061 L
.95565 .59705 L
.95672 .59145 L
.95787 .58326 L
.95995 .56231 L
.96204 .53252 L
.96431 .48893 L
.96645 .43591 L
.96844 .37543 L
.9722 .22753 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[106]:=",
  ImageSize->{244.625, 151.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003d0000Ub000`400?l00000o`00003om03oool0
0?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03o
ool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo00090?ooo`03
0000003oool0oooo0080oooo0P0000040?ooo`8000000`3oool01P000000oooo0?ooo`3oool00000
0?ooo`D000000P3oool200000140oooo0P00002i0?ooo`002@3oool00`000000oooo0?ooo`070?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2h0?ooo`002@3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`2h0?ooo`0000<0oooo0000000000000P0000050?ooo`030000003oool0oooo00L0oooo0P000004
0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool03P3oool2000002/0oooo0`00000e0?ooo`<00000:`3o
ool200000100oooo00<000000?ooo`3oool00P3oool000L0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool03P3oool3000000h0oooo0`00000Y0?ooo`80
000000<0oooo000000000000<`3oool2000000030?ooo`000000oooo02T0oooo00<000000?ooo`00
0000403oool00`000000oooo0?ooo`020?ooo`001`3oool4000000T0oooo0`0000090?ooo`800000
103oool200000140oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`00000Y0?ooo`05
0000003oool0oooo0?ooo`000000<P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02H0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo0080oooo000`0?oo
o`030<30`02@T900`<300080oooo00D0T92@0<30`02PX:00oooo0000000?0?ooo`050000003oool0
oooo0?ooo`0000009`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`050000003oool0oooo0?ooo`000000
3`3oool00`000000oooo0?ooo`020?ooo`00<@3oool02030`<00oooo0?ooo`3oool0/;2`0?ooo`2P
X:00oooo0P00000>0?ooo`050000003oool0oooo0?ooo`0000009P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0U
0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`020?ooo`00:P3oool0
103Ph>00P8200820P020P8030?ooo`090<30`03oool0oooo0?ooo`30`<00oooo0820P03oool00000
00h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02D0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo0080oooo000a0?oo
o`090<30`03oool0oooo0?ooo`2`/;00oooo092@T03oool0000000h0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080oooo000`0?ooo`80/;2`0`3o
ool01@2PX:00/;2`0;2`/03oool0000000h0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0080oooo000i0?ooo`8000003@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool003T0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00P3oool003T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool003T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00P3oool003T0oooo0P00000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`00>@3oool2000000`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo000i0?ooo`800000303oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool0
03T0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`020?ooo`00503oool2000000<0oooo00H000000?ooo`3oool0oooo0000003oool5
00000080oooo0P00000A0?ooo`800000303oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00P3oool001<0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0>0?ooo`800000303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`800000303o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool000d0oooo100000030?ooo`800000103oool00`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`<000002`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool001@0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00h0oooo0P00000<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00503oool3000000T0oooo0P00
00040?ooo`800000203oool00`30`<00T92@0<30`0020?ooo`04092@T030`<00X:2P0?ooo`800000
2`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool00340oooo00P0`<300?ooo`3oool0oooo0;2`/03oool0X:2P0?ooo`8000002`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool002X0
oooo00@0h>3P0820P020P800P8200`3oool02030`<00oooo0?ooo`3oool0`<300?ooo`20P800oooo
0P00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`00<@3oool02030`<00oooo0?ooo`3oool0/;2`0?ooo`2@T900oooo0P00000;0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`00<03oool20;2`/0<0oooo00@0X:2P0;2`/02`/;00oooo0P00000;0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`00>@3oool2000000/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo000i0?ooo`8000002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00`3oool003T0oooo0P00000;0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`00>@3oool2000000/0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo000i0?oo
o`8000002`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00`3oool003T0oooo0P00000:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`030?ooo`00>@3oool2000000X0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo000i0?ooo`8000002P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool000L0oooo100000030?ooo`800000103oool2000000<0oooo00H000000?ooo`3oool0oooo0000
003oool500000080oooo0P00000A0?ooo`8000002P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00`3oool000L0oooo00<000000?ooo`3oool02@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00h0oooo0P00000:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`00203oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool03P3oool2000000X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo00000`3oool00000
00000002000000@0oooo00<000000?ooo`3oool0203oool2000000@0oooo00<000000?ooo`000000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03P3oool3000000T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0
oooo00070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00h0oooo0P00000:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`00203oool2000000X0oooo0`0000090?ooo`800000103oool20000
00P0oooo00<0`<30092@T030`<000P3oool0102@T900`<300:2PX03oool2000000X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo000a0?oo
o`080<30`03oool0oooo0?ooo`2`/;00oooo0:2PX03oool2000000X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo000Z0?ooo`040>3Ph020
P800P8200820P0<0oooo00P0`<300?ooo`3oool0oooo0<30`03oool0P8200?ooo`8000002P3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool0
0340oooo00P0`<300?ooo`3oool0oooo0;2`/03oool0T92@0?ooo`8000002@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00300oooo0P2`
/;030?ooo`040:2PX02`/;00/;2`0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool003T0oooo0P0000090?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`00>@3oool2
000000T0oooo00<000000?ooo`3oool0303oool010000000oooo0?ooo`3oool2000000@0oooo0P00
00030?ooo`@000001P3oool00`000000oooo0?ooo`0<0?ooo`800000103oool3000000@0oooo0`00
000D0?ooo`8000000`3oool3000000<0oooo0`00000>0?ooo`030000003oool0oooo00D0oooo0P00
00040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`060?ooo`D000000P3oool003T0oooo0P0000090?ooo`030000003oool0oooo00`0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00L0oooo0P0000040?ooo`00>@3oool2000000T0oooo00<000000?ooo`3oool0303oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`000000
1000000C0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3o
ool2000000@0oooo000i0?ooo`8000002@3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00/0oooo00@000000?ooo`3oool000001P3oool00`000000oooo000000020?ooo`030000
003oool0oooo0180oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`<000003`3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000T0oooo0P0000040?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool01`3oool2000000@0oooo000i0?ooo`8000002@3oool00`00
0000oooo0?ooo`0<0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01P3oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool00000
1P3oool01P000000oooo0?ooo`000000oooo000001@0oooo00H000000?ooo`3oool000000?ooo`00
00070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`070?ooo`800000103oool003T0oooo0P0000090?ooo`030000003oool0oooo00`0oooo
00@000000?ooo`3oool0oooo0P00000:0?ooo`8000001`3oool00`000000oooo0?ooo`0<0?ooo`80
00001`3oool010000000oooo0?ooo`3oool2000001D0oooo0P0000020?ooo`030000003oool0oooo
00D0oooo0`00000>0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`800000103oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`00>@3oool2000000T0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0
oooo000i0?ooo`8000002@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool003T0oooo0P0000090?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`00>@3oool2000000T0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00@0oooo000e0?oo
okl00000000i0?ooo`8000001`3oool2000000P0oooo00<000000?ooo`3oool01@3oool2000000P0
oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool01P3oool2000000L0oooo
00<000000?ooo`3oool01@3oool00`000000oooo000000060?ooo`030000003oool0000000@0oooo
000i0?ooo`800000203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo000001`0oooo
00D000000?ooo`3oool0oooo0000000F0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
0000103oool003T0oooo0P0000080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`00>@3oool2000000P0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo000i0?ooo`800000203oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool0
03T0oooo0P0000080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`040?ooo`00>@3oool00`000000oooo000000070?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`00>@3oool3000000L0oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
000i0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00@0oooo000i0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo000i0?oo
o`<000001`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0103oool003T0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool003T0oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool003T0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0103oool000L0oooo100000030?ooo`800000103oool2
000000<0oooo00H000000?ooo`3oool0oooo0000003oool500000080oooo0P00000A0?ooo`<00000
1P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
103oool000L0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool000P0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool000T0oooo00<000000?ooo`3oool0
203oool2000000@0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool03P3oool00`000000oooo000000060?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`001`3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`<000001P3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
00P0oooo0P00000:0?ooo`<000002@3oool2000000@0oooo0P00000A0?ooo`030000003oool00000
00H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo000`0?ooo`030<30`02@T900`<300080oooo00L0T92@0<30`02PX:00oooo0000003oool0
000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00@0oooo000a0?ooo`080<30`03oool0oooo0?ooo`2`/;00oooo0:2PX03oool3000000H0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
000Z0?ooo`040>3Ph020P800P8200820P0<0oooo00/0`<300?ooo`3oool0oooo0<30`03oool0P820
0?ooo`000000oooo000000060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`00<@3oool02`30`<00oooo0?ooo`3oool0/;2`0?ooo`2@T900
oooo0000003oool0000000H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00@0oooo000`0?ooo`80/;2`0`3oool01`2PX:00/;2`0;2`/03oool00000
0?ooo`0000001P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool003T0oooo0`0000060?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`040?ooo`00>@3oool00`000000oooo000000060?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`00
>@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`00>@3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`00
>@3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo000i0?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
000i0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo000i0?ooo`80000000<0oooo0000003oool00`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool001@0oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000oooo1@0000020?ooo`800000
4@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`004`3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00h0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool001H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00D0oooo000D0?ooo`800000103oool00`000000oooo00000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`@00000103o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool001@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool01@3oool001@0oooo0`0000090?ooo`800000103oool2000000P0oooo00<0`<30092@T030`<00
0P3oool01@2@T900`<300:2PX03oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool00340oooo
00T0`<300?ooo`3oool0oooo0;2`/03oool0X:2P0?ooo`0000000P3oool01@000000oooo0?ooo`3o
ool0000001T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`00:P3oool0
103Ph>00P8200820P020P8030?ooo`080<30`03oool0oooo0?ooo`30`<00oooo0820P03oool20000
00030?ooo`000000oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool0
000000L0oooo000a0?ooo`090<30`03oool0oooo0?ooo`2`/;00oooo092@T03oool000000080oooo
00D000000?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0G0?ooo`050000003oool0oooo0?ooo`0000001`3oool00300
oooo0P2`/;030?ooo`050:2PX02`/;00/;2`0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000001T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo01L0oooo00D000000?ooo`3oool0oooo000000070?ooo`00>@3oool2000000030?ooo`000000
oooo0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0000000L0oooo000i
0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?oo
o`3oool0000000L0oooo000i0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
5`3oool01@000000oooo0?ooo`3oool0000000L0oooo000i0?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0603oool01@000000oooo0?ooo`3oool0000000L0oooo000i0?ooo`80
000000D0oooo0000003oool0oooo0000000K0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`050000003oool0oooo0?ooo`0000001`3oool0
03T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0I0?ooo`040000003oool0
oooo000000L0oooo000i0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool06@3o
ool010000000oooo0?ooo`0000070?ooo`00>@3oool01`000000oooo0?ooo`3oool000000?ooo`00
0000703oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo000000080?ooo`002@3oool00`000000oooo0?ooo`020?ooo`800000
103oool2000000<0oooo00H000000?ooo`3oool0oooo0000003oool500000080oooo0P00000A0?oo
o`8000000P3oool00`000000oooo0000000L0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0000000P0oooo00090?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`070000003oool0
oooo0?ooo`000000oooo0000000M0?ooo`050000003oool0oooo0?ooo`000000;`3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0000000P0oooo00090?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0>0?ooo`070000003oool0oooo0?ooo`000000oooo0000000M
0?ooo`050000003oool0oooo0?ooo`000000;`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02h0oooo00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0000000P0oooo
000:0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`030000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo0`0000000`3oool00000
0000000N0?ooo`80000000<0oooo0000003oool0<03oool00`000000oooo0?ooo`0200000300oooo
00D000000?ooo`3oool0oooo0000000M0?ooo`030000003oool0000000P0oooo00070?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`800000<`3oool300000380oooo0`00000O
0?ooo`800000203oool000L0oooo100000090?ooo`<000002@3oool2000000@0oooo0P0000080?oo
o`030<30`02@T900`<300080oooo00D0T92@0<30`02PX:00oooo0000002`0?ooo`030000003oool0
oooo00L0oooo000a0?ooo`090<30`03oool0oooo0?ooo`2`/;00oooo0:2PX03oool000000;X0oooo
000Z0?ooo`040>3Ph020P800P8200820P0<0oooo00P0`<300?ooo`3oool0oooo0<30`03oool0P820
0?ooo`800000^@3oool00340oooo00L0`<300?ooo`3oool0oooo0;2`/03oool0T92@0;`0oooo000`
0?ooo`80/;2`0`3oool00`2PX:00/;2`0;2`/02l0?ooo`00m03oool00?@0oooo003d0?ooo`00m03o
ool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00
m03oool00?@0oooo0000\
\>"],
  ImageRangeCache->{{{0, 243.625}, {150.125, 0}} -> {-0.319397, \
-1.02588*^-09, 0.00551832, 1.36671*^-11}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[106]="]
}, Open  ]],

Cell["Example 4", "Subsubsection"],

Cell["Boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {x^2*\(y''\)[x] + x*\(y'\)[x] + x^2*y[x] \[Equal] 0, 
        y[0] \[Equal] 1}\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(x\^2\ y[x]\), "+", 
            RowBox[{"x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{\(x\^2\), " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], "==", "0"}], 
        ",", \(y[0] == 1\)}], "}"}]], "Output",
  CellLabel->"Out[107]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 7]\)], "Input",
  CellLabel->"In[108]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \(LdeApprox::"regsp" \(\(:\)\(\ \)\) 
      "regular singular point encountered: \!\(x\) = \!\(0\)"\)], "Message",
  CellLabel->"From In[108]:="],

Cell[BoxData[
    \({y[x] \[Rule] 
        1 - x\^2\/4 + \(1510505\ x\^3\)\/76219020477059 + \(1190858229296\ \
x\^4\)\/76219020477059 + \(461039104\ x\^5\)\/76219020477059 - \(34286045760\ \
x\^6\)\/76219020477059 + \(1317428480\ x\^7\)\/76219020477059}\)], "Output",
  CellLabel->"Out[108]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " tot find exact solution of the BVP."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[109]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] BesselJ[0, x]}}\)], "Output",
  CellLabel->"Out[109]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\), {x, 0, 
        1}]\)], "Input",
  CellLabel->"In[110]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.279928 3.967e+007 [
[.21429 .26743 -9 -9 ]
[.21429 .26743 9 0 ]
[.40476 .26743 -9 -9 ]
[.40476 .26743 9 0 ]
[.59524 .26743 -9 -9 ]
[.59524 .26743 9 0 ]
[.78571 .26743 -9 -9 ]
[.78571 .26743 9 0 ]
[.97619 .26743 -3 -9 ]
[.97619 .26743 3 0 ]
[.01131 .04191 -39 -6.25 ]
[.01131 .04191 0 6.25 ]
[.01131 .12125 -39 -6.25 ]
[.01131 .12125 0 6.25 ]
[.01131 .20059 -39 -6.25 ]
[.01131 .20059 0 6.25 ]
[.01131 .35927 -33 -6.25 ]
[.01131 .35927 0 6.25 ]
[.01131 .43861 -33 -6.25 ]
[.01131 .43861 0 6.25 ]
[.01131 .51795 -33 -6.25 ]
[.01131 .51795 0 6.25 ]
[.01131 .59729 -33 -6.25 ]
[.01131 .59729 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .27993 m
.21429 .28618 L
s
[(0.2)] .21429 .26743 0 1 Mshowa
.40476 .27993 m
.40476 .28618 L
s
[(0.4)] .40476 .26743 0 1 Mshowa
.59524 .27993 m
.59524 .28618 L
s
[(0.6)] .59524 .26743 0 1 Mshowa
.78571 .27993 m
.78571 .28618 L
s
[(0.8)] .78571 .26743 0 1 Mshowa
.97619 .27993 m
.97619 .28618 L
s
[(1)] .97619 .26743 0 1 Mshowa
.125 Mabswid
.07143 .27993 m
.07143 .28368 L
s
.11905 .27993 m
.11905 .28368 L
s
.16667 .27993 m
.16667 .28368 L
s
.2619 .27993 m
.2619 .28368 L
s
.30952 .27993 m
.30952 .28368 L
s
.35714 .27993 m
.35714 .28368 L
s
.45238 .27993 m
.45238 .28368 L
s
.5 .27993 m
.5 .28368 L
s
.54762 .27993 m
.54762 .28368 L
s
.64286 .27993 m
.64286 .28368 L
s
.69048 .27993 m
.69048 .28368 L
s
.7381 .27993 m
.7381 .28368 L
s
.83333 .27993 m
.83333 .28368 L
s
.88095 .27993 m
.88095 .28368 L
s
.92857 .27993 m
.92857 .28368 L
s
.25 Mabswid
0 .27993 m
1 .27993 L
s
.02381 .04191 m
.03006 .04191 L
s
gsave
.01131 .04191 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .12125 m
.03006 .12125 L
s
gsave
.01131 .12125 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .20059 m
.03006 .20059 L
s
gsave
.01131 .20059 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .35927 m
.03006 .35927 L
s
gsave
.01131 .35927 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .43861 m
.03006 .43861 L
s
gsave
.01131 .43861 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .51795 m
.03006 .51795 L
s
gsave
.01131 .51795 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .59729 m
.03006 .59729 L
s
gsave
.01131 .59729 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.125 Mabswid
.02381 .06174 m
.02756 .06174 L
s
.02381 .08158 m
.02756 .08158 L
s
.02381 .10141 m
.02756 .10141 L
s
.02381 .14108 m
.02756 .14108 L
s
.02381 .16092 m
.02756 .16092 L
s
.02381 .18075 m
.02756 .18075 L
s
.02381 .22042 m
.02756 .22042 L
s
.02381 .24026 m
.02756 .24026 L
s
.02381 .26009 m
.02756 .26009 L
s
.02381 .29976 m
.02756 .29976 L
s
.02381 .3196 m
.02756 .3196 L
s
.02381 .33943 m
.02756 .33943 L
s
.02381 .3791 m
.02756 .3791 L
s
.02381 .39894 m
.02756 .39894 L
s
.02381 .41877 m
.02756 .41877 L
s
.02381 .45844 m
.02756 .45844 L
s
.02381 .47828 m
.02756 .47828 L
s
.02381 .49811 m
.02756 .49811 L
s
.02381 .53778 m
.02756 .53778 L
s
.02381 .55762 m
.02756 .55762 L
s
.02381 .57745 m
.02756 .57745 L
s
.02381 .02207 m
.02756 .02207 L
s
.02381 .00224 m
.02756 .00224 L
s
.02381 .61712 m
.02756 .61712 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .27993 m
.02499 .27993 L
.02605 .27993 L
.02729 .27993 L
.02846 .27993 L
.02954 .27993 L
.03053 .27993 L
.03163 .27993 L
.03279 .27993 L
.03786 .27993 L
.04035 .27993 L
.04152 .27993 L
.04262 .27993 L
.04373 .27993 L
.04495 .27993 L
.04602 .27993 L
.04716 .27993 L
.04848 .27993 L
.04973 .27993 L
.05084 .27993 L
.05205 .27993 L
.05331 .27993 L
.05468 .27993 L
.05746 .27993 L
.06004 .27994 L
.06244 .27994 L
.06506 .27995 L
.06791 .27996 L
.07308 .27998 L
.07812 .28001 L
.08278 .28005 L
.09335 .28016 L
.09869 .28023 L
.10458 .28033 L
.12393 .28075 L
.14478 .28134 L
.16443 .28189 L
.16981 .28202 L
.17556 .28215 L
.18095 .28225 L
.18592 .28231 L
.18841 .28234 L
.19105 .28236 L
.19241 .28237 L
.19369 .28237 L
.19443 .28238 L
.19509 .28238 L
.19587 .28238 L
.1966 .28238 L
.19781 .28238 L
Mistroke
.1991 .28238 L
.20032 .28237 L
.20143 .28237 L
.20273 .28236 L
.20413 .28234 L
.20668 .28231 L
.20897 .28228 L
.21147 .28223 L
.21651 .28211 L
.22119 .28195 L
.22555 .28177 L
.23603 .28118 L
.24594 .28041 L
.26451 .27838 L
.28446 .27528 L
.30289 .2716 L
.34221 .26174 L
.38001 .25152 L
.40102 .24668 L
.41022 .24496 L
.41508 .24419 L
.42027 .24347 L
.4254 .24288 L
.43006 .24246 L
.4323 .24229 L
.43474 .24215 L
.43703 .24204 L
.43915 .24197 L
.4403 .24195 L
.44153 .24193 L
.44269 .24192 L
.44375 .24191 L
.44499 .24192 L
.44569 .24193 L
.44634 .24194 L
.44753 .24196 L
.4488 .242 L
.45 .24205 L
.4513 .24211 L
.45365 .24224 L
.45644 .24246 L
.45901 .2427 L
.46374 .24328 L
.46879 .24407 L
.47791 .24602 L
.48874 .24921 L
.4986 .25298 L
.51776 .26274 L
.53855 .27695 L
.57943 .3145 L
Mistroke
.6188 .35747 L
.65666 .39547 L
.66662 .40336 L
.67608 .4096 L
.6813 .41243 L
.68699 .41497 L
.6895 .41589 L
.69217 .41673 L
.69446 .41734 L
.69697 .41788 L
.69958 .41829 L
.701 .41845 L
.70168 .41852 L
.70233 .41856 L
.70358 .41863 L
.70471 .41866 L
.70593 .41865 L
.70662 .41863 L
.70726 .41861 L
.7079 .41857 L
.70859 .41852 L
.70983 .41839 L
.71131 .4182 L
.71266 .41797 L
.71545 .41735 L
.71839 .41647 L
.72339 .41445 L
.72803 .41194 L
.73309 .4085 L
.73857 .40392 L
.7491 .3925 L
.75904 .3785 L
.77763 .34375 L
.79753 .29469 L
.81857 .23157 L
.85648 .10606 L
.87594 .05093 L
.88155 .03849 L
.88687 .02869 L
.89164 .02186 L
.89434 .01892 L
.89684 .01685 L
.89813 .01604 L
.89884 .01568 L
.8995 .01539 L
.90066 .015 L
.90194 .01476 L
.90266 .01472 L
.90333 .01473 L
.9046 .01491 L
Mistroke
.90531 .0151 L
.90596 .01534 L
.90745 .01608 L
.90863 .0169 L
.90975 .01785 L
.91229 .02071 L
.91476 .02444 L
.91742 .02958 L
.9224 .04256 L
.92714 .05931 L
.93604 .10391 L
.94107 .13759 L
.94562 .17408 L
.95584 .27892 L
.9653 .4086 L
.97422 .56417 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[110]:=",
  ImageSize->{223.875, 138.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003O0000RR000`400?l00000o`00003og`3oool0
0=l0oooo003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3o
ool002T0oooo00<000000?ooo`3oool0/`3oool002T0oooo0P00002d0?ooo`00:@3oool00`000000
oooo0?ooo`2c0?ooo`00:@3oool00`000000oooo0?ooo`2O0?ooo`@00000403oool002T0oooo0P00
002O0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`001`3oool3000000<0oooo00H00000
0?ooo`3oool0oooo0000003oool500000080oooo0P00000=0?ooo`030000003oool0oooo09d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`001`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00d0oooo00070?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00003
0?ooo`0000000000008000000P3oool3000000@0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000009d0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0<0?ooo`00203oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0303oool000P0oooo0`0000090?ooo`800000103oool2000000P0oooo00<0`<300;2`
/02`/;000P3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool02`3oool002H0oooo00@0/;2`0?ooo`3oool00000W@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00/0oooo000N0?ooo`040>3Ph020P800P8200820P080oooo00<0X:2P0<30
`01PH6000P3oool2000009/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?oo
o`00903oool00`2@T900oooo0:2PX0020?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0;0?ooo`00903oool00`2PX:00/;2`0<30`0020?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?ooo`00:@3o
ool2000009X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`00:@3oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool0
02T0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo000Y0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0:0?ooo`002@3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`000000
100000020?ooo`8000003@3oool2000009T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0:0?ooo`002P3oool01`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2H0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool02P3oool000L0oooo1@0000030?ooo`03
0000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00X0oooo00000`3oool000000000000200000080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0:
0?ooo`00203oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000009P0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`002@3oool2000000T0oooo0P000004
0?ooo`8000003@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool02@3oool002@0oooo00<0`<300;2`/02`/;000P3oool00`000000oooo0?ooo`2F0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool002H0oooo00<0/;2`0?ooo`3o
ool00P00002G0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool001h0oooo
00@0h>3P0820P020P800P8200P3oool00`2PX:00`<30061PH0020?ooo`030000003oool0oooo09H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`00903oool00`2@T900oooo
0:2PX0020?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`090?ooo`00903oool00`2PX:00/;2`0<30`0020?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`090?ooo`00:@3oool2000009H0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`00:@3oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0203oool002T0oooo00<000000?ooo`3o
ool0U03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo000Y0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`080?ooo`001`3o
ool400000080oooo00H000000?ooo`3oool0oooo0000003oool500000080oooo0P00000=0?ooo`80
0000U@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00P0oooo00070?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0203oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo09<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`00
00<0oooo0000000000000P0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000009@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`001`3oool010000000oooo
0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool01`3oool000P0oooo0P00000:0?ooo`800000103oool20000
00P0oooo00<0`<300;2`/02`/;000P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01`3oool002H0oooo00@0/;2`0?ooo`3oool00000U03oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo000N0?ooo`040>3Ph020P800P8200820
P080oooo00<0X:2P0<30`01PH6000P3oool2000009<0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`070?ooo`00903oool00`2@T900oooo0:2PX0020?ooo`030000003oool0oooo01T0
oooo0P0000040?ooo`8000000`3oool4000001D0oooo0P0000040?ooo`8000001@3oool3000001<0
oooo0P0000040?ooo`8000000`3oool3000001H0oooo0P0000040?ooo`800000103oool2000001L0
oooo00<000000?ooo`3oool01@0000020?ooo`00903oool00`2PX:00/;2`0<30`0020?ooo`030000
003oool0oooo01P0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0E0?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000001@0oooo00@000000?ooo`3oool00000203oool010000000oooo
00000000000F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool002T0oooo
00<000000?ooo`3oool0603oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo01@0
oooo00@000000?ooo`3oool00000203oool500000180oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000D0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`000000
00005P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000Y0?ooo`800000
6@3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo01<0oooo00@000000?ooo`3o
ool000001`3oool9000000l0oooo00@000000?ooo`3oool00000203oool3000001D0oooo00@00000
0?ooo`3oool000002@3oool2000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`00:@3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool00000503oool010000000oooo0?ooo`0000020?ooo`D000000P3oool00`000000
oooo000000040?ooo`8000003@3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
01@0oooo00@000000?ooo`3oool00000203oool2000000030?ooo`000000oooo01D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`0I0?oo
o`8000002P3oool2000001H0oooo1@0000080?ooo`8000001P3oool4000000X0oooo0P00000:0?oo
o`<000005@3oool2000000X0oooo0P00000G0?ooo`040000003oool0oooo0?ooo`800000103oool0
02T0oooo00<000000?ooo`3oool0>P3oool4000001P0oooo0P00000g0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01P3oool002T0oooo0P00000h0?ooo`<000007P3oool2000003D0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00:@3oool00`000000oooo
0?ooo`0c0?ooo`@000008`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01P3oool002T0oooo00<000000?ooo`3oool0;03oool7000002P0oooo0P00
000a0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool002@0oooo^`000000
02T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00<0oooo3`0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool002T0oooo00<00000
0?ooo`3oool0G`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool01P3oool002T0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool002T0oooo0P00001R0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`00
:@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`060?ooo`00:@3oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00:@3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`050?ooo`00:@3oool2000006H0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00D0oooo000Y0?ooo`030000003oool0oooo06H0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00D0
oooo000Y0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00D0oooo000Y0?ooo`800000J03oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01@3oool000L0oooo10000002
0?ooo`060000003oool0oooo0?ooo`000000oooo1@0000020?ooo`8000003@3oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`050?ooo`001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1@3oool000P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo
00090?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool2000006`0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00D0oooo00070?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00D0oooo00080?ooo`80
00002P3oool2000000@0oooo0P0000080?ooo`030<30`02`/;00/;2`0080oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01@3oool002H0oooo00@0/;2`0?ooo`3oool00000L03oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool001h0oooo00@0h>3P0820P020P800
P8200P3oool00`2PX:00`<30061PH0020?ooo`800000L03oool2000001D0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`040?ooo`00903oool00`2@T900oooo0:2PX0020?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00@0oooo000T0?ooo`030:2PX02`/;00`<300080oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0103o
ool002T0oooo0P00001d0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`040?ooo`00:@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`040?ooo`00:@3oool00`000000
oooo0?ooo`1e0?ooo`8000002P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00@0
oooo000Y0?ooo`030000003oool0oooo07L0oooo0P0000060?ooo`800000:`3oool00`000000oooo
0?ooo`040?ooo`002@3oool3000000030?ooo`000000oooo0080oooo00<000000?ooo`0000001000
00020?ooo`8000003@3oool2000007X0oooo1P00000]0?ooo`030000003oool0oooo00@0oooo000:
0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3o
ool0103oool000L0oooo1@0000030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0[03oool00`000000
oooo0?ooo`040?ooo`001`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0[03oool00`000000oooo0?ooo`040?ooo`00203oool00`000000oooo000000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02P3oool200000:d0oooo00<000000?ooo`3oool0103oool000T0oooo0P0000090?oo
o`800000103oool2000000d0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`040?oo
o`00903oool00`30`<00/;2`0;2`/0020?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool00`3oool002H0oooo00<0/;2`0?ooo`3oool00P00002^0?ooo`030000003oool0oooo00<0oooo
000N0?ooo`040>3Ph020P800P8200820P080oooo00<0X:2P0<30`01PH6000P3oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo00<0oooo000T0?ooo`03092@T03oool0X:2P0080oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`030?ooo`00903oool00`2PX:00/;2`0<30`002
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00`3oool002T0oooo0P00002^0?oo
o`030000003oool0oooo00<0oooo000Y0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool00`3oool002T0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`030?ooo`00:@3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo00<0oooo00070?ooo`<000000`3oool0
1P000000oooo0?ooo`3oool000000?ooo`D000000P3oool2000000d0oooo0P00002^0?ooo`030000
003oool0oooo00<0oooo00070?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo00<0oooo00070?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo00<0oooo00070?ooo`<0
0000103oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool00`3oool000P0
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002^0?ooo`030000003oool0
oooo00<0oooo00080?ooo`<000002@3oool2000000@0oooo0P00000=0?ooo`030000003oool0oooo
0:h0oooo00<000000?ooo`3oool00P3oool002@0oooo00<0`<300;2`/02`/;000P3oool00`000000
oooo0?ooo`2^0?ooo`030000003oool0oooo0080oooo000V0?ooo`030;2`/03oool0oooo00800000
[`3oool00`000000oooo0?ooo`020?ooo`007P3oool0103Ph>00P8200820P020P8020?ooo`030:2P
X030`<00H61P0080oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`020?ooo`00903o
ool00`2@T900oooo0:2PX0020?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool00P3o
ool002@0oooo00<0X:2P0;2`/030`<000P3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0
oooo0080oooo000Y0?ooo`800000[`3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000
oooo0?ooo`2^0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`020?ooo`00203oool2000000<0oooo00H000000?ooo`3oool0oooo0000003oool500000080oooo
0P00000=0?ooo`800000[`3oool00`000000oooo0?ooo`020?ooo`001`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`020?ooo`00
1`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0[P3oool00`00
0000oooo0?ooo`020?ooo`00203oool2000000@0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000:l0oooo00<000000?oo
o`3oool00P3oool000L0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`020?ooo`00203oool2000000X0oooo0P000004
0?ooo`800000203oool00`30`<00/;2`0;2`/0020?ooo`030000003oool0oooo0;<0oooo000V0?oo
o`040;2`/03oool0oooo00000;D0oooo000N0?ooo`040>3Ph020P800P8200820P080oooo00<0X:2P
0<30`01PH6000P3oool200000;@0oooo000T0?ooo`03092@T03oool0X:2P0;P0oooo000T0?ooo`03
0:2PX02`/;00`<300;P0oooo003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00g`3oool00=l0oooo
003O0?ooo`00g`3oool00=l0oooo003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 222.875}, {137.313, 0}} -> {-0.233319, \
-8.41054*^-09, 0.00564587, 1.35544*^-10}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[110]="]
}, Open  ]],

Cell["Example 5", "Subsubsection"],

Cell["Initial value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\(y''\)[x] == \(-y[x]\) - 2*x*\(y'\)[x], 
        y[0] \[Equal] 0, \(y'\)[0] \[Equal] 1}\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", "]"}], "==", 
          RowBox[{\(-y[x]\), "-", 
            RowBox[{"2", " ", "x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}]}], 
        ",", \(y[0] == 0\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", "1"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[111]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[ivp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[112]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 
          5802888\/162557926871 + \(162140696512\ x\)\/162557926871 + \
\(4855352320\ x\^2\)\/162557926871 - \(101738521600\ x\^3\)\/162557926871 + \
\(112928757760\ x\^4\)\/487673780613 + \(694837248\ \
x\^5\)\/162557926871}}\)], "Output",
  CellLabel->"Out[112]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Unfortunately ",
    FontColor->RGBColor[0, 0, 0.500008]],
  StyleBox["DSolve",
    FontFamily->"Courier New",
    FontColor->RGBColor[0, 0, 0.500008]],
  StyleBox[" can not find exact solution of the IVP. ",
    FontColor->RGBColor[0, 0, 0.500008]]
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[113]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \($MaxExtraPrecision::"meprec" \(\(:\)\(\ \)\) 
      "In increasing internal precision while attempting to evaluate \!\(1 + \
\(4\\ \(\(Gamma[\(\(3\/4\)\)]\)\)\)\/\(Gamma[\(\(-\(\(1\/4\)\)\)\)]\)\), the \
limit $MaxExtraPrecision = \!\(49.99999999999999`\) was reached. Increasing \
the value of $MaxExtraPrecision may help resolve the uncertainty."\)], \
"Message",
  CellLabel->"From In[113]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[113]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \($MaxExtraPrecision\  = 1000\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(1000\)], "Output",
  CellLabel->"Out[114]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \($MaxExtraPrecision::"meprec" \(\(:\)\(\ \)\) 
      "In increasing internal precision while attempting to evaluate \!\(1 + \
\(4\\ \(\(Gamma[\(\(3\/4\)\)]\)\)\)\/\(Gamma[\(\(-\(\(1\/4\)\)\)\)]\)\), the \
limit $MaxExtraPrecision = \!\(1000.`\) was reached. Increasing the value of \
$MaxExtraPrecision may help resolve the uncertainty."\)], "Message",
  CellLabel->"From In[115]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[115]="]
}, Open  ]],

Cell["Nevertheless the exact solution is as follows.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = {{y[x] \[Rule] 
            1/2*Pi/Gamma[3/4]*Exp[\(-1\)/2*x^2]*x^\((1/2)\)*
              BesselI[1/4, 1/2*x^2]}}\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(\[ExponentialE]\^\(-\(x\^2\/2\)\)\ \[Pi]\ \@x\ \
BesselI[1\/4, x\^2\/2]\)\/\(2\ Gamma[3\/4]\)}}\)], "Output",
  CellLabel->"Out[116]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\), {x, 0, 
        1}]\)], "Input",
  CellLabel->"In[117]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309337 7993.63 [
[.21429 .29684 -9 -9 ]
[.21429 .29684 9 0 ]
[.40476 .29684 -9 -9 ]
[.40476 .29684 9 0 ]
[.59524 .29684 -9 -9 ]
[.59524 .29684 9 0 ]
[.78571 .29684 -9 -9 ]
[.78571 .29684 9 0 ]
[.97619 .29684 -3 -9 ]
[.97619 .29684 3 0 ]
[.01131 .06953 -48 -4.5 ]
[.01131 .06953 0 4.5 ]
[.01131 .14946 -48 -4.5 ]
[.01131 .14946 0 4.5 ]
[.01131 .2294 -48 -4.5 ]
[.01131 .2294 0 4.5 ]
[.01131 .38927 -42 -4.5 ]
[.01131 .38927 0 4.5 ]
[.01131 .46921 -42 -4.5 ]
[.01131 .46921 0 4.5 ]
[.01131 .54915 -42 -4.5 ]
[.01131 .54915 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30934 m
.21429 .31559 L
s
[(0.2)] .21429 .29684 0 1 Mshowa
.40476 .30934 m
.40476 .31559 L
s
[(0.4)] .40476 .29684 0 1 Mshowa
.59524 .30934 m
.59524 .31559 L
s
[(0.6)] .59524 .29684 0 1 Mshowa
.78571 .30934 m
.78571 .31559 L
s
[(0.8)] .78571 .29684 0 1 Mshowa
.97619 .30934 m
.97619 .31559 L
s
[(1)] .97619 .29684 0 1 Mshowa
.125 Mabswid
.07143 .30934 m
.07143 .31309 L
s
.11905 .30934 m
.11905 .31309 L
s
.16667 .30934 m
.16667 .31309 L
s
.2619 .30934 m
.2619 .31309 L
s
.30952 .30934 m
.30952 .31309 L
s
.35714 .30934 m
.35714 .31309 L
s
.45238 .30934 m
.45238 .31309 L
s
.5 .30934 m
.5 .31309 L
s
.54762 .30934 m
.54762 .31309 L
s
.64286 .30934 m
.64286 .31309 L
s
.69048 .30934 m
.69048 .31309 L
s
.7381 .30934 m
.7381 .31309 L
s
.83333 .30934 m
.83333 .31309 L
s
.88095 .30934 m
.88095 .31309 L
s
.92857 .30934 m
.92857 .31309 L
s
.25 Mabswid
0 .30934 m
1 .30934 L
s
.02381 .06953 m
.03006 .06953 L
s
[(-0.00003)] .01131 .06953 1 0 Mshowa
.02381 .14946 m
.03006 .14946 L
s
[(-0.00002)] .01131 .14946 1 0 Mshowa
.02381 .2294 m
.03006 .2294 L
s
[(-0.00001)] .01131 .2294 1 0 Mshowa
.02381 .38927 m
.03006 .38927 L
s
[(0.00001)] .01131 .38927 1 0 Mshowa
.02381 .46921 m
.03006 .46921 L
s
[(0.00002)] .01131 .46921 1 0 Mshowa
.02381 .54915 m
.03006 .54915 L
s
[(0.00003)] .01131 .54915 1 0 Mshowa
.125 Mabswid
.02381 .08552 m
.02756 .08552 L
s
.02381 .1015 m
.02756 .1015 L
s
.02381 .11749 m
.02756 .11749 L
s
.02381 .13348 m
.02756 .13348 L
s
.02381 .16545 m
.02756 .16545 L
s
.02381 .18144 m
.02756 .18144 L
s
.02381 .19743 m
.02756 .19743 L
s
.02381 .21341 m
.02756 .21341 L
s
.02381 .24539 m
.02756 .24539 L
s
.02381 .26138 m
.02756 .26138 L
s
.02381 .27736 m
.02756 .27736 L
s
.02381 .29335 m
.02756 .29335 L
s
.02381 .32532 m
.02756 .32532 L
s
.02381 .34131 m
.02756 .34131 L
s
.02381 .3573 m
.02756 .3573 L
s
.02381 .37329 m
.02756 .37329 L
s
.02381 .40526 m
.02756 .40526 L
s
.02381 .42125 m
.02756 .42125 L
s
.02381 .43724 m
.02756 .43724 L
s
.02381 .45322 m
.02756 .45322 L
s
.02381 .4852 m
.02756 .4852 L
s
.02381 .50118 m
.02756 .50118 L
s
.02381 .51717 m
.02756 .51717 L
s
.02381 .53316 m
.02756 .53316 L
s
.02381 .05354 m
.02756 .05354 L
s
.02381 .03755 m
.02756 .03755 L
s
.02381 .02157 m
.02756 .02157 L
s
.02381 .00558 m
.02756 .00558 L
s
.02381 .56513 m
.02756 .56513 L
s
.02381 .58112 m
.02756 .58112 L
s
.02381 .59711 m
.02756 .59711 L
s
.02381 .6131 m
.02756 .6131 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .02399 m
.03279 .19698 L
.04262 .34352 L
.04758 .40224 L
.05288 .45485 L
.05785 .49532 L
.06244 .52568 L
.06788 .55364 L
.07069 .56493 L
.07379 .57504 L
.07647 .58196 L
.07899 .58693 L
.08035 .58905 L
.08165 .5907 L
.08314 .59217 L
.08384 .59271 L
.08451 .59313 L
.08577 .59369 L
.08692 .59394 L
.08815 .59393 L
.08884 .59381 L
.08948 .59362 L
.09055 .59315 L
.09173 .5924 L
.09296 .59138 L
.0941 .59021 L
.09675 .58673 L
.09916 .58266 L
.10458 .57064 L
.11449 .53992 L
.12366 .50361 L
.14443 .40462 L
.18369 .20985 L
.20339 .13088 L
.22144 .0771 L
.23087 .05698 L
.23566 .04892 L
.24079 .04195 L
.24349 .03895 L
.24595 .03663 L
.24845 .03466 L
.25075 .03321 L
.25344 .03193 L
.25485 .03144 L
.25558 .03123 L
.25635 .03105 L
.25766 .03083 L
.25887 .03072 L
.25962 .0307 L
.26032 .03071 L
Mistroke
.26096 .03075 L
.26165 .03081 L
.26229 .0309 L
.26298 .03102 L
.26421 .03131 L
.26553 .03172 L
.26698 .03229 L
.26957 .03362 L
.27199 .03522 L
.27651 .03909 L
.28136 .04451 L
.29234 .06136 L
.30234 .08178 L
.32147 .13223 L
.34224 .19981 L
.38307 .34928 L
.40337 .42089 L
.42239 .48059 L
.44082 .5283 L
.45086 .54922 L
.4602 .56507 L
.46986 .57763 L
.47497 .58262 L
.47759 .58473 L
.48042 .58667 L
.48302 .58813 L
.48542 .5892 L
.48771 .58998 L
.48886 .59028 L
.49013 .59055 L
.49128 .59072 L
.49232 .59083 L
.49353 .59089 L
.49468 .59089 L
.49574 .59083 L
.49672 .59073 L
.49779 .59058 L
.49894 .59035 L
.50131 .58969 L
.50381 .58872 L
.50829 .58628 L
.51311 .58265 L
.51838 .57749 L
.52784 .56522 L
.53665 .55043 L
.55709 .50472 L
.57567 .4513 L
.61562 .31236 L
.65405 .17521 L
.67351 .11585 L
Mistroke
.68384 .08926 L
.69494 .0654 L
.70038 .0557 L
.70556 .0478 L
.7106 .0414 L
.71527 .03666 L
.71968 .03327 L
.72214 .03184 L
.72437 .03085 L
.72566 .03041 L
.72683 .03008 L
.72813 .02982 L
.72878 .02973 L
.72949 .02965 L
.73069 .02959 L
.73198 .02962 L
.7332 .02974 L
.73431 .02992 L
.73549 .0302 L
.7366 .03054 L
.73912 .03158 L
.74158 .03297 L
.74423 .03488 L
.74902 .03941 L
.75341 .04481 L
.76353 .06177 L
.77417 .08633 L
.79393 .14917 L
.8123 .22501 L
.85137 .4169 L
.87129 .50987 L
.88178 .55042 L
.88752 .5688 L
.89288 .58297 L
.89767 .59277 L
.90035 .59698 L
.9028 .59993 L
.90419 .60122 L
.90548 .60214 L
.90622 .60256 L
.90689 .60286 L
.90767 .60311 L
.90839 .60326 L
.90904 .60332 L
.90972 .6033 L
.91095 .60307 L
.91226 .60253 L
.91301 .60209 L
.9137 .60158 L
.9149 .60049 L
Mistroke
.9162 .599 L
.91855 .59545 L
.92085 .5909 L
.92297 .58569 L
.92778 .57011 L
.93289 .54744 L
.9378 .51915 L
.94229 .48724 L
.95241 .39202 L
.96179 .27128 L
.97071 .12339 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[117]:=",
  ImageSize->{227.938, 140.813},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003S0000S2000`400?l00000o`00003oh`3oool0
0><0oooo003S0?ooo`00h`3oool00><0oooo003S0?ooo`00h`3oool00><0oooo003S0?ooo`00h`3o
ool00><0oooo003S0?ooo`00h`3oool00><0oooo000b0?ooo`030000003oool0oooo0:h0oooo000b
0?ooo`030000003oool0oooo0:h0oooo000b0?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool00P3oool00380oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`020?ooo`00
<P3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo0080oooo000b0?ooo`030000003o
ool0oooo02H0oooo1000001A0?ooo`@00000:P3oool00`000000oooo0?ooo`020?ooo`00<P3oool0
0`000000oooo0?ooo`0U0?ooo`8000000P3oool2000004l0oooo0P0000030?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool00P3oool00380oooo00<000000?ooo`3oool0903oool20000
00@0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool00P3oool00380oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo0080oooo000b0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`020?ooo`00203oool2000000@0oooo0P00
00040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0080oooo0007
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`020?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool200000280oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000000000000P0000020?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool01@00
0000oooo0?ooo`3oool0000002<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`03
0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool00`3oool000P0oooo0P00000:0?ooo`800000103oool20000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00<0oooo000b0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?ooo`00<P3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool00`3oool00380oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo000b
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`03
0?ooo`00<P3oool2000001l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?oo
o`00<P3oool2000001l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`00
<P3oool2000001h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`00<P3o
ool2000001h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`00<P3oool2
000001h0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`030?ooo`00203oool20000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3oool40000
00<0oooo0P00000N0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00@0oooo0P00000M0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool00`3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00<0oooo0P00000M0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool00`3oool000030?ooo`0000000000008000000P3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3o
ool2000001d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`030?ooo`001`3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool2000001d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`030?ooo`00203oool2000000X0oooo0P0000040?ooo`800000103oool2000000@0oooo0P000004
0?ooo`800000103oool2000001d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`03
0?ooo`00<P3oool2000001`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?oo
o`00<P3oool2000001`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`00
<P3oool2000001`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`00<P3o
ool2000001`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`00<P3oool2
000001`0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`00<P3oool20000
01/0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`00<P3oool2000001/0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`040?ooo`00<P3oool2000001/0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`00203oool2000000@0oooo0P00
00040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3oool500000080oooo0P00
000K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool000L0oooo00@00000
0?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo0P00000K0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0080oooo0P00000J0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0103oool000030?ooo`0000000000008000000P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0103oool000L0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo0080oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00@0oooo00080?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`040?ooo`00<P3oool00`000000oooo0000000H0?ooo`800000103oool2
000000<0oooo1000000B0?ooo`040000003oool00000000000@0oooo0P0000050?ooo`<000004P3o
ool2000000@0oooo0P0000030?ooo`@00000503oool2000000@0oooo0P0000040?ooo`8000006@3o
ool500000080oooo000b0?ooo`030000003oool0000001L0oooo0P0000000`3oool000000?ooo`07
0?ooo`030000003oool0oooo01<0oooo0P0000020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0403oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001<0oooo
00@000000?ooo`3oool00000203oool2000000030?ooo`000000oooo01L0oooo00<000000?ooo`00
0000103oool00380oooo00<000000?ooo`0000005`3oool2000000030?ooo`000000oooo00P0oooo
00<000000?ooo`3oool04P3oool200000080oooo00<000000?ooo`3oool01P3oool500000140oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`0000000000603oool00`000000oooo000000040?ooo`00<P3oool0
0`000000oooo0000000G0?ooo`80000000<0oooo0000003oool02@3oool00`000000oooo0?ooo`0B
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000004P3oool010000000oooo
0?ooo`0000080?ooo`<00000503oool010000000oooo0?ooo`0000090?ooo`8000006@3oool00`00
0000oooo000000040?ooo`00<P3oool00`000000oooo0000000G0?ooo`80000000<0oooo0000003o
ool01`3oool010000000oooo0?ooo`00000C0?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`0000004P3oool010000000oooo0?ooo`0000090?ooo`800000503oool010000000oooo0?oo
o`0000080?ooo`040000003oool00000000001P0oooo00<000000?ooo`000000103oool00380oooo
00<000000?ooo`000000603oool2000000X0oooo0P00000D0?ooo`<000002`3oool2000001<0oooo
0P00000:0?ooo`<00000503oool2000000X0oooo0P00000I0?ooo`<00000103oool00380oooo00<0
00000?ooo`0000005`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo000b
0?ooo`030000003oool0000001L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`04
0?ooo`00<P3oool00`000000oooo0000000G0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0103oool00380oooo00<000000?ooo`0000005`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00@0oooo000b0?ooo`030000003oool0000001L0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`050?ooo`00;@3ooonf00000000<P3oool010000000oooo0?ooo`00
000E0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01l0oooo00D000000?ooo`3oool0oooo0000000N0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0503oool010000000oooo0?ooo`0000040?ooo`00
<P3oool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool00380oooo00@000000?ooo`3oool000005@3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000b0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`050?ooo`00<P3oool010000000oooo0?ooo`00000D0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool01@3oool00380oooo00@000000?ooo`3oool0
0000503oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo000b0?ooo`040000
003oool0oooo000001@0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`050?ooo`00
<P3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool01@3oool00380oooo00@000000?ooo`3oool00000503oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00D0oooo000b0?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`060?ooo`00<P3oool010000000oooo0?ooo`00000C0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool01P3oool000P0oooo0P0000040?ooo`800000
103oool2000000@0oooo0P0000040?ooo`800000103oool2000000<0oooo1@0000020?ooo`050000
003oool0oooo0?ooo`0000004P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0
oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000004P3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`800000
0P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1P3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool01P3oool000L0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1P3oool000P0oooo0P00000:0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103o
ool2000000@0oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool01P3oool00380oooo00D000000?ooo`3oool0oooo0000000A0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00380oooo00D000000?ooo`3oool0oooo
0000000A0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01P3oool00380oooo00D0
00000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
1`3oool00380oooo00D000000?ooo`3oool0oooo0000000@0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool01`3oool00380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00380oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01`3oool00380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool00380oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01`3oool00380oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000103o
ool2000000@0oooo0P0000040?ooo`800000103oool2000000<0oooo100000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00L0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo00070?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`030?ooo`8000000`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0203oool000L0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0203oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool000P0oooo
0P00000:0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0203oool00380oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00380oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0203oool00380oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00380oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool02@3oool00380oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00380oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3o
ool00380oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00380oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool000P0
oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0
oooo0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo00070?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00X0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02P3oool000L0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool02P3oool000L0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
2`3oool000P0oooo0P00000:0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103o
ool2000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02`3oool00380oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool0
0380oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool000000480oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool02`3oool00380oooo00<000000?ooo`3oool01P3oool01@000000oooo0?ooo`3oool0
000004<0oooo0P0000050?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0<0?ooo`00<P3oool00`000000oooo0?ooo`070?ooo`040000003oool00000
000004@0oooo0`0000000`3oool00000000000150?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0303oool00380oooo00<000000?ooo`3oool01`3oool3000004L0oooo0`0000170?oo
o`050000003oool0oooo0?ooo`0000003P3oool00380oooo00<000000?ooo`3oool0V`3oool20000
00030?ooo`000000oooo00h0oooo000b0?ooo`030000003oool0oooo09`0oooo0`00000?0?ooo`00
<P3oool00`000000oooo0?ooo`2^0?ooo`00<P3oool00`000000oooo0?ooo`2^0?ooo`00<P3oool0
0`000000oooo0?ooo`2^0?ooo`00h`3oool00><0oooo003S0?ooo`00h`3oool00><0oooo003S0?oo
o`00h`3oool00><0oooo003S0?ooo`00h`3oool00><0oooo003S0?ooo`00h`3oool00001\
\>"],
  ImageRangeCache->{{{0, 226.938}, {139.813, 0}} -> {-0.291609, \
-4.83612*^-05, 0.00580166, 6.91224*^-07}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[117]="]
}, Open  ]],

Cell["Example 6", "Subsubsection"],

Cell["Initial value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\((x^2 + x)\)*\(y'''\)[x] - \((x^2 - 2)\)*\(y''\)[
                x] - \((x + 2)\)*\(y'\)[x] \[Equal] 3*x*\((x + 1)\)^2, 
        y[1] \[Equal] 1, \(y'\)[1] \[Equal] 1, \(y''\)[1] \[Equal] 
          1}\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(-\((2 + x)\)\), " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{\((\(-2\) + x\^2)\), " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{\((x + x\^2)\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((3)\),
                    Derivative],
                  MultilineFunction->None], "[", "x", "]"}]}]}], 
          "==", \(3\ x\ \((1 + x)\)\^2\)}], ",", \(y[1] == 1\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "1", "]"}], "==", "1"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "1", "]"}], "==", "1"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[118]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[ivp, y[x], {x, 1, 2}, 3]\)], "Input",
  CellLabel->"In[119]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 
          8095543412254379137157\/8095523118005643399977 + \
\(8093620176261493459425\ \((\(-1\) + x)\)\)\/8095523118005643399977 + \
\(8154627628041880866867\ \((\(-1\) + x)\)\^2\)\/16191046236011286799954 + \
\(9262623164436158757277\ \((\(-1\) + x)\)\^3\)\/8095523118005643399977 + \
\(912515971766077636608\ \((\(-1\) + x)\)\^4\)\/8095523118005643399977 + \
\(5159160180124722659328\ \((\(-1\) + x)\)\^5\)\/40477615590028216999885 + \
\(207237427095666688\ \((\(-1\) + x)\)\^6\)\/8095523118005643399977}}\)], \
"Output",
  CellLabel->"Out[119]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["Unfortunately ",
    FontColor->RGBColor[0, 0, 0.500008]],
  StyleBox["DSolve",
    FontFamily->"Courier New",
    FontColor->RGBColor[0, 0, 0.500008]],
  StyleBox[" can not find exact solution of the IVP. ",
    FontColor->RGBColor[0, 0, 0.500008]]
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[120]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \(Power::"infy" \(\(:\)\(\ \)\) 
      "Infinite expression \!\(1\/0\) encountered."\)], "Message",
  CellLabel->"From In[120]:="],

Cell[BoxData[
    \(Power::"infy" \(\(:\)\(\ \)\) 
      "Infinite expression \!\(1\/0\) encountered."\)], "Message",
  CellLabel->"From In[120]:="],

Cell[BoxData[
    \({}\)], "Output",
  CellLabel->"Out[120]="]
}, Open  ]],

Cell["Nevertheless the exact solution is as follows.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = {{y[x] \[Rule] 
            Log[x] + 7*Exp[x]/Exp[1] - 3/2*x^2 - 1/3*x^3 - 3*x - 
              7/6}}\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \({{y[x] \[Rule] \(-\(7\/6\)\) + 7\ \[ExponentialE]\^\(\(-1\) + x\) - 
            3\ x - \(3\ x\^2\)\/2 - x\^3\/3 + Log[x]}}\)], "Output",
  CellLabel->"Out[121]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\), {x, 1, 
        2}]\)], "Input",
  CellLabel->"In[122]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.307206 116677 [
[.21429 .29471 -9 -9 ]
[.21429 .29471 9 0 ]
[.40476 .29471 -9 -9 ]
[.40476 .29471 9 0 ]
[.59524 .29471 -9 -9 ]
[.59524 .29471 9 0 ]
[.78571 .29471 -9 -9 ]
[.78571 .29471 9 0 ]
[.97619 .29471 -3 -9 ]
[.97619 .29471 3 0 ]
[.01131 .07385 -39 -6.25 ]
[.01131 .07385 0 6.25 ]
[.01131 .19053 -39 -6.25 ]
[.01131 .19053 0 6.25 ]
[.01131 .42388 -33 -6.25 ]
[.01131 .42388 0 6.25 ]
[.01131 .54056 -33 -6.25 ]
[.01131 .54056 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30721 m
.21429 .31346 L
s
[(1.2)] .21429 .29471 0 1 Mshowa
.40476 .30721 m
.40476 .31346 L
s
[(1.4)] .40476 .29471 0 1 Mshowa
.59524 .30721 m
.59524 .31346 L
s
[(1.6)] .59524 .29471 0 1 Mshowa
.78571 .30721 m
.78571 .31346 L
s
[(1.8)] .78571 .29471 0 1 Mshowa
.97619 .30721 m
.97619 .31346 L
s
[(2)] .97619 .29471 0 1 Mshowa
.125 Mabswid
.07143 .30721 m
.07143 .31096 L
s
.11905 .30721 m
.11905 .31096 L
s
.16667 .30721 m
.16667 .31096 L
s
.2619 .30721 m
.2619 .31096 L
s
.30952 .30721 m
.30952 .31096 L
s
.35714 .30721 m
.35714 .31096 L
s
.45238 .30721 m
.45238 .31096 L
s
.5 .30721 m
.5 .31096 L
s
.54762 .30721 m
.54762 .31096 L
s
.64286 .30721 m
.64286 .31096 L
s
.69048 .30721 m
.69048 .31096 L
s
.7381 .30721 m
.7381 .31096 L
s
.83333 .30721 m
.83333 .31096 L
s
.88095 .30721 m
.88095 .31096 L
s
.92857 .30721 m
.92857 .31096 L
s
.25 Mabswid
0 .30721 m
1 .30721 L
s
.02381 .07385 m
.03006 .07385 L
s
gsave
.01131 .07385 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .19053 m
.03006 .19053 L
s
gsave
.01131 .19053 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .42388 m
.03006 .42388 L
s
gsave
.01131 .42388 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .54056 m
.03006 .54056 L
s
gsave
.01131 .54056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.02381 .09719 m
.02756 .09719 L
s
.02381 .12052 m
.02756 .12052 L
s
.02381 .14386 m
.02756 .14386 L
s
.02381 .16719 m
.02756 .16719 L
s
.02381 .21386 m
.02756 .21386 L
s
.02381 .2372 m
.02756 .2372 L
s
.02381 .26053 m
.02756 .26053 L
s
.02381 .28387 m
.02756 .28387 L
s
.02381 .33054 m
.02756 .33054 L
s
.02381 .35388 m
.02756 .35388 L
s
.02381 .37721 m
.02756 .37721 L
s
.02381 .40055 m
.02756 .40055 L
s
.02381 .44722 m
.02756 .44722 L
s
.02381 .47055 m
.02756 .47055 L
s
.02381 .49389 m
.02756 .49389 L
s
.02381 .51722 m
.02756 .51722 L
s
.02381 .05052 m
.02756 .05052 L
s
.02381 .02718 m
.02756 .02718 L
s
.02381 .00385 m
.02756 .00385 L
s
.02381 .5639 m
.02756 .5639 L
s
.02381 .58723 m
.02756 .58723 L
s
.02381 .61057 m
.02756 .61057 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02846 .1387 L
.03279 .2375 L
.03793 .33595 L
.04262 .40923 L
.04721 .46752 L
.0522 .51712 L
.05494 .53886 L
.05746 .55575 L
.06007 .57013 L
.06244 .58079 L
.06487 .58935 L
.06611 .5929 L
.06747 .59615 L
.06872 .59857 L
.06988 .60036 L
.07099 .60166 L
.07218 .60263 L
.0729 .60301 L
.07357 .60323 L
.0743 .60332 L
.07507 .60325 L
.07637 .60277 L
.07711 .6023 L
.0778 .60173 L
.07909 .60036 L
.08026 .59875 L
.0829 .594 L
.08567 .58742 L
.08823 .58002 L
.09403 .55923 L
.10458 .51045 L
.14385 .28967 L
.15344 .2416 L
.16354 .19746 L
.17289 .16343 L
.1816 .13816 L
.19084 .11827 L
.19572 .11065 L
.20094 .10469 L
.20364 .10248 L
.20506 .10155 L
.20656 .10074 L
.20788 .10017 L
.20858 .09993 L
.20933 .09971 L
.21064 .09942 L
.21187 .09928 L
.21314 .09925 L
.21386 .09929 L
Mistroke
.21453 .09935 L
.21576 .09956 L
.21706 .09991 L
.21834 .10037 L
.21955 .10091 L
.2218 .10219 L
.22647 .10594 L
.23159 .11169 L
.24192 .12802 L
.25148 .14811 L
.2604 .17038 L
.29936 .29083 L
.31921 .35477 L
.34078 .41687 L
.35084 .4416 L
.36151 .46414 L
.37152 .48148 L
.38067 .49392 L
.38516 .49878 L
.39007 .50315 L
.395 .50654 L
.39769 .50797 L
.40018 .50903 L
.40257 .50981 L
.40375 .5101 L
.40482 .51032 L
.40581 .51049 L
.40685 .51062 L
.40789 .5107 L
.40903 .51074 L
.41027 .51073 L
.41139 .51067 L
.41269 .51053 L
.41392 .51034 L
.41505 .51012 L
.4161 .50986 L
.41848 .50912 L
.42089 .50815 L
.4231 .50707 L
.42809 .50396 L
.43712 .49607 L
.44715 .48413 L
.45771 .4683 L
.49579 .39141 L
.53632 .29842 L
.55503 .26049 L
.57533 .22752 L
.58642 .21412 L
.59129 .2094 L
.59665 .20505 L
Mistroke
.6017 .20181 L
.60643 .19953 L
.60904 .1986 L
.61143 .19794 L
.61274 .19767 L
.61418 .19743 L
.61484 .19734 L
.61554 .19727 L
.61679 .19718 L
.61804 .19714 L
.61874 .19714 L
.6194 .19716 L
.6201 .19719 L
.62073 .19724 L
.62147 .19731 L
.62216 .19739 L
.62339 .19758 L
.62452 .1978 L
.62709 .19845 L
.62966 .19933 L
.63249 .20056 L
.63822 .20386 L
.64323 .20762 L
.64863 .21258 L
.6584 .22381 L
.67845 .25504 L
.69956 .29705 L
.73768 .38189 L
.75895 .42412 L
.769 .44052 L
.77827 .45288 L
.78791 .46248 L
.79299 .46604 L
.79555 .46742 L
.79837 .46861 L
.79963 .46903 L
.80084 .46936 L
.80193 .4696 L
.80309 .4698 L
.80435 .46995 L
.80552 .47002 L
.80624 .47003 L
.80691 .47002 L
.80817 .46994 L
.80928 .4698 L
.81046 .4696 L
.81147 .46937 L
.81257 .46907 L
.81504 .46818 L
.81733 .46708 L
Mistroke
.82236 .46379 L
.82782 .45882 L
.83774 .44614 L
.84739 .42947 L
.85631 .41064 L
.87662 .35845 L
.89565 .30536 L
.90499 .28167 L
.91387 .26302 L
.91876 .25512 L
.92135 .2518 L
.9241 .249 L
.92542 .24796 L
.92665 .24716 L
.92776 .2466 L
.92896 .24616 L
.9301 .24592 L
.93131 .24586 L
.93234 .24597 L
.93347 .24626 L
.93478 .24683 L
.93598 .2476 L
.9373 .24871 L
.93871 .2502 L
.94107 .25349 L
.94367 .25831 L
.94847 .27076 L
.95297 .28712 L
.95822 .31255 L
.96304 .34263 L
.97388 .43795 L
.97619 .46375 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[122]:=",
  ImageSize->{244.813, 151.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003d0000Ub000`400?l00000o`00003om03oool0
0?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03o
ool00?@0oooo000Y0?ooo`030000003oool0oooo0<P0oooo000Y0?ooo`800000b@3oool002T0oooo
00<000000?ooo`3oool0b03oool002T0oooo00<000000?ooo`3oool0b03oool002T0oooo00<00000
0?ooo`3oool0b03oool002T0oooo00<000000?ooo`3oool0b03oool002T0oooo0P0000390?ooo`00
:@3oool00`000000oooo0?ooo`380?ooo`00:@3oool00`000000oooo0?ooo`380?ooo`00:@3oool0
0`000000oooo0?ooo`380?ooo`00:@3oool00`000000oooo0?ooo`380?ooo`00:@3oool200000<T0
oooo00070?ooo`@000000P3oool01P000000oooo0?ooo`3oool000000?ooo`D000000P3oool20000
00d0oooo00<000000?ooo`3oool0b03oool000L0oooo00<000000?ooo`3oool0103oool00`000000
oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0<P0oooo00080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`380?ooo`0000<0oooo0000000000000P0000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`380?ooo`001`3oool010000000oooo0?ooo`0000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02P3oool200000<T0oooo00080?ooo`8000002P3oool2000000@0oooo0P00000=
0?ooo`800000b@3oool002@0oooo00<0`<300;2`/02@T9000P3oool200000<T0oooo000T0?ooo`03
0:2PX03oool0`<300080oooo0P0000390?ooo`007P3oool0103Ph>00P8200820P020P8020?ooo`03
061PH02@T900X:2P0080oooo0P0000390?ooo`00903oool00`2PX:00oooo0?ooo`020?ooo`800000
903oool400000:40oooo000U0?ooo`040:2PX02`/;00oooo0?ooo`8000008`3oool010000000oooo
0?ooo`3oool200000:00oooo000Y0?ooo`8000008P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo09d0oooo000Y0?ooo`8000008@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo09d0oooo000Y0?ooo`8000008@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo09`0oooo000Y0?ooo`800000803oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
09`0oooo000Y0?ooo`800000803oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09/0
oooo000Y0?ooo`8000007`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo09/0oooo
000Y0?ooo`8000007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09X0oooo000Y
0?ooo`8000007`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09X0oooo000Y0?oo
o`8000007P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo09T0oooo000Y0?ooo`80
00007P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo09T0oooo000Y0?ooo`800000
7@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo09P0oooo000Y0?ooo`8000007@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo09P0oooo000Y0?ooo`8000007@3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo09L0oooo000Y0?ooo`800000703oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo09L0oooo00070?ooo`D0000000<0oooo0000003o
ool00P3oool00`000000oooo0000000400000080oooo0P00000=0?ooo`800000703oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo09L0oooo00090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool2000001`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`2F0?ooo`00
2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00X0oooo0P00000L0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0UP3oool000030?ooo`000000000000800000103oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0`00000J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0UP3oool000T0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000`3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0000001X0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`140?ooo`@00000C@3oool000P0oooo0P00000:0?oo
o`800000103oool2000000P0oooo00<0`<300;2`/02@T9000P3oool00`000000oooo0000000J0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0@P3oool2000000@0oooo00<000000?oo
o`3oool0BP3oool002@0oooo00<0X:2P0?ooo`30`<000P3oool00`000000oooo0000000J0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`050?ooo`80
0000BP3oool001h0oooo00@0h>3P0820P020P800P8200P3oool00`1PH600T92@0:2PX0020?ooo`03
0000003oool0000001T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo00P0oooo0P0000180?ooo`00903oool00`2PX:00oooo0?ooo`020?ooo`<00000
6@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`150?ooo`009@3oool01`2PX:00/;2`0?ooo`3oool000000?ooo`00
00006@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03`0oooo0P00000>0?ooo`03
0000003oool0oooo04D0oooo000Y0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
A03oool002T0oooo00<000000?ooo`000000603oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`130?ooo`00:@3oool3
000001P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0@`3oool002T0oooo00<000000?ooo`000000603oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`120?ooo`00:@3oool00`000000oooo0000000H0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0340
oooo0`00000=0?ooo`00:@3oool00`000000oooo0000000H0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0340oooo
00@000000?ooo`0000000000303oool002T0oooo00<000000?ooo`0000005`3oool00`000000oooo
0?ooo`030?ooo`D000000P3oool2000000<0oooo100000060?ooo`030000003oool0oooo00h0oooo
1@0000020?ooo`8000001@3oool3000001H0oooo1@0000020?ooo`8000000`3oool3000000/0oooo
00<000000?ooo`3oool02`3oool500000080oooo0P0000040?ooo`800000503oool2000000<0oooo
00<000000?ooo`3oool00P3oool4000000@0oooo000Y0?ooo`<000005`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0000
00090?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`070?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0103oool01@000000
oooo0?ooo`3oool0000000L0oooo000Y0?ooo`030000003oool0000001L0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`070?ooo`D000005@3oool010000000oooo0?ooo`0000090?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo000Y0?ooo`030000003oool0000001L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000001H0oooo00@0
00000?ooo`3oool000002@3oool3000000`0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`080?ooo`8000004`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00`3oool002T0oooo00<000000?ooo`0000005`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000005@3oool01@000000oooo
0?ooo`3oool0000000X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?oo
o`0000005P3oool00`000000oooo0?ooo`050?ooo`8000002P3oool2000000T0oooo00<000000?oo
o`3oool03@3oool2000000/0oooo0P00000E0?ooo`030000003oool0oooo008000002P3oool30000
00`0oooo00<000000?ooo`3oool02P3oool2000000X0oooo0P00000B0?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`00:@3oool3000001H0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo000Y0?ooo`03
0000003oool0000001H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo000Y0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo000Y0?ooo`040000
003oool0oooo000001D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo000Y0?ooo`040000003oool0oooo000001@0oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0oooo000T0?ooom000000
000Y0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool01`3oool01@000000oooo
0?ooo`3oool0000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00H0oooo0P0000090?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`0000050?ooo`00:@3oool010000000oooo0?ooo`00000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`00:@3o
ool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`060?ooo`00:@3oool010000000oooo0?ooo`00000D0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?ooo`00:@3o
ool2000000030?ooo`000000oooo0180oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00D0oooo000Y0?ooo`040000003oool0oooo000001<0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo000Y
0?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00D0oooo000Y0?ooo`040000003oool0oooo000001<0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo000Y
0?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00D0oooo000Y0?ooo`80000000<0oooo0000003oool04P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool0
02T0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool01@3oool002T0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01@3oool0
02T0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0103oool002T0oooo0P0000020?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00@0oooo000Y0?ooo`050000003oool0oooo0?ooo`0000004@3oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool002T0oooo00D000000?ooo`3o
ool0oooo0000000A0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`040?ooo`00:@3oool01@000000oooo0?ooo`3oool000000100oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000Y0?ooo`05
0000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool002T0oooo0P0000020?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0
oooo000Y0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool000L0oooo1@0000000`3oool00000
0?ooo`020?ooo`030000003oool0000000@000000P3oool2000000d0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`040?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3o
ool0oooo0000000?0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`040?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`030?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P000002
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00<0oooo00090?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool00000303oool01@000000oooo
0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00<0oooo00080?ooo`8000002P3oool2000000@0oooo0P0000080?ooo`030<30
`02`/;00T92@0080oooo00D000000?ooo`3oool0oooo0000000?0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`030?ooo`00903oool00`2PX:00oooo
0<30`0020?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool00`3oool001h0oooo00@0h>3P0820P020P800
P8200P3oool00`1PH600T92@0:2PX0020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool00`3oool002@0oooo00<0X:2P0?ooo`3oool00P3oool2000000<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
?03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
0`3oool002D0oooo00D0X:2P0;2`/03oool0oooo000000040?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00<0oooo
000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool00`3oool002T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`030?ooo`00:@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0480oooo0`0000020?ooo`8000009@3oool002T0oooo0P0000030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo04D0oooo0`00000W0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo06l0oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0L03o
ool002T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1`0?ooo`00:@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0740oooo000Y0?ooo`800000103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`1b0?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07<0oooo
000Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0h0?ooo`8000001@3oool2000007H0oooo000Y0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0j0?ooo`D00000N03oool002T0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;L0oooo000Y0?ooo`80
0000103oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0;L0oooo00070?ooo`@00000
0P3oool01P000000oooo0?ooo`3oool000000?ooo`D000000P3oool2000000d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;P0oooo00070?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0^03oool000P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2h0?oo
o`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0^03oool000L0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0;P0oooo00080?ooo`8000002P3oool2000000@0oooo0P0000080?ooo`030<30`02`/;00
T92@0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0;T0oooo000T0?ooo`030:2PX03oool0`<300080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0;T0oooo000N0?ooo`040>3Ph020P800P8200820
P080oooo00<0H61P092@T02PX:000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0^@3oool002@0oooo00<0X:2P0?ooo`3oool00P3oool2000000H0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2i0?ooo`009@3oool01@2PX:00/;2`
0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2j0?ooo`00
:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
^P3oool002T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0;/0oooo000Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2k0?ooo`00:@3oool2000000L0oooo00D000000?ooo`3oool0oooo0000002m
0?ooo`00:@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000;h0oooo000Y0?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool00000_P3oool002T0oooo00<000000?oo
o`3oool01`3oool300000;h0oooo000Y0?ooo`030000003oool0oooo0<P0oooo000Y0?ooo`800000
b@3oool002T0oooo00<000000?ooo`3oool0b03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo
003d0?ooo`00m03oool00?@0oooo003d0?ooo`00m03oool00?@0oooo003d0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 243.813}, {150.25, 0}} -> {0.789191, -3.09268*^-06, \
0.00506871, 4.13735*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[122]="]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->False,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 157, 6, 39, "Subsection"],
Cell[1865, 58, 381, 12, 22, "SmallText"],
Cell[2249, 72, 229, 6, 25, "Text"],
Cell[2481, 80, 46, 0, 31, "MathCaption"],
Cell[2530, 82, 93, 2, 29, "Input"],
Cell[2626, 86, 34, 0, 35, "Subsubsection"],
Cell[2663, 88, 85, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2773, 94, 145, 3, 29, "Input"],
Cell[2921, 99, 387, 10, 23, "Output"]
}, Open  ]],
Cell[3323, 112, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3470, 119, 138, 4, 29, "Input"],
Cell[3611, 125, 308, 6, 39, "Output"]
}, Open  ]],
Cell[3934, 134, 228, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[4187, 147, 124, 4, 29, "Input"],
Cell[4314, 153, 303, 6, 55, "Output"]
}, Open  ]],
Cell[4632, 162, 231, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[4888, 175, 139, 3, 29, "Input"],
Cell[5030, 180, 23569, 631, 139, 6173, 411, "GraphicsData", "PostScript", \
"Graphics"],
Cell[28602, 813, 155, 4, 23, "Output"]
}, Open  ]],
Cell[28772, 820, 34, 0, 35, "Subsubsection"],
Cell[28809, 822, 85, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[28919, 828, 138, 3, 29, "Input"],
Cell[29060, 833, 486, 14, 23, "Output"]
}, Open  ]],
Cell[29561, 850, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[29708, 857, 139, 4, 29, "Input"],
Cell[29850, 863, 398, 8, 73, "Output"]
}, Open  ]],
Cell[30263, 874, 228, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[30516, 887, 125, 4, 29, "Input"],
Cell[30644, 893, 291, 6, 36, "Output"]
}, Open  ]],
Cell[30950, 902, 231, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[31206, 915, 153, 4, 29, "Input"],
Cell[31362, 921, 31318, 782, 136, 7535, 483, "GraphicsData", "PostScript", \
"Graphics"],
Cell[62683, 1705, 156, 4, 23, "Output"]
}, Open  ]],
Cell[62854, 1712, 34, 0, 35, "Subsubsection"],
Cell[62891, 1714, 85, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[63001, 1720, 146, 3, 29, "Input"],
Cell[63150, 1725, 512, 13, 23, "Output"]
}, Open  ]],
Cell[63677, 1741, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[63824, 1748, 139, 4, 29, "Input"],
Cell[63966, 1754, 604, 11, 76, "Output"]
}, Open  ]],
Cell[64585, 1768, 228, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[64838, 1781, 125, 4, 29, "Input"],
Cell[64966, 1787, 159, 4, 79, "Output"]
}, Open  ]],
Cell[65140, 1794, 231, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[65396, 1807, 140, 3, 29, "Input"],
Cell[65539, 1812, 45840, 1013, 158, 8594, 548, "GraphicsData", "PostScript", \
"Graphics"],
Cell[111382, 2827, 156, 4, 23, "Output"]
}, Open  ]],
Cell[111553, 2834, 34, 0, 35, "Subsubsection"],
Cell[111590, 2836, 86, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[111701, 2842, 143, 3, 29, "Input"],
Cell[111847, 2847, 542, 14, 23, "Output"]
}, Open  ]],
Cell[112404, 2864, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[112551, 2871, 139, 4, 29, "Input"],
Cell[112693, 2877, 163, 3, 23, "Message"],
Cell[112859, 2882, 294, 5, 39, "Output"]
}, Open  ]],
Cell[113168, 2890, 228, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[113421, 2903, 125, 4, 29, "Input"],
Cell[113549, 2909, 90, 2, 23, "Output"]
}, Open  ]],
Cell[113654, 2914, 231, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[113910, 2927, 140, 3, 29, "Input"],
Cell[114053, 2932, 24770, 708, 145, 7835, 494, "GraphicsData", "PostScript", \
"Graphics"],
Cell[138826, 3642, 156, 4, 23, "Output"]
}, Open  ]],
Cell[138997, 3649, 34, 0, 35, "Subsubsection"],
Cell[139034, 3651, 85, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[139144, 3657, 154, 3, 29, "Input"],
Cell[139301, 3662, 650, 18, 23, "Output"]
}, Open  ]],
Cell[139966, 3683, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[140113, 3690, 139, 4, 29, "Input"],
Cell[140255, 3696, 302, 6, 39, "Output"]
}, Open  ]],
Cell[140572, 3705, 316, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[140913, 3718, 125, 4, 29, "Input"],
Cell[141041, 3724, 416, 7, 97, "Message"],
Cell[141460, 3733, 62, 2, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141559, 3740, 86, 2, 29, "Input"],
Cell[141648, 3744, 64, 2, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[141749, 3751, 85, 2, 29, "Input"],
Cell[141837, 3755, 402, 6, 97, "Message"],
Cell[142242, 3763, 62, 2, 23, "Output"]
}, Open  ]],
Cell[142319, 3768, 69, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[142413, 3772, 179, 4, 29, "Input"],
Cell[142595, 3778, 185, 4, 63, "Output"]
}, Open  ]],
Cell[142795, 3785, 231, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[143051, 3798, 140, 3, 29, "Input"],
Cell[143194, 3803, 31254, 737, 147, 6187, 423, "GraphicsData", "PostScript", \
"Graphics"],
Cell[174451, 4542, 156, 4, 23, "Output"]
}, Open  ]],
Cell[174622, 4549, 34, 0, 35, "Subsubsection"],
Cell[174659, 4551, 85, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[174769, 4557, 269, 5, 29, "Input"],
Cell[175041, 4564, 1133, 29, 23, "Output"]
}, Open  ]],
Cell[176189, 4596, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[176336, 4603, 139, 4, 29, "Input"],
Cell[176478, 4609, 586, 10, 76, "Output"]
}, Open  ]],
Cell[177079, 4622, 316, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[177420, 4635, 125, 4, 29, "Input"],
Cell[177548, 4641, 148, 3, 36, "Message"],
Cell[177699, 4646, 148, 3, 36, "Message"],
Cell[177850, 4651, 62, 2, 23, "Output"]
}, Open  ]],
Cell[177927, 4656, 69, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[178021, 4660, 166, 4, 29, "Input"],
Cell[178190, 4666, 183, 3, 39, "Output"]
}, Open  ]],
Cell[178388, 4672, 231, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[178644, 4685, 140, 3, 29, "Input"],
Cell[178787, 4690, 27747, 711, 158, 6899, 449, "GraphicsData", "PostScript", \
"Graphics"],
Cell[206537, 5403, 156, 4, 23, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

