(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    567189,      13061]*)
(*NotebookOutlinePosition[    567935,      13086]*)
(*  CellTagsIndexPosition[    567891,      13082]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Symbolic examples of the ",
  StyleBox["DifferentialEquations`LdeApprox`",
    FontSlant->"Italic"],
  " package"
}], "Subsection"],

Cell[TextData[{
  StyleBox["Copyright \[Copyright] 2003-2005 ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Graph Tree Ltd",
    ButtonData:>{
      URL[ "http://www.mathshop.digi-area.com/"], None},
    Active->True,
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[". All rights reserved.",
    FontSlant->"Italic"]
}], "SmallText",
  TextAlignment->Right],

Cell[TextData[{
  "This notebook illustrates ",
  StyleBox["DifferentialEquations`LdeApprox`",
    FontFamily->"Courier New"],
  " package capability of doing symbolic polynomial approximation of an LDE \
solution. "
}], "Text"],

Cell["This loads the package.", "MathCaption"],

Cell[BoxData[
    \(<< DifferentialEquations`LdeApprox`\)], "Input",
  CellLabel->"In[160]:="],

Cell["Example 1", "Subsubsection"],

Cell["Simple boundary value problem.", "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''\)[x] + k^2*y[x] \[Equal] x, y[0] \[Equal] 1, 
        y[1] \[Equal] 2}\)], "Input",
  CellLabel->"In[161]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(k\^2\ y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", "x"}], 
        ",", \(y[0] == 1\), ",", \(y[1] == 2\)}], "}"}]], "Output",
  CellLabel->"Out[161]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 3]\)], "Input",
  CellLabel->"In[162]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(\(16\ \((\(-5898240\) + 767136\ k\^2 - 
                        15313\ k\^4 + 5\ k\^6)\)\)\/\(\((30720 - 800\ k\^2 + 
                        k\^4)\)\ \((3072 - 320\ k\^2 + 
                        k\^4)\)\)\)\) + \(\((78643200 + 50424832\ k\^2 - \
735808\ k\^4 - 1055\ k\^6)\)\ x\)\/\(\((30720 - 800\ k\^2 + k\^4)\)\ \((3072 \
- 320\ k\^2 + k\^4)\)\) + \(768\ k\^2\ \((\(-59040\) - 809\ k\^2 + 7\ k\^4)\)\
\ x\^2\)\/\(\((30720 - 800\ k\^2 + k\^4)\)\ \((3072 - 320\ k\^2 + k\^4)\)\) - \
\(5120\ \((\(-1\) + k\^2)\)\ x\^3\)\/\(30720 - 800\ k\^2 + k\^4\)}}\)], \
"Output",
  CellLabel->"Out[162]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[163]:=",
  CellFrame->False,
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(x + k\^2\ Cos[k\ x] - k\^2\ Cot[k]\ Sin[k\ x] - \
Csc[k]\ Sin[k\ x] + 2\ k\^2\ Csc[k]\ Sin[k\ x]\)\/k\^2}}\)], "Output",
  CellLabel->"Out[163]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
              apr[\([1]\)])\))\), {k, 1/10, 1}, {x, 0, 1}]\)], "Input",
  CellLabel->"In[164]:=",
  CellFrame->False,
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.32056e-016 1.04977 -0.0679587 1.04977 [
[.09267 .22056 -18 -8.89284 ]
[.09267 .22056 0 .10716 ]
[.22808 .16727 -17.3856 -9 ]
[.22808 .16727 .61442 0 ]
[.37094 .11108 -16.5516 -9 ]
[.37094 .11108 1.44839 0 ]
[.52186 .05175 -15.7176 -9 ]
[.52186 .05175 2.28236 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 18 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 24 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.01653 .31263 -48 -2.78249 ]
[.01653 .31263 0 6.21751 ]
[.00679 .37371 -6 -2.8343 ]
[.00679 .37371 0 6.1657 ]
[-0.00335 .43722 -42 -2.88839 ]
[-0.00335 .43722 0 6.11161 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.10206 .22973 m
.10675 .23431 L
s
[(0.2)] .09267 .22056 1 .97619 Mshowa
.23703 .17687 m
.2415 .18167 L
s
[(0.4)] .22808 .16727 .93173 1 Mshowa
.37937 .12114 m
.38359 .12616 L
s
[(0.6)] .37094 .11108 .83907 1 Mshowa
.52971 .06227 m
.53364 .06753 L
s
[(0.8)] .52186 .05175 .7464 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.13514 .21677 m
.13793 .21955 L
s
.16866 .20365 m
.17141 .20646 L
s
.20262 .19035 m
.20534 .1932 L
s
.2719 .16322 m
.27455 .16613 L
s
.30724 .14938 m
.30985 .15233 L
s
.34306 .13535 m
.34564 .13834 L
s
.41618 .10672 m
.41867 .10977 L
s
.4535 .09211 m
.45595 .0952 L
s
.49134 .07729 m
.49374 .08041 L
s
.56863 .04703 m
.57093 .05022 L
s
.60809 .03158 m
.61035 .0348 L
s
.64813 .0159 m
.65033 .01916 L
s
.0694 .24251 m
.07225 .24523 L
s
.03716 .25514 m
.04004 .25782 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(0.25)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0.5)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.75)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02879 .30795 m
.03492 .30561 L
s
[(-0.00005)] .01653 .31263 1 -0.38167 Mshowa
.01909 .36915 m
.02525 .36687 L
s
[(0)] .00679 .37371 1 -0.37016 Mshowa
.00901 .43279 m
.01518 .43058 L
s
[(0.00005)] -0.00335 .43722 1 -0.35814 Mshowa
.125 Mabswid
.02688 .32 m
.03056 .31861 L
s
.02496 .33215 m
.02864 .33076 L
s
.02302 .34439 m
.0267 .343 L
s
.02106 .35672 m
.02475 .35535 L
s
.01711 .38168 m
.0208 .38032 L
s
.01511 .39431 m
.0188 .39296 L
s
.01309 .40703 m
.01679 .40569 L
s
.01106 .41986 m
.01476 .41853 L
s
.03069 .29599 m
.03436 .29458 L
s
.03257 .28412 m
.03624 .2827 L
s
.03443 .27234 m
.0381 .27092 L
s
.03629 .26065 m
.03995 .25922 L
s
.00694 .44583 m
.01065 .44451 L
s
.00486 .45896 m
.00857 .45765 L
s
.00276 .47221 m
.00648 .47091 L
s
.00064 .48556 m
.00436 .48427 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.627 .777 .952 r
.37892 .68421 .40173 .70085 .43959 .6871 .41703 .67513 Metetra
.592 .823 .988 r
.41703 .67513 .43959 .6871 .47794 .67226 .45571 .66648 Metetra
.5 .861 .988 r
.45571 .66648 .47794 .67226 .51675 .65703 .495 .65785 Metetra
.317 .806 .856 r
.495 .65785 .51675 .65703 .55602 .64238 .53493 .64868 Metetra
.53493 .64868 .55602 .64238 .59581 .6295 .57548 .63825 Metetra
.57548 .63825 .59581 .6295 .63626 .61992 .6166 .62566 Metetra
.317 .797 .733 r
.6166 .62566 .63626 .61992 .67759 .6155 .6582 .60984 Metetra
.691 .935 .965 r
.6582 .60984 .67759 .6155 .72012 .61852 .70011 .58952 Metetra
.744 .726 .835 r
.70011 .58952 .72012 .61852 .76438 .63184 .74207 .56327 Metetra
.698 .575 .713 r
.74207 .56327 .76438 .63184 .81109 .6591 .78376 .52949 Metetra
.664 .498 .65 r
.78376 .52949 .81109 .6591 .85988 .69018 .82473 .48651 Metetra
.648 .463 .62 r
.82473 .48651 .85988 .69018 .90585 .67815 .86441 .43259 Metetra
.594 .419 .614 r
.86441 .43259 .90585 .67815 .95255 .66592 .90828 .41783 Metetra
.592 .417 .614 r
.90828 .41783 .95255 .66592 1 .6535 .95296 .40417 Metetra
.619 .75 .94 r
.35559 .66467 .37892 .68421 .41703 .67513 .39398 .65652 Metetra
.603 .757 .952 r
.39398 .65652 .41703 .67513 .45571 .66648 .43298 .64915 Metetra
.594 .77 .964 r
.43298 .64915 .45571 .66648 .495 .65785 .47264 .64183 Metetra
.598 .789 .972 r
.47264 .64183 .495 .65785 .53493 .64868 .51299 .63359 Metetra
.621 .809 .972 r
.51299 .63359 .53493 .64868 .57548 .63825 .55401 .62317 Metetra
.666 .824 .959 r
.55401 .62317 .57548 .63825 .6166 .62566 .5956 .60899 Metetra
.723 .823 .927 r
.5956 .60899 .6166 .62566 .6582 .60984 .63759 .58916 Metetra
.771 .797 .874 r
.63759 .58916 .6582 .60984 .70011 .58952 .67968 .56153 Metetra
.797 .75 .81 r
.67968 .56153 .70011 .58952 .74207 .56327 .72145 .5237 Metetra
.803 .698 .749 r
.72145 .5237 .74207 .56327 .78376 .52949 .76231 .47315 Metetra
.77 .636 .713 r
.76231 .47315 .78376 .52949 .82473 .48651 .80261 .41992 Metetra
.632 .541 .734 r
.80261 .41992 .82473 .48651 .86441 .43259 .84643 .40628 Metetra
.664 .73 .898 r
.84643 .40628 .86441 .43259 .90828 .41783 .89092 .39244 Metetra
.664 .741 .907 r
.89092 .39244 .90828 .41783 .95296 .40417 .9361 .37838 Metetra
.633 .74 .925 r
.3317 .64324 .35559 .66467 .39398 .65652 .37045 .63385 Metetra
.628 .73 .921 r
.37045 .63385 .39398 .65652 .43298 .64915 .4098 .62492 Metetra
.628 .719 .912 r
.4098 .62492 .43298 .64915 .47264 .64183 .44981 .61591 Metetra
.636 .711 .901 r
.44981 .61591 .47264 .64183 .51299 .63359 .49048 .6061 Metetra
.65 .706 .887 r
.49048 .6061 .51299 .63359 .55401 .62317 .53182 .59453 Metetra
.672 .707 .874 r
.53182 .59453 .55401 .62317 .5956 .60899 .57377 .58005 Metetra
.7 .717 .862 r
.57377 .58005 .5956 .60899 .63759 .58916 .6162 .56126 Metetra
.737 .738 .852 r
.6162 .56126 .63759 .58916 .67968 .56153 .65889 .53655 Metetra
.784 .773 .843 r
.65889 .53655 .67968 .56153 .72145 .5237 .70155 .50409 Metetra
.842 .825 .831 r
.70155 .50409 .72145 .5237 .76231 .47315 .74373 .46194 Metetra
.908 .893 .803 r
.74373 .46194 .76231 .47315 .80261 .41992 .78487 .4081 Metetra
.777 .909 .931 r
.78487 .4081 .80261 .41992 .84643 .40628 .82808 .38056 Metetra
.664 .741 .907 r
.82808 .38056 .84643 .40628 .89092 .39244 .87307 .36632 Metetra
.664 .741 .907 r
.87307 .36632 .89092 .39244 .9361 .37838 .91876 .35185 Metetra
.653 .741 .914 r
.3072 .62066 .3317 .64324 .37045 .63385 .34637 .60914 Metetra
.653 .725 .902 r
.34637 .60914 .37045 .63385 .4098 .62492 .38613 .5975 Metetra
.653 .707 .886 r
.38613 .5975 .4098 .62492 .44981 .61591 .4265 .58561 Metetra
.654 .689 .87 r
.4265 .58561 .44981 .61591 .49048 .6061 .46749 .5733 Metetra
.656 .676 .857 r
.46749 .5733 .49048 .6061 .53182 .59453 .50912 .56036 Metetra
.66 .672 .85 r
.50912 .56036 .53182 .59453 .57377 .58005 .55137 .5465 Metetra
.668 .681 .853 r
.55137 .5465 .57377 .58005 .6162 .56126 .59423 .53143 Metetra
.682 .713 .872 r
.59423 .53143 .6162 .56126 .65889 .53655 .63765 .51476 Metetra
.703 .787 .917 r
.63765 .51476 .65889 .53655 .70155 .50409 .68159 .49607 Metetra
.69 .927 .969 r
.68159 .49607 .70155 .50409 .74373 .46194 .72594 .47487 Metetra
.72594 .47487 .74373 .46194 .78487 .4081 .77058 .45064 Metetra
.251 0 .134 r
.77058 .45064 .78487 .4081 .82808 .38056 .81536 .42281 Metetra
.215 0 .126 r
.81536 .42281 .82808 .38056 .87307 .36632 .86005 .39076 Metetra
.86005 .39076 .87307 .36632 .91876 .35185 .90441 .35385 Metetra
.67 .745 .907 r
.28204 .59751 .3072 .62066 .34637 .60914 .32165 .58385 Metetra
.674 .731 .893 r
.32165 .58385 .34637 .60914 .38613 .5975 .36186 .56954 Metetra
.673 .714 .879 r
.36186 .56954 .38613 .5975 .4265 .58561 .40263 .55486 Metetra
.669 .696 .866 r
.40263 .55486 .4265 .58561 .46749 .5733 .44398 .54025 Metetra
.662 .681 .858 r
.44398 .54025 .46749 .5733 .50912 .56036 .4859 .52621 Metetra
.651 .673 .858 r
.4859 .52621 .50912 .56036 .55137 .5465 .52846 .51343 Metetra
.634 .675 .872 r
.52846 .51343 .55137 .5465 .59423 .53143 .57173 .50272 Metetra
.602 .696 .91 r
.57173 .50272 .59423 .53143 .63765 .51476 .61584 .49508 Metetra
.507 .743 .98 r
.61584 .49508 .63765 .51476 .68159 .49607 .661 .49174 Metetra
.06 .616 .815 r
.661 .49174 .68159 .49607 .72594 .47487 .70751 .49419 Metetra
.484 0 0 r
.70751 .49419 .72594 .47487 .77058 .45064 .75578 .50432 Metetra
.588 .209 .292 r
.75578 .50432 .77058 .45064 .81536 .42281 .8064 .52451 Metetra
.575 .261 .398 r
.8064 .52451 .81536 .42281 .86005 .39076 .85873 .54317 Metetra
.509 .237 .437 r
.85873 .54317 .86005 .39076 .90441 .35385 .90916 .52869 Metetra
.681 .751 .904 r
.25616 .57411 .28204 .59751 .32165 .58385 .29622 .55892 Metetra
.686 .743 .894 r
.29622 .55892 .32165 .58385 .36186 .56954 .33687 .54274 Metetra
.686 .731 .885 r
.33687 .54274 .36186 .56954 .40263 .55486 .37808 .52617 Metetra
.68 .718 .878 r
.37808 .52617 .40263 .55486 .44398 .54025 .41981 .51005 Metetra
.666 .706 .878 r
.41981 .51005 .44398 .54025 .4859 .52621 .46209 .49543 Metetra
.641 .696 .886 r
.46209 .49543 .4859 .52621 .52846 .51343 .50498 .48365 Metetra
.597 .689 .907 r
.50498 .48365 .52846 .51343 .57173 .50272 .54864 .47636 Metetra
.505 .681 .945 r
.54864 .47636 .57173 .50272 .61584 .49508 .59332 .4756 Metetra
.262 .623 .96 r
.59332 .4756 .61584 .49508 .661 .49174 .6394 .48392 Metetra
.314 0 0 r
.6394 .48392 .661 .49174 .70751 .49419 .68749 .50458 Metetra
.667 .146 0 r
.68749 .50458 .70751 .49419 .75578 .50432 .73844 .54187 Metetra
.354 0 .09 r
.73844 .54187 .75578 .50432 .8064 .52451 .78798 .53094 Metetra
.78798 .53094 .8064 .52451 .85873 .54317 .83816 .51625 Metetra
.645 .763 .934 r
.83816 .51625 .85873 .54317 .90916 .52869 .88922 .50131 Metetra
.683 .756 .906 r
.22952 .55066 .25616 .57411 .29622 .55892 .26998 .53483 Metetra
.69 .755 .901 r
.26998 .53483 .29622 .55892 .33687 .54274 .31105 .51795 Metetra
.691 .753 .899 r
.31105 .51795 .33687 .54274 .37808 .52617 .35268 .50072 Metetra
.684 .749 .901 r
.35268 .50072 .37808 .52617 .41981 .51005 .39483 .48413 Metetra
.666 .744 .909 r
.39483 .48413 .41981 .51005 .46209 .49543 .43752 .46941 Metetra
.631 .735 .923 r
.43752 .46941 .46209 .49543 .50498 .48365 .48082 .45812 Metetra
.566 .718 .944 r
.48082 .45812 .50498 .48365 .54864 .47636 .52489 .4522 Metetra
.439 .677 .964 r
.52489 .4522 .54864 .47636 .59332 .4756 .57001 .45406 Metetra
.183 .56 .934 r
.57001 .45406 .59332 .4756 .6394 .48392 .61665 .46676 Metetra
0 .28 .714 r
.61665 .46676 .6394 .48392 .68749 .50458 .66547 .49424 Metetra
.31 0 0 r
.66547 .49424 .68749 .50458 .73844 .54187 .71619 .51853 Metetra
.64 .792 .955 r
.71619 .51853 .73844 .54187 .78798 .53094 .76611 .50362 Metetra
.645 .763 .934 r
.76611 .50362 .78798 .53094 .83816 .51625 .81691 .48845 Metetra
.645 .763 .934 r
.81691 .48845 .83816 .51625 .88922 .50131 .86863 .47301 Metetra
.678 .76 .913 r
.20205 .52714 .22952 .55066 .26998 .53483 .24285 .51159 Metetra
.683 .767 .914 r
.24285 .51159 .26998 .53483 .31105 .51795 .28429 .49521 Metetra
.684 .774 .92 r
.28429 .49521 .31105 .51795 .35268 .50072 .32631 .47857 Metetra
.677 .781 .929 r
.32631 .47857 .35268 .50072 .39483 .48413 .3689 .46248 Metetra
.658 .784 .941 r
.3689 .46248 .39483 .48413 .43752 .46941 .41205 .44796 Metetra
.622 .779 .957 r
.41205 .44796 .43752 .46941 .48082 .45812 .45583 .43631 Metetra
.56 .758 .97 r
.45583 .43631 .48082 .45812 .52489 .4522 .50037 .42913 Metetra
.463 .706 .974 r
.50037 .42913 .52489 .4522 .57001 .45406 .5459 .42841 Metetra
.324 .612 .952 r
.5459 .42841 .57001 .45406 .61665 .46676 .59279 .43666 Metetra
.155 .47 .893 r
.59279 .43666 .61665 .46676 .66547 .49424 .64159 .45709 Metetra
.043 .341 .82 r
.64159 .45709 .66547 .49424 .71619 .51853 .69298 .4908 Metetra
.645 .763 .934 r
.69298 .4908 .71619 .51853 .76611 .50362 .74352 .47541 Metetra
.645 .763 .934 r
.74352 .47541 .76611 .50362 .81691 .48845 .79496 .45973 Metetra
.645 .763 .934 r
.79496 .45973 .81691 .48845 .86863 .47301 .84734 .44377 Metetra
.664 .761 .922 r
.17372 .50339 .20205 .52714 .24285 .51159 .21479 .48887 Metetra
.666 .773 .929 r
.21479 .48887 .24285 .51159 .28429 .49521 .25652 .47391 Metetra
.664 .788 .94 r
.25652 .47391 .28429 .49521 .32631 .47857 .29889 .45879 Metetra
.658 .804 .953 r
.29889 .45879 .32631 .47857 .3689 .46248 .34191 .44386 Metetra
.644 .815 .965 r
.34191 .44386 .3689 .46248 .41205 .44796 .38557 .42959 Metetra
.623 .815 .974 r
.38557 .42959 .41205 .44796 .45583 .43631 .42992 .41657 Metetra
.597 .797 .976 r
.42992 .41657 .45583 .43631 .50037 .42913 .47503 .40555 Metetra
.569 .755 .965 r
.47503 .40555 .50037 .42913 .5459 .42841 .52101 .39741 Metetra
.54 .682 .931 r
.52101 .39741 .5459 .42841 .59279 .43666 .56804 .39327 Metetra
.511 .588 .869 r
.56804 .39327 .59279 .43666 .64159 .45709 .61638 .3945 Metetra
.484 .493 .791 r
.61638 .3945 .64159 .45709 .69298 .4908 .6664 .40282 Metetra
.46 .42 .726 r
.6664 .40282 .69298 .4908 .74352 .47541 .71863 .42044 Metetra
.461 .516 .828 r
.71863 .42044 .74352 .47541 .79496 .45973 .77227 .43004 Metetra
.645 .763 .934 r
.77227 .43004 .79496 .45973 .84734 .44377 .82533 .41353 Metetra
.646 .758 .931 r
.14451 .47914 .17372 .50339 .21479 .48887 .18581 .46594 Metetra
.642 .772 .942 r
.18581 .46594 .21479 .48887 .25652 .47391 .22777 .4528 Metetra
.638 .79 .955 r
.22777 .4528 .25652 .47391 .29889 .45879 .27045 .43955 Metetra
.634 .809 .967 r
.27045 .43955 .29889 .45879 .34191 .44386 .31387 .42596 Metetra
.634 .825 .974 r
.31387 .42596 .34191 .44386 .38557 .42959 .35807 .41172 Metetra
.643 .831 .973 r
.35807 .41172 .38557 .42959 .42992 .41657 .40307 .39648 Metetra
.661 .82 .96 r
.40307 .39648 .42992 .41657 .47503 .40555 .44886 .37982 Metetra
.681 .781 .926 r
.44886 .37982 .47503 .40555 .52101 .39741 .49542 .36121 Metetra
.689 .713 .867 r
.49542 .36121 .52101 .39741 .56804 .39327 .54269 .3401 Metetra
.68 .631 .794 r
.54269 .3401 .56804 .39327 .61638 .3945 .59057 .31584 Metetra
.66 .555 .725 r
.59057 .31584 .61638 .3945 .6664 .40282 .63891 .28773 Metetra
.64 .494 .669 r
.63891 .28773 .6664 .40282 .71863 .42044 .68751 .25501 Metetra
.621 .449 .628 r
.68751 .25501 .71863 .42044 .77227 .43004 .73612 .2169 Metetra
.612 .425 .605 r
.73612 .2169 .77227 .43004 .82533 .41353 .7844 .17261 Metetra
.631 .753 .936 r
.11443 .45396 .14451 .47914 .18581 .46594 .15594 .44181 Metetra
.621 .762 .947 r
.15594 .44181 .18581 .46594 .22777 .4528 .19814 .43012 Metetra
.617 .777 .957 r
.19814 .43012 .22777 .4528 .27045 .43955 .2411 .4183 Metetra
.621 .794 .965 r
.2411 .4183 .27045 .43955 .31387 .42596 .28493 .40559 Metetra
.639 .81 .965 r
.28493 .40559 .31387 .42596 .35807 .41172 .32968 .39096 Metetra
.671 .819 .954 r
.32968 .39096 .35807 .41172 .40307 .39648 .37535 .37318 Metetra
.712 .811 .926 r
.37535 .37318 .40307 .39648 .44886 .37982 .4219 .35076 Metetra
.747 .779 .879 r
.4219 .35076 .44886 .37982 .49542 .36121 .46917 .32199 Metetra
.765 .726 .817 r
.46917 .32199 .49542 .36121 .54269 .3401 .51691 .28495 Metetra
.764 .665 .752 r
.51691 .28495 .54269 .3401 .59057 .31584 .56473 .23763 Metetra
.753 .607 .696 r
.56473 .23763 .59057 .31584 .63891 .28773 .61208 .17799 Metetra
.642 .499 .673 r
.61208 .17799 .63891 .28773 .68751 .25501 .66012 .14509 Metetra
.597 .471 .679 r
.66012 .14509 .68751 .25501 .73612 .2169 .70945 .12694 Metetra
.61 .507 .711 r
.70945 .12694 .73612 .2169 .7844 .17261 .75965 .10848 Metetra
.626 .746 .934 r
.0835 .42734 .11443 .45396 .15594 .44181 .12532 .41523 Metetra
.617 .747 .939 r
.12532 .41523 .15594 .44181 .19814 .43012 .16783 .40365 Metetra
.616 .751 .942 r
.16783 .40365 .19814 .43012 .2411 .4183 .21116 .39187 Metetra
.626 .758 .941 r
.21116 .39187 .2411 .4183 .28493 .40559 .25541 .37889 Metetra
.65 .767 .934 r
.25541 .37889 .28493 .40559 .32968 .39096 .30066 .36342 Metetra
.685 .774 .919 r
.30066 .36342 .32968 .39096 .37535 .37318 .34693 .34383 Metetra
.726 .774 .891 r
.34693 .34383 .37535 .37318 .4219 .35076 .39416 .31823 Metetra
.765 .766 .853 r
.39416 .31823 .4219 .35076 .46917 .32199 .44215 .28444 Metetra
.797 .748 .807 r
.44215 .28444 .46917 .32199 .51691 .28495 .49058 .24008 Metetra
.819 .723 .759 r
.49058 .24008 .51691 .28495 .56473 .23763 .53895 .18271 Metetra
.784 .677 .746 r
.53895 .18271 .56473 .23763 .61208 .17799 .58699 .12975 Metetra
.649 .646 .833 r
.58699 .12975 .61208 .17799 .66012 .14509 .63605 .11134 Metetra
.664 .741 .907 r
.63605 .11134 .66012 .14509 .70945 .12694 .68597 .0926 Metetra
.664 .741 .907 r
.68597 .0926 .70945 .12694 .75965 .10848 .7368 .07352 Metetra
.642 .741 .921 r
.05179 .3987 .0835 .42734 .12532 .41523 .09414 .38472 Metetra
.638 .73 .915 r
.09414 .38472 .12532 .41523 .16783 .40365 .13721 .37085 Metetra
.638 .718 .905 r
.13721 .37085 .16783 .40365 .21116 .39187 .18107 .35669 Metetra
.643 .707 .893 r
.18107 .35669 .21116 .39187 .25541 .37889 .22581 .34167 Metetra
.652 .7 .882 r
.22581 .34167 .25541 .37889 .30066 .36342 .27146 .3251 Metetra
.668 .703 .873 r
.27146 .3251 .30066 .36342 .34693 .34383 .31807 .30609 Metetra
.691 .717 .869 r
.31807 .30609 .34693 .34383 .39416 .31823 .3656 .28359 Metetra
.724 .749 .872 r
.3656 .28359 .39416 .31823 .44215 .28444 .41397 .25638 Metetra
.771 .807 .882 r
.41397 .25638 .44215 .28444 .49058 .24008 .46303 .22308 Metetra
.828 .898 .89 r
.46303 .22308 .49058 .24008 .53895 .18271 .5125 .18218 Metetra
.854 .992 .838 r
.5125 .18218 .53895 .18271 .58699 .12975 .562 .13211 Metetra
.865 .996 .794 r
.562 .13211 .58699 .12975 .63605 .11134 .61118 .07647 Metetra
.664 .741 .907 r
.61118 .07647 .63605 .11134 .68597 .0926 .66171 .0571 Metetra
.664 .741 .907 r
.66171 .0571 .68597 .0926 .7368 .07352 .71317 .03738 Metetra
.678 .738 .896 r
.01937 .36738 .05179 .3987 .09414 .38472 .06268 .34873 Metetra
.679 .712 .873 r
.06268 .34873 .09414 .38472 .13721 .37085 .10675 .32907 Metetra
.672 .68 .85 r
.10675 .32907 .13721 .37085 .18107 .35669 .15149 .30911 Metetra
.658 .65 .83 r
.15149 .30911 .18107 .35669 .22581 .34167 .19682 .28984 Metetra
.639 .625 .82 r
.19682 .28984 .22581 .34167 .27146 .3251 .24267 .27251 Metetra
.614 .613 .827 r
.24267 .27251 .27146 .3251 .31807 .30609 .28904 .25868 Metetra
.571 .621 .863 r
.28904 .25868 .31807 .30609 .3656 .28359 .336 .2503 Metetra
.451 .659 .95 r
.336 .2503 .3656 .28359 .41397 .25638 .38374 .24976 Metetra
0 .448 .696 r
.38374 .24976 .41397 .25638 .46303 .22308 .4326 .26013 Metetra
.559 .085 .086 r
.4326 .26013 .46303 .22308 .5125 .18218 .48314 .28534 Metetra
.518 .153 .287 r
.48314 .28534 .5125 .18218 .562 .13211 .53611 .30341 Metetra
.424 .116 .337 r
.53611 .30341 .562 .13211 .61118 .07647 .59064 .28447 Metetra
.439 .142 .364 r
.59064 .28447 .61118 .07647 .66171 .0571 .64625 .26515 Metetra
.439 .142 .364 r
.64625 .26515 .66171 .0571 .71317 .03738 .70298 .24544 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.10206 .22973 m
.10675 .23431 L
s
[(0.2)] .09267 .22056 1 .97619 Mshowa
.23703 .17687 m
.2415 .18167 L
s
[(0.4)] .22808 .16727 .93173 1 Mshowa
.37937 .12114 m
.38359 .12616 L
s
[(0.6)] .37094 .11108 .83907 1 Mshowa
.52971 .06227 m
.53364 .06753 L
s
[(0.8)] .52186 .05175 .7464 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.13514 .21677 m
.13793 .21955 L
s
.16866 .20365 m
.17141 .20646 L
s
.20262 .19035 m
.20534 .1932 L
s
.2719 .16322 m
.27455 .16613 L
s
.30724 .14938 m
.30985 .15233 L
s
.34306 .13535 m
.34564 .13834 L
s
.41618 .10672 m
.41867 .10977 L
s
.4535 .09211 m
.45595 .0952 L
s
.49134 .07729 m
.49374 .08041 L
s
.56863 .04703 m
.57093 .05022 L
s
.60809 .03158 m
.61035 .0348 L
s
.64813 .0159 m
.65033 .01916 L
s
.0694 .24251 m
.07225 .24523 L
s
.03716 .25514 m
.04004 .25782 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[164]:=",
  ImageSize->{190.375, 154.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002n0000VR000`400?l00000o`00003o_P3oool0
0;h0oooo002n0?ooo`00_P3oool00;h0oooo002n0?ooo`00_P3oool00;h0oooo002n0?ooo`00_P3o
ool00;h0oooo002n0?ooo`00_P3oool00;h0oooo002n0?ooo`00_P3oool00;h0oooo002n0?ooo`00
_P3oool00;h0oooo00220?ooo`D00000=`3oool008@0oooo00<000000?ooo`3oool0=`3oool008@0
oooo00<000000?ooo`3oool0=`3oool008@0oooo00<000000?ooo`3oool0=`3oool008@0oooo00<0
00000?ooo`3oool0=`3oool008<0oooo0P0000050?ooo`800000<P3oool008T0oooo00@000000?oo
o`3oool00000<@3oool008T0oooo00@000000?ooo`3oool00000<@3oool006<0oooo0P0000040?oo
o`800000103oool2000001P0oooo00@000000?ooo`3oool00000<@3oool00680oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000D0?ooo`80000000D0oooo0000003oool0oooo
0000000a0?ooo`00HP3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000180
oooo1@0000000`3oool000000000000b0?ooo`00HP3oool010000000oooo0?ooo`0000090?ooo`80
0000403oool3000000<0oooo0P00000e0?ooo`00HP3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000d0oooo100000040?ooo`030000003oool0000003@0oooo001S0?ooo`80
00002P3oool2000000/0oooo0`0000080?ooo`@00000<`3oool007X0oooo0`00000:0?ooo`040000
003oool00000000003<0oooo001g0?ooo`<000003@3oool200000003070TG@00000000000380oooo
001?0?ooo`800000103oool2000000<0oooo0`00000H0?ooo`<000003@3oool300000080L2AM0P00
000b0?ooo`00CP3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001@0oooo
0`00000=0?ooo`<000000P1`95d01P000000L2AM070TG@000000ZKgX00000340oooo001>0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000004P3oool4000000/0oooo0`000000
0`1`95d00000070TG@02070TG@050000001`95d0L2AM0000002Y_NP00P00000`0?ooo`00CP3oool0
10000000oooo0?ooo`0000080?ooo`<00000403oool3000000d0oooo0P000004070TG@050000001`
95d0L2AM070TG@0000000P1`95d010000000ZKgX00000000000`0?ooo`00CP3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00d0oooo0`00000>0?ooo`8000001@1`95d01@000000
L2AM070TG@1`95d000000080L2AM0P0000020:Vmj0030000003oool0oooo02d0oooo001?0?ooo`80
00002P3oool3000000X0oooo0`00000@0?ooo`030000001/7EH0000000D0L2AM00L00000070TG@1`
95d0L2AM0000001`95d0000000@0ZKgX0P0000050?ooo`800000103oool2000000<0oooo10000003
0?ooo`8000005@3oool006H0oooo0`00000A0?ooo`040000001/7EH0K1eF000000D0L2AM00L00000
070TG@1`95d0L2AM0000001`95d0000000D0ZKgX00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000503oool003/0
oooo0P0000040?ooo`8000001@3oool3000001P0oooo0`00000C0?ooo`050000001/7EH0K1eF06`M
EP0000001@1`95d01`000000L2AM070TG@1`95d00000070TG@0000001@2Y_NP2000000<0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo
000j0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool05@3oool2000000030?oo
o`000000oooo01<0oooo00@0000006`MEP1/7EH000001@1`95d00`000000L2AM070TG@02070TG@03
0000001`95d0000000D0ZKgX0`0000020?ooo`040000003oool0oooo000000X0oooo00<000000?oo
o`3oool00P3oool2000001D0oooo000j0?ooo`040000003oool0oooo000000P0oooo1@00000C0?oo
o`<000005`3oool01@000000K1eF06`MEP1/7EH0000000D0L2AM00<00000070TG@1`95d00P1`95d0
10000000L2AM0000002Y_NP40000000309b1]P00000000000080oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo01@0oooo000j0?ooo`040000
003oool0oooo000000P0oooo00@000000?ooo`3oool000004P3oool2000000030?ooo`000000oooo
01H0oooo00<0000006`MEP1/7EH00P1/7EH00`000000L2AM070TG@03070TG@030000001`95d0L2AM
00<0L2AM0`00000609b1]P8000000P3oool2000000X0oooo0P0000040?ooo`<00000503oool003X0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0000000?0?ooo`<000006P3oool00`00
0000K1eF06`MEP0306`MEP030000001`95d0L2AM00<0L2AM00<00000070TG@1`95d00`1`95d20000
00L0W86f00<000000?ooo`000000:P3oool003/0oooo0P00000;0?ooo`8000003@3oool2000001`0
oooo0P00000506`MEP030000001`95d0L2AM00<0L2AM00<00000070TG@1`95d00`1`95d3000000H0
W86f00<000000?ooo`000000:P3oool005@0oooo0`00000M0?ooo`03000000249dT0000000D0K1eF
00<00000070TG@1`95d00`1`95d00`000000L2AM070TG@03070TG@<000001`2LPKH3000002T0oooo
000Y0?ooo`800000103oool2000000<0oooo1000000J0?ooo`8000007`3oool010000000Q2M908@W
B@00000506`MEP030000001`95d0L2AM00<0L2AM00<00000070TG@1`95d00`1`95d3000000L0W86f
00<000000?ooo`000000:@3oool002P0oooo00@000000?ooo`3oool00000203oool00`000000oooo
0?ooo`0H0?ooo`<00000803oool010000000Q2M908@WB@00000606`MEP030000001`95d0L2AM00<0
L2AM00<00000070TG@1`95d00`1`95d20000000309Qh[@000000W86f00H0W86f00<000000?ooo`00
0000:03oool002P0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0D0?ooo`<0
00008P3oool01@000000Q2M908@WB@249dT0000000H0K1eF00<00000070TG@1`95d00`1`95d00`00
0000L2AM070TG@03070TG@80000000<0V7R]0000002LPKH01P2LPKH010000000oooo00000000000W
0?ooo`00:03oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0140oooo1000000R
0?ooo`03000000249dT0Q2M90080Q2M900<0000006`MEP1/7EH00`1/7EH00`000000L2AM070TG@04
070TG@030000001`95d0L2AM00<0L2AM0P0000000`2HN:d0000009b1]P0509b1]P8000000P3oool0
0`000000oooo0?ooo`0U0?ooo`00:03oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo00000100oooo0P00000T0?ooo`<0000010249dT00`000000K1eF06`MEP0306`MEP030000001`
95d0L2AM00@0L2AM00<00000070TG@1`95d00`1`95d200000080V7R]00<0000009b1]P2LPKH00P2L
PKH00`000000W6bJ000000030?ooo`030000003oool0oooo02@0oooo000Y0?ooo`8000002P3oool2
000000h0oooo1000000T0?ooo`030000002?5AH0000000D0Q2M900<0000006`MEP1/7EH00`1/7EH0
0`000000L2AM070TG@04070TG@030000001`95d0L2AM00<0L2AM00D0000009Qh[@2HN:d0V7R]0000
000309b1]P040000002LK9X0W6bJ000000<0oooo0P00000U0?ooo`00@`3oool2000002L0oooo00@0
000008lE5P2?5AH000001@249dT00`000000K1eF06`MEP0306`MEP030000001`95d0L2AM00@0L2AM
00<00000070TG@1`95d00`1`95d01@000000V7R]09Qh[@2HN:d000000080W86f00<0000009a/VP2L
K9X00P2LK9X01@000000oooo0?ooo`3oool0000000D0oooo0P0000040?ooo`800000103oool20000
0180oooo00100?ooo`<000009`3oool2000000<0SaDF00<0000008@WB@249dT00`249dT00`000000
K1eF06`MEP0306`MEP030000001`95d0L2AM00@0L2AM00<00000070TG@1`95d00`1`95d00`000000
V7R]09Qh[@0209Qh[@8000001@2LK9X00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000140oooo000n0?oo
o`800000:@3oool00`000000SaDF08lE5P0208lE5P03000000249dT0Q2M900<0Q2M900<0000006`M
EP1/7EH0101/7EH00`000000L2AM070TG@03070TG@030000001`95d0L2AM00@0L2AM00<0000009Qh
[@2HN:d00P2HN:d00`000000W6bJ09a/VP0409a/VP070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool03`3oool003/0oooo0`00
000Z0?ooo`030000002?5AH0SaDF00<0SaDF00<0000008@WB@249dT00`249dT00`000000K1eF06`M
EP0406`MEP030000001`95d0L2AM00<0L2AM00<00000070TG@1`95d0101`95d00`000000V7R]09Qh
[@03000000H0W6bJ00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo00L0oooo0P00000B0?ooo`00>@3oool3000002/0oooo00<0000008lE5P2?5AH0102?
5AH00`000000Q2M908@WB@0308@WB@030000001/7EH0K1eF00@0K1eF00<00000070TG@1`95d00`1`
95d00`000000L2AM070TG@04070TG@030000002HN:d000000080WW:P00<0000009a/VP2LK9X0102L
K9X00`000000oooo0?ooo`040?ooo`030000003oool000000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0A0?ooo`00=P3oool3000002`0oooo0`00000608lE5P03000000249dT0
Q2M900<0Q2M900<0000006`MEP1/7EH0101/7EH00`000000L2AM070TG@03070TG@030000001`95d0
L2AM00<0L2AM0`00000309ibX0030000002LK9X0W6bJ00@0W6bJ00<000000?ooo`3oool00`3oool0
10000000oooo0000003oool2000000X0oooo0`00000A0?ooo`00=03oool200000240oooo2`000002
0?ooo`0300000000L[80000000H0SaDF00<0000008@WB@249dT010249dT00`000000K1eF06`MEP03
06`MEP030000001`95d0L2AM00@0L2AM00<00000070TG@1`95d01P00000409ibX0030000002LK9X0
W6bJ00@0W6bJ00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0O0?ooo`00<P3oool20000
01h0oooo1@00000309:Ng0030000001cZ?<0LjSc00@0LjSc1P00000608lE5P03000000249dT0Q2M9
00@0Q2M900<0000006`MEP1/7EH00`1/7EH00`000000L2AM070TG@04070TG@@0000000D0Y7n/0000
002NLZ00WW:P0000000409ibX0030000002LK9X0W6bJ00@0W6bJ00<000000?ooo`3oool0103oool2
00000200oooo000b0?ooo`8000006`3oool300000080WIcC00<0000009:Ng02BW]`0102BW]`00`00
0000LjSc07>Xl`0307>Xl`80000000@0^KoO00000035c^40aLkQ0P00000408lE5P03000000249dT0
Q2M900@0Q2M900<0000006`MEP1/7EH00`1/7EH00`000000L2AM070TG@02070TG@@0000000@0Y7n/
00000000000000000`2NLZ001@000000WW:P09ibX02NLZ00000000H0W6bJ00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0N0?ooo`00<P3oool00`000000oooo0000000G0?ooo`<000001@2M
W=<00`000000TYkL09:Ng00509:Ng0030000001cZ?<0LjSc00800000102i_ml2000000060<G>h@00
000000000000002?5AH000001`249dT00`000000K1eF06`MEP0306`MEP030000001`95d0000000@0
00000P2TOj`010000000Xgj[0:=nZ`00000409ibX0040000002NLZ00WW:P000000H0W6bJ00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0M0?ooo`00<@3oool200000080oooo00<000000?oo
o`3oool04@3oool300000080XioA00<0000009fLd`2MW=<0102MW=<00`000000TYkL09:Ng00509:N
g0800000202i_ml010000000c;o>0<bocP3<_lh3000000D0Q2M900<0000006`MEP1/7EH00`1/7EH3
000000@0`9^b0`0000040:=nZ`030000002NLZ00WW:P0080WW:P00<0000009ibX00000001P2LK9X0
0`000000oooo0?ooo`060?ooo`8000007P3oool00340oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0>0?ooo`8000001@2SWm400`000000WIcC09fLd`0509fLd`030000002BW]`0TYkL
0080TYkL0P0000000`2`]mh000000;Vog`050;Vog`80000000<0`lCJ0000003<_lh0103<_lh20000
00<0Q2M900<0000006`MEP1/7EH0100000060<2K/P030000002SOZ/0Xgj[00@0Xgj[00<0000009ib
X02NLZ000P2NLZ000`000000WW:P0000000609a/VP030000003oool0oooo00L0oooo00<000000?oo
o`3oool0703oool00340oooo0P0000040?ooo`030000003oool0oooo00/0oooo0P0000000`2XY]@0
00000:>Od@050:>Od@030000002MW=<0WIcC00@0WIcC00<0000009:Ng02BW]`00P0000030;2ggP03
0000002i_ml0^KoO00<0^KoO00D000000<?4fP33a=X0`lCJ000000050<bocP0500000033^M400000
000000249dT0100000020<>Z`00300000030Vk80`9^b0080`9^b0`0000060:=nZ`030000002NLZ00
WW:P00<0WW:P0P00000709a/VP030000003oool0oooo00H0oooo0P00000M0?ooo`00<@3oool20000
00D0oooo0P0000090?ooo`8000000`2XY]@00`000000XioA0:>Od@040:>Od@030000002MW=<0WIcC
00D0WIcC0P0000060;2ggP050000002i_ml0^KoO0;Vog`0000001@33a=X00`000000c;o>0<bocP02
00000080`kWA1@0000050<>Z`00400000030Vk800000000000<0Z8ji00<000000:=nZ`2SOZ/00`2S
OZ/00`000000WW:P09ibX00409ibX08000001P2LK9X00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00<0oooo0P0000040?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`8000000`3o
ool000P0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo0P0000030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00`3oool3
000000H0Z:KD00<000000:>Od@2SWm40102SWm400`000000WIcC09fLd`0209fLd`80000000<0Zk?O
0000002`]mh01@2`]mh010000000^KoO0000000000060<?4fP040000003<_lh000000<>id@<00000
0P33^M400`000000`j[00<>Z`0050<>Z`08000001@2XS[T00`000000Xgj[0:=nZ`030:=nZ`030000
002NLZ00WW:P00D0WW:P00<0000009a/VP2LK9X0102LK9X00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000002P3oool01@000000oooo0?ooo`3oool00000
0080oooo0@0000010?ooo`40oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`0000000P0000020:b^f@030000002XY]@0Z:KD00@0Z:KD00<000000:>O
d@2SWm40102SWm400`000000WIcC09fLd`02000000<0Zk?O00<000000;2ggP2`]mh01@2`]mh00`00
0000`lCJ0<?4fP070<?4fP<000001@33^M400`000000`j[00<>Z`0030<>Z`0<000001P2XS[T00`00
0000Xgj[0:=nZ`040:=nZ`030000002NLZ00WW:P00@0WW:P00<0000009a/VP2LK9X0102LK9X00`00
0000oooo0?ooo`080?ooo`8000000`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0
oooo00@0oooo0@0000010?ooo`40oooo00070?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000001@3oool010000000oooo0000000000090?ooo`8000001@2/[]T0
0`000000Z:KD0:RVe0050:RVe0030000002SWm40XioA00<0XioA0`0000060:^cg`030000002`]mh0
/;ON0080/;ON0P0000000`2ia^@000000<?4fP050<?4fP@000001`33^M401@000000`j[00<>Z`033
Z/00000000<0[Z7;00<000000:R>^@2XS[T00`2XS[T00`000000Xgj[0:=nZ`040:=nZ`030000002N
LZ00WW:P00@0WW:P0P00000509a/VP030000003oool0oooo00X0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`8000000`3oool000030?oo
o`0000000000008000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000<0oooo0P0000020?ooo`8000001`3oool2000000030:ffg`000000[:kI00D0[:kI
00<000000:RVe02XY]@0102XY]@00`000000XioA0:>Od@0300000080Y[?Q00<000000:^cg`2[/ml0
102[/ml00`000000/;ON0;2ggP02000000@0^LKT00<000000<?4fP33a=X00`0000040;o7h@030000
0033^M40`kWA00@0`kWA00@000000<>Z`00000000000102^XL/00`000000Z8ji0:R>^@040:R>^@03
0000002SOZ/0Xgj[00<0Xgj[00<0000009ibX02NLZ00102NLZ000`000000W6bJ0000000409a/VP03
0000003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool000L0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo
0?ooo`8000001@3oool2000000<0[KKO00<000000:b^f@2/[]T01@2/[]T00`000000Z:KD0:RVe003
0:RVe0<000001@2V/n400`000000Zk?O0:^cg`050:^cg`8000001P2ia^@5000000D0_lOQ00<00000
0<>id@33^M401033^M42000000H0[Z7;00<000000:R>^@2XS[T0102XS[T00`000000Xgj[0:=nZ`03
0:=nZ`030000002NLZ00WW:P00@0WW:P00@0000009a/VP2LK9X00000102LK9X00`000000oooo0?oo
o`080?ooo`030000003oool000000080oooo0P0000090?ooo`@000000`3oool300000080oooo0008
0?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0`000000
0`3oool000000?ooo`020?ooo`<000001P2]]]l00`000000[:kI0:b^f@040:b^f@030000002XY]@0
Z:KD00<000000P2T]>@00`000000Y[?Q0:Jch@040:Jch@030000002[/ml0Zk?O0080Zk?O0P000000
0`2_a^/000000;W6i0020;W6i0<000000P2ia^@00`000000_lOQ0;o7h@060;o7h@0300000033^M40
`kWA00<0000000<0/;KM0000002^XL/01@2^XL/00`000000Z8ji0:R>^@040:R>^@030000002SOZ/0
Xgj[00<0Xgj[00<0000009ibX02NLZ001@2NLZ000`000000W6bJ0000000409a/VP030000003oool0
oooo00T0oooo0`00000H0?ooo`00<03oool400000080[KcU00<000000:ffg`2]]]l01@2]]]l00`00
0000[:kI0:b^f@030:b^f@<000001@2T]>@00`000000Y[?Q0:Jch@040:Jch@030000002[/ml0Zk?O
00800000102_a^/3000000<0^LKT0P0000000`2fcnd000000;o7h@070;o7h@8000001@2`]]d00`00
0000[Z7;0:jQb`040:jQb`030000002XS[T0Z8ji00<0Z8ji00<000000:=nZ`2SOZ/00`2SOZ/00`00
0000WW:P09ibX00509ibX0040000002LK9X0W6bJ000000<0W6bJ00<000000?ooo`3oool01P3oool4
000000030:Vmj0000000oooo01L0oooo000`0?ooo`8000001@2]_>D2000000D0[KKO00<000000:b^
f@2/[]T00`0000020:>gi`030000002T]>@0Y;CT00@0Y;CT00<000000:Jch@2V/n400`2V/n430000
00@0[lK[0P000000102_a^/000000;W6i02ia^@2000000@0]/o]00<000000;o7h@2oan400`2oan42
000000030:k7k@000000/;KM00@0/;KM00<000000:jQb`2^XL/0102^XL/00`000000Z8ji0:R>^@04
0:R>^@030000002SOZ/0Xgj[00<0Xgj[00<0000009ibX02NLZ00102NLZ001@000000W6bJ09a/VP2L
K9X000000080W6bJ00<000000?ooo`3oool00`3oool500000005088lK`000000ZKgX0:Vmj0000000
5`3oool002X0oooo0P0000030?ooo`030000003oool0000000L0[KcU00@000000:ffg`2]]]l0[KKO
100000060:>gi`030000002T]>@0Y;CT00<0Y;CT00<000000:Jch@2V/n400`0000020:K4k`030000
002_a^/00000008000000`2_a^/3000000L0]/o]00<000000;o7h@2oan400P0000030:k7k@030000
002`]]d0/;KM00@0/;KM00<000000:jQb`2^XL/00`2^XL/00`000000Z8ji0:R>^@040:R>^@030000
002SOZ/0Xgj[00<0Xgj[00<0000009ibX02NLZ00102NLZ000`000000W6bJ09a/VP0209a/VP030000
002LK9X0000000<0oooo0P000000100g02000000000000000002088lK`030000002Y_NP0ZKgX0080
00005P3oool002T0oooo00@000000?ooo`3oool000000P3oool2000000030?ooo`000000[KcU00D0
[KcU100000030:>jjP030000002S]nL0XkOW00D0XkOW00@000000:Bdi02T]>@0Y;CT100000040:K4
k`@000000P2_a^/300000080Zm7d00<000000;K?k@2fcnd01@2fcnd3000000H0[/O]00<000000;2f
g@2`]]d00`2`]]d00`000000[Z7;0:jQb`030:jQb`030000002XS[T0Z8ji00@0Z8ji00<000000:=n
Z`2SOZ/00`2SOZ/00`000000WW:P09ibX00409ibX0030000002LK9X0W6bJ0080W6bJ00@0000009a/
VP000000oooo0P00000203L0808000001022?6l3000000030:Vmj0000000oooo01D0oooo000Y0?oo
o`040000003oool0oooo00000080oooo0P0000020?ooo`030000002]_>D0[KcU00<000000P2T_N/0
0`000000Xk[Z0:>jjP030:>jjP030000002S]nL0XkOW00@0XkOW100000030:32l0030000002Va>l0
0000008000000`2Va>l3000000H0Zm7d0P0000020;K?k@<000000P2YdOD00`000000[/O]0:k7k@04
0:k7k@030000002`]]d0/;KM0080/;KM1@0000030:jQb`030000002XS[T0Z8ji00<0Z8ji00<00000
0:=nZ`2SOZ/00`2SOZ/00`000000WW:P09ibX00409ibX0030000002LK9X0W6bJ00<0W6bJ00@00000
09a/VP00000000000`0g02000`000000PSa_088lK`03088lK`030000002Y_NP0ZKgX0080ZKgX00<0
00000?ooo`3oool04`3oool002T0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`020?ooo`8000001P2T_N/00`000000Xk[Z0:>jjP030:>jjP030000002S]nL0XkOW00<000000P2M
`?4010000000X<;`0:32l02P`_0400000080Y/C_0`0000020:??m`030000002[dO@0Zm7d00D0Zm7d
0`0000060:WAm@030000002^and0[/O]0080[/O]1P00000208Z^kP0300000022U]h0PYKN00L00000
0`2XS[T00`000000Xgj[0:=nZ`020:=nZ`030000002NLZ00WW:P00@0WW:P00<0000009a/VP2LK9X0
102LK9X200000080=`0P0`000005088lK`030000002Y_NP0ZKgX0080ZKgX00<000000?ooo`3oool0
0`3oool5000000/0oooo000Y0?ooo`040000003oool0oooo00000080oooo0P0000040?ooo`030000
002T_N/0Y;g[00D0Y;g[00@000000:>jjP2S^^X0Xk[Z1000000609g0l@<000000`2P`_03000000H0
Xlog0P0000020:_Am0<000000P2Te?T2000000@0ZM7e1P0000030971m`030000002:[^h0RZk^00<0
RZk^00<0000008:FgP22U]h00P22U]h010000000Ngk:07]nbP1kO/X5000000@0Xgj[00<0000009ib
X02NLZ00102NLZ000`000000W6bJ09a/VP0309a/VP80000000D0=`0P0000002C@VD0Td9U00000005
088lK`030000002Y_NP0ZKgX0080ZKgX0P0000060?ooo`030000003oool0oooo00/0oooo000Z0?oo
o`8000000`3oool00`000000oooo0?ooo`040?ooo`030000002T_N/0Y;g[00@0Y;g[1000000309fo
l0030000002M`?40WL3a0080WL3a0P000000102M`?4000000:32l02P`_0200000080W/_g00<00000
0:??m`2ScoL01@2ScoL3000000H0Y=Ci1@00000309S<n@030000002A`OL0TL7g00<0TL7g00<00000
08Z^kP2:[^h00`2:[^h00`000000PYKN08:FgP0308:FgP030000001kO/X0Ngk:00<0Ngk:00<00000
07E[^@0000000P0000000`2SOZ/0000009ibX00509ibX0030000002LK9X0W6bJ00<0W6bJ0`000003
09=2I@0300000022?6l0PSa_00<0PSa_00<000000:Vmj00000000P0000000`2GJYd0000000000005
0?ooo`030000003oool0oooo00/0oooo000^0?ooo`8000001`3oool00`000000Y;g[0:Bmj`030000
0080X;k_00<0000009fol02M_o000`2M_o0400000080WL3a1000000509k;m`8000000P2ScoL30000
0080X]?i0P0000020:CDn@<000000P2Od?T00`000000V<ci09S<n@0409S<n@030000002A`OL0TL7g
00<0TL7g00<0000008Z^kP2:[^h00`2:[^h00`000000PYKN08:FgP0208:FgP030000001kO/X0Ngk:
00@0Ngk:00@0000007E[^@1eJkT0MF^i1@00000309ibX0030000002LK9X0000000<000000P2U`nl0
1@000000Td9U09=2I@2C@VD0000000D0PSa_0P00000409MZW@8000001@3oool00`000000oooo0?oo
o`0;0?ooo`00;P3oool2000000P0oooo0P0000060:2nk`030000002M_o00WKo`00P000000`2Ma_@2
000000@0W/_g100000060:;Cn@<000001P2Od?T00`000000V<ci09S<n@0209S<n@/000000P2:[^h0
0`000000PYKN08:FgP0208:FgP030000001kO/X0Ngk:00@0Ngk:00<0000007E[^@1eJkT00`1eJkT0
0`000000MXCC07J4d`05000000H0YL?_0P00000209=2I@0300000022?6l0PSa_00<0PSa_00<00000
09MZW@2GJYd0102GJYd2000000@0oooo00<000000?ooo`3oool02`3oool000D0oooo0P0000040?oo
o`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000030?oo
o`8000002@3oool00`000000X;k_0:2nk`040:2nk`<0000000<0WKo`0000000000000P2N`o800`00
0000WLKd09g6m00409g6m0D000000`2RcoL2000000<0X]?i0P0000020:C@m`030000002Od?T0Wm3i
00@0Wm3i1@00000308o2n0030000001f]?T0M[Ci00<0M[Ci00<0000005:Ll`0000000`00000408:F
gP030000001kO/X0Ngk:00<0Ngk:00<0000007E[^@1eJkT00`1eJkT00`000000MXCC07J4d`0407J4
d`030000002U`nl0YL?_00D0YL?_00@0000009=2I@2C@VD000001@22?6l00`000000UfZM09MZW@04
09MZW@8000000`3oool2000000d0oooo00040?ooo`040000003oool0oooo000000P0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`8000002P3oool2
000000030:2nk`000000000000D000001@2N`o8200000080WLKd0P0000020:?:m0030000002RcoL0
X/og00D0X/og0`0000050:C@m`8000000P2Od?T200000080WlOd00<0000008o2n02?`_P0102?`_P0
0`000000M[Ci07Jdn@0307Jdn@030000001BW?<0DYcc0080DYcc0P00000208:FgP030000001kO/X0
Ngk:00<0Ngk:00<0000007E[^@1eJkT0101eJkT00`000000MXCC07J4d`0307J4d`030000002U`nl0
YL?_00D0YL?_0P0000000`2C@VD00000088lK`04088lK`8000001@2GJYd200000180oooo00040?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool01000
0000oooo0?ooo`00000;0?ooo`H000000`2Q`>l00`000000W/?b09k3lP0409k3lP<000001@2Sb_@2
00000080X/og0`0000020:S=l`800000102Td?L4000000D0WlOd0P00000308o2n0X000000P1BW?<0
1P0000009gST000000000000PYKN000000D0Ngk:00<0000007E[^@1eJkT00`1eJkT00`000000MXCC
07J4d`0407J4d`030000002U`nl0YL?_00@000000P2U`nl2000000D0PSa_0P00000509MZW@800000
4P3oool000@0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00030?ooo`8000000`3oool00`000000oooo0?ooo`060?ooo`<000000`3oool00`000000XL3_0:70
k`040:70k`030000002N`o80W/?b00<000000P2TaO400`000000Xl[d0:?:m0040:?:m0<000001P2X
cO<5000000<0Z<S`0P00000409o7m0D000000`2@]o400`000000L:gf072]mP03072]mPD000000P0W
N>@2000000D0Ngk:00<0000007E[^@1eJkT0101eJkT00`000000MXCC07J4d`0307J4d`<000001P2U
`nl2000000D0PSa_0P00000509MZW@030000003oool000000140oooo00040?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`3o
ool2000000H0oooo0P0000070?ooo`030000002Q`>l0XL3_00<0XL3_0`0000060:C5l@8000000P2S
b_@200000080ZLW`0P0000030:S=l`8000000P2]and00`000000Z<S`0:S8l0040:S8l0D000000`2Q
_>`00`000000T;Oa092gl@03092gl@030000001`[OH0L:gf00<0L:gf00<0000002j?k`0^Snl00P00
000302Mhi08000000`1kO/X00`000000MF^i07E[^@0407E[^@030000001fQ=<0MXCC00<000000P2U
`nl00`000000YL?_0:G3k`050:G3k`0300000022?6l0PSa_00<0PSa_0P00000509MZW@030000003o
ool000000140oooo00050?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool2
000000@0oooo0`0000000`3oool00000000000030?ooo`<000002P3oool00`000000XL3_0:70k`02
00000080YL;^00<000000:C5l@2TaO401@2TaO43000000H0ZLW`0`0000050:g7k@8000000P2Xb?02
00000080Z[kX00<000000:6lk02Q_>`0102Q_>`010000000T;Oa092gl@2@]o4;0000000302j?k`00
0000000000809gST0`0000000`1kO/X0000007E[^@0507E[^@<000001@2U`nl00`000000YL?_0:G3
k`050:G3k`8000001022?6l2000000H0UfZM0P00000A0?ooo`00;@3oool5000000h0oooo0P000005
0:G2kP8000000P2TaO4300000080Z/G]00<000000:W9l02YbO000`2YbO02000000030:o6j`000000
[LO]00D0[LO]0`0000040:Znj0030000002Q_>`0XKc/00@0XKc/1000000309R`j00300000021[_40
PJka00<0PJka00<0000004>Om@0000001@00000200]Gd@<0000000<0MF^i0000000000000P000002
0:G3k`030000002U`nl0YL?_00@0YL?_00<000000:G3k`2U`nl0100000020:G3k`0400000022?6l0
PSa_088lK`8000001P2GJYd200000140oooo000]0?ooo`8000004P3oool00`000000YL;^0:G2kP04
0:G2kP<000001P2ZaNd00`000000ZLW`0:W9l002000000@0[lK[00<000000:g7k@2]and00`000002
0:noiP030000002Z_^P0Z[kX00<0Z[kX00<000000:6lk02Q_>`00`0000020:BbhP030000002H/>P0
V;3X0080V;3X00<00000086^l@21[_401021[_400`000000@ioe04>Om@0204>Om@<000000`0;Em42
000000H0YL?_00<000000:G3k`2U`nl0102U`nl3000000L0YL?_00H00000088lK`22?6l0000009Q[
W@00000509MZW@8000004@3oool002h0oooo00<000000?ooo`3oool04@3oool200000080YL;^0P00
00020:W2k0030000002ZaNd0Z/G]00@0Z/G]0`0000070:o6j`8000001@2__nH00`000000Z[kX0:Zn
j0030:Znj0<000001@2T/^800`000000V;3X09R`j00309R`j00300000021[_40PJka0080PJka1P00
0002086nnP8000000`0;Em400`000000YL?_0:G3k`050:G3k`030000002U`nl0YL?_00<000000P2U
`nl00`000000YL?_0:G3k`050:G3k`80000000@0PSa_0000002HJid000001@2GJYd200000140oooo
000_0?ooo`8000004`3oool2000000D0ZL;/0P0000020:[5k@8000000P2^a>T00`000000[lK[0:o6
j`030:o6j`80000000<0/<3V0000002__nH01@2__nH00`000000Z[kX0:Znj00200000080Z[CP00<0
00000:BbhP2T/^80102T/^8010000000V;3X09R`j02H/>P6000000<0V[;X0P000002086nnPD00000
00<02eOA0000002U`nl01P2U`nl3000000H0YL?_00<000000:G3k`2U`nl0100000001P2U`nl00000
088lK`000000V6^M000000D0UfZM0P00000A0?ooo`00<@3oool00`000000oooo0?ooo`0A0?ooo`03
0000002Y`^`0ZL;/00@0ZL;/0`0000050:k4j@80000000<0[lK[0000000000000`2``>H00`000000
[koV0:noiP040:noiP<00000102Z]>000`000000Y;;R0:BbhP040:BbhP@000000`2R[=l00`000000
V[;X09Zbj00409Zbj0<000001@2cbNX300000080YL?_100000020:?:m0030000002U`nl0YL?_00@0
YL?_0`0000060:G3k`80000000<0V6^M0000002GJYd01@2GJYd200000100oooo000b0?ooo`030000
003oool0oooo0140oooo0P0000020:W2k08000000P2]`^T00`000000[/CY0:k4j@040:k4j@800000
1P2``>H00`000000[koV0:noiP0300000080[[OP00<000000:Zdh02Z]>000`2Z]>000`000000Y;;R
0:BbhP0300000080YZcK00<000000::/g`2R[=l00`2R[=l00`000000V[;X09Zbj00300000080[[KO
00@000000;?9jP2cbNX0/lWZ0P0000020<S5e`<000001P2Sb_@00`000000YL?_0:G3k`07000000H0
YL?_0P0000000`2HJid0000009MZW@0509MZW@800000403oool003<0oooo00<000000?ooo`3oool0
4P3oool2000000D0[L;Y00<000000:k4j@2^a>T00`0000020;31iP030000002``>H0/<3V00<0/<3V
0`0000060:jgh0040000002Z]>00Z[CP0:Zdh0@000001@2V[=/00`000000XZcO0::/g`030::/g`<0
00001P2^]]l00`000000/lWZ000000050<S5e`8000001P2Sb_@3000000<0ZGnV100000060:G3k`80
00000P2HJid00`000000UfZM09MZW@0309MZW@800000403oool003@0oooo0P00000C0?ooo`030000
002]`^T0[L;Y00<0[L;Y0`0000060;31iP030000002``>H0/<3V008000000P2_^n800`000000[[OP
0:jgh0040:jgh0@000000`2Y[]/00`000000YZcK0:J/f`040:J/f`030000002R[=l0XZcO00800000
0P2[[]X00`000000[[KO0:jfg`050:jfg`0300000038aML0b<GG00<0b<GG00@000000<boc`000000
00000P2Sb_@5000000D0ZGnV100000020:G3k`<000000P2HJid00`000000V6^M0000000509MZW@80
0000403oool003H0oooo00<000000?ooo`3oool04@3oool00`000000[L;Y0:g2j@0200000080[/7W
00<000000;31iP2``NH0102``NH3000000D0[k_R0P0000020:jgh08000000P2[/]d00`000000ZJkK
0:V^f`020:V^f`030000002V[=/0YZcK00@0YZcK0`0000040:^^fP030000002^]]l0[[KO00<0[[KO
0P000000102l_=X000000<S5e`38aML2000000@0c;o?0P0000001@3=/[l000000000002bTkH00000
00D0ZGnV00<000000:EfWP2UMYh00`0000000`2UMYh0000009Q[W@0309Q[W@8000001@2GJYd20000
0100oooo000g0?ooo`030000003oool0oooo0140oooo0P0000050:k1i`8000000P2``NH200000080
[kkT00<000000:nkhP2_^n80102_^n83000000@0Zk;M00<000000:V^f`2Y[]/00`2Y[]/00`000000
YZcK0:J/f`0300000080Z:cI00<000000:^^fP2[[]X00`2[[]X00`000000[[KO0:jfg`02000000<0
_;cJ00<000000<S5e`0000001P3<_ll00`000000cK:o000000040;:C]P030000002YOjH0ZGnV00<0
ZGnV00<000000:EfWP2UMYh00`2UMYh00`000000V6^M09Q[W@0209Q[W@8000001P2GJYd00`000000
oooo0?ooo`0>0?ooo`00>03oool00`000000oooo0?ooo`0A0?ooo`030000002^`NL0[/7W00@0[/7W
0`0000050:nni0030000002_^n80[k_R00<000000P2/]^400`000000Zk;M0:^bg@030:^bg@030000
002Y[]/0ZJkK0080ZJkK0`0000050:R/f@030000002[[]X0ZjkJ00@0ZjkJ0P0000060;blfP030000
003<_ll0c;o?00H0c;o?00<000000;:C]P2bTkH00`2bTkH00`000000ZGnV0:UoYP030:UoYP030000
002UMYh0YGJN00<0YGJN00<0000009Q[W@2HJid00`2HJid00`000000UfZM09MZW@0409MZW@030000
003oool0oooo00h0oooo000i0?ooo`030000003oool0oooo0140oooo0P0000020:k1i`8000000P2^
`>L00`000000[kkT0:nni0030:nni0<000001@2/]^400`000000Zk;M0:^bg@030:^bg@030000002Y
[]/0ZJkK008000000P2W[M/00`000000Z:cI0:R/f@040:R/f@040000002[[]X0ZjkJ0:^^fP800000
00<0/kOL0000002l_=X0102l_=X00`000000aLcO000000050<boc`<000001@2bTkH00`000000ZGnV
0:UoYP030:UoYP030000002UMYh0YGJN00<0YGJN00<0000009Q[W@2HJid0102HJid00`000000UfZM
09MZW@0309MZW@030000003oool0oooo00h0oooo000j0?ooo`8000004`3oool2000000D0[/3W00<0
00000:nni02__^@00P0000020:bki0030000002/]^40[;KQ00@0[;KQ00@000000:^bg@2[/]d0Zk;M
100000040:N]f`030000002X[=T0Z:cI00@0Z:cI00@000000:^^fP00000000000`2c]m`010000000
_;cJ0;blfP2l_=X200000080aLcO00<000000<boc`3<_ll00P3<_ll010000000_[WE0;jie@000005
0;:C]P030000002YOjH0ZGnV00<0ZGnV00<000000:EfWP2UMYh00`2UMYh00`000000V6^M09Q[W@04
09Q[W@800000102GJYd2000000l0oooo000l0?ooo`030000003oool0oooo0140oooo00<000000:k0
i`2^`>L00`2^`>L3000000@0[;_T00<000000:bfh@2/]^40102/]^44000000<0Yk3N00<000000:N]
f`2W[M/00`2W[M/00`000000Z:cI0:R/f@030:R/f@8000001P2c]m`00`000000_;cJ000000050<G<
g`040000003<_ll00000000000@0_[WE00<000000;:C]P2bTkH00P2bTkH00`000000ZGnV0:UoYP03
0:UoYP030000002UMYh0YGJN00@0YGJN00<0000009Q[W@2HJid00`2HJid2000000@0UfZM0P00000?
0?ooo`00?@3oool00`000000oooo0?ooo`0A0?ooo`030000002^`>L0[/3W008000000P2[_^P00`00
0000[;_T0:bki0030:bki0030000002/]^40[;KQ00<000000P2W]>800`000000Yk3N0:N`gP020:N`
gP030000002W[M/0YjgK00<0YjgK00<000000:R/f@2X[=T00`0000020:bdg`030000002c]m`0/kOL
00<0/kOL0P0000060<G<g`8000001P2n^MD00`000000/Y>f0;:C]P020;:C]P030000002YOjH0ZGnV
00<0ZGnV00<000000:EfWP2UMYh0102UMYh00`000000V6^M09Q[W@0309Q[W@030000002GJYd00000
00<0UfZM0P00000?0?ooo`00?P3oool00`000000oooo0?ooo`0A0?ooo`8000001@2[_^P010000000
[;_T0:bki02/^n@4000000D0YkCR00<000000:N`gP2W/=h00`2W/=h010000000YjgK0:N]f`2W[M/4
000000H0[;CO00<000000;>gg02c]m`00P0000020;WBk@8000000P35c=l200000080/>og00<00000
0;jie@2n^MD00`2n^MD00`000000/Y>f0;:C]P030;:C]P030000002YOjH0ZGnV00<0ZGnV00<00000
0:EfWP2UMYh00`2UMYh00`000000V6^M09Q[W@0309Q[W@040000002GJYd0UfZM000000<0UfZM00<0
00000?ooo`3oool03@3oool003l0oooo0P00000B0?ooo`030000002[_^P0ZkkX00<0ZkkX10000003
0:NiiP030000002W]>80YkCR00@0YkCR00@000000:N`gP2W/=h0Yk3N1@0000030:Jdh`030000002/
]=l0[;CO00@0[;CO0`0000060;WBk@800000102`koL00`000000_[WE0;jie@030;jie@030000002b
TkH0/Y>f00<0/Y>f00<000000:UoYP2YOjH00`2YOjH00`000000YGJN0:EfWP030:EfWP030000002H
Jid0V6^M00<0V6^M00D0000009MZW@2GJYd0UfZM0000000209MZW@030000003oool0oooo00d0oooo
00110?ooo`030000003oool0oooo0100oooo00<000000:^nj02[_^P00P0000020:Nmj@030000002W
^NH0YkWV00<0YkWV00<000000:NdhP2W]>800P2W]>85000000<0X[KV00<000000:Jdh`2V]><00`2V
]><00`000000[;CO0:bdg`0300000080Z];e00<000000;WBk@2id^d00P2id^d700000080/>og00<0
00000;jie@2n^MD00`2n^MD00`000000/Y>f0;:C]P020;:C]P030000002YOjH0ZGnV00<0ZGnV00<0
00000:EfWP2UMYh00`2UMYh00`000000V6^M09Q[W@0409Q[W@040000002GJYd0UfZM00000080UfZM
00<000000?ooo`3oool03@3oool00480oooo00<000000?ooo`3oool0403oool2000000@0YkgY00<0
00000:NiiP2W^NH00`2W^NH5000000<0X;SY00<000000::fiP2R]^H00P2R]^H00`000000Y[CS0:Jd
h`030:Jdh`<000001@2Zd_D00`000000^M;]0;WBk@04000000D0oooo1P0000020;jie@030000002b
TkH0/Y>f0080/Y>f00<000000:UoYP2YOjH00`2YOjH00`000000YGJN0:EfWP040:EfWP030000002H
Jid0V6^M00<0V6^M00L0000009MZW@2GJYd0UfZM0000002GJYd0000000l0oooo00130?ooo`030000
003oool0oooo0100oooo00<000000:Nmj@2W_NT00`2W_NT00`000000YkWV0:NiiP0200000080X;[[
00<000000:2hj@2P^>T00`2P^>T00`000000X[KV0::fiP030::fiP030000002V]><0Y[CS00800000
0P2NcoP2000000<0Z];e1000000?0?ooo`<00000102bTkH00`000000ZGnV0:UoYP030:UoYP030000
002UMYh0YGJN00@0YGJN00<0000009Q[W@2HJid00`2HJid00`000000UfZM09MZW@0209MZW@<00000
3P3oool004@0oooo0P00000A0?ooo`040000002W_NT0YkgY0:Nmj@@00000102P^^/00`000000X;SY
0:2hj@040:2hj@040000002R]^H0X[KV0::fiP@000001@2NcoP4000001H0oooo0P0000020;:C]P03
0000002YOjH0ZGnV00@0ZGnV00<000000:EfWP2UMYh00`2UMYh00`000000V6^M09Q[W@0309Q[W@03
0000002GJYd0UfZM00<0UfZM0P00000>0?ooo`00AP3oool00`000000oooo0?ooo`0?0?ooo`<00000
0`2R_N`00`000000X;[[0:2jj`030:2jj`030000002P^>T0X;SY0080X;SY1@00000309W9n0800000
0P2NcoP2000001`0oooo00@000000;:C]P2bTkH000001@2YOjH00`000000YGJN0:EfWP030:EfWP03
0000002HJid0V6^M00<0V6^M00<0000009MZW@2GJYd00`2GJYd2000000h0oooo00170?ooo`030000
003oool0oooo00l0oooo00<000000::mk02R_N`00`2R_N`010000000X;[[0:2jj`2P^^/6000000<0
V<Gf00<0000009W9n02IbOP00P2IbOP4000001l0oooo0`0000050:UoYP030000002UMYh0YGJN00<0
YGJN00<0000009Q[W@2HJid0102HJid00`000000UfZM09MZW@0209MZW@8000003P3oool004P0oooo
00<000000?ooo`3oool03`3oool010000000X[g/0::mk02R_N`5000000<0V/7c0P00000309S5mPL0
0000903oool00`000000ZGnV0:UoYP030:UoYP030000002UMYh0YGJN00@0YGJN00<0000009Q[W@2H
Jid00`2HJid00`000000UfZM0000000200000100oooo00190?ooo`800000403oool3000000<0W[o`
0P00000309[1l`D000000P1og?`2000002P0oooo0P0000030:UoYP030000002UMYh0YGJN00@0YGJN
00@0000009Q[W@2HJid0V6^M1000000C0?ooo`00B`3oool00`000000oooo0?ooo`0>0?ooo`800000
0`2N_o05000000<0Um;l1000000/0?ooo`8000000P2YOjH00`000000YGJN0:EfWP020:EfWPD00000
5`3oool004`0oooo00<000000?ooo`3oool03`3oool3000000@0X<Kc1000000b0?ooo`<0000000<0
YGJN0000000000000P00000K0?ooo`00C@3oool00`000000oooo0?ooo`0?0?ooo`8000000P2Pa_<2
000003H0oooo1000000O0?ooo`00CP3oool200000140oooo0P00000d0?ooo`@000008`3oool00500
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`<000009`3oool00540oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0/0?ooo`@00000:P3oool00580oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`@00000;P3oool005<0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`<00000<P3oool005@0oooo0P00000;0?oo
o`030000003oool0oooo0240oooo1000000e0?ooo`00EP3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo01d0oooo1000000i0?ooo`00E`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01T0oooo1000000m0?ooo`00F03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo01H0oooo0`0000110?ooo`00F@3oool2000000H0oooo00<000000?ooo`3oool04P3oool4
000004@0oooo001K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool40000
04P0oooo001L0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02`3oool3000004`0
oooo001M0?ooo`050000003oool0oooo0?ooo`0000002@3oool4000004l0oooo001N0?ooo`800000
00<0oooo0000003oool0103oool4000005<0oooo001P0?ooo`80000000<0oooo0000000000000P00
001G0?ooo`00H@3oool2000005/0oooo002n0?ooo`00_P3oool00;h0oooo002n0?ooo`00_P3oool0
0;h0oooo002n0?ooo`00_P3oool00;h0oooo002n0?ooo`00_P3oool00;h0oooo002n0?ooo`00_P3o
ool00;h0oooo002n0?ooo`00_P3oool00;h0oooo0000\
\>"],
  ImageRangeCache->{{{0, 189.375}, {153.375, 0}} -> {-0.33715, -0.151035, \
0.00735191, 0.00735191}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[164]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(k = 1\/10\)]]
}], "MathCaption",
  CellFrame->False,
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\))\) /. 
        k \[Rule] 1/10, {x, 0, 1}]\)], "Input",
  CellLabel->"In[165]:=",
  CellFrame->False,
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.312556 171016 [
[.21429 .30006 -9 -9 ]
[.21429 .30006 9 0 ]
[.40476 .30006 -9 -9 ]
[.40476 .30006 9 0 ]
[.59524 .30006 -9 -9 ]
[.59524 .30006 9 0 ]
[.78571 .30006 -9 -9 ]
[.78571 .30006 9 0 ]
[.97619 .30006 -3 -9 ]
[.97619 .30006 3 0 ]
[.01131 .05603 -51 -6.25 ]
[.01131 .05603 0 6.25 ]
[.01131 .14154 -39 -6.25 ]
[.01131 .14154 0 6.25 ]
[.01131 .22705 -39 -6.25 ]
[.01131 .22705 0 6.25 ]
[.01131 .39806 -33 -6.25 ]
[.01131 .39806 0 6.25 ]
[.01131 .48357 -33 -6.25 ]
[.01131 .48357 0 6.25 ]
[.01131 .56908 -45 -6.25 ]
[.01131 .56908 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .31256 m
.21429 .31881 L
s
[(0.2)] .21429 .30006 0 1 Mshowa
.40476 .31256 m
.40476 .31881 L
s
[(0.4)] .40476 .30006 0 1 Mshowa
.59524 .31256 m
.59524 .31881 L
s
[(0.6)] .59524 .30006 0 1 Mshowa
.78571 .31256 m
.78571 .31881 L
s
[(0.8)] .78571 .30006 0 1 Mshowa
.97619 .31256 m
.97619 .31881 L
s
[(1)] .97619 .30006 0 1 Mshowa
.125 Mabswid
.07143 .31256 m
.07143 .31631 L
s
.11905 .31256 m
.11905 .31631 L
s
.16667 .31256 m
.16667 .31631 L
s
.2619 .31256 m
.2619 .31631 L
s
.30952 .31256 m
.30952 .31631 L
s
.35714 .31256 m
.35714 .31631 L
s
.45238 .31256 m
.45238 .31631 L
s
.5 .31256 m
.5 .31631 L
s
.54762 .31256 m
.54762 .31631 L
s
.64286 .31256 m
.64286 .31631 L
s
.69048 .31256 m
.69048 .31631 L
s
.7381 .31256 m
.7381 .31631 L
s
.83333 .31256 m
.83333 .31631 L
s
.88095 .31256 m
.88095 .31631 L
s
.92857 .31256 m
.92857 .31631 L
s
.25 Mabswid
0 .31256 m
1 .31256 L
s
.02381 .05603 m
.03006 .05603 L
s
gsave
.01131 .05603 -51 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .14154 m
.03006 .14154 L
s
gsave
.01131 .14154 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .22705 m
.03006 .22705 L
s
gsave
.01131 .22705 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .39806 m
.03006 .39806 L
s
gsave
.01131 .39806 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .48357 m
.03006 .48357 L
s
gsave
.01131 .48357 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02381 .56908 m
.03006 .56908 L
s
gsave
.01131 .56908 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.02381 .07313 m
.02756 .07313 L
s
.02381 .09023 m
.02756 .09023 L
s
.02381 .10734 m
.02756 .10734 L
s
.02381 .12444 m
.02756 .12444 L
s
.02381 .15864 m
.02756 .15864 L
s
.02381 .17574 m
.02756 .17574 L
s
.02381 .19284 m
.02756 .19284 L
s
.02381 .20995 m
.02756 .20995 L
s
.02381 .24415 m
.02756 .24415 L
s
.02381 .26125 m
.02756 .26125 L
s
.02381 .27835 m
.02756 .27835 L
s
.02381 .29545 m
.02756 .29545 L
s
.02381 .32966 m
.02756 .32966 L
s
.02381 .34676 m
.02756 .34676 L
s
.02381 .36386 m
.02756 .36386 L
s
.02381 .38096 m
.02756 .38096 L
s
.02381 .41517 m
.02756 .41517 L
s
.02381 .43227 m
.02756 .43227 L
s
.02381 .44937 m
.02756 .44937 L
s
.02381 .46647 m
.02756 .46647 L
s
.02381 .50067 m
.02756 .50067 L
s
.02381 .51778 m
.02756 .51778 L
s
.02381 .53488 m
.02756 .53488 L
s
.02381 .55198 m
.02756 .55198 L
s
.02381 .03893 m
.02756 .03893 L
s
.02381 .02183 m
.02756 .02183 L
s
.02381 .00473 m
.02756 .00473 L
s
.02381 .58618 m
.02756 .58618 L
s
.02381 .60328 m
.02756 .60328 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .06984 m
.04262 .20116 L
.06244 .31433 L
.08255 .40473 L
.09409 .44631 L
.10458 .47808 L
.11396 .50186 L
.12415 .52296 L
.13491 .54023 L
.14017 .54688 L
.14509 .5521 L
.15002 .55637 L
.15453 .55946 L
.15954 .56203 L
.1623 .56305 L
.16368 .56347 L
.16493 .56378 L
.16614 .56404 L
.16745 .56426 L
.16817 .56436 L
.16883 .56443 L
.17014 .56454 L
.17126 .56458 L
.17249 .56458 L
.17378 .56453 L
.17498 .56443 L
.17566 .56436 L
.1764 .56426 L
.17775 .56403 L
.18028 .56346 L
.18323 .56255 L
.18596 .56147 L
.19059 .55915 L
.19558 .55598 L
.20462 .54855 L
.21537 .5371 L
.22522 .52433 L
.26485 .45559 L
.30295 .37242 L
.34352 .27794 L
.38256 .19187 L
.40247 .15277 L
.42406 .1156 L
.4431 .08819 L
.45392 .07512 L
.46404 .06464 L
.47443 .05575 L
.48392 .04931 L
.48877 .04666 L
.49406 .04427 L
Mistroke
.49696 .04318 L
.49965 .04231 L
.50242 .04157 L
.50496 .04101 L
.50744 .04059 L
.5087 .04042 L
.51005 .04027 L
.51076 .04021 L
.51141 .04016 L
.51268 .04008 L
.51338 .04006 L
.51415 .04004 L
.51488 .04003 L
.51555 .04003 L
.51674 .04006 L
.51785 .04011 L
.51908 .04019 L
.52039 .04031 L
.5217 .04046 L
.52307 .04066 L
.52552 .0411 L
.53013 .04225 L
.53442 .04369 L
.54414 .04829 L
.55469 .05536 L
.56464 .06397 L
.58324 .08505 L
.60329 .11469 L
.62176 .14784 L
.66121 .23443 L
.69915 .33134 L
.73954 .4376 L
.77842 .52823 L
.78858 .54786 L
.79963 .56654 L
.80919 .58007 L
.81427 .58615 L
.81975 .59178 L
.82506 .59625 L
.82993 .59944 L
.83234 .60068 L
.83459 .60163 L
.83693 .6024 L
.83817 .60271 L
.8395 .60298 L
.84018 .60309 L
.84091 .60318 L
.84221 .60329 L
.84293 .60331 L
.84361 .60332 L
Mistroke
.84435 .6033 L
.84515 .60325 L
.84584 .60319 L
.84658 .6031 L
.84794 .60286 L
.84927 .60255 L
.8505 .60219 L
.85304 .6012 L
.85534 .60004 L
.8605 .59647 L
.86538 .59181 L
.87053 .58547 L
.87976 .57029 L
.88969 .54806 L
.90058 .51605 L
.92011 .43659 L
.94103 .31585 L
.95909 .17784 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[165]:=",
  ImageSize->{216, 133.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003H0000QB000`400?l00000o`00003of03oool0
0=P0oooo003H0?ooo`00f03oool00=P0oooo003H0?ooo`00f03oool00=P0oooo003H0?ooo`00f03o
ool00=P0oooo003H0?ooo`00f03oool00=P0oooo003H0?ooo`00=@3oool00`000000oooo0?ooo`2P
0?ooo`00=@3oool00`000000oooo0?ooo`2P0?ooo`00=@3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0080oooo000e0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0
0P3oool003D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`020?ooo`00=@3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0080oooo00070?ooo`D000000P3oool20000
00@0oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000oooo1@0000020?ooo`8000003@3o
ool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0080oooo00090?ooo`030000003oool0
oooo00L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04/0oooo
1`0000180?ooo`030000003oool0oooo00<0oooo00090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo04T0oooo0P0000070?ooo`800000
AP3oool00`000000oooo0?ooo`030?ooo`0000<0oooo0000000000000P0000040?ooo`030000003o
ool0oooo00P0oooo0P0000040?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo0P0000180?ooo`8000002`3oool2000004@0oooo
00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`030?ooo`00203oool2000000X0oooo
0`0000090?ooo`800000103oool2000000P0oooo00<0`<300;2`/02@T9000P3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`030?ooo`00<03oool00`2PX:00oooo0<30`0020?ooo`030000003oool0oooo04@0oooo0P00
000A0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool00`3oool002X0oooo00@0h>3P
0820P020P800P8200P3oool00`1PH600T92@0:2PX0020?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00<0oooo000`
0?ooo`030:2PX03oool0oooo0080oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool00`3oool00340oooo00D0X:2P0;2`
/03oool0oooo000000140?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`030?ooo`00=@3oool200000480oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00@0oooo000e0?ooo`800000@@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0103oool003D0oooo
0P0000110?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`040?ooo`00=@3oool200000400oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00@0oooo000C0?ooo`D0000000<0oooo0000003oool00P3oool0
0`000000oooo0000000400000080oooo0P00000=0?ooo`800000?`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0103oool001D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`800000?`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0103oool001D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`800000?P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0103oool000d0oooo100000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool3
000003`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00@0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00@000000?ooo`3oool00000303oool00`000000oooo0000000l0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`00503o
ool2000000X0oooo0P0000040?ooo`800000203oool00`30`<00/;2`092@T0020?ooo`030000003o
ool0000003/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo00@0oooo000`0?ooo`030:2PX03oool0`<300080oooo00<000000?ooo`000000>`3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01@3oool0
02X0oooo00@0h>3P0820P020P800P8200P3oool00`1PH600T92@0:2PX0020?ooo`030000003oool0
000003X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`030:2PX03oool0oooo0080oooo00<000000?ooo`000000>P3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool01@3oool00340
oooo00L0X:2P0;2`/03oool0oooo0000003oool0000003T0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00D0oooo000e0?ooo`040000003oool0oooo
000003P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00D0oooo000e0?ooo`040000003oool0oooo000003L0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00D0oooo000e0?ooo`040000003oool0oooo
000003L0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo00D0oooo000e0?ooo`040000003oool0oooo000003L0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00D0oooo000D0?ooo`8000000`3oool01P00
0000oooo0?ooo`3oool000000?ooo`D000000P3oool2000000d0oooo00@000000?ooo`3oool00000
=P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
1P3oool001<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0000
03H0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00H0oooo000F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000e
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`06
0?ooo`003@3oool4000000<0oooo0P0000040?ooo`030000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000
000d0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`060?ooo`00503oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000080oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool01P3oool001@0oooo0`0000090?ooo`800000103oool2000000d0oooo00D0
00000?ooo`3oool0oooo0000000c0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`060?ooo`00<@3oool01@2`/;00oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool01P3oool00340oooo00D0/;2`0?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo00L0oooo000Z0?ooo`040>3Ph020P800P8200820P0<0oooo00D0h>3P0<30`03oool0
oooo000000030?ooo`030000003oool0oooo0140oooo0P0000040?ooo`8000000`3oool400000100
oooo0`0000040?ooo`8000001@3oool3000000l0oooo0P0000040?ooo`8000000`3oool3000000D0
oooo00<000000?ooo`3oool02P3oool2000000@0oooo0P0000040?ooo`800000503oool00`000000
oooo0?ooo`0500000080oooo000b0?ooo`040:2PX03oool0oooo000000@0oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo0100oooo0P0000020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0203oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000001<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`00;`3oool01030`<00L71`0820P020P8020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00l0oooo0P0000020?ooo`030000003oool0oooo00H0oooo1@00000>0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`080?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo000e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
3`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000l0oooo00@000000?oo
o`3oool00000203oool3000000L0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00
00090?ooo`800000503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo000e
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0000000l0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`00000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
03D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0@0?ooo`8000002P3oool20000
00l0oooo00<000000?ooo`3oool00P00000;0?ooo`800000403oool2000000X0oooo0`0000060?oo
o`030000003oool0oooo00P0oooo0P00000:0?ooo`800000503oool010000000oooo0?ooo`3oool2
000000@0oooo000e0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool003D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`00=@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000e0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0203oool00340ooooY`00000003D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool003D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00=@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00T0oooo000e0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool02@3oool003D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`09
0?ooo`00=@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00T0oooo000e0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool02@3oool003D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`0:0?ooo`00=@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00X0oooo000e0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02P3oool0
01@0oooo0P0000030?ooo`060000003oool0oooo0?ooo`000000oooo1@0000020?ooo`8000003@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo000C0?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00X0oooo
000F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00/0oooo000D0?ooo`800000103oool00`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`8000001`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`0;0?ooo`00503oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00/0oooo000D0?ooo`<000002@3oool2000000@0oooo
0P0000090?ooo`050;2`/03oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0;0?ooo`00
<@3oool01@2`/;00oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02`3oool002X0oooo
00@0h>3P0820P020P800P8200`3oool01@3Ph>00`<300?ooo`3oool0000000T0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0303oool00380oooo00@0X:2P0?ooo`3oool000002@3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0<0?oo
o`00;`3oool01030`<00L71`0820P020P8020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0303oool003D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`00
=@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00`0oooo000e0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool03@3oool003D0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0=0?ooo`004`3oool5000000030?ooo`000000oooo0080oooo00<000000?oo
o`000000100000020?ooo`8000003@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00d0oooo000E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00d0oooo000E0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00h0oooo000E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool2000000/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1A0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00
000<0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool001@0oooo0P00000:
0?ooo`800000103oool2000000P0oooo00<0`<300;2`/02@T9000P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00h0oooo000`0?ooo`030:2PX03oool0`<300080oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0>0?ooo`00:P3oool0103Ph>00P8200820P020P8020?oo
o`03061PH02@T900X:2P0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0?0?oo
o`00<03oool00`2PX:00oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool03`3oool00340oooo00D0X:2P0;2`/03oool0oooo0000000?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0
oooo000e0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1I0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03`3oool003D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`00=@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo0100oooo000e0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool04@3oool000L0oooo1@0000020?ooo`800000103oool2000000<0oooo00H000000?ooo`3o
ool0oooo0000003oool500000080oooo0P00000=0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool04@3oool000T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool04@3oool2000000H0oooo0P00001Q0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool04@3oool000T0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool300000080oooo0P00
001S0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool04P3oool000T0oooo00<00000
0?ooo`3oool0203oool2000000@0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02P3oool2000001D0oooo0`00001V0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool04P3oool000T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool000P0oooo0P00000:0?ooo`<000002@3o
ool2000000@0oooo0P0000080?ooo`030<30`02`/;00T92@0080oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo000`0?ooo`030:2PX03oool0
`<300080oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01@0oooo000Z0?ooo`040>3Ph020P800P8200820P080oooo00<0H61P092@T02PX:000P3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool0
0300oooo00<0X:2P0?ooo`3oool00P3oool00`000000oooo0?ooo`210?ooo`800000103oool00`00
0000oooo0?ooo`0F0?ooo`00<@3oool01@2PX:00/;2`0?ooo`3oool0000008D0oooo1@00000H0?oo
o`00=@3oool00`000000oooo0?ooo`2P0?ooo`00=@3oool00`000000oooo0?ooo`2P0?ooo`00=@3o
ool00`000000oooo0?ooo`2P0?ooo`00f03oool00=P0oooo003H0?ooo`00f03oool00=P0oooo003H
0?ooo`00f03oool00=P0oooo003H0?ooo`00f03oool00=P0oooo003H0?ooo`00f03oool00=P0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 215}, {132.438, 0}} -> {-0.335964, -2.35505*^-06, \
0.00633009, 3.5252*^-08}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[165]="]
}, Open  ]],

Cell["Example 2", "Subsubsection"],

Cell["Initial value problem.", "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\(y'''\)[x] + \[Lambda]*x*\(y'\)[x] + \[Lambda]^2*y[x] \[Equal] 
          0, y[0] \[Equal] 0, \(y'\)[0] \[Equal] 
          0, \(y''\)[0] \[Equal] \[Lambda]}\)], "Input",
  CellLabel->"In[166]:=",
  Background->None],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\[Lambda]\^2\ y[x]\), "+", 
            RowBox[{"x", " ", "\[Lambda]", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
        ",", \(y[0] == 0\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", "0"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", 
          "\[Lambda]"}]}], "}"}]], "Output",
  CellLabel->"Out[166]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[ivp, y[x], {x, \(-1\), 1}, 3]\)], "Input",
  CellLabel->"In[167]:=",
  Background->None],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\(\(2304\ \[Lambda]\^3\ \((2 + \
\[Lambda])\)\)\/\(84934656 - 46080\ \[Lambda]\^2 + 41472\ \[Lambda]\^3 + 
                    23040\ \[Lambda]\^4 + 6\ \[Lambda]\^5 + 
                    11\ \[Lambda]\^6 + 
                    6\ \[Lambda]\^7 + \[Lambda]\^8\)\)\) + \(9216\ x\^2\ \
\[Lambda]\ \((4608 + 3\ \[Lambda]\^3 + \[Lambda]\^4)\)\)\/\(84934656 - 46080\ \
\[Lambda]\^2 + 41472\ \[Lambda]\^3 + 23040\ \[Lambda]\^4 + 6\ \[Lambda]\^5 + \
11\ \[Lambda]\^6 + 6\ \[Lambda]\^7 + \[Lambda]\^8\) + \(48\ x\ \[Lambda]\^2\ \
\((2 + \[Lambda])\)\ \((4608 + 3\ \[Lambda]\^3 + \
\[Lambda]\^4)\)\)\/\(84934656 - 46080\ \[Lambda]\^2 + 41472\ \[Lambda]\^3 + \
23040\ \[Lambda]\^4 + 6\ \[Lambda]\^5 + 11\ \[Lambda]\^6 + 6\ \[Lambda]\^7 + \
\[Lambda]\^8\) - \(192\ x\^3\ \[Lambda]\^2\ \((9216 + 4608\ \[Lambda] + 2\ \
\[Lambda]\^3 + 3\ \[Lambda]\^4 + \[Lambda]\^5)\)\)\/\(84934656 - 46080\ \
\[Lambda]\^2 + 41472\ \[Lambda]\^3 + 23040\ \[Lambda]\^4 + 6\ \[Lambda]\^5 + \
11\ \[Lambda]\^6 + 6\ \[Lambda]\^7 + \[Lambda]\^8\)}}\)], "Output",
  CellLabel->"Out[167]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the IVP."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[168]:=",
  Background->None],

Cell[BoxData[
    \({{y[x] \[Rule] 
          1\/2\ x\^2\ \[Lambda]\ HypergeometricPFQ[{2\/3 + \[Lambda]\/3}, \
{4\/3, 5\/3}, \(-\(\(x\^3\ \[Lambda]\)\/9\)\)]}}\)], "Output",
  CellLabel->"Out[168]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption",
  Background->None],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
              apr[\([1]\)])\))\), {x, \(-1\), 1}, {\[Lambda], \(-1\)/8, 
        1/8}]\)], "Input",
  CellLabel->"In[169]:=",
  Background->None],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.378e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.73498 .04732 0 -6.2105 ]
[.73498 .04732 24 2.7895 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95881 .39008 0 -5.88604 ]
[.95881 .39008 18 3.11396 ]
[.01711 .30899 -48 -2.77941 ]
[.01711 .30899 0 6.22059 ]
[.00705 .37205 -6 -2.83289 ]
[.00705 .37205 0 6.16711 ]
[-0.00343 .43771 -42 -2.88881 ]
[-0.00343 .43771 0 6.11119 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72272 .05198 m
.71658 .05431 L
s
[(-0.1)] .73498 .04732 -1 .38011 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94627 .39394 m
.94 .39587 L
s
[(0.1)] .95881 .39008 -1 .30801 Mshowa
.125 Mabswid
.74878 .09184 m
.74509 .09321 L
s
.77389 .13026 m
.77019 .1316 L
s
.79812 .16731 m
.79441 .16863 L
s
.8215 .20308 m
.81778 .20437 L
s
.86589 .27099 m
.86216 .27223 L
s
.88699 .30325 m
.88324 .30448 L
s
.90739 .33447 m
.90364 .33567 L
s
.92714 .36468 m
.92339 .36586 L
s
.69566 .01059 m
.69199 .01202 L
s
.9648 .42229 m
.96104 .42343 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.02937 .3043 m
.0355 .30196 L
s
[(-0.00001)] .01711 .30899 1 -0.38235 Mshowa
.01936 .36749 m
.02551 .36521 L
s
[(0)] .00705 .37205 1 -0.37047 Mshowa
.00893 .43329 m
.01511 .43107 L
s
[(0.00001)] -0.00343 .43771 1 -0.35804 Mshowa
.125 Mabswid
.0274 .31674 m
.03108 .31534 L
s
.02541 .32928 m
.02909 .32789 L
s
.02341 .34191 m
.02709 .34053 L
s
.02139 .35465 m
.02508 .35328 L
s
.0173 .38044 m
.021 .37908 L
s
.01524 .39349 m
.01893 .39214 L
s
.01315 .40665 m
.01685 .4053 L
s
.01105 .41991 m
.01475 .41858 L
s
.03132 .29197 m
.035 .29055 L
s
.03326 .27972 m
.03694 .2783 L
s
.03519 .26758 m
.03886 .26615 L
s
.0371 .25553 m
.04076 .25409 L
s
.00679 .44677 m
.0105 .44545 L
s
.00464 .46037 m
.00835 .45906 L
s
.00246 .47408 m
.00618 .47278 L
s
.00027 .48791 m
.00399 .48662 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.868 .676 .641 r
.37587 .75752 .39806 .80578 .4417 .60039 .41922 .60396 Metetra
.148 0 0 r
.41922 .60396 .4417 .60039 .47884 .60519 .45694 .60446 Metetra
.812 .356 .148 r
.45694 .60446 .47884 .60519 .51669 .67879 .49502 .65552 Metetra
0 0 .49 r
.49502 .65552 .51669 .67879 .55691 .74184 .53507 .6981 Metetra
.539 .555 .819 r
.53507 .6981 .55691 .74184 .59833 .75219 .57641 .70213 Metetra
.738 .632 .742 r
.57641 .70213 .59833 .75219 .63901 .70492 .61763 .6644 Metetra
.819 .691 .723 r
.61763 .6644 .63901 .70492 .67797 .62409 .65789 .60194 Metetra
.877 .782 .753 r
.65789 .60194 .67797 .62409 .71596 .54511 .69758 .54028 Metetra
.853 .952 .877 r
.69758 .54028 .71596 .54511 .75519 .49929 .7382 .50284 Metetra
.158 0 0 r
.7382 .50284 .75519 .49929 .79847 .50563 .7818 .50414 Metetra
.671 .12 0 r
.7818 .50414 .79847 .50563 .84787 .5643 .82993 .54397 Metetra
0 .017 .536 r
.82993 .54397 .84787 .5643 .90194 .64225 .88158 .59718 Metetra
.566 .574 .821 r
.88158 .59718 .90194 .64225 .95038 .64821 .92955 .59761 Metetra
.924 .711 .596 r
.92955 .59761 .95038 .64821 .97003 .43424 .95726 .43659 Metetra
.852 .68 .668 r
.35322 .71353 .37587 .75752 .41922 .60396 .39598 .60354 Metetra
.151 .693 .806 r
.39598 .60354 .41922 .60396 .45694 .60446 .43428 .60027 Metetra
.686 .144 0 r
.43428 .60027 .45694 .60446 .49502 .65552 .47279 .63209 Metetra
0 .326 .802 r
.47279 .63209 .49502 .65552 .53507 .6981 .51291 .65756 Metetra
.573 .59 .832 r
.51291 .65756 .53507 .6981 .57641 .70213 .55429 .65633 Metetra
.722 .64 .766 r
.55429 .65633 .57641 .70213 .61763 .6644 .59596 .62641 Metetra
.794 .695 .756 r
.59596 .62641 .61763 .6644 .65789 .60194 .63726 .57925 Metetra
.842 .785 .796 r
.63726 .57925 .65789 .60194 .69758 .54028 .67835 .53229 Metetra
.803 .93 .917 r
.67835 .53229 .69758 .54028 .7382 .50284 .72018 .50203 Metetra
.126 .675 .79 r
.72018 .50203 .7382 .50284 .7818 .50414 .76417 .49888 Metetra
.412 0 0 r
.76417 .49888 .7818 .50414 .82993 .54397 .8114 .52252 Metetra
0 .313 .792 r
.8114 .52252 .82993 .54397 .88158 .59718 .86124 .55492 Metetra
.591 .604 .833 r
.86124 .55492 .88158 .59718 .92955 .59761 .90895 .55072 Metetra
.901 .717 .644 r
.90895 .55072 .92955 .59761 .95726 .43659 .9433 .43444 Metetra
.828 .685 .705 r
.33001 .67357 .35322 .71353 .39598 .60354 .37201 .59901 Metetra
.4 .827 .962 r
.37201 .59901 .39598 .60354 .43428 .60027 .41088 .59255 Metetra
.32 0 0 r
.41088 .59255 .43428 .60027 .47279 .63209 .44997 .60847 Metetra
.277 .567 .935 r
.44997 .60847 .47279 .63209 .51291 .65756 .49034 .62005 Metetra
.601 .623 .845 r
.49034 .62005 .51291 .65756 .55429 .65633 .53186 .61455 Metetra
.705 .649 .792 r
.53186 .61455 .55429 .65633 .59596 .62641 .57392 .59082 Metetra
.763 .699 .791 r
.57392 .59082 .59596 .62641 .63726 .57925 .61605 .55599 Metetra
.799 .784 .838 r
.61605 .55599 .63726 .57925 .67835 .53229 .65828 .52105 Metetra
.753 .897 .943 r
.65828 .52105 .67835 .53229 .72018 .50203 .70115 .49669 Metetra
.376 .818 .952 r
.70115 .49669 .72018 .50203 .76417 .49888 .74558 .48974 Metetra
.013 .544 .851 r
.74558 .48974 .76417 .49888 .8114 .52252 .79226 .4999 Metetra
.232 .55 .93 r
.79226 .4999 .8114 .52252 .86124 .55492 .84084 .51535 Metetra
.613 .632 .846 r
.84084 .51535 .86124 .55492 .90895 .55072 .88847 .50735 Metetra
.865 .722 .702 r
.88847 .50735 .90895 .55072 .9433 .43444 .92816 .42761 Metetra
.793 .692 .753 r
.30614 .63748 .33001 .67357 .37201 .59901 .34735 .59027 Metetra
.545 .853 .998 r
.34735 .59027 .37201 .59901 .41088 .59255 .38679 .58121 Metetra
.232 .679 .954 r
.38679 .58121 .41088 .59255 .44997 .60847 .42652 .58464 Metetra
.487 .677 .949 r
.42652 .58464 .44997 .60847 .49034 .62005 .46728 .58546 Metetra
.624 .653 .858 r
.46728 .58546 .49034 .62005 .53186 .61455 .50904 .57662 Metetra
.688 .663 .821 r
.50904 .57662 .53186 .61455 .57392 .59082 .55145 .55753 Metetra
.729 .704 .827 r
.55145 .55753 .57392 .59082 .61605 .55599 .59424 .53211 Metetra
.75 .776 .874 r
.59424 .53211 .61605 .55599 .65828 .52105 .63737 .50646 Metetra
.709 .86 .954 r
.63737 .50646 .65828 .52105 .70115 .49669 .68115 .48666 Metetra
.531 .854 .997 r
.68115 .48666 .70115 .49669 .74558 .48974 .72605 .47661 Metetra
.376 .747 .99 r
.72605 .47661 .74558 .48974 .79226 .4999 .7725 .4761 Metetra
.459 .676 .958 r
.7725 .4761 .79226 .4999 .84084 .51535 .82033 .47835 Metetra
.63 .66 .86 r
.82033 .47835 .84084 .51535 .88847 .50735 .86804 .46734 Metetra
.813 .723 .765 r
.86804 .46734 .88847 .50735 .92816 .42761 .91182 .41591 Metetra
.742 .7 .811 r
.2815 .60509 .30614 .63748 .34735 .59027 .32205 .57724 Metetra
.615 .833 .984 r
.32205 .57724 .34735 .59027 .38679 .58121 .36202 .56619 Metetra
.528 .788 .992 r
.36202 .56619 .38679 .58121 .42652 .58464 .40243 .56058 Metetra
.593 .722 .934 r
.40243 .56058 .42652 .58464 .46728 .58546 .44365 .55368 Metetra
.641 .683 .873 r
.44365 .55368 .46728 .58546 .50904 .57662 .48571 .54238 Metetra
.672 .681 .85 r
.48571 .54238 .50904 .57662 .55145 .55753 .52847 .52644 Metetra
.694 .711 .861 r
.52847 .52644 .55145 .55753 .59424 .53211 .57179 .50757 Metetra
.703 .765 .901 r
.57179 .50757 .59424 .53211 .63737 .50646 .61566 .48846 Metetra
.677 .822 .953 r
.61566 .48846 .63737 .50646 .68115 .48666 .66018 .47181 Metetra
.609 .838 .987 r
.66018 .47181 .68115 .48666 .72605 .47661 .70559 .45939 Metetra
.56 .797 .988 r
.70559 .45939 .72605 .47661 .7725 .4761 .75208 .45108 Metetra
.581 .73 .945 r
.75208 .45108 .7725 .4761 .82033 .47835 .79961 .44383 Metetra
.644 .687 .876 r
.79961 .44383 .82033 .47835 .86804 .46734 .84756 .43056 Metetra
.747 .72 .826 r
.84756 .43056 .86804 .46734 .91182 .41591 .89431 .39921 Metetra
.685 .711 .868 r
.25599 .57628 .2815 .60509 .32205 .57724 .29616 .55985 Metetra
.645 .801 .958 r
.29616 .55985 .32205 .57724 .36202 .56619 .33661 .54746 Metetra
.63 .787 .957 r
.33661 .54746 .36202 .56619 .40243 .56058 .37763 .53627 Metetra
.642 .742 .922 r
.37763 .53627 .40243 .56058 .44365 .55368 .41935 .52461 Metetra
.652 .711 .89 r
.41935 .52461 .44365 .55368 .48571 .54238 .46178 .51169 Metetra
.661 .705 .88 r
.46178 .51169 .48571 .54238 .52847 .52644 .5049 .49746 Metetra
.667 .722 .89 r
.5049 .49746 .52847 .52644 .57179 .50757 .54869 .48233 Metetra
.668 .755 .915 r
.54869 .48233 .57179 .50757 .61566 .48846 .59314 .46697 Metetra
.659 .789 .944 r
.59314 .46697 .61566 .48846 .66018 .47181 .6383 .45206 Metetra
.643 .805 .96 r
.6383 .45206 .66018 .47181 .70559 .45939 .68424 .43802 Metetra
.634 .79 .956 r
.68424 .43802 .70559 .45939 .75208 .45108 .73101 .42483 Metetra
.639 .75 .929 r
.73101 .42483 .75208 .45108 .79961 .44383 .77863 .41171 Metetra
.653 .713 .892 r
.77863 .41171 .79961 .44383 .84756 .43056 .82696 .3969 Metetra
.684 .72 .876 r
.82696 .3969 .84756 .43056 .89431 .39921 .87564 .37738 Metetra
.656 .735 .907 r
.22949 .55096 .25599 .57628 .29616 .55985 .26973 .53807 Metetra
.655 .767 .932 r
.26973 .53807 .29616 .55985 .33661 .54746 .3106 .52498 Metetra
.655 .764 .93 r
.3106 .52498 .33661 .54746 .37763 .53627 .35211 .51169 Metetra
.656 .75 .919 r
.35211 .51169 .37763 .53627 .41935 .52461 .39428 .49818 Metetra
.656 .738 .91 r
.39428 .49818 .41935 .52461 .46178 .51169 .43712 .48446 Metetra
.656 .735 .907 r
.43712 .48446 .46178 .51169 .5049 .49746 .48065 .47052 Metetra
.656 .74 .912 r
.48065 .47052 .5049 .49746 .54869 .48233 .52489 .45635 Metetra
.656 .751 .92 r
.52489 .45635 .54869 .48233 .59314 .46697 .56985 .44195 Metetra
.655 .763 .929 r
.56985 .44195 .59314 .46697 .6383 .45206 .61555 .42732 Metetra
.655 .769 .933 r
.61555 .42732 .6383 .45206 .68424 .43802 .66201 .41244 Metetra
.655 .765 .931 r
.66201 .41244 .68424 .43802 .73101 .42483 .70925 .39731 Metetra
.656 .753 .922 r
.70925 .39731 .73101 .42483 .77863 .41171 .75728 .38193 Metetra
.656 .739 .911 r
.75728 .38193 .77863 .41171 .82696 .3969 .80614 .36628 Metetra
.656 .736 .909 r
.80614 .36628 .82696 .3969 .87564 .37738 .85584 .35036 Metetra
.692 .776 .915 r
.20186 .52904 .22949 .55096 .26973 .53807 .24282 .5119 Metetra
.653 .736 .91 r
.24282 .5119 .26973 .53807 .3106 .52498 .28403 .49875 Metetra
.639 .734 .917 r
.28403 .49875 .3106 .52498 .35211 .51169 .32582 .48679 Metetra
.641 .749 .927 r
.32582 .48679 .35211 .51169 .39428 .49818 .36833 .47433 Metetra
.651 .764 .932 r
.36833 .47433 .39428 .49818 .43712 .48446 .41161 .46061 Metetra
.662 .77 .93 r
.41161 .46061 .43712 .48446 .48065 .47052 .45563 .44555 Metetra
.668 .766 .924 r
.45563 .44555 .48065 .47052 .52489 .45635 .50036 .42958 Metetra
.668 .755 .916 r
.50036 .42958 .52489 .45635 .56985 .44195 .5458 .41336 Metetra
.662 .743 .91 r
.5458 .41336 .56985 .44195 .61555 .42732 .59197 .39756 Metetra
.653 .734 .909 r
.59197 .39756 .61555 .42732 .66201 .41244 .63894 .38262 Metetra
.643 .733 .914 r
.63894 .38262 .66201 .41244 .70925 .39731 .68677 .36849 Metetra
.64 .743 .924 r
.68677 .36849 .70925 .39731 .75728 .38193 .7355 .35441 Metetra
.652 .763 .931 r
.7355 .35441 .75728 .38193 .80614 .36628 .785 .33862 Metetra
.69 .78 .92 r
.785 .33862 .80614 .36628 .85584 .35036 .83494 .31811 Metetra
.778 .815 .882 r
.17297 .5105 .20186 .52904 .24282 .5119 .2155 .48135 Metetra
.643 .706 .892 r
.2155 .48135 .24282 .5119 .28403 .49875 .25694 .46878 Metetra
.587 .693 .916 r
.25694 .46878 .28403 .49875 .32582 .48679 .2987 .46157 Metetra
.591 .737 .944 r
.2987 .46157 .32582 .48679 .36833 .47433 .34139 .45302 Metetra
.633 .788 .956 r
.34139 .45302 .36833 .47433 .41161 .46061 .38512 .44008 Metetra
.68 .81 .945 r
.38512 .44008 .41161 .46061 .45563 .44555 .42975 .4225 Metetra
.704 .798 .923 r
.42975 .4225 .45563 .44555 .50036 .42958 .47509 .40198 Metetra
.701 .765 .901 r
.47509 .40198 .50036 .42958 .5458 .41336 .52103 .38118 Metetra
.677 .728 .888 r
.52103 .38118 .5458 .41336 .59197 .39756 .56763 .36279 Metetra
.642 .7 .888 r
.56763 .36279 .59197 .39756 .63894 .38262 .61507 .34856 Metetra
.605 .693 .905 r
.61507 .34856 .63894 .38262 .68677 .36849 .66357 .33834 Metetra
.588 .718 .934 r
.66357 .33834 .68677 .36849 .7355 .35441 .71317 .32913 Metetra
.638 .784 .952 r
.71317 .32913 .7355 .35441 .785 .33862 .76344 .31389 Metetra
.779 .839 .897 r
.76344 .31389 .785 .33862 .83494 .31811 .81299 .28061 Metetra
.856 .826 .817 r
.14265 .49531 .17297 .5105 .2155 .48135 .18782 .44647 Metetra
.628 .677 .877 r
.18782 .44647 .2155 .48135 .25694 .46878 .22938 .4351 Metetra
.483 .628 .916 r
.22938 .4351 .25694 .46878 .2987 .46157 .27073 .43598 Metetra
.484 .699 .963 r
.27073 .43598 .2987 .46157 .34139 .45302 .31333 .43422 Metetra
.598 .806 .98 r
.31333 .43422 .34139 .45302 .38512 .44008 .3575 .42285 Metetra
.71 .852 .95 r
.3575 .42285 .38512 .44008 .42975 .4225 .40289 .40132 Metetra
.757 .829 .908 r
.40289 .40132 .42975 .4225 .47509 .40198 .44901 .37348 Metetra
.746 .776 .877 r
.44901 .37348 .47509 .40198 .52103 .38118 .49557 .3454 Metetra
.698 .718 .864 r
.49557 .3454 .52103 .38118 .56763 .36279 .54259 .32304 Metetra
.625 .668 .871 r
.54259 .32304 .56763 .36279 .61507 .34856 .59045 .31026 Metetra
.539 .64 .898 r
.59045 .31026 .61507 .34856 .66357 .33834 .63961 .30684 Metetra
.486 .666 .942 r
.63961 .30684 .66357 .33834 .71317 .32913 .69021 .30606 Metetra
.612 .802 .973 r
.69021 .30606 .71317 .32913 .76344 .31389 .74134 .29206 Metetra
.879 .877 .828 r
.74134 .29206 .76344 .31389 .81299 .28061 .79006 .23792 Metetra
.903 .814 .749 r
.11073 .48348 .14265 .49531 .18782 .44647 .15984 .40733 Metetra
.607 .648 .865 r
.15984 .40733 .18782 .44647 .22938 .4351 .20139 .39775 Metetra
.295 .511 .895 r
.20139 .39775 .22938 .4351 .27073 .43598 .24183 .41001 Metetra
.272 .597 .95 r
.24183 .41001 .27073 .43598 .31333 .43422 .28402 .41791 Metetra
.534 .813 .997 r
.28402 .41791 .31333 .43422 .3575 .42285 .32859 .40893 Metetra
.75 .889 .942 r
.32859 .40893 .3575 .42285 .40289 .40132 .37494 .38197 Metetra
.814 .851 .877 r
.37494 .38197 .40289 .40132 .44901 .37348 .42211 .34405 Metetra
.793 .783 .844 r
.42211 .34405 .44901 .37348 .49557 .3454 .46945 .30602 Metetra
.721 .711 .84 r
.46945 .30602 .49557 .3454 .54259 .32304 .51693 .27837 Metetra
.603 .636 .857 r
.51693 .27837 .54259 .32304 .59045 .31026 .56512 .26778 Metetra
.438 .566 .886 r
.56512 .26778 .59045 .31026 .63961 .30684 .61486 .27393 Metetra
.311 .566 .928 r
.61486 .27393 .63961 .30684 .69021 .30606 .6665 .28518 Metetra
.568 .811 .99 r
.6665 .28518 .69021 .30606 .74134 .29206 .7186 .27314 Metetra
.948 .877 .731 r
.7186 .27314 .74134 .29206 .79006 .23792 .76619 .19011 Metetra
.927 .795 .695 r
.07702 .47506 .11073 .48348 .15984 .40733 .13164 .36403 Metetra
.581 .619 .855 r
.13164 .36403 .15984 .40733 .20139 .39775 .17302 .35679 Metetra
0 .296 .793 r
.17302 .35679 .20139 .39775 .24183 .41001 .21197 .3836 Metetra
0 .366 .814 r
.21197 .3836 .24183 .41001 .28402 .41791 .25329 .4041 Metetra
.43 .796 .995 r
.25329 .4041 .28402 .41791 .32859 .40893 .2982 .39834 Metetra
.796 .919 .921 r
.2982 .39834 .32859 .40893 .37494 .38197 .34578 .36442 Metetra
.864 .861 .834 r
.34578 .36442 .37494 .38197 .42211 .34405 .39435 .31361 Metetra
.834 .786 .806 r
.39435 .31361 .42211 .34405 .46945 .30602 .44272 .26307 Metetra
.744 .706 .815 r
.44272 .26307 .46945 .30602 .51693 .27837 .49071 .22889 Metetra
.575 .603 .844 r
.49071 .22889 .51693 .27837 .56512 .26778 .53913 .22118 Metetra
.292 .463 .858 r
.53913 .22118 .56512 .26778 .61486 .27393 .5893 .23959 Metetra
.046 .39 .85 r
.5893 .23959 .61486 .27393 .6665 .28518 .64192 .26648 Metetra
.501 .808 1 r
.64192 .26648 .6665 .28518 .7186 .27314 .69507 .25714 Metetra
.982 .854 .638 r
.69507 .25714 .7186 .27314 .76619 .19011 .74146 .1373 Metetra
.939 .778 .655 r
.0413 .47012 .07702 .47506 .13164 .36403 .10327 .31669 Metetra
.549 .588 .846 r
.10327 .31669 .13164 .36403 .17302 .35679 .14432 .3123 Metetra
0 0 .554 r
.14432 .3123 .17302 .35679 .21197 .3836 .18107 .35674 Metetra
.489 0 0 r
.18107 .35674 .21197 .3836 .25329 .4041 .22098 .3928 Metetra
.272 .733 .95 r
.22098 .3928 .25329 .4041 .2982 .39834 .26615 .39114 Metetra
.84 .938 .89 r
.26615 .39114 .2982 .39834 .34578 .36442 .31525 .34865 Metetra
.903 .859 .788 r
.31525 .34865 .34578 .36442 .39435 .31361 .36567 .28213 Metetra
.867 .784 .767 r
.36567 .28213 .39435 .31361 .44272 .26307 .41541 .21659 Metetra
.767 .702 .79 r
.41541 .21659 .44272 .26307 .49071 .22889 .46401 .17475 Metetra
.542 .569 .832 r
.46401 .17475 .49071 .22889 .53913 .22118 .51254 .17054 Metetra
.098 .321 .796 r
.51254 .17054 .53913 .22118 .5893 .23959 .5629 .20377 Metetra
0 .149 .679 r
.5629 .20377 .5893 .23959 .64192 .26648 .61634 .24998 Metetra
.404 .783 .992 r
.61634 .24998 .64192 .26648 .69507 .25714 .6706 .24414 Metetra
.995 .826 .562 r
.6706 .24414 .69507 .25714 .74146 .1373 .71596 .07966 Metetra
.944 .763 .627 r
.00331 .46875 .0413 .47012 .10327 .31669 .07481 .26546 Metetra
.51 .554 .836 r
.07481 .26546 .10327 .31669 .14432 .3123 .11533 .26438 Metetra
.699 .283 0 r
.11533 .26438 .14432 .3123 .18107 .35674 .14908 .32937 Metetra
.738 .236 0 r
.14908 .32937 .18107 .35674 .22098 .3928 .18689 .38406 Metetra
.063 .609 .839 r
.18689 .38406 .22098 .3928 .26615 .39114 .23219 .38741 Metetra
.88 .946 .852 r
.23219 .38741 .26615 .39114 .31525 .34865 .28322 .33464 Metetra
.93 .85 .742 r
.28322 .33464 .31525 .34865 .36567 .28213 .33605 .24953 Metetra
.893 .779 .729 r
.33605 .24953 .36567 .28213 .41541 .21659 .38756 .16664 Metetra
.788 .699 .766 r
.38756 .16664 .41541 .21659 .46401 .17475 .43692 .1161 Metetra
.503 .533 .82 r
.43692 .1161 .46401 .17475 .51254 .17054 .48541 .11596 Metetra
0 .146 .689 r
.48541 .11596 .51254 .17054 .5629 .20377 .53562 .16644 Metetra
0 0 .458 r
.53562 .16644 .5629 .20377 .61634 .24998 .5896 .23572 Metetra
.274 .727 .957 r
.5896 .23572 .61634 .24998 .6706 .24414 .64503 .2342 Metetra
.998 .799 .507 r
.64503 .2342 .6706 .24414 .71596 .07966 .68974 .01736 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[169]:=",
  ImageSize->{196.625, 159.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000340000Wb000`400?l00000o`00003oa03oool0
0<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03o
ool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00
a03oool008L0oooo1@00000h0?ooo`00R@3oool00`000000oooo0?ooo`0h0?ooo`00R@3oool00`00
0000oooo0?ooo`0h0?ooo`00R@3oool00`000000oooo0?ooo`0h0?ooo`00R@3oool00`000000oooo
0?ooo`0h0?ooo`00R03oool2000003X0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00I03o
ool2000000@0oooo0P0000040?ooo`8000006@3oool2000003L0oooo001S0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000005P3oool2000000030?ooo`000000000003H0oooo
001S0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool04@3oool3000000<0oooo
0P00000<0?ooo`800000103oool2000000<0oooo1@00000J0?ooo`00H`3oool010000000oooo0?oo
o`0000090?ooo`8000004P3oool2000000H0oooo00<000000?ooo`0000002P3oool010000000oooo
0?ooo`00000:0?ooo`030000003oool0oooo01X0oooo001S0?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool03P3oool3000000P0oooo0P0000000`3oool000000?ooo`080?ooo`04
0000003oool0oooo000000X0oooo00<000000?ooo`3oool06P3oool006@0oooo0P00000:0?ooo`<0
00002`3oool3000000X0oooo0`0000000`3oool000000?ooo`020?ooo`@000000P3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo01X0oooo001l0?ooo`8000003@3oool200000004
0?o<P@000000oooo000000P0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`0J
0?ooo`00N03oool4000000l0oooo0P0000000`3oc84000000?ooo`02000000P0oooo0P00000:0?oo
o`800000703oool007L0oooo0`00000A0?ooo`8000000P3oc8400`000000oooo0000000b0?ooo`00
F03oool2000001T0oooo1000000D0?ooo`050000003oc84000000?o<P@0000000P3oool00`000000
oooo0?ooo`0_0?ooo`00E`3oool010000000oooo0?ooo`00000G0?ooo`<000005@3oool010000000
olb10?o<P@0000020?o<P@040000003oool0oooo00000300oooo001G0?ooo`040000003oool0oooo
000001@0oooo0`00000H0?ooo`040000003oc840olb100000080olb100@000000?ooo`3oool00000
<03oool005L0oooo00@000000?ooo`3oool000004@3oool4000001X0oooo00@000000?o<P@3oc840
00000P3oc8401@000000oooo0?ooo`3oool0000002l0oooo001G0?ooo`040000003oool0oooo0000
00l0oooo0P00000N0?ooo`080000003oc840olb10000003oc84000000?kCS`0000020?ooo`800000
;P3oool005P0oooo0P00000=0?ooo`<00000803oool020000000olb10?o<P@000000olb10000003n
dhl000000`3oool00`000000oooo0?ooo`0/0?ooo`00I@3oool200000280oooo00T000000?o<P@3o
c840olb10000003oc84000000?kCS`000000103oool00`000000oooo0?ooo`0[0?ooo`00HP3oool3
000000@0oooo2000000H0?ooo`040000003oc840olb10?o<P@8000000`3ndhl00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02X0oooo001P0?ooo`8000001P3oool2000000L0P8SA00<00000
0?ooo`3oool05@3oool010000000olb10?o<P@3oc842000000<0o]>?00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0Z0?ooo`00=P3oool2000000@0oooo0P0000040?ooo`800000603oool4
000000L0oooo00@000000<Vba039//@000001P20R=42000001H0oooo00@000000?o<P@3oc840olb1
0P0000040?kCS`040000003oool0oooo0?ooo`800000:`3oool003D0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000E0?ooo`@00000203oool01@000000bK;40<Vba039//@0
000000L0P8SA0P00000E0?ooo`050000003oc840olb10?o<P@0000001@3ndhl00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02P0oooo000e0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool04@3oool2000000/0oooo00<000000<Vba039//@00`39//@00`000000P8SA0828
d@040828d@03000000009K00000001<0oooo00<000000?o<P@3oc8400P3oc8400`000000o]>?0?kC
S`030?kCS`800000103oool00`000000oooo0?ooo`0X0?ooo`00;`3oool400000080oooo00@00000
0?ooo`3oool000002@3oool200000140oooo0`00000<0?ooo`0300000039//@0bK;400@0bK;400<0
00000828d@20R=401@20R=400`00000002F`0000000B0?ooo`030000003oc840olb10080olb100<0
00000?kCS`3ndhl00P3ndhl00`000000nmZS000000050?ooo`030000003oool0oooo02L0oooo000e
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool03P3oool2000000h0oooo00<0
00000<Vba039//@01P39//@00`000000P8SA0828d@040828d@04000000009K0002F`00000140oooo
00@000000?o<P@3oc840olb10P0000040?kCS`040000003kfZ<0nmZS000000D0oooo00<000000?oo
o`3oool09P3oool003H0oooo0P00000:0?ooo`<000002P3oool4000000l0oooo00<000000<Vba039
//@01`39//@00`000000P8SA0828d@020828d@@000000P009K000`000000oooo0?ooo`0>0?ooo`04
0000003oc840olb10?o<P@8000000`3ndhl01@000000nmZS0?_JX`3kfZ<0000000@0oooo0P00000X
0?ooo`00CP3oool300000100oooo00<000000>C7^P0000002@39//@4000000<0RY7D0`0000000`00
9K0000000?ooo`0>0?ooo`040000003oc840olb10?o<P@8000000`3ndhl00`000000nmZS0?_JX`02
0?_JX`030000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool004/0oooo0`00000C0?oo
o`030000003TakX0000000P0bK;400<000000<BcbP0000001P2:TM@01@0000006E;;000000009K00
000000d0oooo00<000000?o<P@3oc8400P3oc8400`000000o]>?000000020?kCS`030000003kfZ<0
nmZS0080nmZS00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0T0?ooo`00;03oool50000
01L0oooo1000000D0?ooo`050000003TakX0i<Nj0>C7^P0000001P39//@010000000a;?:0<BcbP00
000608ZAe0030000000ID//06E;;008000003@3oool01@000000olb10?o<P@3oc84000000080o]>?
00<000000?kCS`0000001P3kfZ<00`000000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo
000^0?ooo`030000003oool0oooo01D0oooo0P00000G0?ooo`030000003TakX0i<Nj0080i<Nj00<0
00000<Vba039//@00P39//@2000000@0a;?:00<0000008ZAe02:TM@0102:TM@00`0000006E;;01UB
b`02000000`0oooo00D000000?o<P@3oc840olb1000000020?kCS`030000003ndhl0000000D0nmZS
0P0000060?ooo`030000003oool0oooo02<0oooo000^0?ooo`030000003oool0oooo0180oooo0`00
000I0?ooo`030000003TakX0i<Nj00<0i<Nj00@000000<Vba039//@000001P34/lX00`000000RY7D
08ZAe00408ZAe0030000000ID//06E;;00806E;;00<000000?ooo`3oool02@3oool01@000000olb1
0?o<P@3oc84000000080o]>?00<000000?kCS`0000001@3kfZ<00`000000l^2k000000050?ooo`80
00001@3oool2000001d0oooo000V0?ooo`@00000103oool00`000000oooo0?ooo`0@0?ooo`<00000
6P3oool00`000000i<Nj0>C7^P040>C7^P0300000039//@0000000P0a;?:00<0000008ZAe02:TM@0
102:TM@00`0000006E;;01UBb`0201UBb`030000003oool0oooo00P0oooo00@000000?o<P@3oc840
00000`3ndhl2000000D0nmZS00@000000?;P^`3bh;/000001P3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000001`0oooo000^0?ooo`030000003oool0oooo00d0oooo0`00000M0?oo
o`030000003TakX0i<Nj00D0i<Nj00<000000<BcbP34/lX01`34/lX00`000000RY7D08ZAe00208ZA
e0@000000`0ID//2000000P0oooo00D000000?o<P@3oc840olb1000000030?kCS`800000103kfZ<0
0`000000l^2k0?;P^`020?;P^`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo01X0oooo000]0?ooo`8000003@3oool2000001l0oooo00<00000
0>C7^P3TakX01@3TakX00`000000gLS4000000090<BcbP@000000`2CV]P3000000806E;;0`000006
0?ooo`050000003oc840olb10?o<P@0000000`3ndhl00`000000nmZS0?_JX`030?_JX`030000003b
h;/0l^2k0080l^2k00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool06P3oool003T0oooo0`00000P0?ooo`030000003TakX0i<Nj00D0i<Nj00@0
00000=g8a03Mb<@000001`34/lX3000000H0Ti[H00<0000004Yff`1:M]/03@0000000`3oc8400000
0?kCS`030?kCS`030000003kfZ<0nmZS0080nmZS00<000000?;P^`3bh;/0103bh;/00`000000oooo
0?ooo`040?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool06P3oool003H0oooo
0`00000S0?ooo`030000003TakX0i<Nj00D0i<Nj00D000000=g8a03Mb<@0gLS4000000050<BcbP05
0000002n]=00_[C@0;jdd00000001P2CV]P010000000BWKK04Yff`1:M]/4000000D0A[[d10000003
0?kCS`800000103kfZ<00`000000l^2k0?;P^`030?;P^`8000001@3oool00`000000oooo00000002
0?ooo`8000007@3oool003@0oooo0P0000000`3oool000000?ooo`0R0?ooo`030000003TakX0i<Nj
00D0i<Nj00<000000=g8a03Mb<@00`3Mb<@01@000000a;?:0<BcbP34/lX0000000@0_[C@00<00000
09>Jf02CV]P0102CV]P00`000000BWKK04Yff`0304Yff`L00000101Wb?d4000000050?_JX`000000
nmZS0?_JX`0000001@3bh;/010000000hN3C0>7Pd`0000060?ooo`030000003oool0oooo01l0oooo
000b0?ooo`8000009P3oool00`000000k]Vm000000050>C7^P030000003Mb<@0gLS400@0gLS400@0
00000<BcbP00000000001P2n]=000`000000Ti[H09>Jf00409>Jf0030000001:M]/0BWKK00<0BWKK
00<0000000]Sf@0000000P00000206O8o@L0000000@0nmZS0000003kfZ<000001@3bh;/01@000000
hN3C0>7Pd`3Qh=<0000000L0oooo00<000000?ooo`3oool07P3oool00380oooo0P0000030?ooo`L0
0000703oool010000000k]Vm0>kI_@0000030>C7^P030000003Mb<@0gLS400H0gLS400<000000;jd
d02n]=001P2n]=000`000000Ti[H09>Jf00409>Jf0030000001:M]/0BWKK00@0BWKK00@0000000]S
f@0;HmT02f?I1@000004083>o`@00000103bh;/00`000000hN3C0>7Pd`030>7Pd`030000003oool0
oooo00D0oooo00<000000?ooo`3oool07@3oool00380oooo00<000000?ooo`0000000P3oool20000
00D0PXgF00<000000?ooo`3oool0603oool01@000000k]Vm0>kI_@3^fKd0000000<0i<Nj00<00000
0=g8a03Mb<@01@3Mb<@00`000000eLW>000000080;jdd0040000002CV]P0Ti[H09>Jf0d000000P0;
HmT00`000000P<ko083>o`05083>o`<00000103bh;/00`000000hN3C0>7Pd`030>7Pd`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool07@3oool00380oooo00<000000?ooo`3oool00P000000
0`3a`j00000008:=eP0408:=eP030000003oool0oooo01P0oooo00<000000>kI_@3^fKd00P3^fKd0
0`000000i<Nj000000070=g8a0040000003EbLh0eLW>000000P0_[C@1000000409ZRf`030000001`
T>80L93R00<0000000<0L93R00000000000010000002083>o`@000000P2Acod200000080l^2k00<0
00000>7Pd`3Qh=<01@3Qh=<00`000000oooo0?ooo`050?ooo`030000003oool0oooo01`0oooo000a
0?ooo`030000003oool0oooo0080oooo00@000000?73X03a`j0000001@22SMH00`000000oooo0?oo
o`0F0?ooo`030000003^fKd0k]Vm00@0k]Vm00<000000=g8a03Mb<@01@3Mb<@00`000000eLW>0=G9
cP020=G9cP030000002n]=00_[C@00<0_[C@0P0000000`2h]]L0000009ZRf`0509ZRf`<00000101`
T>800`000000Ci3]04n@k@0204n@k@<000001`2Acod00`000000l^2k000000060>7Pd`80000000<0
amKU0000003oool01P3oool00`000000oooo0?ooo`0K0?ooo`00<@3oool2000000<0oooo00@00000
0?73X03a`j0000001@22SMH00`000000oooo0?ooo`0E0?ooo`030000003^fKd0k]Vm00@0k]Vm00<0
00000>OKb@0000001@3Mb<@00`000000eLW>0=G9cP040=G9cP050000002n]=00_[C@0;jdd0000000
0`2h]]L010000000VZ;K09ZRf`2JX]/30000000309ZRf`000000L93R00D0L93R00<0000004n@k@1?
T>d00`1?T>d00`000000TLom097?o@05097?o@8000001P3Qh=<01@000000amKU0<OFi@37e^D00000
00L0oooo00<000000?ooo`3oool06`3oool00340oooo0P0000020?ooo`030000003a`j00lL>P0080
lL>P00<0000008:=eP22SMH00`22SMH00`000000oooo0?ooo`0D0?ooo`030000003^fKd0k]Vm00@0
k]Vm00@000000>OKb@3WflT000000`3Mb<@00`000000eLW>0=G9cP050=G9cP040000002n]=000000
000000D0^;KG0`00000409ZRf`030000001`T>80L93R00@0L93R00<0000004n@k@1?T>d0101?T>d0
0`000000TLom097?o@0400000080W<gi00<000000>7Pd`3Qh=<00P3Qh=<00`000000amKU0<OFi@03
0<OFi@030000003oool0oooo00D0oooo00<000000?ooo`3oool06P3oool00340oooo00D000000?oo
o`3oool0oooo000000040?73X00300000022SMH0PXgF00<0PXgF00<000000?ooo`3oool04`3oool0
0`000000k]Vm0>kI_@040>kI_@030000003WflT0im_90080im_900<000000=g8a00000002@3EbLh0
0`000000^;KG0;Rfe`020;Rfe`<0000000<0^;KG0000002JX]/0102JX]/A000000H0W<gi0P000000
0`3Qh=<00000000000060<OFi@030000003oool0oooo00D0oooo0P00000K0?ooo`00203oool20000
00@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000`3oool50000
00030?ooo`000000oooo0080oooo00<000000?73X03a`j000`3a`j07000001@0oooo00<000000>kI
_@3^fKd00`3^fKd00`000000im_90>OKb@040>OKb@030000003EbLh0eLW>00H0eLW>0P0000000`3;
b=P000000;Rfe`02000000@0^;KG00<0000009ZRf`2JX]/00`00000209n[gP0300000029XnD0RJ?U
00@0RJ?U00<0000007bZl@1lZ_40101lZ_400`000000W<gi09c=n@0509c=n@8000002037e^D20000
00L0oooo00<000000?ooo`3oool06@3oool000L0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000lL>P0?73X0040?73X0800000102<U]P200000180oooo00<000000>kI_@3^fKd0103^fKd00`00
0000im_90>OKb@030>OKb@030000003Mg=D0000000H0eLW>00<000000<_8f03;b=P00`0000060;Rf
e`<000001@2OZmh00`000000RJ?U08VSi@0408VSi@030000001lZ_40O:[a00D0O:[a00<0000009c=
n@2LcOT0100000000`2Sb?<00000000000050<OFi@8000000P2`an/00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01P0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0200000080oooo00<000000?73X03a
`j000`3a`j000`000000l<NW0000000508bFf08000004@3oool00`000000k]Vm0>kI_@030>kI_@03
0000003WflT0im_900<0im_900D000000=gLe@3Mg=D0gMcE000000040=G9cP@000000P3;b=P00`00
0000^;KG0;Rfe`020;Rfe`80000000<0/[OM0000002OZmh01P2OZmh00`000000RJ?U08VSi@0408VS
i@030000001lZ_40O:[a0080O:[a1@0000060:?8l`8000000P37e^D2000000@0/<O[00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`0000<0oooo0000000000000P0000020?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool010000000
oooo0?ooo`0000030?ooo`030000003a`j00lL>P00<0lL>P00@000000?37Y`3`ajL000001@2<U]P0
0`000000oooo0?ooo`0>0?ooo`800000103^fKd00`000000im_90>OKb@030>OKb@030000003Mg=D0
gMcE00<0gMcE00<000000=G9cP0000000P0000050<_8f0030000002h]]L0^;KG00800000102b]md0
0`000000Wj_N09n[gP0509n[gP0300000029XnD0RJ?U00<0RJ?U1@00000409Jgk`030000002Sb?<0
XlSc00@0XlSc100000070;37j`030000003oool0oooo00D0oooo00<000000?ooo`3oool05`3oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo0080000000<0oooo0000003a`j00103a`j001@000000l<NW0?37Y`3`ajL0
000000D0S9KH0P00000>0?ooo`030000003Ql]X0hO;J008000000P3^fKd00`000000im_90>OKb@03
0>OKb@030000003Mg=D0gMcE0080gMcE0`0000090<_8f08000001P2b]md00`000000Wj_N09n[gP05
09n[gP0300000029XnD0RJ?U00<000000P2J/NL00`000000U[O_09Jgk`0509Jgk`030000002Sb?<0
XlSc00D0000000<0Y/?^0000002`an/01P2`an/00`000000oooo0?ooo`060?ooo`030000003oool0
oooo01H0oooo00080?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`800000103oool20000
00@0oooo0P0000020?ooo`80000000<0oooo0000003a`j00103a`j000`000000l<NW0?37Y`020?37
Y`030000002<U]P0S9KH00<0S9KH0P00000<0?ooo`030000003Ql]X0hO;J00<0hO;J0P0000050>OK
b@030000003Mg=D0gMcE00<0000000@0gMcE0000003@fN0000001P3;b=P2000000030;k6h0000000
/[OM00H0/[OM00<0000009n[gP2OZmh0102OZmh3000000H0V[7W00<0000009Jgk`2F]nl0102F]nl3
000000D0Y/?^0P0000070;37j`800000203oool00`000000oooo0?ooo`0E0?ooo`00<03oool01000
0000oooo0?ooo`0000050?73X0030000003`ajL0l<NW0080l<NW00<0000008bFf02<U]P00P2<U]P2
000000030;`l00000000oooo00T0oooo00<000000>7bfP3Ql]X0103Ql]X010000000eo3S00000000
00020>OKb@@000000`3Mg=D01@000000d=WP0=3Ih03@fN00000000@0blSH00<000000;k6h02na^00
0P2na^000`000000/[OM0;:gg@040;:gg@030000002OZmh0Wj_N00@000000P2T/n<00`000000V[7W
09Zai`0509Zai`030000002F]nl0U[O_00<000000P2S_^`00`000000Y/?^0:K3kP040:K3kP800000
0P2`an/400000080YkcX00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`00<03o
ool3000000D0lL>P00<000000?37Y`3`ajL0103`ajL400000080U9kJ00<000000;`l00000000203o
ool00`000000hO;J0>7bfP040>7bfP030000003Gl><0eo3S0080eo3S0`0000040=gLe@8000001@3@
fN0010000000blSH0000000000050;k6h0030000002b]md0/[OM00@0/[OM0`0000060:Bch`030000
002J/NL0V[7W00D0V[7W0`0000050:>nk0030000002V`nh0Y/?^00@0Y/?^100000060:Nlj0030000
003oool0oooo00D0oooo0P0000050?ooo`800000103oool2000000<0oooo1@0000010?ooo`00:P3o
ool2000000<0oooo00@000000?ooo`3oool000001@3a`j000`000000l<NW0?37Y`040?37Y`800000
1@2DW]X00`000000_3`0000000060?ooo`030000003Ql]X0hO;J00<0hO;J0P0000030=O`h`<00000
00<0bn_[0000000000000P3Mg=D00`000000d=WP0=3Ih0060=3Ih0030000002na^00_/KP00H0_/KP
00<000000;:gg@2b]md00`0000020:fjh`030000002T/n<0Y;?S00D0Y;?S00<0000009Zai`2J/NL0
100000020:Bkj@030000002S_^`0Xkk/00@0Xkk/00<000000:K3kP2V`nh01@0000000`2W_NT00000
0:Nlj0060:Nlj0030000003oool0oooo00H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00@3oool002T0oooo00@000000?ooo`3oool0
00000P3oool2000000030?ooo`000000lL>P00@0lL>P00<000000?37Y`3`ajL00`3`ajL00`000000
kL^a0000000509BNfP030000002l?000_3`0008000000`3oool00`000000hO;J0>7bfP030>7bfP03
0000003Gl><0eo3S00@000001@3;jn/2000000L0d=WP0P0000000`31e>P000000;k6h0070;k6h080
00001P2]^^<00`000000Y;?S0:Bch`040:Bch`<000001P2T^nT00`000000Xkk/0:>nk0040:>nk0<0
00001@2W_NT2000000L0YkcX0P0000070?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000Y0?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool00000103a`j000`000000l<NW0?37Y`040?37Y`040000003]bk40
kL^a000000D0U9kJ2@0000030>7bfP@000000P3Gl><00`000000bn_[0<_[j`030<_[j`80000000<0
_n?a0000003@fN00103@fN000`000000`MCX0<7Dj0020<7Dj0030000002na^00_/KP00<0_/KP0P00
00000`2c`nH000000:fjh`060:fjh`030000002T/n<0Y;?S00<000000P2W^nP00`000000Y;_Y0:Bk
j@050:Bkj@030000002S_^`0Xkk/00<000000P2W`>`00`000000YkgY0:Nmj@030:Nmj@030000002W
_NT000000080YkcX100000020:nhh0030000003oool0oooo00D0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0040oooo000Y0?ooo`040000003o
ool0oooo00000080oooo0`0000050?73X0030000003`ajL0l<NW00<0l<NW00<000000>g;/@3]bk40
0P3]bk400`000000U9kJ09BNfP0309BNfP`000000`3Gl><2000000@0bn_[0P0000040;oSl@800000
00<0d=WP0000000000001P31e>P00`000000_/KP0;k6h002000000<0/l?V00<000000:fjh`2]^^<0
1@2]^^<3000000D0Yk_X00<000000:Bkj@2T^nT01@2T^nT3000000D0Yl3/00<000000:Nmj@2W_NT0
102W_NT4000000H0[kSP00<000000?ooo`3oool01@3oool2000000050?ooo`000000oooo0?ooo`00
00002P3oool00`000000oooo0?ooo`010?ooo`00:@3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0000000@0lL>P00<000000?37Y`3`ajL0103`ajL00`000000kL^a0>g;/@020>g;/@03
0000002DW]X0U9kJ00<000000P2KYMd>000000<0bn_[0P0000070;oSl@8000002031e>P3000000H0
/l?V00<000000:fjh`2]^^<00P2]^^<200000080ZKkX00<000000:Nkj02W^nP0102W^nP00`000000
Y;_Y0:Bkj@0400000080Yl?^00<000000:O0k02W`>`0102W`>`00`000000YkgY0:Nmj@0500000003
0:Nfi0000000[kSP00H0[kSP00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02000000X0
oooo0P0000030?ooo`00:P3oool2000000<0oooo00<000000?ooo`000000103a`j000`000000l<NW
0?37Y`030?37Y`030000003]bk40kL^a00@0kL^a0P00000509^Ug@T000001@1^boh3000000L0_n?a
0P0000020;GJl`0300000031e>P0`MCX00<0`MCX0P0000020;C<k0030000002c`nH0/l?V00@0/l?V
00<000000:fjh`2]^^<00P0000040:Vnj0030000002W^nP0Yk_X00D0Yk_X0P0000060:O3kP030000
002W`>`0Yl3/00@0Yl3/0`0000050:Nfi08000001@2_^>02000000030;nhd`000000000000H0oooo
00<000000?ooo`3oool0403oool002l0oooo0P0000050?73X0030000003`ajL0l<NW00<0l<NW00<0
00000>g;/@3]bk400`3]bk400`000000im2o0000000409^Ug@<000000`1;P^D00`000000AISc0000
0006000000<0R=3o0P0000030;oSl@8000001@2ef_<00`000000`MCX0<7Dj002000000@0]<c/00<0
00000;?3iP2c`nH0102c`nH3000000L0ZKkX00<000000:Nkj02W^nP00P2W^nP2000000030:O4kP00
0000Yl?^00H0Yl?^00<000000:O0k02W`>`00`0000020:>ok@030000002W]^@0YkKT00<0YkKT00<0
00000:Nfi00000000`2_^>000`000000_kSC0;nhd`030;nhd`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool03`3oool002h0oooo0`0000040?73X0030000003`ajL0l<NW00<0l<NW00<00000
0>g;/@3]bk40103]bk400`000000im2o0>O@_`04000000<0VjGM00D0000004^2i@1;P^D0Bh;U0000
000404FHl`8000001@28d?l4000000L0]M[c0`0000070;C<k0030000002c`nH0/l?V00<000000P2[
`NX00`000000ZKkX0:Vnj0050:Vnj0030000002W^nP0Yk_X008000000`2Wa>h00`000000Yl?^0:O3
kP050:O3kP<000001@2S_nd00`000000YkKT0:Nfi0040:Nfi080000000<0[kSP0000000000001@2o
^=<00`000000d;W3000000040?ooo`8000004@3oool002h0oooo0`0000040?73X0030000003`ajL0
l<NW00<0l<NW00<000000>g;/@3]bk400`3]bk400`000000im2o00000002000000H0VjGM00<00000
04^2i@1;P^D00P1;P^D00`000000AISc04FHl`0204FHl`H000000`2Ic_X2000000<0]M[c0`000002
0:k?l@030000002dc>`0]<c/00D0]<c/0`0000060:_1jP030000002Y_^P0ZKkX00@0ZKkX0`000006
0:O4kP030000002W`nh0Yl?^00@000000P2Rb_@00`000000Xko]0:>ok@040:>ok@030000002W]^@0
YkKT00@0YkKT0P0000060;nhd`050000003@^L<0d;W30=2i``000000103oool200000100oooo0005
0?ooo`800000103oool2000000@0oooo0P0000040?ooo`800000103oool2000000@0oooo0P000003
0?ooo`D0000000<0oooo0000000000001@3a`j000`000000l<NW0?37Y`020?37Y`030000003]bk40
kL^a00<0kL^a0`0000030>O@_`030000002KYMd0VjGM0080VjGM2`00000307^bmP030000002Ic_X0
VLkj00D0VLkj0`0000060:k?l@8000000P2dc>`300000080ZlC/00<000000:_1jP2[`NX01@2[`NX0
0`000000ZKkX0:Vnj00300000080Yl?]00<000000:O4kP2Wa>h0102Wa>h3000000H0X/[d00<00000
0:>ok@2S_nd0102S_nd00`000000YkKT0:Nfi005000000030:B_h0000000_kSC00<0_kSC00H00000
0=2i``3@^L<0d;W30000003M^;<600000100oooo00040?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`3oool2000000@0lL>P
00<000000?37Y`3`ajL00`3`ajL00`000000kL^a0>g;/@03000000L0im2o100000030:2]h0030000
001kX>X0Nj3Z0080Nj3Z00<0000007^bmP1k/_H0101k/_H200000080VLkj0`0000020:;9m0030000
002^co40[/oa00D0[/oa0`0000050:_4k0030000002[`NX0Zl7Z00D0Zl7Z0`0000060:O3k@030000
002Wa>h0YlC^00<000000P2Tc_D00`000000X/[d0:;:m0050:;:m0030000002S_nd0Xko]0080Xko]
100000050:B_h0800000102o^=<01@000000d;W30=2i``3@^L<000000080gKRc00D000000>JgY000
0000k;JH0000000@0?ooo`00103oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo000000@0oooo00@000000?ooo`3oool0oooo0P0000040?73X0030000003`ajL0l<NW
0080l<NW100000020>g;/@030000003Wd;l0im2o00@0im2o00<000000=_Cd@0000001P2P[N000`00
0000Nj3Z07^PjP0207^PjP800000101k/_H4000000H0X/Wd0P0000020:k?l@<000000P2YaNh00`00
0000ZlC/0:_4k0040:_4k0030000002[`NX0Zl7Z00@000000P2W`>/00`000000Yl?]0:O3k@040:O3
k@<000001P2Tc_D00`000000X/[d0:;:m0020:;:m0L000000`2D^_400`000000Y:oP0:B_h0040:B_
h08000000P2o^=<01@000000d;W30=2i``3@^L<000000080gKRc00H000000>JgY03V]j@000000>bf
V000000@0?ooo`00103oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000@0oooo00D000000?ooo`3oool0oooo000000040?73X0040000003`ajL0l<NW0?37Y`<0
0000103]bk400`000000im2o0>O@_`040>O@_`050000003Kdm40fm?A0=_Cd@0000001P2P[N001000
0000Nj3Z07^PjP1kX>X6000000<0Ukca00<000000:;9m02RbO@01@2RbO@3000000H0ZLG^00<00000
0:_4k02[a>`00P2[a>`4000000L0Yl3[00<000000:O3k@2W`nd00`0000020:S9l@030000002Tc_D0
Y<ke00@0Y<ke1@00000408o<o0030000002D^_40U;[a00<0U;[a00<000000:B_h02T[n001@2T[n00
0`000000_kSC000000040=2i``060000003M^;<0gKRc0000003V]j@000000P3/]YP2000000l0oooo
00040?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool00`000000oooo0?ooo`0:000000030?37Y`000000kL^a00<0kL^a00<000000>O@_`3Wd;l0103W
d;l00`000000fm?A0=_Cd@020=_Cd@030000002P[N00X:gP00@0X:gP1000000309JajP030000002G
_?40Ukca00@0Ukca0P0000020:;9m0<000000P2V`nh00`000000ZLG^0:W5kP040:W5kPD000000`2W
_NT00`000000Yl3[0:O0j`050:O0j`<000001P2XbO400`000000Y<ke0:C>m@0300000080VmKl0P00
000508o<o0030000002D^_40U;[a00@0U;[a00<000000:B_h02T[n00102T[n02000000@0d;W300/0
00000=fh/`3M^;<0gKRc0000003V]j@000000>bfV0000000oooo0000000?0?ooo`001@3oool20000
00X0oooo0P0000040?ooo`800000103oool2000000@0oooo0P0000040?ooo`8000000P3oool20000
00<0oooo0`0000000`3oool0000000000002000000<0kL^a00<000000>O@_`3Wd;l0103Wd;l00`00
0000fm?A0=_Cd@030=_Cd@030000002P[N00X:gP00<000000P2T]>@00`000000U[7Z09JajP0309Ja
jP030000002G_?40Ukca00@0Ukca0`0000060:K3kP030000002YaNh0ZLG^00<000000P2W_>P00`00
0000YkgY0:Nmj@040:Nmj@8000000P2W`>/300000080Zl7Z00<000000:S9l@2XbO40102XbO430000
00H0VmKl2`00000209Bjl@030000002T[n00Y:oP00@0000000<0XJSL0000003@^L<00`3@^L<01000
0000gKRc0=fh/`0000020>JgY0050000003/]YP000000?ooo`0000003`3oool002d0oooo00<00000
0?ooo`0000000P0000080?ooo`@000001@3Wd;l00`000000fm?A0=_Cd@050=_Cd@8000001@2T]>@0
0`000000U[7Z09JajP0409JajP030000002G_?40Ukca00<000000P2T_nd00`000000Y/?^0:K3kP04
0:K3kP<000001P2W_>P00`000000YkgY0:Nmj@040:Nmj@<000001P2[`NX00`000000Z<Wa0:S9l@03
00000080[M;c0P00000209_Fo0<000000P27f_l2000000@0H;om00<0000007F]m@1e[OD01@000006
0:6Xg0040000003@^L<0d;W3000000<0gKRc00P000000>JgY03V]j@000000>bfV0000000oooo0000
00l0oooo000]0?ooo`8000003`3oool200000080im2o00<000000=_Cd@3Kdm40103Kdm4200000003
0<O@h@000000Y;CT00D0Y;CT00<0000009JajP2F/NX00P2F/NX4000000H0Y;o]00<000000:K3kP2V
`nh00`0000020:Nlj0030000002W_>P0YkcX00D0YkcX00<000000:Nmj@2W_NT00`0000020:Zhh`03
0000002[`NX0Zl7Z00D0Zl7Z0P0000060:gBl`<000001@27f_l400000080H;om00<0000007F]m@1e
[OD0101e[OD00`000000XJSL0:6Xg0040:6Xg0040000003@^L<0d;W3000000<0gKRc00P000000>Jg
Y03V]j@000000>bfV0000000oooo000000l0oooo000^0?ooo`030000003oool0oooo00l0oooo0P00
00060=_Cd@0300000037d>40am3Q0080am3Q00<000000:Bdi02T]>@00`2T]>@5000000<0Xk_Z00<0
00000:Bok@2T_nd0102T_nd3000000H0YkcX00<000000:Nlj02W_>P0102W_>P3000000D0Z[SS00<0
00000:_1jP2[`NX00`2[`NX2000000030;?3iP00000000000080[M;c0`0000030;GLm0D000000P1P
dO<6000000D0MJge00<000000:6Xg02QZ=`0102QZ=`3000000<0gKRc00T000000>JgY03V]j@0i[NT
0000003/]YP000000?ooo`0000003`3oool002l0oooo0P00000A0?ooo`8000000P3Kdm42000000H0
am3Q00<000000:Bdi02T]>@00P0000020:Nlj0030000002S^nX0Xk_Z00@0Xk_Z0P0000020:Bok@80
00000P2W_n/00`000000YkcX0:Nlj0050:Nlj0030000002W_>P0YkcX00<000000P2Y]>400`000000
Z[SS0:Zhh`040:Zhh`030000002[`NX0Zl7Z008000001@2c`nH2000000D0]Mcd0P0000000`30iO40
00000000000;000000@0MJge00<000000:6Xg02QZ=`0102QZ=`2000000<0gKRc00@000000>JgY03V
]j@000000P3/]YP00`000000oooo0000000?0?ooo`00<@3oool00`000000oooo0?ooo`0@0?ooo`80
00002@37d>42000000D0YkcX00<000000:>kjP2S^nX0102S^nX3000000D0Yko[00<000000:Nlj02W
_>P0102W_>P3000000D0ZKCQ00<000000:Zhh`2Z^><0102Z^><3000000D0/l?V0P0000000`2oa]l0
0000000000020;GLm08000000`30iO401P000000cNkZ0<g^jP000000f_?P000000@0oooo20000004
0:6Xg0<0000000D0gKRc0000003M^;<0gKRc000000020>JgY0060000003/]YP0k;JH0000003oool0
00003`3oool00380oooo00<000000?ooo`3oool04@3oool00`000000am3Q0<O@h@040<O@h@800000
00<0/LKZ0000002W_>P01@2W_>P00`000000Xk_Z0:>kjP0300000080Yl?^00<000000:Noj`2W_n/0
102W_n/00`000000YkcX0:Nlj00300000080Y[KS00<000000:Vdh@2Y]>40102Y]>400`000000Z[SS
0:Zhh`0300000080/KKL00<000000;?3iP2c`nH00P2c`nH00`000000_lKO0;o6g`030;o6g`800000
0`30iO4200000080cNkZ00<000000=[ch00000001`3oool2000000<0>hc^1@00000209bQf0030000
003M^;<000000080gKRc00@000000>JgY03V]j@000000P3/]YP010000000oooo0?ooo`00000>0?oo
o`00<`3oool00`000000oooo0?ooo`0A0?ooo`8000000P37d>42000000<0/LKZ00<000000:Nlj02W
_>P0102W_>P3000000D0Yl?^00<000000:Noj`2W_n/0102W_n/3000000D0Y[KS00<000000:Vdh@2Y
]>40102Y]>43000000H0/KKL00@000000;?3iP00000000001@2oa]l01P000000c<SF000000000000
`>Ga00000080cNkZ0P0000000`3Jln0000000?ooo`080?ooo`800000100kS>h00`000000W:7H09bQ
f00309bQf0040000003M^;<00000000000<0i[NT00@000000>bfV03/]YP000000P3oool00`000000
oooo0?ooo`0<0?ooo`00=03oool2000001<0oooo0P0000060;76jP030000002W_>P0YkcX00<00000
0P2Wa>h00`000000Yl?^0:O3kP040:O3kP030000002W_n/0Yko[00<000000P2T_N`00`000000Y[KS
0:Jfh`040:Jfh`030000002Y]>40ZKCQ00<000000P2/[]T00`000000/KKL0;6fg0050;6fg0030000
002oa]l0_lKO00@0_lKO00<000000<c8eP3<b=H00P3<b=H010000000cNkZ0<g^jP0000020=[ch003
0000003oool0oooo00T0oooo0`00000203^<kP030000002LXMP0W:7H00<0W:7H00@000000=fh/`3M
^;<000000`3V]j@010000000k;JH0>bfV00000020?ooo`030000003oool0oooo00`0oooo000f0?oo
o`030000003oool0oooo0140oooo00<000000;76jP2aa^X0102aa^X3000000H0YlC^00<000000:O3
kP2W`nh00P2W`nh4000000D0Y;g/00<000000:Jfh`2V]^<0102V]^<3000000D0[:kI00<000000;6f
g02a]]`00`2a]]`2000000030;Zdd`000000_lKO0080_lKO0P0000040<c8eP030000003Gb</00000
008000000P3Jln000`000000oooo0?ooo`0:0?ooo`0600000000D<X000000000000kS>h000001@2L
XMP00`000000gKRc000000020>JgY0040000003/]YP0k;JH000000<0oooo00<000000?ooo`3oool0
303oool003L0oooo00<000000?ooo`3oool04@3oool200000080/LKZ0P0000020:Nlj0030000002W
a>h0YlC^00@0YlC^1@0000030:79m0030000002T_N`0Y;g/00@0Y;g/00<000000:Jfh`2V]^<00`00
00020:B^g`030000002/[]T0[:kI00@0[:kI00<000000;6fg02a]]`00P0000040;Zdd`030000002o
a]l0000000D0c<SF00@000000=O8b`3Gb</000000P3Pb<02000000h0oooo00<00000001@bP00D<X0
0P00000509bQf080000000@0i[NT0000003V]j@000000P3/]YP01@000000oooo0?ooo`3oool00000
00h0oooo000h0?ooo`030000003oool0oooo0180oooo0P0000050:Nlj08000000P2Wa>h200000080
YLge00<000000:79m02QbO@0102QbO@2000000<0Y;g/100000050:B^g`030000002/[]T0[:kI00D0
[:kI0P0000070;Zdd`030000003<b=H0c<SF00<0c<SF00D000000=O8b`3Gb</0elS;000000020>38
`0030000003oool0oooo00h0oooo00@00000001@bP00D<X0053:1`0000020>JgY08000000P3/]YP0
1@000000oooo0?ooo`3oool0000000h0oooo000i0?ooo`8000004`3oool00`000000YkcX0:Nlj004
0:Nlj0<000001@2UcOD2000000@0XLWd1@00000309Nhk`030000002T[]l0Y:kO00@0Y:kO00<00000
0:b^f@2/[]T00P2/[]T2000000030;2YdP000000^[CC00D0^[CC00<000000<>bbP0000000`3<b=H0
1@000000elS;0=O8b`3Gb</0000000<0h<S000<000000?ooo`3oool03`3oool010000000053:001@
bP00000509NJe@050000003V]j@0i[NT0>JgY00000000P3/]YP01@000000oooo0?ooo`3oool00000
00h0oooo000k0?ooo`030000003oool0oooo0140oooo00<000000:Nlj02W_>P00`0000020:nfgP80
0000102UcOD6000000<0QlWm00<0000009Nhk`2G^>l00P2G^>l00`000000Y:kO0:B^g`040:B^g`03
0000002/[]T0[:kI008000000`2`ZM800`000000^[CC0;Zdd`030;Zdd`0700000033//X0`k;:0<>b
bP000000c<SF000000040=O8b`040000003Pb<00h<S0000001<0oooo00@00000001@bP00D<X00000
1@2GV]D010000000i[NT0>JgY00000020>bfV0050000003oool0oooo0?ooo`0000003P3oool003`0
oooo00<000000?ooo`3oool04@3oool2000000L0[kKN1000000309gEn`8000001@27bOd00`000000
UkS_09Nhk`0209Nhk`030000002T[]l0Y:kO0080Y:kO100000060;2YdP030000002j]=<0^[CC0080
00001@33//X00`000000elS;0=O8b`020=O8b`050000003Pb<00h<S00>38`0000000503oool00`00
0000053:0000000509NJe@030000003V]j@0i[NT0080000000<0k;JH0000003oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`00?@3oool00`000000oooo0?ooo`0A0?ooo`030000002_]]h0[kKN00@0
[kKN00@000000;fcc`0000000000102MeO/A000000<0WjOK00<000000;2YdP2`ZM80102`ZM800`00
0000^[CC000000060<>bbP030000003;/L40000000<0elS;00@000000>38`03Pb<0000005P3oool2
000000H0Ui[E0P0000020>bfV0800000103oool00`000000oooo0?ooo`0;0?ooo`00?P3oool20000
0180oooo00@000000:nfgP2_]]h0[kKN0P0000040;fcc`@00000102;f_l40000000303^]m0000000
O:gb00<0O:gb00<0000009nWf`2OYm/00`2OYm/00`000000/:WB0;2YdP050;2YdP0300000033//X0
`k;:00@0`k;:00@000000<^a`@3;/L4000000P3Gb</01@000000h<S00>38`03Pb<00000001L0oooo
0P00000509NJe@8000000`3/]YP00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo
00100?ooo`030000003oool0oooo0100oooo00<000000:nfgP0000001P2m/ll00`000000bk700<^a
`005000000<0I]?f1000000407b]lP030000002OYm/0WjOK00<0WjOK00<000000;2YdP2`ZM800P2`
ZM82000000030;BVbP000000`k;:00<0`k;:00<000000<^a`@3;/L400P3;/L400`000000elS;0000
00020>38`0030000003oool0oooo01H0oooo2@0000030>bfV0030000003oool0oooo0080oooo00<0
00000?ooo`3oool02`3oool00440oooo00<000000?ooo`3oool0403oool00`000000_K??0;fcc`04
0;fcc`050000003;/L00bk700<^a`00000000P3C[k@;00000080O:gb00<0000009nWf`2OYm/00`2O
Ym/00`000000/:WB0;2YdP02000000<0]:K:00<000000<>bbP33//X00P33//X00`000000bk710<^a
`@030<^a`@050000003Pb<00h<S00>38`00000006@3oool00`000000T9;B092BdP04092BdP040000
003/]YP0k;JH0>bfV08000000`3oool00`000000oooo0?ooo`0;0?ooo`00@P3oool00`000000oooo
0?ooo`0@0?ooo`030000002m/ll0_K??0080_K??00<000000<^a`03;/L000P3;/L000`000000djnd
0=>_]0020=>_]0040000003J[Z/0fZj[00000080gZfT1`00000309nWf`@000001P2dY/X010000000
`k;:0<>bbP0000050<^a`@050000003A/;T000000>38`00000006P3oool2000000H0T9;B00<00000
0>bfV00000000P3oool010000000oooo0?ooo`00000=0?ooo`00@`3oool200000100oooo00D00000
0;fcc`2m/ll0_K??000000040<^a`0030000003C[k@0djnd0080djnd00@000000=Z^Z`3J[Z/00000
0P3N[J@010000000oooo0?ooo`00000304JAk`@000000P2IWmP00`000000]:K:0;BVbP050;BVbP03
00000033//X0000000D0bk7100H000000=6`^@3A/;T000000>38`000000K0?ooo`030000002@T]80
T9;B00@0T9;B00<000000>bfV00000000P3oool010000000oooo0?ooo`00000=0?ooo`00A@3oool0
0`000000oooo0?ooo`0>0?ooo`030000002m/ll0000000D0bk7000<000000=>_]03C[k@00P3C[k@0
10000000fZj[0=Z^Z`0000020=j]Y0050000003oool0oooo0?ooo`0000001016TNl00`000000VIoH
09VOf00209VOf0030000002dY/X0]:K:00D0]:K:00<000000<^a`@3;/L40103;/L401@000000dK2i
0=6`^@3A/;T0000001d0oooo00<00000092BdP2@T]80102@T]82000000<0oooo00<000000?ooo`00
00003@3oool004H0oooo00<000000?ooo`3oool03P3oool00`000000bk700<^a`0030<^a`0030000
003C[k@0djnd0080djnd00D000000=Z^Z`3J[Z/0fZj[000000020=j]Y0030000003oool0oooo0080
oooo00D0000004JAk`16TNl0AY7_0000000409VOf0030000002dY/X0]:K:00<0]:K:0P0000000`2h
Xl@000000<^a`@030<^a`@030000003A/;T0dK2i0080dK2i00<000000?ooo`3oool06`3oool00`00
0000T9;B092BdP04092BdP800000103oool00`000000oooo0000000<0?ooo`00A`3oool00`000000
oooo0?ooo`0>0?ooo`030000003;/L00bk700080bk7000<000000=>_]03C[k@00P3C[k@01@000000
fZj[0=Z^Z`3J[Z/000000080gZfT00<000000?ooo`3oool00`3oool200000080AY7_00<0000009VO
f02IWmP00P2IWmP01@000000]:K:0;BVbP2dY/X0000000<0^:?400D000000<^a`@3;/L40bk710000
00040=6`^@030000003oool0oooo01d0oooo10000003092BdP030000003oool0oooo00<0oooo0P00
000<0?ooo`00B03oool2000000l0oooo00@000000<^a`03;/L0000001@3C[k@010000000fZj[0=Z^
Z`0000030=j]Y0030000003oool0oooo00@0oooo1000000409VOf0040000002dY/X00000000000D0
^:?400<000000<^a`@0000001@3A/;T00`000000oooo0?ooo`0Q0?ooo`@000001@3oool2000000`0
oooo001:0?ooo`030000003oool0oooo00`0oooo00@000000<^a`03;/L000000103C[k@01@000000
fZj[0=Z^Z`3J[Z/000000080gZfT00<000000?ooo`3oool01P3oool00`00000005?=000000060000
00L0^:?400<000000<^a`@000000103A/;T00`000000oooo0?ooo`0[0?ooo`800000303oool004/0
oooo00<000000?ooo`3oool0303oool2000000D0djnd00D000000=Z^Z`3J[Z/0fZj[000000020=j]
Y0030000003oool0oooo00L0oooo00<00000001Cc@000000102BUm@00`000000^:?40;RSa0060;RS
a0030000003A/;T0dK2i00<0dK2i00<000000?ooo`3oool09`3oool4000000h0oooo001<0?ooo`03
0000003oool0oooo00`0oooo00<000000=>_]03C[k@00P3C[k@01@000000fZj[0=Z^Z`3J[Z/00000
00<0gZfT00<000000?ooo`3oool0203oool00`00000005?=0000000409:Ge0030000002hXl@0^:?4
00@0^:?40P0000040=6`^@030000003oool0oooo02@0oooo1000000B0?ooo`00C@3oool2000000`0
oooo00<000000=>_]03C[k@00P3C[k@01@000000fZj[0=Z^Z`3J[Z/0000000<0gZfT00<000000?oo
o`3oool02@3oool2000000@0TYOD00<000000;RSa02hXl@00`2hXl@010000000_:6m0;bQ_@000003
0=6`^@030000003oool0oooo0200oooo1000000F0?ooo`00C`3oool00`000000oooo0?ooo`0:0?oo
o`050000003C[k@0djnd0=>_]00000000`3J[Z/01@000000gZfT0=j]Y03N[J@0000000`0oooo0P00
000409:Ge0030000002hXl@0^:?4008000000`2lXKd010000000dK2i0=6`^@00000O0?ooo`@00000
6P3oool00500oooo00<000000?ooo`3oool02@3oool010000000djnd0=>_]00000040=Z^Z`040000
003N[J@0gZfT000000d0oooo0P00000409:Ge0030000002hXl@0000000H0_:6m00<000000=6`^@00
00006`3oool4000001h0oooo001A0?ooo`030000003oool0oooo00T0oooo00<000000=>_]0000000
0`3J[Z/01@000000gZfT0=j]Y03N[J@0000000h0oooo1`0000070;bQ_@800000603oool400000280
oooo001B0?ooo`8000002@3oool2000000@0fZj[00D000000=j]Y03N[J@0gZfT0000000?0?ooo`03
00000029S]40RHkA00<0RHkA00<000000;bQ_@2lXKd01@2lXKd00`000000oooo0?ooo`0B0?ooo`@0
00009P3oool005@0oooo00<000000?ooo`3oool01`3oool00`000000fZj[0=Z^Z`020=Z^Z`050000
003N[J@0gZfT0=j]Y00000003`3oool2000000@0RHkA00<000000;bQ_@2lXKd0102lXKd00`000000
oooo0?ooo`0?0?ooo`@00000:P3oool005D0oooo00<000000?ooo`3oool01P3oool01@000000fZj[
0=Z^Z`3J[Z/0000000<0gZfT00<000000?ooo`3oool03`3oool00`000000RHkA08V>d@0308V>d@03
0000002lXKd0_:6m0080_:6m00<000000?ooo`3oool0303oool4000002h0oooo001F0?ooo`030000
003oool0oooo00H0oooo00@000000=Z^Z`3J[Z/000000`3N[J@00`000000oooo0?ooo`0@0?ooo`03
00000029S]40RHkA0080RHkA00D000000;bQ_@2lXKd0_:6m0000000;0?ooo`@00000<P3oool005L0
oooo0P0000060?ooo`040000003J[Z/0fZj[000000<0gZfT00<000000?ooo`3oool0403oool00`00
0000RHkA08V>d@0308V>d@040000002lXKd0_:6m000000L0oooo1000000f0?ooo`00F@3oool00`00
0000oooo0?ooo`040?ooo`030000003J[Z/0000000<0gZfT00<000000?ooo`3oool04@3oool30000
0080RHkA00<000000;bQ_@000000103oool4000003X0oooo001J0?ooo`030000003oool0oooo00<0
oooo0P0000040=j]Y0030000003oool0oooo01@0oooo100000000`3oool0000000000002000003h0
oooo001K0?ooo`030000003oool0oooo00<0oooo00D000000=j]Y03N[J@0gZfT0000000H0?ooo`@0
0000@P3oool005`0oooo0P0000030?ooo`050000003N[J@0gZfT0=j]Y0000000503oool4000004H0
oooo001N0?ooo`050000003oool0oooo0?ooo`0000000P3N[J@00`000000oooo0?ooo`0>0?ooo`@0
0000BP3oool005l0oooo00@000000?ooo`3oool000000P3N[J@00`000000oooo0?ooo`0:0?ooo`@0
0000CP3oool00600oooo00H000000?ooo`3oool000000=j]Y00000080?ooo`@00000DP3oool00640
oooo100000050?ooo`@00000EP3oool006<0oooo0P0000000`3oool0000000000002000005X0oooo
001T0?ooo`800000GP3oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool0
0<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03oool00<@0oooo00340?ooo`00a03o
ool00<@0oooo00340?ooo`00a03oool00001\
\>"],
  ImageRangeCache->{{{0, 195.625}, {158.438, 0}} -> {-0.315887, -0.133522, \
0.00692044, 0.00692044}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[169]="]
}, Open  ]],

Cell["Example 3", "Subsubsection"],

Cell["Boundary value problem.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''\)[x] - y[x] \[Equal] \(-2\)*x, y[0] \[Equal] \(y'\)[0], 
        y[a] + \(y'\)[a] \[Equal] 0}\)], "Input",
  CellLabel->"In[170]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(-y[x]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], 
          "==", \(\(-2\)\ x\)}], ",", 
        RowBox[{\(y[0]\), "==", 
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}]}], ",", 
        RowBox[{
          RowBox[{\(y[a]\), "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]",
                MultilineFunction->None], "[", "a", "]"}]}], "==", "0"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[170]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, a}, 3]\)], "Input",
  CellLabel->"In[171]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(32\ a\^2\ \((2949120 + 983040\ a + 138240\ a\^2 + \
15040\ a\^3 + 2464\ a\^4 + 350\ a\^5 + 15\ a\^6)\)\)\/\(\((3072 + 1536\ a + \
320\ a\^2 + 32\ a\^3 + a\^4)\)\ \((61440 + 30720\ a + 6720\ a\^2 + 800\ a\^3 \
+ 50\ a\^4 + a\^5)\)\) + \(2\ a\^2\ \((47185920 + 15728640\ a + 1382400\ a\^2 \
- 124928\ a\^3 - 25984\ a\^4 + 128\ a\^5 + 82\ a\^6 + a\^7)\)\ x\)\/\(\((3072 \
+ 1536\ a + 320\ a\^2 + 32\ a\^3 + a\^4)\)\ \((61440 + 30720\ a + 6720\ a\^2 \
+ 800\ a\^3 + 50\ a\^4 + a\^5)\)\) + \(1536\ a\^2\ \((30720 + 15040\ a + 3040\
\ a\^2 + 290\ a\^3 + 9\ a\^4)\)\ x\^2\)\/\(\((3072 + 1536\ a + 320\ a\^2 + 32\
\ a\^3 + a\^4)\)\ \((61440 + 30720\ a + 6720\ a\^2 + 800\ a\^3 + 50\ a\^4 + a\
\^5)\)\) - \(10240\ \((2 + a)\)\ x\^3\)\/\(61440 + 30720\ a + 6720\ a\^2 + \
800\ a\^3 + 50\ a\^4 + a\^5\)}}\)], "Output",
  CellLabel->"Out[171]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[172]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(-\[ExponentialE]\^\(\(-a\) - x\)\)\ \((\(-\
\[ExponentialE]\^a\) + \[ExponentialE]\^\(2\ x\) + 
                a\ \[ExponentialE]\^\(2\ x\) - 
                2\ \[ExponentialE]\^\(a + x\)\ x)\)}}\)], "Output",
  CellLabel->"Out[172]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(a = 1\/9\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\))\) /. 
        a \[Rule] 1/9, {x, 0, 1/9}]\)], "Input",
  CellLabel->"In[173]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 8.57143 0.313618 5.16677e+007 [
[.19524 .30112 -12 -9 ]
[.19524 .30112 12 0 ]
[.36667 .30112 -12 -9 ]
[.36667 .30112 12 0 ]
[.5381 .30112 -12 -9 ]
[.5381 .30112 12 0 ]
[.70952 .30112 -12 -9 ]
[.70952 .30112 12 0 ]
[.88095 .30112 -9 -9 ]
[.88095 .30112 9 0 ]
[.01131 .00361 -39 -6.25 ]
[.01131 .00361 0 6.25 ]
[.01131 .10695 -39 -6.25 ]
[.01131 .10695 0 6.25 ]
[.01131 .21028 -39 -6.25 ]
[.01131 .21028 0 6.25 ]
[.01131 .41695 -33 -6.25 ]
[.01131 .41695 0 6.25 ]
[.01131 .52029 -33 -6.25 ]
[.01131 .52029 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19524 .31362 m
.19524 .31987 L
s
[(0.02)] .19524 .30112 0 1 Mshowa
.36667 .31362 m
.36667 .31987 L
s
[(0.04)] .36667 .30112 0 1 Mshowa
.5381 .31362 m
.5381 .31987 L
s
[(0.06)] .5381 .30112 0 1 Mshowa
.70952 .31362 m
.70952 .31987 L
s
[(0.08)] .70952 .30112 0 1 Mshowa
.88095 .31362 m
.88095 .31987 L
s
[(0.1)] .88095 .30112 0 1 Mshowa
.125 Mabswid
.06667 .31362 m
.06667 .31737 L
s
.10952 .31362 m
.10952 .31737 L
s
.15238 .31362 m
.15238 .31737 L
s
.2381 .31362 m
.2381 .31737 L
s
.28095 .31362 m
.28095 .31737 L
s
.32381 .31362 m
.32381 .31737 L
s
.40952 .31362 m
.40952 .31737 L
s
.45238 .31362 m
.45238 .31737 L
s
.49524 .31362 m
.49524 .31737 L
s
.58095 .31362 m
.58095 .31737 L
s
.62381 .31362 m
.62381 .31737 L
s
.66667 .31362 m
.66667 .31737 L
s
.75238 .31362 m
.75238 .31737 L
s
.79524 .31362 m
.79524 .31737 L
s
.8381 .31362 m
.8381 .31737 L
s
.92381 .31362 m
.92381 .31737 L
s
.96667 .31362 m
.96667 .31737 L
s
.25 Mabswid
0 .31362 m
1 .31362 L
s
.02381 .00361 m
.03006 .00361 L
s
gsave
.01131 .00361 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .10695 m
.03006 .10695 L
s
gsave
.01131 .10695 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .21028 m
.03006 .21028 L
s
gsave
.01131 .21028 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .41695 m
.03006 .41695 L
s
gsave
.01131 .41695 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.02381 .52029 m
.03006 .52029 L
s
gsave
.01131 .52029 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.125 Mabswid
.02381 .02945 m
.02756 .02945 L
s
.02381 .05528 m
.02756 .05528 L
s
.02381 .08111 m
.02756 .08111 L
s
.02381 .13278 m
.02756 .13278 L
s
.02381 .15862 m
.02756 .15862 L
s
.02381 .18445 m
.02756 .18445 L
s
.02381 .23612 m
.02756 .23612 L
s
.02381 .26195 m
.02756 .26195 L
s
.02381 .28778 m
.02756 .28778 L
s
.02381 .33945 m
.02756 .33945 L
s
.02381 .36529 m
.02756 .36529 L
s
.02381 .39112 m
.02756 .39112 L
s
.02381 .44279 m
.02756 .44279 L
s
.02381 .46862 m
.02756 .46862 L
s
.02381 .49446 m
.02756 .49446 L
s
.02381 .54612 m
.02756 .54612 L
s
.02381 .57196 m
.02756 .57196 L
s
.02381 .59779 m
.02756 .59779 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07162 m
.04262 .20174 L
.06244 .31401 L
.08255 .40379 L
.09409 .44514 L
.10458 .47676 L
.11396 .50045 L
.12415 .5215 L
.13491 .53877 L
.14017 .54543 L
.14509 .55066 L
.15002 .55496 L
.15453 .55809 L
.15954 .56069 L
.1623 .56174 L
.16368 .56217 L
.16493 .5625 L
.16614 .56277 L
.16745 .563 L
.16817 .56311 L
.16883 .56319 L
.17014 .5633 L
.17126 .56336 L
.17249 .56337 L
.17378 .56334 L
.17498 .56325 L
.17566 .56319 L
.1764 .5631 L
.17775 .56289 L
.18028 .56235 L
.18323 .56147 L
.18596 .56044 L
.19059 .55818 L
.19558 .55507 L
.20462 .54778 L
.21537 .5365 L
.22522 .5239 L
.26485 .45583 L
.30295 .37322 L
.34352 .27919 L
.38256 .19334 L
.40247 .15428 L
.42406 .1171 L
.4431 .08963 L
.45392 .0765 L
.46404 .06597 L
.47443 .057 L
.48392 .05049 L
.49406 .04536 L
.49965 .04335 L
Mistroke
.50239 .04259 L
.50496 .042 L
.50738 .04156 L
.50866 .04138 L
.51 .04122 L
.51114 .04111 L
.51238 .04102 L
.51352 .04096 L
.51457 .04093 L
.51521 .04092 L
.5159 .04092 L
.51716 .04095 L
.51838 .041 L
.51951 .04107 L
.52073 .04118 L
.52208 .04134 L
.5248 .04175 L
.52719 .04224 L
.52938 .04278 L
.5343 .04434 L
.53864 .04611 L
.5432 .04837 L
.55277 .05441 L
.56298 .06279 L
.58136 .08282 L
.60275 .11376 L
.62291 .14986 L
.66143 .23443 L
.7024 .33926 L
.74186 .44281 L
.7798 .5305 L
.79928 .56562 L
.81022 .58107 L
.81505 .58677 L
.82019 .59198 L
.82489 .59596 L
.83009 .5994 L
.83236 .60059 L
.83481 .60163 L
.83713 .6024 L
.83824 .60268 L
.83925 .6029 L
.84046 .6031 L
.84175 .60324 L
.84295 .60331 L
.84408 .60332 L
.84539 .60325 L
.84661 .60313 L
.84724 .60303 L
.84794 .60291 L
Mistroke
.84936 .60258 L
.85201 .60172 L
.85486 .60041 L
.85754 .59881 L
.86 .59702 L
.86477 .59265 L
.86986 .58662 L
.879 .57203 L
.88988 .54795 L
.89973 .51928 L
.91899 .44243 L
.92984 .38578 L
.93982 .32437 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[173]:=",
  ImageSize->{207.188, 128},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003?0000P2000`400?l00000o`00003oc`3oool0
0<l0oooo003?0?ooo`00c`3oool00<l0oooo003?0?ooo`00c`3oool00<l0oooo003?0?ooo`00c`3o
ool00<l0oooo003?0?ooo`001`3oool3000000<0oooo00H000000?ooo`3oool0oooo0000003oool5
00000080oooo0P00002c0?ooo`001`3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0;00oooo0007
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0/03oool000030?ooo`0000000000008000000P3o
ool3000000@0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02P3oool200000:@0oooo00080?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0:<0oooo00080?ooo`<000002@3oool2000000@0oooo
0P0000080?ooo`030<30`02`/;00/;2`0080oooo00<000000?ooo`3oool0WP3oool00`000000oooo
0?ooo`020?ooo`009P3oool0102`/;00oooo0?ooo`00002P0?ooo`030000003oool0oooo0080oooo
000N0?ooo`040>3Ph020P800P8200820P080oooo00<0X:2P0<30`01PH6000P3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo0080oooo000T0?ooo`03092@T03oool0X:2P0080oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`020?ooo`00903oool00`2PX:00/;2`0<30`002
0?ooo`030000003oool0oooo04l0oooo0P00001=0?ooo`030000003oool0oooo0080oooo000Y0?oo
o`030000003oool0oooo04`0oooo2@0000180?ooo`030000003oool0oooo00<0oooo000Y0?ooo`03
0000003oool0oooo04X0oooo0P0000080?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool00`3oool002T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`090?ooo`800000
AP3oool00`000000oooo0?ooo`030?ooo`00:@3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo00`0oooo0P0000140?ooo`030000003oool0oooo00<0oooo000Y0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00<0oooo000Y0?ooo`030000003oool0oooo04D0oooo0P00000B0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool00`3oool002T0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool00`3oool000T0oooo
0`0000000`3oool000000?ooo`020?ooo`030000003oool0000000@000000P3oool2000000d0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool00`3oool000X0oooo00L000000?ooo`3oool0oooo0000003oool0000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool0103oool000L0oooo1@0000030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000140?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`040?ooo`0000<0oooo00000000
00000P0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000004<0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00@0oooo00080?oo
o`030000003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000@P3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0103oool000T0oooo0P000009
0?ooo`800000103oool2000000d0oooo0P0000110?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`040?ooo`00903oool00`30`<00/;2`0;2`/0020?oo
o`800000@@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0103oool002H0oooo00<0/;2`0?ooo`3oool00P0000100?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`040?ooo`007P3oool0103Ph>00P820
0820P020P8020?ooo`030:2PX030`<00H61P0080oooo0P0000100?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`040?ooo`00903oool00`2@T900oooo
0:2PX0020?ooo`800000?`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0103oool002@0oooo00<0X:2P0;2`/030`<000P3oool00`000000oooo0000
000n0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`050?ooo`00:@3oool00`000000oooo0000000m0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`050?ooo`00:@3oool00`000000oooo0000000m0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`050?oo
o`00:@3oool00`000000oooo0000000l0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`050?ooo`00:@3oool00`000000oooo0000000l0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`050?ooo`00:@3o
ool00`000000oooo0000000k0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`050?ooo`00:@3oool00`000000oooo0000000j0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`050?ooo`00:@3oool01000
0000oooo0?ooo`00000i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`050?ooo`001`3oool400000080oooo00H000000?ooo`3oool0oooo0000003o
ool500000080oooo0P00000=0?ooo`040000003oool0oooo000003P0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00D0oooo00070?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000h0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`060?ooo`00203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo00@000000?ooo`3oool00000=`3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool01P3oool000030?ooo`00000000000080
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000000`3oool000000?ooo`0f0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`060?oo
o`001`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool010000000oooo0?oo
o`00000f0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`060?ooo`00203oool2000000X0oooo0P0000040?ooo`800000203oool00`30`<00/;2`0;2`
/0020?ooo`040000003oool0oooo000003H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00H0oooo000V0?ooo`040;2`/03oool0oooo000000<0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool01P3oool001h0oooo00@0h>3P0820P020P800P8200P3oool00`2PX:00`<30
061PH0020?ooo`050000003oool0oooo0?ooo`000000=03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool01P3oool002@0oooo00<0T92@0?ooo`2PX:00
0P3oool01@000000oooo0?ooo`3oool0000003@0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo00H0oooo000T0?ooo`030:2PX02`/;00`<300080oooo
00D000000?ooo`3oool0oooo0000000c0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`070?ooo`00:@3oool01@000000oooo0?ooo`3oool0000000h0
oooo0P0000040?ooo`800000103oool2000000<0oooo100000080?ooo`800000103oool3000000<0
oooo0P0000050?ooo`<000001`3oool2000000@0oooo0P0000040?ooo`8000000`3oool3000000T0
oooo0`0000030?ooo`800000103oool2000000@0oooo0P00000<0?ooo`800000103oool2000000<0
oooo1@0000020?ooo`030000003oool0oooo00L0oooo000Y0?ooo`050000003oool0oooo0?ooo`00
00003@3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0203oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo008000001`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0
oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool01`3oool01000
0000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`05000000H0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000L0oooo00<000000?ooo`3oool00P0000070?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01`3oool002T0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo0`0000080?ooo`03
0000003oool0oooo008000001`3oool010000000oooo0?ooo`0000030?ooo`8000002`3oool01000
0000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool0
02T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo
000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000070?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00
00030?ooo`030000003oool0oooo00L0oooo00H000000?ooo`3oool000000?ooo`0000060?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000002P3oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool002T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`8000002P3oool2000000@0oooo0P000009
0?ooo`800000103oool00`000000oooo0?ooo`030?ooo`8000001@3oool2000000P0oooo0P00000:
0?ooo`800000103oool3000000P0oooo0P0000020?ooo`030000003oool0oooo00D0oooo0P000004
0?ooo`800000303oool2000000X0oooo0P0000040?ooo`030000003oool0oooo00L0oooo000Y0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool01`3oool002T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`070?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00P0oooo000Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203o
ool002T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`080?ooo`009@3ooonZ0000
0000:@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool05`3oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool002T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00
:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000Y0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool02@3oool002T0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`090?ooo`00:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00T0oooo000Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool02@3oool002T0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`090?ooo`00:@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00T0oooo000Y0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool02P3oool002T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0:0?oo
o`00:@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00X0oooo000Y0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool02P3oool000L0oooo100000020?ooo`060000003o
ool0oooo0?ooo`000000oooo1@0000020?ooo`8000003@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00X0oooo00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00/0oooo00080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00/0oooo00090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000000T0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02`3oool000L0oooo
00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0;0?ooo`00203oool2000000X0oooo0P0000040?ooo`800000203oool00`30
`<00/;2`0;2`/0020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0303oool002H0
oooo00@0/;2`0?ooo`3oool000002P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0103Ph>00
P8200820P020P8020?ooo`030:2PX030`<00H61P0080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0<0?ooo`00903oool00`2@T900oooo0:2PX0020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0303oool002@0oooo00<0X:2P0;2`/030`<000P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00`0oooo000Y0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool03@3oool002T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0=
0?ooo`00:@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00d0oooo000Y0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool03@3oool002T0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0>0?ooo`00:@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00h0oooo000Y0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool03P3oool0
00T0oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0000000@000000P3oool20000
00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0>0?ooo`002P3oool01`000000
oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00l0oooo0007
0?ooo`D000000`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool03`3o
ool000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool03`3oool000P0oooo00<000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0
oooo0P00000?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00090?ooo`8000002@3oool2000000@0oooo
0P00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1K0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0403oool002@0oooo00<0
`<300;2`/02`/;000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0100oooo000V
0?ooo`040;2`/03oool0oooo00000140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool04@3oool001h0oooo00@0h>3P
0820P020P800P8200P3oool00`2PX:00`<30061PH0020?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool04@3oool002@0oooo00<0T92@0?ooo`2PX:000P3oool00`000000oooo0?ooo`0A
0?ooo`8000001`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<0X:2P0;2`/030`<000P3oool00`000000oooo0?ooo`0C0?oo
o`8000000`3oool2000006D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0B0?oo
o`00:@3oool00`000000oooo0?ooo`0D0?ooo`D00000I`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01<0oooo000Y0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0C0?ooo`00:@3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool04`3oool002T0oooo00<000000?ooo`3oool0PP3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo000Y0?ooo`030000003oool0oooo
0880oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`00:@3oool00`000000
oooo0?ooo`230?ooo`8000001P3oool00`000000oooo0?ooo`0E0?ooo`00:@3oool00`000000oooo
0?ooo`250?ooo`80000000@0oooo0000000000000000603oool002T0oooo00<000000?ooo`3oool0
Q`3oool2000001X0oooo000Y0?ooo`030000003oool0oooo0:<0oooo000Y0?ooo`030000003oool0
oooo0:<0oooo003?0?ooo`00c`3oool00<l0oooo003?0?ooo`00c`3oool00<l0oooo003?0?ooo`00
c`3oool00001\
\>"],
  ImageRangeCache->{{{0, 206.188}, {127, 0}} -> {-0.0283663, -7.67984*^-09, \
0.000689934, 1.14457*^-10}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[173]="]
}, Open  ]],

Cell["Example 4", "Subsubsection"],

Cell["Boundary value problem.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {\(y'''\)[x] + 3*a*x*\(y''\)[x] + 3*a^2*x^2*\(y'\)[x] + 
            a^3*x^3*y[x] == 0, 
        y[0] \[Equal] 0, \(y'\)[0] \[Equal] 0, \(y''\)[0] \[Equal] 
          a}\)], "Input",
  CellLabel->"In[174]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(a\^3\ x\^3\ y[x]\), "+", 
            RowBox[{"3", " ", \(a\^2\), " ", \(x\^2\), " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"3", " ", "a", " ", "x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
              SuperscriptBox["y", 
                TagBox[\((3)\),
                  Derivative],
                MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
        ",", \(y[0] == 0\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", "0"}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", "a"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[174]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[ivp, y[x], {x, \(-1\), 1}, 7]\)], "Input",
  CellLabel->"In[175]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \((960\ a\^4\ \((29491200 + 24772608\ a + 
                      6312960\ a\^2 + 760320\ a\^3 + 48960\ a\^4 + 
                      1680\ a\^5 + 25\ a\^6)\))\)/\((9740985827328000 + 
                  5218385264640000\ a + 1228494864384000\ a\^2 + 
                  166698418176000\ a\^3 + 14591773900800\ a\^4 + 
                  864351682560\ a\^5 + 29594419200\ a\^6 - 353894400\ a\^7 - 
                  102620160\ a\^8 - 4853760\ a\^9 - 84096\ a\^10 + 
                  5\ a\^12)\) - \((7680\ a\ \((\(-634178764800\) - 
                      339738624000\ a - 79980134400\ a\^2 - 
                      10734796800\ a\^3 - 862617600\ a\^4 - 39186432\ a\^5 - 
                      779520\ a\^6 + 10080\ a\^7 + 1200\ a\^8 + 
                      35\ a\^9)\)\ x\^2)\)/\((9740985827328000 + 
                  5218385264640000\ a + 1228494864384000\ a\^2 + 
                  166698418176000\ a\^3 + 14591773900800\ a\^4 + 
                  864351682560\ a\^5 + 29594419200\ a\^6 - 353894400\ a\^7 - 
                  102620160\ a\^8 - 4853760\ a\^9 - 84096\ a\^10 + 
                  5\ a\^12)\) + \((30720\ a\^2\ \((\(-39636172800\) - 
                      21233664000\ a - 4851302400\ a\^2 - 567705600\ a\^3 - 
                      33868800\ a\^4 - 913152\ a\^5 - 6720\ a\^6 + 
                      360\ a\^7 + 25\ a\^8)\)\ x\^4)\)/\((9740985827328000 + 
                  5218385264640000\ a + 1228494864384000\ a\^2 + 
                  166698418176000\ a\^3 + 14591773900800\ a\^4 + 
                  864351682560\ a\^5 + 29594419200\ a\^6 - 353894400\ a\^7 - 
                  102620160\ a\^8 - 4853760\ a\^9 - 84096\ a\^10 + 
                  5\ a\^12)\) - \((122880\ a\^3\ \((\(-990904320\) - 
                      471859200\ a - 82944000\ a\^2 - 6451200\ a\^3 - 
                      207360\ a\^4 - 2016\ a\^5 + 
                      5\ a\^7)\)\ x\^6)\)/\((9740985827328000 + 
                  5218385264640000\ a + 1228494864384000\ a\^2 + 
                  166698418176000\ a\^3 + 14591773900800\ a\^4 + 
                  864351682560\ a\^5 + 29594419200\ a\^6 - 353894400\ a\^7 - 
                  102620160\ a\^8 - 4853760\ a\^9 - 84096\ a\^10 + 
                  5\ a\^12)\)}}\)], "Output",
  CellLabel->"Out[175]="]
}, Open  ]],

Cell[TextData[{
  "Unfortunately ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " can not find exact solution of the IVP."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[176]:="],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{\(a\^3\ x\^3\ y[x]\), "+", 
                RowBox[{"3", " ", \(a\^2\), " ", \(x\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}]}], "+", 
                RowBox[{"3", " ", "a", " ", "x", " ", 
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}]}], "+", 
                RowBox[{
                  SuperscriptBox["y", 
                    TagBox[\((3)\),
                      Derivative],
                    MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
            ",", \(y[0] == 0\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], "==", "0"}], ",",
             
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], "==", "a"}]}], 
          "}"}], ",", \(y[x]\), ",", "x"}], "]"}]], "Output",
  CellLabel->"Out[176]="]
}, Open  ]],

Cell["Nevertheless the exact solution is as follows.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = {{y[x] \[Rule] 
            Exp[\(-1\)/2*a*x^2]*\((\(-1\)/3 + 1/6*Exp[Sqrt[3]*Sqrt[a]*x] + 
                  1/6*Exp[\(-Sqrt[3]\)*Sqrt[a]*x])\)}}\)], "Input",
  CellLabel->"In[177]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \[ExponentialE]\^\(-\(\(a\ x\^2\)\/2\)\)\ \((\(-\(1\/3\
\)\) + 1\/6\ \[ExponentialE]\^\(\(-\@3\)\ \@a\ x\) + 
                1\/6\ \[ExponentialE]\^\(\@3\ \@a\ x\))\)}}\)], "Output",
  CellLabel->"Out[177]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
              apr[\([1]\)])\))\), {x, \(-1\), 1}, {a, \(-1\), 1}]\)], "Input",\

  CellLabel->"In[178]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-7.378e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 12 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 24 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 18 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.01861 .29963 -39 -3.84928 ]
[.01861 .29963 0 8.65072 ]
[.00532 .38292 -6 -2.84214 ]
[.00532 .38292 0 6.15786 ]
[-0.00871 .4708 -33 -4.0515 ]
[-0.00871 .4708 0 8.4485 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-1)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-0.5)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(0.5)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03086 .29492 m
.03698 .29257 L
s
gsave
.01861 .29963 -39 -1.84928 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.01763 .37839 m
.02379 .37612 L
s
[(0)] .00532 .38292 1 -0.36841 Mshowa
.00367 .46645 m
.00986 .46427 L
s
gsave
-0.00871 .4708 -33 -2.0515 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.02827 .31126 m
.03194 .30986 L
s
.02565 .32778 m
.02933 .32639 L
s
.023 .34447 m
.02669 .34309 L
s
.02033 .36134 m
.02402 .35997 L
s
.0149 .39562 m
.0186 .39427 L
s
.01214 .41304 m
.01584 .4117 L
s
.00935 .43065 m
.01305 .42932 L
s
.00653 .44845 m
.01024 .44713 L
s
.03342 .27875 m
.03709 .27733 L
s
.03596 .26274 m
.03962 .26131 L
s
.00079 .48464 m
.00451 .48335 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.941 .603 .357 r
.38333 .57844 .40529 .59895 .43704 .79202 .41531 .73075 Metetra
.864 .662 .628 r
.41531 .73075 .43704 .79202 .47922 .5767 .45791 .55562 Metetra
.644 .143 0 r
.45791 .55562 .47922 .5767 .51696 .56535 .49549 .60075 Metetra
.854 .531 .44 r
.49549 .60075 .51696 .56535 .55716 .76944 .53522 .74934 Metetra
.791 .789 .851 r
.53522 .74934 .55716 .76944 .59847 .75862 .57664 .71766 Metetra
.902 .704 .625 r
.57664 .71766 .59847 .75862 .63336 .53033 .61473 .55533 Metetra
.678 .863 .467 r
.61473 .55533 .63336 .53033 .67327 .51832 .65377 .4957 Metetra
0 .201 .71 r
.65377 .4957 .67327 .51832 .71375 .50614 .69709 .53084 Metetra
.874 .511 .356 r
.69709 .53084 .71375 .50614 .77006 .7137 .74899 .67109 Metetra
.497 .545 .836 r
.74899 .67109 .77006 .7137 .81462 .70203 .79539 .68001 Metetra
.964 .76 .579 r
.79539 .68001 .81462 .70203 .83874 .46853 .82622 .503 Metetra
.82622 .503 .83874 .46853 .88163 .45563 .86428 .4313 Metetra
.855 .45 0 r
.86428 .4313 .88163 .45563 .9514 .65652 .92855 .58916 Metetra
.909 .682 .584 r
.92855 .58916 .9514 .65652 .96935 .42924 .95296 .40417 Metetra
.886 .53 .366 r
.35969 .58023 .38333 .57844 .41531 .73075 .39293 .68452 Metetra
.854 .678 .663 r
.39293 .68452 .41531 .73075 .45791 .55562 .43507 .57012 Metetra
.754 .332 .247 r
.43507 .57012 .45791 .55562 .49549 .60075 .47309 .61244 Metetra
.819 .417 .286 r
.47309 .61244 .49549 .60075 .53522 .74934 .51284 .6785 Metetra
.669 .554 .716 r
.51284 .6785 .53522 .74934 .57664 .71766 .55427 .65389 Metetra
.804 .637 .675 r
.55427 .65389 .57664 .71766 .61473 .55533 .59478 .56933 Metetra
.809 .978 .689 r
.59478 .56933 .61473 .55533 .65377 .4957 .63525 .51844 Metetra
.652 .211 .191 r
.63525 .51844 .65377 .4957 .69709 .53084 .6789 .54443 Metetra
.793 .353 .202 r
.6789 .54443 .69709 .53084 .74899 .67109 .72624 .60525 Metetra
.572 .512 .75 r
.72624 .60525 .74899 .67109 .79539 .68001 .77187 .60585 Metetra
.806 .629 .662 r
.77187 .60585 .79539 .68001 .82622 .503 .81059 .51299 Metetra
.897 .961 .631 r
.81059 .51299 .82622 .503 .86428 .4313 .85016 .44371 Metetra
.845 .404 .175 r
.85016 .44371 .86428 .4313 .92855 .58916 .90745 .53756 Metetra
.907 .707 .622 r
.90745 .53756 .92855 .58916 .95296 .40417 .93918 .40235 Metetra
.688 .317 .34 r
.33326 .61527 .35969 .58023 .39293 .68452 .36977 .64902 Metetra
.807 .696 .743 r
.36977 .64902 .39293 .68452 .43507 .57012 .41077 .59603 Metetra
.555 .12 .17 r
.41077 .59603 .43507 .57012 .47309 .61244 .45001 .60658 Metetra
.431 0 0 r
.45001 .60658 .47309 .61244 .51284 .6785 .49028 .62562 Metetra
.662 .59 .764 r
.49028 .62562 .51284 .6785 .55427 .65389 .53185 .60798 Metetra
.76 .657 .748 r
.53185 .60798 .55427 .65389 .59478 .56933 .57357 .56601 Metetra
.773 .963 .927 r
.57357 .56601 .59478 .56933 .63525 .51844 .61555 .53741 Metetra
.432 0 0 r
.61555 .53741 .63525 .51844 .6789 .54443 .65905 .54056 Metetra
.344 0 0 r
.65905 .54056 .6789 .54443 .72624 .60525 .70439 .55754 Metetra
.611 .589 .804 r
.70439 .55754 .72624 .60525 .77187 .60585 .7496 .55008 Metetra
.752 .635 .732 r
.7496 .55008 .77187 .60585 .81059 .51299 .79266 .50482 Metetra
.835 .949 .893 r
.79266 .50482 .81059 .51299 .85016 .44371 .83635 .46789 Metetra
.642 .18 .14 r
.83635 .46789 .85016 .44371 .90745 .53756 .88735 .49711 Metetra
.838 .724 .739 r
.88735 .49711 .90745 .53756 .93918 .40235 .92912 .43539 Metetra
.171 0 0 r
.30732 .6187 .33326 .61527 .36977 .64902 .34578 .62043 Metetra
.737 .719 .835 r
.34578 .62043 .36977 .64902 .41077 .59603 .3862 .59577 Metetra
.204 .73 .829 r
.3862 .59577 .41077 .59603 .45001 .60658 .42635 .59069 Metetra
.484 .759 .991 r
.42635 .59069 .45001 .60658 .49028 .62562 .46724 .5879 Metetra
.661 .651 .83 r
.46724 .5879 .49028 .62562 .53185 .60798 .50905 .57357 Metetra
.709 .689 .829 r
.50905 .57357 .53185 .60798 .57357 .56601 .55141 .55153 Metetra
.696 .85 .956 r
.55141 .55153 .57357 .56601 .61555 .53741 .59427 .53352 Metetra
.374 .825 .936 r
.59427 .53352 .61555 .53741 .65905 .54056 .63801 .52542 Metetra
.482 .776 .996 r
.63801 .52542 .65905 .54056 .70439 .55754 .68279 .52148 Metetra
.639 .662 .856 r
.68279 .52148 .70439 .55754 .7496 .55008 .72807 .50979 Metetra
.704 .671 .815 r
.72807 .50979 .7496 .55008 .79266 .50482 .77325 .48619 Metetra
.718 .836 .937 r
.77325 .48619 .79266 .50482 .83635 .46789 .81911 .46479 Metetra
.123 .668 .827 r
.81911 .46479 .83635 .46789 .88735 .49711 .86766 .46376 Metetra
.743 .733 .843 r
.86766 .46376 .88735 .49711 .92912 .43539 .91411 .43502 Metetra
.597 .822 .986 r
.28149 .60522 .30732 .6187 .34578 .62043 .32095 .59558 Metetra
.677 .736 .895 r
.32095 .59558 .34578 .62043 .3862 .59577 .36131 .58085 Metetra
.621 .818 .976 r
.36131 .58085 .3862 .59577 .42635 .59069 .40209 .56972 Metetra
.633 .764 .942 r
.40209 .56972 .42635 .59069 .46724 .5879 .44353 .55885 Metetra
.658 .708 .884 r
.44353 .55885 .46724 .5879 .50905 .57357 .48568 .54557 Metetra
.67 .722 .888 r
.48568 .54557 .50905 .57357 .55141 .55153 .52848 .53064 Metetra
.662 .783 .938 r
.52848 .53064 .55141 .55153 .59427 .53352 .57192 .51633 Metetra
.63 .814 .971 r
.57192 .51633 .59427 .53352 .63801 .52542 .61608 .50379 Metetra
.632 .774 .948 r
.61608 .50379 .63801 .52542 .68279 .52148 .66101 .49188 Metetra
.652 .716 .895 r
.66101 .49188 .68279 .52148 .72807 .50979 .70663 .4783 Metetra
.669 .712 .88 r
.70663 .4783 .72807 .50979 .77325 .48619 .75286 .46222 Metetra
.667 .775 .93 r
.75286 .46222 .77325 .48619 .81911 .46479 .79982 .44634 Metetra
.61 .812 .977 r
.79982 .44634 .81911 .46479 .86766 .46376 .84792 .43417 Metetra
.676 .739 .898 r
.84792 .43417 .86766 .46376 .91411 .43502 .89631 .41661 Metetra
.652 .768 .934 r
.25535 .58443 .28149 .60522 .32095 .59558 .29533 .57209 Metetra
.657 .748 .917 r
.29533 .57209 .32095 .59558 .36131 .58085 .33595 .55926 Metetra
.653 .767 .933 r
.33595 .55926 .36131 .58085 .40209 .56972 .37719 .54647 Metetra
.654 .755 .924 r
.37719 .54647 .40209 .56972 .44353 .55885 .41907 .5335 Metetra
.656 .741 .913 r
.41907 .5335 .44353 .55885 .48568 .54557 .46162 .52019 Metetra
.656 .744 .915 r
.46162 .52019 .48568 .54557 .52848 .53064 .50485 .50658 Metetra
.655 .758 .926 r
.50485 .50658 .52848 .53064 .57192 .51633 .54876 .49281 Metetra
.653 .766 .932 r
.54876 .49281 .57192 .51633 .61608 .50379 .59339 .47894 Metetra
.654 .758 .926 r
.59339 .47894 .61608 .50379 .66101 .49188 .63875 .46489 Metetra
.655 .744 .915 r
.63875 .46489 .66101 .49188 .70663 .4783 .68485 .45052 Metetra
.656 .742 .913 r
.68485 .45052 .70663 .4783 .75286 .46222 .7317 .43577 Metetra
.656 .756 .924 r
.7317 .43577 .75286 .46222 .79982 .44634 .77934 .4208 Metetra
.652 .766 .933 r
.77934 .4208 .79982 .44634 .84792 .43417 .8278 .40583 Metetra
.657 .748 .917 r
.8278 .40583 .84792 .43417 .89631 .41661 .87705 .39029 Metetra
.655 .753 .922 r
.22858 .56133 .25535 .58443 .29533 .57209 .26894 .54849 Metetra
.655 .752 .921 r
.26894 .54849 .29533 .57209 .33595 .55926 .30993 .53544 Metetra
.655 .753 .922 r
.30993 .53544 .33595 .55926 .37719 .54647 .35157 .52218 Metetra
.655 .753 .922 r
.35157 .52218 .37719 .54647 .41907 .5335 .39386 .50872 Metetra
.655 .752 .921 r
.39386 .50872 .41907 .5335 .46162 .52019 .43684 .49504 Metetra
.655 .752 .921 r
.43684 .49504 .46162 .52019 .50485 .50658 .48051 .48114 Metetra
.655 .753 .922 r
.48051 .48114 .50485 .50658 .54876 .49281 .52489 .46701 Metetra
.655 .753 .922 r
.52489 .46701 .54876 .49281 .59339 .47894 .56999 .45265 Metetra
.655 .753 .922 r
.56999 .45265 .59339 .47894 .63875 .46489 .61585 .43806 Metetra
.655 .752 .921 r
.61585 .43806 .63875 .46489 .68485 .45052 .66246 .42322 Metetra
.655 .752 .921 r
.66246 .42322 .68485 .45052 .7317 .43577 .70987 .40813 Metetra
.655 .753 .922 r
.70987 .40813 .7317 .43577 .77934 .4208 .75807 .39278 Metetra
.655 .753 .922 r
.75807 .39278 .77934 .4208 .8278 .40583 .8071 .37718 Metetra
.655 .752 .921 r
.8071 .37718 .8278 .40583 .87705 .39029 .85698 .3613 Metetra
.654 .751 .921 r
.20106 .53737 .22858 .56133 .26894 .54849 .24178 .52427 Metetra
.656 .753 .921 r
.24178 .52427 .26894 .54849 .30993 .53544 .28316 .51071 Metetra
.654 .751 .921 r
.28316 .51071 .30993 .53544 .35157 .52218 .32519 .49715 Metetra
.654 .752 .922 r
.32519 .49715 .35157 .52218 .39386 .50872 .3679 .48338 Metetra
.655 .753 .922 r
.3679 .48338 .39386 .50872 .43684 .49504 .41131 .46927 Metetra
.656 .753 .921 r
.41131 .46927 .43684 .49504 .48051 .48114 .45544 .45484 Metetra
.656 .752 .921 r
.45544 .45484 .48051 .48114 .52489 .46701 .50028 .44022 Metetra
.654 .751 .921 r
.50028 .44022 .52489 .46701 .56999 .45265 .54588 .42548 Metetra
.654 .752 .922 r
.54588 .42548 .56999 .45265 .61585 .43806 .59224 .41054 Metetra
.655 .753 .922 r
.59224 .41054 .61585 .43806 .66246 .42322 .63939 .39526 Metetra
.656 .753 .922 r
.63939 .39526 .66246 .42322 .70987 .40813 .68734 .37958 Metetra
.656 .753 .921 r
.68734 .37958 .70987 .40813 .75807 .39278 .73611 .36367 Metetra
.654 .751 .921 r
.73611 .36367 .75807 .39278 .8071 .37718 .78574 .34769 Metetra
.656 .753 .921 r
.78574 .34769 .8071 .37718 .85698 .3613 .83623 .33116 Metetra
.637 .738 .921 r
.17285 .51158 .20106 .53737 .24178 .52427 .21377 .49981 Metetra
.673 .761 .917 r
.21377 .49981 .24178 .52427 .28316 .51071 .2557 .48406 Metetra
.643 .739 .918 r
.2557 .48406 .28316 .51071 .32519 .49715 .29804 .47127 Metetra
.639 .747 .927 r
.29804 .47127 .32519 .49715 .3679 .48338 .34108 .45856 Metetra
.658 .765 .928 r
.34108 .45856 .3679 .48338 .41131 .46927 .38497 .44366 Metetra
.67 .765 .921 r
.38497 .44366 .41131 .46927 .45544 .45484 .42961 .42723 Metetra
.663 .751 .915 r
.42961 .42723 .45544 .45484 .50028 .44022 .47494 .41131 Metetra
.647 .739 .916 r
.47494 .41131 .50028 .44022 .54588 .42548 .52101 .39694 Metetra
.64 .743 .923 r
.52101 .39694 .54588 .42548 .59224 .41054 .5679 .38311 Metetra
.651 .759 .929 r
.5679 .38311 .59224 .41054 .63939 .39526 .61562 .36772 Metetra
.669 .769 .925 r
.61562 .36772 .63939 .39526 .68734 .37958 .66408 .35003 Metetra
.666 .756 .917 r
.66408 .35003 .68734 .37958 .73611 .36367 .71337 .33237 Metetra
.638 .735 .919 r
.71337 .33237 .73611 .36367 .78574 .34769 .76373 .31772 Metetra
.671 .763 .919 r
.76373 .31772 .78574 .34769 .83623 .33116 .81469 .29885 Metetra
.563 .687 .923 r
.14423 .48161 .17285 .51158 .21377 .49981 .18476 .47607 Metetra
.73 .782 .894 r
.18476 .47607 .21377 .49981 .2557 .48406 .22777 .45287 Metetra
.595 .694 .912 r
.22777 .45287 .2557 .48406 .29804 .47127 .27006 .44449 Metetra
.569 .723 .946 r
.27006 .44449 .29804 .47127 .34108 .45856 .31313 .43741 Metetra
.671 .805 .947 r
.31313 .43741 .34108 .45856 .38497 .44366 .35762 .42054 Metetra
.725 .804 .913 r
.35762 .42054 .38497 .44366 .42961 .42723 .40305 .39715 Metetra
.691 .747 .894 r
.40305 .39715 .42961 .42723 .47494 .41131 .44892 .37726 Metetra
.616 .696 .901 r
.44892 .37726 .47494 .41131 .52101 .39694 .49538 .3659 Metetra
.574 .704 .93 r
.49538 .3659 .52101 .39694 .5679 .38311 .54279 .35813 Metetra
.632 .78 .952 r
.54279 .35813 .5679 .38311 .61562 .36772 .59115 .34381 Metetra
.721 .821 .928 r
.59115 .34381 .61562 .36772 .66408 .35003 .64007 .3194 Metetra
.705 .769 .902 r
.64007 .3194 .66408 .35003 .71337 .33237 .68969 .29618 Metetra
.575 .678 .91 r
.68969 .29618 .71337 .33237 .76373 .31772 .74108 .28829 Metetra
.725 .794 .907 r
.74108 .28829 .76373 .31772 .81469 .29885 .79213 .26188 Metetra
.335 .533 .9 r
.11561 .44452 .14423 .48161 .18476 .47607 .15453 .45428 Metetra
.816 .801 .838 r
.15453 .45428 .18476 .47607 .22777 .45287 .19977 .41386 Metetra
.458 .586 .893 r
.19977 .41386 .22777 .45287 .27006 .44449 .24121 .41712 Metetra
.293 .596 .948 r
.24121 .41712 .27006 .44449 .31313 .43741 .2835 .42484 Metetra
.696 .89 .968 r
.2835 .42484 .31313 .43741 .35762 .42054 .32891 .40356 Metetra
.829 .861 .869 r
.32891 .40356 .35762 .42054 .40305 .39715 .37582 .36316 Metetra
.741 .741 .851 r
.37582 .36316 .40305 .39715 .44892 .37726 .42244 .33392 Metetra
.539 .609 .872 r
.42244 .33392 .44892 .37726 .49538 .3659 .46901 .33086 Metetra
.363 .576 .922 r
.46901 .33086 .49538 .3659 .54279 .35813 .51677 .33931 Metetra
.554 .813 .994 r
.51677 .33931 .54279 .35813 .59115 .34381 .56591 .32855 Metetra
.829 .912 .894 r
.56591 .32855 .59115 .34381 .64007 .3194 .61527 .28799 Metetra
.78 .791 .862 r
.61527 .28799 .64007 .3194 .68969 .29618 .66498 .25169 Metetra
.416 .547 .88 r
.66498 .25169 .68969 .29618 .74108 .28829 .71782 .26063 Metetra
.823 .839 .861 r
.71782 .26063 .74108 .28829 .79213 .26188 .76836 .21715 Metetra
0 .097 .653 r
.08755 .39758 .11561 .44452 .15453 .45428 .12283 .43542 Metetra
.886 .797 .756 r
.12283 .43542 .15453 .45428 .19977 .41386 .17221 .36406 Metetra
.126 .332 .798 r
.17221 .36406 .19977 .41386 .24121 .41712 .21136 .38977 Metetra
.488 0 0 r
.21136 .38977 .24121 .41712 .2835 .42484 .25136 .42697 Metetra
.701 .976 .914 r
.25136 .42697 .2835 .42484 .32891 .40356 .29827 .39737 Metetra
.93 .887 .768 r
.29827 .39737 .32891 .40356 .37582 .36316 .34805 .32388 Metetra
.798 .731 .789 r
.34805 .32388 .37582 .36316 .42244 .33392 .39587 .27705 Metetra
.39 .464 .817 r
.39587 .27705 .42244 .33392 .46901 .33086 .44199 .29046 Metetra
0 .186 .717 r
.44199 .29046 .46901 .33086 .51677 .33931 .48956 .33134 Metetra
.243 .736 .916 r
.48956 .33134 .51677 .33931 .56591 .32855 .53963 .3282 Metetra
.934 .96 .761 r
.53963 .3282 .56591 .32855 .61527 .28799 .58966 .25644 Metetra
.868 .808 .789 r
.58966 .25644 .61527 .28799 .66498 .25169 .63925 .19587 Metetra
.117 .303 .776 r
.63925 .19587 .66498 .25169 .71782 .26063 .69389 .23577 Metetra
.921 .859 .763 r
.69389 .23577 .71782 .26063 .76836 .21715 .74326 .16183 Metetra
.786 .413 0 r
.06056 .33894 .08755 .39758 .12283 .43542 .08943 .41978 Metetra
.922 .778 .684 r
.08943 .41978 .12283 .43542 .17221 .36406 .14557 .30194 Metetra
0 0 .467 r
.14557 .30194 .17221 .36406 .21136 .38977 .18037 .36321 Metetra
.878 .442 .084 r
.18037 .36321 .21136 .38977 .25136 .42697 .21554 .45029 Metetra
.616 .926 .682 r
.21554 .45029 .25136 .42697 .29827 .39737 .26486 .40708 Metetra
.979 .866 .655 r
.26486 .40708 .29827 .39737 .34805 .32388 .31989 .27854 Metetra
.847 .719 .723 r
.31989 .27854 .34805 .32388 .39587 .27705 .3697 .20366 Metetra
.145 .249 .714 r
.3697 .20366 .39587 .27705 .44199 .29046 .41442 .24392 Metetra
.724 .315 0 r
.41442 .24392 .44199 .29046 .48956 .33134 .46066 .33942 Metetra
.322 0 0 r
.46066 .33942 .48956 .33134 .53963 .3282 .51181 .34941 Metetra
.967 .918 .579 r
.51181 .34941 .53963 .3282 .58966 .25644 .56317 .2255 Metetra
.931 .804 .697 r
.56317 .2255 .58966 .25644 .63925 .19587 .61269 .12718 Metetra
0 0 .563 r
.61269 .12718 .63925 .19587 .69389 .23577 .66917 .21396 Metetra
.975 .839 .645 r
.66917 .21396 .69389 .23577 .74326 .16183 .7169 .09405 Metetra
.944 .61 .185 r
.03503 .26856 .06056 .33894 .08943 .41978 .05426 .4065 Metetra
.936 .757 .635 r
.05426 .4065 .08943 .41978 .14557 .30194 .1201 .22847 Metetra
.816 .485 0 r
.1201 .22847 .14557 .30194 .18037 .36321 .1481 .33759 Metetra
.881 .447 .102 r
.1481 .33759 .18037 .36321 .21554 .45029 .18244 .42626 Metetra
.641 .805 .962 r
.18244 .42626 .21554 .45029 .26486 .40708 .23016 .40968 Metetra
.974 .806 .612 r
.23016 .40968 .26486 .40708 .31989 .27854 .29143 .22743 Metetra
.86 .708 .692 r
.29143 .22743 .31989 .27854 .3697 .20366 .34306 .13535 Metetra
0 .074 .627 r
.34306 .13535 .3697 .20366 .41442 .24392 .38642 .19153 Metetra
.871 .49 .011 r
.38642 .19153 .41442 .24392 .46066 .33942 .43021 .34019 Metetra
.413 .863 .868 r
.43021 .34019 .46066 .33942 .51181 .34941 .48265 .32198 Metetra
.953 .803 .658 r
.48265 .32198 .51181 .34941 .56317 .2255 .53572 .19533 Metetra
.963 .786 .616 r
.53572 .19533 .56317 .2255 .61269 .12718 .5856 .04673 Metetra
0 0 .32 r
.5856 .04673 .61269 .12718 .66917 .21396 .64346 .1943 Metetra
.992 .804 .553 r
.64346 .1943 .66917 .21396 .7169 .09405 .68954 .01392 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[178]:=",
  ImageSize->{192.75, 156.313},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000300000W2000`400?l00000o`00003o`03oool0
0<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00`03o
ool00<00oooo00300?ooo`00`03oool008D0oooo1@00000f0?ooo`00Q`3oool00`000000oooo0?oo
o`0f0?ooo`00Q`3oool00`000000oooo0?ooo`0f0?ooo`00Q`3oool00`000000oooo0?ooo`0f0?oo
o`00Q`3oool00`000000oooo0?ooo`0f0?ooo`00QP3oool2000000/0oooo1@00000X0?ooo`00U@3o
ool00`000000oooo0?ooo`0X0?ooo`00U@3oool00`000000oooo0?ooo`0X0?ooo`00S@3oool40000
00@0oooo00<000000?ooo`3oool0:03oool009D0oooo00<000000?ooo`3oool0:03oool008T0oooo
0P0000090?ooo`800000:P3oool00640oooo0P0000040?ooo`800000103oool2000001P0oooo0P00
00000`3oool000000000000d0?ooo`00H03oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000001@0oooo0`0000030?ooo`800000=03oool00600oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`0@0?ooo`8000001P3oool3000003<0oooo001P0?ooo`040000003o
ool0oooo000000T0oooo0P00000@0?ooo`<00000203oool010000000oLf=00000000000b0?ooo`00
H03oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00`0oooo0`00000;0?ooo`04
0000003mcHd0000000000380oooo001Q0?ooo`8000002P3oool3000000X0oooo0P00000>0?ooo`05
0000003mcHd000000?ooo`000000<@3oool007L0oooo0`0000000`3oool000000?ooo`0=0?ooo`80
000000@0oLf=0000003oool00000<03oool007D0oooo0P0000040?ooo`030000003oool0oooo00/0
oooo00L000000?g=S@000000oLf=0000003oool000000300oooo001b0?ooo`@00000103oool00`00
0000m/VM0000000<0?ooo`050000003mcHd000000?g=S@0000000P3oool00`000000oooo0?ooo`0]
0?ooo`00DP3oool2000001`0oooo0P0000080?ooo`030000003fbId0000000`0oooo00<000000?g=
S@0000000P3mcHd010000000oooo0?ooo`00000^0?ooo`00D@3oool010000000oooo0?ooo`00000H
0?ooo`@000002@3oool010000000m/VM00000000000;0?ooo`030000003mcHd000000080oLf=00<0
00000?ooo`3oool00P00000]0?ooo`00D@3oool010000000oooo0?ooo`00000F0?ooo`800000303o
ool01@000000m/VM0?K9W@3fbId0000000X0oooo00@000000?g=S@3mcHd000000P3mcHd01@000000
oooo0?ooo`3oool0000002d0oooo001A0?ooo`040000003oool0oooo000001<0oooo1000000=0?oo
o`050000003fbId0m/VM0?K9W@0000002P3oool010000000oLf=0?g=S@0000030?g=S@050000003o
ool0oooo0?ooo`000000;03oool00540oooo00@000000?ooo`3oool00000403oool300000140oooo
00@000000?K9W@3fbId0m/VM0P0000090?ooo`040000003mcHd0oLf=000000<0oLf=00D000000?oo
o`3oool0oooo0000000<0?ooo`800000103oool2000000@0oooo0P00000B0?ooo`00DP3oool20000
00l0oooo0P0000000`3oool000000?ooo`0@0?ooo`030000003fbId0m/VM00<0m/VM00<000000?oo
o`3oool01`3oool010000000oLf=0?g=S@0000030?g=S@030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000140oooo
001P0?ooo`<000005@3oool00`000000m/VM0?K9W@030?K9W@8000001`3oool01@000000oLf=0?g=
S@3mcHd000000080oLf=00<000000?WFY@0000000`3oool00`000000oooo0?ooo`080?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool03`3oool005h0oooo0P00000H0?ooo`030000
003fbId0m/VM00<0m/VM0P0000070?ooo`050000003mcHd0oLf=0?g=S@0000000P3mcHd00`000000
nMJU000000040?ooo`040000003oool0oooo0?ooo`@000000P3oool010000000oooo0?ooo`000009
0?ooo`8000004P3oool005/0oooo0`00000I0?ooo`030000003fbId0m/VM00D0m/VM00<000000?oo
o`3oool01@3oool01`000000oLf=0?g=S@3mcHd000000?g=S@0000000`3ieZD00`000000oooo0?oo
o`020?ooo`8000001`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0140oooo
001I0?ooo`800000703oool00`000000m/VM0?K9W@050?K9W@8000001P3oool00`000000oLf=0?g=
S@020?g=S@8000000`3ieZD00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo0P00
000:0?ooo`<000004@3oool002h0oooo0P0000040?ooo`800000103oool2000001X0oooo0`00000N
0?ooo`030000003fbId0m/VM00@0m/VM0`0000050?ooo`030000003mcHd0oLf=00<0oLf=00<00000
0?WFY@3ieZD00P3ieZD00`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo000]0?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000005`3oool5000001h0oooo00<0
00000?K9W@3fbId0103fbId010000000k/fb0000000000040?ooo`030000003mcHd0oLf=00<0oLf=
00<000000?WFY@3ieZD00`3ieZD00`000000oooo0?ooo`030?ooo`030000003oool0oooo02D0oooo
000]0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool04P3oool300000080oooo
00<000000=be/@0000007@3oool00`000000m/VM0?K9W@040?K9W@030000003^cK80k/fb00800000
103oool00`000000oLf=0?g=S@020?g=S@8000001@3ieZD00`000000oooo0?ooo`030?ooo`800000
9P3oool002L0oooo100000020?ooo`040000003oool0oooo000000T0oooo0P00000C0?ooo`800000
103oool00`000000g;Fa0=be/@02000001`0oooo00<000000?K9W@3fbId0103fbId010000000k/fb
0>k=/P3^cK82000000<0oooo00<000000?g=S@3mcHd00P3mcHd2000000H0nMJU00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0T0?ooo`00;@3oool010000000oooo0?ooo`0000090?ooo`03
0000003oool0oooo00l0oooo0`0000060?ooo`040000003L]K40g;Fa0=be/@8000006`3oool00`00
0000m/VM0?K9W@030?K9W@030000003^cK80k/fb0080k/fb0P0000020?ooo`030000003mcHd0oLf=
00<0oLf=0P0000060?WFY@030000003oool0oooo00@0oooo00<000000?ooo`3oool08`3oool002h0
oooo0P00000:0?ooo`<00000303oool3000000P0oooo00<000000=be/@3L]K400P3L]K400`000000
01:P0000000I0?ooo`030000003fbId0m/VM00@0m/VM00<000000>k=/P3^cK800P3^cK8300000003
0?ooo`000000oLf=00<0oLf=00<000000?WFY@0000001@3ieZD2000000H0oooo0P00000T0?ooo`00
A`3oool3000000X0oooo00<000000=be/@3L]K400P3L]K400`00000001:P0000000I0?ooo`030000
003fbId0m/VM00<0m/VM00<000000>k=/P3^cK80103^cK82000000030?ooo`000000oLf=00<0oLf=
00<000000?WFY@0000001@3ieZD00`000000jm_3000000060?ooo`030000003oool0oooo0280oooo
00140?ooo`<00000303oool00`000000g;Fa0=be/@040=be/@03000000004Z00000001P0oooo00<0
00000?K9W@3fbId00`3fbId00`000000k/fb0>k=/P040>k=/P@000000`3mcHd010000000nMJU0?WF
Y@0000040?WFY@040000003[fl<0jm_3000000L0oooo00<000000?ooo`3oool08@3oool00480oooo
0`00000=0?ooo`030000003L]K40g;Fa00D0g;Fa00@00000000BX0004Z0000005P3oool00`000000
m/VM0?K9W@030?K9W@030000003^cK80k/fb00H0k/fb0P0000040?g=S@040000003ieZD0nMJU0000
00<0nMJU00D000000>_K``3[fl<0jm_3000000070?ooo`030000003oool0oooo0240oooo000S0?oo
o`D000005`3oool300000100oooo00<000000=be/@3L]K401P3L]K401000000001:P00000000000E
0?ooo`030000003fbId0m/VM00<0m/VM00<000000>k=/P3^cK801P3^cK82000000<0oLf=00D00000
0?WFY@3ieZD0nMJU000000020?WFY@030000003[fl<0jm_300<0jm_300<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0P0?ooo`009@3oool00`000000oooo0?ooo`0E0?ooo`80000000<0oooo
0000003oool03`3oool00`000000g;Fa0=be/@070=be/@04000000004Z0001:P000001D0oooo0P00
00030?K9W@030000003^cK80k/fb00H0k/fb100000020?g=S@050000003ieZD0nMJU0?WFY@000000
0P3ieZD00`000000jm_30>_K``030>_K``030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool2000001T0oooo000U0?ooo`030000003oool0oooo0180oooo0`00000D0?ooo`030000003L
]K40g;Fa00H0g;Fa0`0000000`004Z0000000000000C0?ooo`040000003ccJP0llfX00000080m/VM
00<000000>k=/P3^cK801@3^cK800`000000g/k90=k>b@04000000D0nMJU0P0000070>_K``030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000H0?ooo`00
7@3oool4000000@0oooo00<000000?ooo`3oool0403oool2000001H0oooo00<000000=be/@3L]K40
1`3L]K400`000000f;Ri00000003000001<0oooo00@000000??=Z03ccJP0llfX0P0000080>k=/P04
0000003Nc/T0g/k9000000807Dg600<000000?WFY@3ieZD00`3ieZD00`000000jm_30>_K``060>_K
``030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000H
0?ooo`009@3oool00`000000oooo0?ooo`0=0?ooo`<00000603oool00`000000g;Fa0=be/@060=be
/@050000003H^;T0f;Ri0000000U?kH00`00000A0?ooo`030000003ccJP0llfX00<0llfX00<00000
0>k=/P3^cK801@3^cK800`000000g/k90=k>b@020=k>b@040000000MCLH07Dg6000000<0nMJU0P00
00070>_K``030000003Be]`0000000P0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01H0oooo000T0?ooo`800000303oool3000000030?ooo`000000oooo01L0oooo00<0
00000=be/@3L]K401P3L]K401@000000f;Ri0=Rh^@3H^;T0000000809Cnf00<000000=im0P000000
403oool00`000000llfX0??=Z0030??=Z08000001@3^cK800`000000g/k90=k>b@030=k>b@040000
000MCLH07Dg601e=aP80000000<0nMJU0000000000001P3[fl<010000000d]KL0=;Fg00000080?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0F0?ooo`00<03oool30000
00<0oooo00<000000?ooo`3oool05P3oool2000000H0g;Fa00<000000=Rh^@3H^;T00`3H^;T01@00
00009Cnf0000003NO@80000000l0oooo00<000000??=Z03ccJP00`3ccJP010000000mn^D0?O[U000
00030>k=/P030000003Nc/T0g/k900D0g/k900<0000001e=aP0MCLH00P0MCLH00`000000jm_30000
00050>_K``030000003Be]`0d]KL0080d]KL00<000000?ooo`3oool01P3oool200000080oooo0P00
000I0?ooo`00;@3oool3000000D0oooo0`00000F0?ooo`030000003icY`0000000H0g;Fa00<00000
0=Rh^@3H^;T00`3H^;T01P0000009Cnf02Do]P000000gWd2000000h0oooo00<000000??=Z03ccJP0
0`3ccJP010000000mn^D0?O[U00000030>k=/P030000003Nc/T0g/k900D0g/k900<0000001e=aP0M
CLH00`0MCLH2000000@0jm_300<000000=;Fg03Be]`00`3Be]`00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01/0oooo000[0?ooo`800000203oool00`000000kl6R0000000F0?ooo`040000
003icY`0nLjL000000@0g;Fa00<000000=Rh^@3H^;T01@3H^;T0100000009Cnf0000003NO@820000
00d0oooo00<000000??=Z03ccJP00P3ccJP00`000000mn^D0?O[U0020?O[U0030000003^cK800000
00T0g/k91@0000000`0MCLH00000000000020>_K``030000003Be]`0d]KL00D0d]KL00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0K0?ooo`00:@3oool2000000T0oooo00@000000>o1XP3_
`J8000005P3oool010000000nLjL0?W>W00000030=be/@030000003H^;T0f;Ri00H0f;Ri00<00000
02Do]P0000000P3NO@800`000000oooo0?ooo`0:0?ooo`030000003ccJP0llfX00<0llfX00<00000
0?O[U03gji@00`3gji@00`000000g/k90=k>b@070=k>b@L0000000@07Dg60000003[fl<00000203B
e]`00`000000oooo0?ooo`070?ooo`8000006`3oool002T0oooo0P0000090?ooo`040000003_`J80
kl6R000001D0oooo00<000000?W>W03icY`00P3icY`00`000000g;Fa000000090=Rh^@030000000U
?kH000000080gWd20P00000;0?ooo`030000003ccJP0llfX0080llfX00<000000?O[U03gji@00`3g
ji@00`000000koG2000000060=k>b@8000000P37b]`00`000000JXcQ06Z<h@0206Z<h@<000002P3B
e]`00`000000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo000Y0?ooo`030000003oool0
000000P0oooo00<000000>o1XP3_`J800P00000D0?ooo`030000003icY`0nLjL0080nLjL00<00000
0=be/@0000002P3H^;T00`0000009Cnf000000020=im0P030000003oool0oooo00P0oooo00<00000
0??=Z03ccJP00`3ccJP00`000000mn^D0?O[U0030?O[U0030000003_mL80000000<0g/k90`000005
0<O:g0030000001ZS>40JXcQ00@0JXcQ00<000000=;Fg03Be]`01@3Be]`2000000030;W;j0000000
oooo00L0oooo00<000000?ooo`3oool06@3oool002T0oooo00@000000?ooo`3oool000001P3oool0
0`000000kl6R0>o1XP020>o1XP030000003oool0oooo0180oooo00<000000?W>W03icY`00`3icY`0
0`000000f;Ri0=Rh^@090=Rh^@<000000P3NO@82000000T0oooo00<000000??=Z03ccJP00`3ccJP0
0`000000mn^D0?O[U0020?O[U0040000003_mL80koG20>oe`P<0000000<0g/k900000037b]`01@37
b]`00`000000JXcQ06Z<h@0406Z<h@800000103Be]`2000000<0^L_X00<000000?ooo`3oool01`3o
ool2000001T0oooo000X0?ooo`<000000P3oool00`000000oooo0?ooo`030?ooo`030000003_`J80
kl6R0080kl6R00<000000?ooo`3oool04@3oool00`000000nLjL0?W>W0040?W>W08000002@3H^;T2
0000000306=fd@000000gWd20080gWd200<000000?ooo`3oool01`3oool00`000000llfX0??=Z002
0??=Z0030000003gji@0mn^D0080mn^D00<000000>oe`P0000000`0000000`3Nc/T0000000000008
0<O:g0030000001ZS>40JXcQ00@0JXcQ00<000000=;Fg03Be]`00P0000060;W;j0030000003oool0
oooo00L0oooo00<000000?ooo`3oool05`3oool002P0oooo0`0000030?ooo`030000003oool0oooo
0080oooo00<000000>o1XP3_`J800P3_`J800`000000oooo0?ooo`0A0?ooo`030000003icY`0nLjL
00<0nLjL00<000000?[MY`000000203H^;T01P000000c;_90<bkb@000000HgKA00000080gWd20P00
00070?ooo`030000003ccJP0llfX00<0llfX00@000000?O[U03gji@0mn^D0`0000040>oe`P030000
0037b]`0al[L00P0al[L00<0000006Z<h@1ZS>400P1ZS>45000000P0^L_X00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0G0?ooo`001`3oool5000000030?ooo`000000oooo0080oooo00<0
00000?ooo`000000100000020?ooo`800000303oool010000000oooo0000000000030?ooo`800000
00<0oooo0000003_`J80103_`J8200000180oooo00<000000?W>W03icY`00`3icY`010000000n]fW
0?[MY`0000060=Rh^@070000003<^lT0c;_90<bkb@000000HgKA000000020=im0P030000002iD000
000000H0oooo00<000000??=Z03ccJP00P3ccJP00`000000mn^D00000003000000D0koG200<00000
0=CYi00000002@37b]`5000000@0TjgX00<000000;W;j02ibnP01P2ibnP2000000T0oooo0P00000G
0?ooo`002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`00000000001@3o
ool2000000H0kl6R00<000000?ooo`3oool03`3oool00`000000nLjL0?W>W0030?W>W0030000003j
gJL0n]fW0080n]fW00<000000=Rh^@3H^;T00P3H^;T00`000000c;_90<bkb@030<bkb@8000000`3N
O@800`000000^E00000000040?ooo`030000003ccJP0llfX00<0llfX0P0000020?O[U0030000003_
mL80koG200<0koG200D000000=CYi03DjN@0e>WT000000060<O:g08000000P2da>H00`000000TjgX
09>]j00409>]j08000001@2ibnP200000080Zl?[00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0E0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00@000000?ooo`000000
00001@3oool00`000000kl6R0>o1XP050>o1XP800000403oool00`000000nLjL0?W>W0030?W>W003
0000003jgJL0n]fW00<0n]fW00@000000=Rh^@3H^;T000001P3<^lT00`000000HgKA000000020=im
0P030000002iD000^E00008000000P3oool00`000000llfX0??=Z00400000080mn^D00<000000>oe
`P3_mL800P3_mL82000000D0e>WT00<000000<O:g037b]`00`0000040;C4iP030000002C[NP0TjgX
00D0TjgX0P0000020;W;j0800000102[`n/00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo0P0000040?ooo`800000103oool2000000<0oooo00000`3oool0000000000002000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`050000003oool000000?6L;`000000103oool0
0`000000kl6R0>o1XP040>o1XP<00000403oool00`000000nLjL0?W>W0020?W>W0030000003jgJL0
n]fW00@0n]fW00<000000=Rh^@000000203<^lT2000000<0gWd200@000000;U@002iD000^E001@00
00020??=Z0040000003gji@0mn^D000000@0koG200<000000=CYi03DjN@01P3DjN@2000000P0]<CV
00<0000009>]j02C[NP01@2C[NP3000000L0Zl?[00<000000?ooo`3oool01`3oool2000000<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`002@3oool01@000000
oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0
oooo000000/0oooo00D000000?ooo`000000lI`_000000040?ooo`030000003_`J80kl6R00@0kl6R
0P0000000`3@O00000000?ooo`0=0?ooo`030000003icY`0nLjL00<0nLjL00<000000?[MY`3jgJL0
1@3jgJL00`000000c;_90<bkb@070<bkb@8000000`3NO@800`000000^E000;U@0003000000D0llfX
00@000000?O[U03gji@000000`3_mL800`000000e>WT0=CYi0050=CYi080000000<0^=;]0000002d
a>H01`2da>H010000000TjgX09>]j02C[NP4000000030:>lj`000000000000L0Zl?[00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000/0oooo0@000001
0?ooo`40oooo00080?ooo`8000002P3oool2000000@0oooo0P0000080?ooo`030<30`02`/;00T92@
0080000000D0oooo0000003aW2l0lI`_000000020?ooo`030000003_`J80kl6R00@0kl6R00H00000
0>c7[`3/ajl000000=1l0000000=0?ooo`030000003icY`0nLjL00<0nLjL00<000000?[MY`3jgJL0
103jgJL00`000000k^?4000000090<bkb@8000000P3NO@8400000080JMcN00D000000??=Z03ccJP0
llfX000000020?O[U0D000001P3DjN@2000000@0^=;]00<000000;C4iP2da>H01@2da>H4000000D0
Xkc[0P0000070:_3j`8000002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01`3oool2000000<0oooo000T0?ooo`040:2PX03oool0`<3000000080oooo00@000000?6L
;`3aW2l000000P3oool00`000000kl6R0>o1XP040>o1XP060000003/ajl0k<N_0000003@O0000000
3@3oool00`000000nLjL0?W>W0020?W>W0030000003jgJL0n]fW00D0n]fW00<000000>kSa0000000
1`3<^lT2000000030;fmf@000000000000@00000101Yg=h01@000000llfX0??=Z0000000mn^D0080
0000102=d?h200000080e>WT0P0000060;SBk@030000002da>H0]<CV00<0]<CV0P0000020:[1jP03
0000002S_>/0Xkc[00D0Xkc[0P0000040:_3j`8000000P2W`>/00`000000oooo0?ooo`060?ooo`80
00000P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0080oooo000N0?ooo`04
0>3Ph020P800P8200820P080oooo00<0H61P092@T02PX:000P0000020?ooo`050000003aW2l00000
0?ooo`0000001P3_`J8010000000k<N_0>c7[`3/ajl2000000030=1l00000000oooo00X0oooo00<0
00000?W>W03icY`00`3icY`00`000000n]fW0?[MY`040?[MY`050000003^hl@0k^?40>kSa0000000
1@3<^lT00`000000_KgI00000002000000D0RI_O100000000`1Yg=h0000000000002000000P0SM3n
0P0000090;SBk@030000002da>H0]<CV00800000102Z`NX00`000000Xkc[0:>lj`060:>lj`030000
002[`n/0Zl?[00800000102W`>/00`000000oooo0?ooo`070?ooo`040000003oool0oooo0?ooo`80
00002P3oool300000080oooo000T0?ooo`040:2PX03oool0oooo000000<0oooo00<000000?6L;`3a
W2l00P0000060>o1XP030000003/ajl0k<N_0080k<N_1000000:0?ooo`030000003icY`0nLjL0080
nLjL00<000000?[MY`3jgJL0103jgJL00`000000k^?40>kSa0030>kSa0040000003<^lT0c;_90<bk
b@<000000`2m_MT00`000000RI_O08VKg`0408VKg`030000001LTn`00000008000000P1LTn`20000
0080SM3n100000020:77l`030000002hd^d0^=;]00H0^=;]0`0000070:[1jP030000002S_>/0Xkc[
00D0Xkc[0`0000070:O0j`030000003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool002D0
oooo00<0X:2P0;2`/00000000`3oool00`000000lI`_0?6L;`02000000D0kl6R00<000000>c7[`3/
ajl00`3/ajl010000000hG8J0>5b6P00000:0?ooo`030000003icY`0nLjL0080nLjL00<000000?[M
Y`3jgJL00`3jgJL00`000000k^?40>kSa0040>kSa0@000001P2m_MT00`000000RI_O08VKg`0508VK
g`030000001LTn`0G9?/0080G9?/1@0000070:77l`030000002hd^d0^=;]00<0^=;]0P0000020:_4
k0030000002Z`NX0Z/7Z00D0Z/7Z00@000000:>lj`2S_>/0Xkc[100000000`2W`>/0000000000007
0:O0j`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool002L0oooo00D000000?oo
o`3oool0oooo000000020?6L;`030000003_`J80kl6R00@0kl6R00<000000>c7[`3/ajl0103/ajl0
10000000hG8J0>5b6P0000080?ooo`030000003icY`0nLjL00<0nLjL00<000000?[MY`3jgJL00`3j
gJL00`000000k^?40>kSa0020>kSa0@000002@2m_MT00`000000RI_O08VKg`0408VKg`D00000102B
]>h00`000000XLOc0:77l`060:77l`030000002hd^d0^=;]00800000102[a>`00`000000Z/7Z0:[1
jP050:[1jP@000001P2W`>/00`000000Yl3[0:O0j`050:O0j`8000002@3oool00`000000oooo0?oo
o`0@0?ooo`009`3oool01@000000oooo0?ooo`3oool000000080lI`_00<000000>o1XP3_`J800`3_
`J800`000000k<N_0>c7[`050>c7[`030000003QLQX0hG8J008000001`3oool00`000000nLjL0?W>
W0020?W>W0030000003jgJL0n]fW00<0n]fW00<000000>kSa03^hl@00`0000020>kSa0030000003D
g=h0000000P0_KgI00<0000008VKg`29Vml01000000209fbiP030000002B]>h0T[C^00@0T[C^00<0
00000:77l`2Qao<01P2Qao<3000000L0ZlC/00<000000:[1jP2Z`NX0100000020:O0j`030000002W
`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/0100000020:O0j`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool03`3oool002H0oooo0P0000030?ooo`040000003aW2l0lI`_000000D0kl6R00<0
00000>c7[`3/ajl01@3/ajl010000000hG8J0>5b6P3QLQX2000000H0oooo00<000000?W>W03icY`0
0P3icY`00`000000n]fW0?[MY`020?[MY`@00000103^hl@01@000000e=cN0=CLgP3Dg=h0000000L0
_KgI0`00000609fbiP030000002B]>h0T[C^00D0T[C^00@000000:77l`2Qao<0XLOc100000020:K2
k@030000002[a>`0ZlC/00D0ZlC/0`0000070:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000060:O0
j`030000003oool0oooo00L0oooo0P00000@0?ooo`008@3oool2000000<0oooo00<000000?ooo`3o
ool00`3oool2000000D0kl6R00<000000>c7[`3/ajl01@3/ajl00`000000h/c1000000020>5b6P03
0000003PLAD0000000@0oooo00<000000?W>W03icY`00P3icY`010000000n]fW0?[MY`3jgJL30000
00D0k^?40P0000040=CLgP030000002m_MT0_KgI00<0_KgI0P0000020;2oi0030000002M/^H0WK;V
00D0WK;V00<0000009:dkP2B]>h0102B]>h4000000H0Y/;]00<000000:_4k02[a>`00`2[a>`20000
0080Yl3/00<000000:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`04000000030:O0k00000000000
00L0Yl3[00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0>0?ooo`00803oool010000000
oooo0?ooo`0000020?ooo`800000103oool2000000D0kl6R00<000000>c7[`3/ajl0103/ajl01000
0000h/c10>;<`@0000030>5b6P030000003PLAD0000000<0oooo00<000000?W>W03icY`00P3icY`0
1P000000n]fW000000000000n]fW000000D0k^?400<000000=CLgP3Dg=h01@3Dg=h00`000000_KgI
0;fmf@02000000D0/;oT00<0000009fbiP2M/^H0102M/^H00`000000T[C^09:dkP0400000080Xkk/
00<000000:K2k@2V`^d01P2V`^d00`000000ZlC/0:_4k002000000D0Yl3/00<000000:O0j`2W`>/0
1@2W`>/3000000H0Yl3/00<000000:O0j`2W`>/01@2W`>/2000000T0oooo0P00000>0?ooo`00803o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo00<000000>o1XP3_`J80
0`3_`J800`000000k<N_0>c7[`050>c7[`040000003Rc<40h/c1000000<0hG8J00@000000>1a5@3P
LAD000000P3oool010000000nLjL0?W>W03icY`8000000<0k^?400<000000=CLgP3Dg=h01P3Dg=h3
000000L0/;oT00<0000009fbiP2M/^H0102M/^H3000000L0Xkk/00<000000:K2k@2V`^d01@2V`^d3
000000L0Yl3/00<000000:O0j`2W`>/00`2W`>/200000080Yl3/00<000000:O0k02W`>`01@2W`>`0
0`000000Yl3[0:O0j`0400000080Z;oZ00<000000?ooo`3oool01P3oool2000000D0oooo1@000004
0?ooo`00803oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<0oooo0P000004
0>o1XP030000003/ajl0k<N_00@0k<N_00<000000>;<`@3Rc<400P3Rc<4010000000hG8J0>5b6P00
00030>1a5@80000000<0nLjL0000000000001P0000030;?ij@<000001`3Dg=h200000080^LgY00<0
00000;2oi02`_n@01P2`_n@00`000000WK;V09fbiP0300000080YKgZ00<000000:>nk02S_^`01P2S
_^`00`000000Y/;]0:K2k@0400000080Yl3/00<000000:O0k02W`>`01P2W`>`00`000000Yl3[0:O0
j`02000000@0Yl3/00<000000:O0k02W`>`01@2W`>`3000000H0Z;oZ00<000000?ooo`3oool01P3o
ool3000000H0oooo00<000000?ooo`3oool0103oool00200oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`050?ooo`80000000<0kl6R0000003/ajl01P3/ajl00`000000h/c10>;<
`@020>;<`@050000003QLQX0hG8J0>5b6P0000000P3PLAD4000000030:C>mP000000WNf^00800000
102cnNT200000080/^?g0P0000030=CLgP8000001@2icNT00`000000/;oT0;2oi0050;2oi0<00000
1P2U_NX00`000000Xkk/0:>nk0050:>nk0<000001P2W`>`00`000000Yl3/0:O0k0060:O0k0<00000
1`2W`>`00`000000Yl3/0:O0k004000000030:K4kP000000000000L0Z;oZ00<000000?ooo`3oool0
1@3oool010000000j;BO0000000000050?ooo`030000003oool0oooo00@0oooo000Q0?ooo`800000
0`3oool00`000000oooo0?ooo`070?ooo`8000001P3/ajl00`000000h/c10>;<`@040>;<`@030000
003QLQX0000000<00000102Tc_H3000000@0/oWY0P0000060;;Sm`<00000202icNT00`000000/;oT
0;2oi00400000080ZL3Z00<000000:FmjP2U_NX01@2U_NX00`000000Xkk/0:>nk00400000080Yl3/
00<000000:O0k02W`>`01@2W`>`010000000Yl3/0:O0k02W`>`400000080Yl3[00<000000:O0k02W
`>`01@2W`>`3000000H0Y/C^00<000000:RojP2X_nX01@2X_nX2000000D0oooo00<000000>RdW`3X
]9l00P0000050?ooo`030000003oool0oooo00@0oooo000U0?ooo`030000003oool0oooo00X0oooo
0P0000030>c7[`030000003Rc<40h/c100D0h/c10`0000060:C>mPP000001P2bhoL200000080Zlkb
00<000000;W=j@2icNT01P2icNT3000000H0ZL3Z00<000000:FmjP2U_NX01@2U_NX3000000L0Yl3/
00<000000:O0k02W`>`0102W`>`4000000H0Yl3[00<000000:O0k02W`>`00`2W`>`200000080Yl7/
00<000000:K4kP2Va>h0102Va>h200000080Z;oZ100000020:fmi@030000003oool0oooo0080oooo
00<000000>RdW`3X]9l00P0000050?ooo`030000003oool0oooo00@0oooo000U0?ooo`8000003@3o
ool2000000030>c7[`000000h/c100@0h/c1100000060:C>mP80000000<0MIKT0000001;V?800`1;
V?82000000<0/^?g0P0000050:_>lP030000002icNT0^LgY00<0^LgY0P0000020:_3j`030000002Y
`>X0ZL3Z00D0ZL3Z00<000000:FmjP2U_NX0100000020:O0j`030000002W`>`0Yl3/00H0Yl3/00<0
00000:O0k02W`>`00`0000020:O0j`030000002W`>/0Yl3[00H0Yl3[00<000000:O0k02W`>`00P00
00040:O1k0030000002Va>h0Y/C^00D0Y/C^0`0000070:fmi@030000003oool0oooo0080000000D0
j;BO0000003X[YD0j:jE000000030?ooo`8000001P3oool002D0oooo00<000000?ooo`3oool0303o
ool01000000001RW0000000000020>;<`@@000000`3@cMH2000000<0Y<kf0P00000307FFi0030000
001;V?80BiSb0080BiSb100000080:_>lP030000002icNT0^LgY008000001@2[`n/00`000000ZL3Z
0:W0jP050:W0jP8000001`2W`>/00`000000Yl3/0:O0k0050:O0k0<000001P2W`>/00`000000Yl3[
0:O0j`050:O0j`<000001`2W`N`00`000000Y/C^0:K4kP040000000309c?nP000000000000P0[KgU
100000001@3X]9l000000>R^U@3X[YD0000000/0oooo000U0?ooo`030000003oool0oooo00d0oooo
1@0000020>;<`@030000003@cMH0d<gF00@0d<gF00<000000:C>mP000000101eU^@6000000<0TKWb
0P0000070:_>lP<000001`2[`n/00`000000ZL3Z0:W0jP030:W0jP80000000<0Yl3[0000002W`>/0
1`2W`>/00`000000Yl3/0:O0k00400000080Yl3/00<000000:O0j`2W`>/01@2W`>/00`000000Yl3[
0:O0j`0400000080YkgY00<000000:O1k02W`N`01@2W`N`3000000H0W<oj00<000000:fmi@2]_ND0
102]_ND2000000030;jke`00000000000080j;BO00@000000>R^U@3X[YD000002`3oool002D0oooo
00<000000?ooo`3oool0303oool30000000305F8iP000000000000800000203@cMH00`000000d<gF
00000003000000<0V;7Y00<00000096ilP2A^O801@2A^O8200000080Zlkb0`0000020:S3k@030000
002[`n/0Zl?[00H0Zl?[00<000000:W0jP2Y`>X00P0000040:O0j`030000002W`>/0Yl3[00D0Yl3[
0`0000060:O0k0030000002W`>/0Yl3[00D0Yl3[0`0000060:Nmj@030000002W`N`0Yl7/00<0Yl7/
0P0000020:[6kP030000002LcoX0W<oj00@0W<oj0P0000030:fmi@8000000`2n^mL200000080j;BO
00@000000>R^U@3X[YD000002`3oool002D0oooo00<000000?ooo`3oool02@3oool3000000<0oooo
00<0000005F8iP1ER>H00P1ER>H00`000000d<gF0=3=eP050=3=eP80000000<0^/ST0000002H/NT0
1@2H/NT00`000000TKWb096ilP05096ilP<000001P2X`nd00`000000Zl?[0:_3j`050:_3j`<00000
1`2W`>/00`000000Yl3[0:O0j`0400000080Yl3/00<000000:O0k02W`>`01@2W`>`00`000000Yl3[
0:O0j`0400000080YkkZ00<000000:Nmj@2W_NT01@2W_NT00`000000Yl7/0:O1k002000000D0Z/K^
00<0000009c?nP2LcoX0102LcoX010000000[KgU0000000000040;jke`030000003F^Kd000000080
j;BO00<000000>R^U@3X[YD00P00000:0?ooo`000P3oool5000000030?ooo`000000oooo0080oooo
00<000000?ooo`000000100000020?ooo`8000003@3oool2000000P0oooo0`0000060?ooo`030000
001ER>H0EHSV00<0EHSV00<000000=3=eP3@cMH00P3@cMH2000000@0^/ST00<0000009Raj@2H/NT0
102H/NT00`000000TKWb096ilP0400000080Xko]00<000000:S3k@2X`nd01@2X`nd00`000000Zl?[
0:_3j`0400000080Yl3[00<000000:O0j`2W`>/01@2W`>/3000000H0Yl3/00<000000:O0k02W`>`0
1@2W`>`3000000H0YkkZ00<000000:Nmj@2W_NT01@2W_NT3000000L0Z/K^2@0000050;jke`040000
003F^Kd0e[Vm00000080j;BO00<000000>R^U@3X[YD00P00000:0?ooo`00103oool00`000000oooo
0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01@3oool2000000X0oooo00<0000005F8iP1E
R>H00`1ER>H010000000d<gF0000000000060;[8i0030000002H/NT0V;7Y00@0V;7Y0`0000070:>o
k@030000002X`nd0Z<?]00@0Z<?]0`0000070:O0j`030000002W`>/0Yl3[00@000000P2W`>`00`00
0000Yl3/0:O0k0050:O0k0030000002W`>`0Yl3/00@000000P2W`^d00`000000YkkZ0:NnjP050:Nn
jP030000002W_NT0YkgY00@000000P2[]^400`000000Z/K^0:[6kP030:[6kP8000000P2ge^l40000
00<07j_C00<000000;jke`2n^mL00P2n^mL00`000000e[Vm000000030>RdW`030000003X[YD0j:jE
008000002P3oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo0`00000=0?ooo`L000002@2jb>@00`000000V;7Y09Raj@0300000080Y;g[00<000000:>o
k@2S_nd01P2S_nd00`000000Z<?]0:S3k@0300000080Yl3/00<000000:O0j`2W`>/01@2W`>/30000
00L0Yl3/00<000000:O0k02W`>`0102W`>`3000000H0Yl;]00<000000:NnjP2W_^X01@2W_^X30000
00L0ZkKQ00<000000:[6kP2Za^h00P0000030;OFk`80000000@0iOJQ0000003oool000000P0OZm<0
1@000000_[_G0;jke`2n^mL000000080e[Vm00@000000>RdW`3X]9l000000`3X[YD2000000X0oooo
00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0000000200000140oooo
00<00000092_k02@[n`00`2@[n`2000000L0^/ST0`0000060:Bmj`030000002S_nd0Xko]00D0Xko]
0`0000060:O0k08000000P2W`>/300000080Yl3[00<000000:O0k02W`>`01P2W`>`00`000000Yl3/
0:O0k00300000080YlC^00<000000:O2k@2W`^d01@2W`^d00`000000YkkZ0:NnjP0400000080Y[OU
00<000000:^fh@2[]^401P2[]^42000000@0]mK_00D000000=Gbi0000000iOJQ000000020?ooo`80
000000@07j_C0000002n^mL000000`3F^Kd010000000j;BO0>RdW`0000030>R^U@8000002P3oool0
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`00000<0?ooo`8000005@3oool00`000000T:o/092_k004092_k0800000
0P2jb>@300000080[<;Z00<000000:Bmj`2T_N/01@2T_N/00`000000Xko]0:>ok@0400000080Yl3/
00<000000:O0k02W`>`01@2W`>`3000000H0Yl3[00<000000:O0k02W`>`01@2W`>`3000000H0YlC^
00<000000:O2k@2W`^d0102W`^d3000000H0Y[OU00<000000:^fh@2[]^40102[]^42000000030;B[
d0000000]mK_0080]mK_00@000000=Gbi0000000iOJQ0P0000040?ooo`@000000`3F^Kd010000000
j;BO0>RdW`0000020>R^U@030000003oool0000000X0oooo00030?ooo`8000002P3oool2000000@0
oooo0P0000080?ooo`030<30`02`/;00T92@00<0oooo00<000000?ooo`3oool04`3oool00`000000
T:o/092_k005092_k0<000001P2/`^X00`000000Y;g[0:Bmj`040:Bmj`<000001P2W`>`00`000000
Yl3/0:O0k0030:O0k08000000P2W`>/00`000000Yl3[0:O0j`050:O0j`030000002W`>`0Yl3/00@0
00000P2W`^d00`000000YlC^0:O4kP050:O4kP030000002W`^d0Yl;]00<000000P2Qa_800`000000
Y[OU0:Jgi@050:Jgi@040000002[]^40ZkKQ0:^fh@800000102dZm000`000000]mK_000000020=Gb
i0040000003UmZ400000000000D0oooo0P0000030=Ji_@050000003X]9l0j;BO0>RdW`0000000P3X
[YD010000000oooo0?ooo`0000090?ooo`007`3oool00`2PX:00oooo0<30`0040?ooo`800000503o
ool00`000000T:o/092_k00400000080Xkc[00<000000:c2jP2/`^X01@2/`^X00`000000Y;g[0:Bm
j`0300000080Yl3[00<000000:O0k02W`>`01@2W`>`00`000000Yl3/0:O0k002000000D0Yl3[00<0
00000:O0j`2W`>/0102W`>/3000000H0Yl;]00<000000:O4kP2Wa>h01@2Wa>h3000000H0XLKb00<0
00000:Jgi@2V]nD0102V]nD010000000ZkKQ0000000000070;B[d080000000<0eO;T0000003UmZ40
0P0000070?ooo`8000000P3F^Kd01@000000j;BO0>RdW`3X]9l000000080j:jE00@000000?ooo`3o
ool000002@3oool001T0oooo00@0h>3P0820P020P800P8200P3oool00`1PH600T92@0:2PX0060?oo
o`030000003oool0oooo0180oooo0P0000070:>lj`030000002/`^X0[<;Z00@0[<;Z0`0000060:O0
j`030000002W`>`0Yl3/00@0Yl3/0`0000080:O0j`030000002W`>/0Yl3[00<000000P2W_^X00`00
0000Yl;]0:O2k@050:O2k@030000002Wa>h0YlC^00@000000P2Qd?P00`000000XLKb0:76lP050:76
lP030000002V]nD0Y[OU0080Y[OU0`0000080;B[d00300000030X[/0`::k00D000001`3oool30000
00030=Ji_@000000j;BO0080j;BO00@000000>R^U@3X[YD000000P3oool00`000000oooo0?ooo`07
0?ooo`007`3oool00`2PX:00oooo0?ooo`070?ooo`030000003oool0oooo0180oooo00<000000:>l
j`2S_>/01P2S_>/00`000000[<;Z0:c2jP0300000080Yl3[00<000000:O0j`2W`>/01@2W`>/00`00
0000Yl3/0:O0k00300000080Yl3/00<000000:O0j`2W`>/01P2W`>/3000000H0YkkZ00<000000:O2
k@2W`^d0102W`^d3000000L0XM3h00<000000:76lP2Qa_800P2Qa_8700000080XjWK00<000000;B[
d02dZm001@2dZm000`000000`::k0<2R^`020<2R^`040000003>XJT00000000000P0oooo00@00000
0=Ji_@00000000000`3X]9l010000000j:jE0>R^U@0000020?ooo`030000003oool0oooo00L0oooo
000P0?ooo`030:2PX02`/;00oooo00L0oooo00<000000?ooo`3oool04P3oool2000000H0Xkc[0`00
00060:O0j`030000002W`>/0Yl3[00@0Yl3[0`0000060:O0k08000000P2W`>/400000080YkgY00<0
00000:NnjP2W_^X01@2W_^X00`000000Yl;]0:O2k@0300000080ZLS`0P0000040:7@n0L000000`1k
a_h00`000000XjWK0:>Yf`040:>Yf`030000002dZm00]:_@00<0]:_@00<000000<2R^`30X[/00P30
X[/01@000000cZ6Y0000003f`Y@0000000T0oooo0P0000030>RdW`050000003X[YD0j:jE0>R^U@00
00000P3oool00`000000oooo0?ooo`070?ooo`00:`3oool00`000000oooo0?ooo`0C0?ooo`030000
002S_>/0Xkc[00<000000P2W`>/00`000000Yl3[0:O0j`050:O0j`030000002W`>/0Yl3[00<00000
0P2W`>`00`000000Yl3/0:O0k0050:O0k0<000001P2W_NT00`000000YkkZ0:NnjP050:NnjP<00000
1`2Yb?04000000@0Gm?_0P00000507_6oP030000002SZM/0XjWK00<0XjWK00<000000;B[d02dZm00
0P2dZm000`000000`::k0<2R^`030<2R^`050000003>XJT000000?K2U00000002@3oool300000080
j;BO00D000000>R^U@3X[YD0j:jE000000020?ooo`030000003oool0oooo00L0oooo000/0?ooo`80
0000503oool2000000H0Yl3[0P0000040:O0j`@000001P2W`>`200000080Yl3/0`0000020:O1k003
0000002W_NT0YkgY00D0YkgY00<000000:NnjP2W_^X0100000020:^hh`030000002Yb?00ZLS`00<0
ZLS`0P0000020;;Im0X000000`1ka_h00`000000XjWK0:>Yf`040:>Yf`040000002dZm00]:_@0000
00D0`::k00H000000<jQZ@3>XJT000000?K2U000000:0?ooo`050000003X]9l000000>RdW`000000
0`3X[YD010000000oooo0?ooo`0000090?ooo`00;P3oool00`000000oooo0?ooo`0B0?ooo`030000
002W`>/0Yl3[00D0Yl3[1@0000030:O0j`030000002W`>`0Yl3/00D0Yl3/0`0000060:O1k0030000
002W_NT0YkgY00@0YkgY0`0000070:^hh`030000002Yb?00ZLS`00800000102bfO@3000000030>Jd
W`000000oooo00@0oooo0P00000207_6oP030000002SZM/0XjWK00<0XjWK00<000000;B[d0000000
1P30X[/01P000000cZ6Y0<jQZ@000000m/:D000000X0oooo00D000000>RdW`000000j;BO00000003
0>R^U@050000003oool0oooo0?ooo`000000203oool002l0oooo00<000000?ooo`3oool04P3oool2
00000080Yl3[0`0000020:O0k0030000002W`>/0Yl3[00@0Yl3[0P0000020:O0k0<000000P2Wa>h0
0`000000Yl7/0:O1k0050:O1k0030000002W_NT0YkgY00<000000P2X]N800`000000ZkSS0:^hh`06
0:^hh`800000102bfO@400000080i[BO00<000000?ooo`3oool01@3oool3000000@0XjWK0`000006
0<2R^`070000003>XJT0cZ6Y0<jQZ@000000m/:D0000000;0?ooo`040000003X]9l00000000000<0
j:jE00D000000?ooo`3oool0oooo000000080?ooo`00<03oool00`000000oooo0?ooo`0C0?ooo`80
00001P2W`>`00`000000Yl3[0:O0j`040:O0j`<000001P2Wa>h00`000000Yl7/0:O1k0040:O1k0<0
00001P2X]N800`000000ZkSS0:^hh`030:^hh`80000000@0]K3D000000000000/]Wd0P0000001P35
m^d00000000000000000i[BO000000T0oooo1P00000209bFc@0300000030X[/0`::k00@0`::k00H0
00000<jQZ@3>XJT000000?K2U000000<0?ooo`040000003X]9l0j;BO000000<0j:jE00D000000?oo
o`3oool0oooo000000080?ooo`00<@3oool2000001@0oooo00<000000:O0k02W`>`01@2W`>`00`00
0000Yl3[0:O0j`0300000080Z;oZ00<000000:O4kP2Wa>h01@2Wa>h00`000000Yl7/0:O1k0030000
0080X/?a00<000000:RehP2X]N801@2X]N800`000000ZkSS0:^hh`02000000D0]K3D0P0000020<Gf
k@050000003=Xj`000000>JdW`0000002@3oool00`000000F0000000000609bFc@0300000030X[/0
`::k00<0`::k00H000000<jQZ@3>XJT000000?K2U000000<0?ooo`030000003X]9l0j;BO00800000
0P3X[YD01@000000oooo0?ooo`3oool0000000P0oooo000c0?ooo`030000003oool0oooo0180oooo
00<000000:O0k02W`>`0102W`>`3000000H0Z;oZ0P0000040:O4kP@000001@2R`o400`000000Z;GR
0:RehP050:RehP<000001P2e/=@00`000000`ZRo0<:X_`02000000050<fS[0000000i[BO0>JdW`00
00002P3oool00`000000F0000000000509bFc@0300000030X[/0`::k0080`::k00L000000<jQZ@3>
XJT0cZ6Y0000003f`Y@0000000d0oooo0P0000001@3X[YD000000>R^U@3X[YD0000000<0oooo00<0
00000?ooo`3oool01P3oool003@0oooo00<000000?ooo`3oool04P3oool00`000000Yl3/0:O0k003
00000080Y/C_00<000000:RojP2X_nX01@2X_nX5000000<0W]7i00<000000:;3l@2R`o40102R`o40
0`000000Z;GR0:RehP0400000080ZJKD00<000000;F`e02e/=@00`2e/=@01@000000`ZRo0<:X_`32
Z;l000000080cJ>/00@000000>JdW`3V]9l000002`3oool2000000H0W9K=00D000000<2R^`30X[/0
`::k000000030<jQZ@030000003f`Y@0000000d0oooo0P0000020>R^U@030000003X[YD0000000<0
oooo00<000000?ooo`3oool01P3oool003D0oooo00<000000?ooo`3oool04P3oool2000000H0Y/C_
0P0000020:RojP<000000P2]_>D00`000000W]7i09kAn@0409kAn@030000002R`o40X/?a0080X/?a
100000060:VVe0030000002e/=@0]K3D0080]K3D00<000000<:X_`32Z;l00P32Z;l010000000cJ>/
0<fS[00000020>JdW`030000003oool0oooo00X0oooo0P00000509bFc@0400000030X[/0`::k0000
00@0cZ6Y00<000000?K2U00000003P3oool010000000j:jE0>R^U@3X[YD2000000<0oooo00<00000
0?ooo`3oool01P3oool003H0oooo0P00000C0?ooo`030000002Va>l0Y/C_00D0Y/C_0`0000060:fl
i@030000002NdOT0W]7i0080W]7i1P00000307_2o@030000002YY]@0ZJKD00D0ZJKD00@000000;F`
e02e/=@000001032Z;l01@000000cJ>/0<fS[03=Xj`000000080i[BO00<000000?ooo`3oool02P3o
ool2000000H0W9K=00<000000<2R^`0000000`3>XJT010000000m/:D0?K2U000000>0?ooo`030000
003X[YD0j:jE0080j:jE00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`00>03o
ool00`000000oooo0?ooo`0A0?ooo`8000000P2Va>l300000080V=;l00<000000:fli@2]_>D01@2]
_>D9000000@0Nl;m00<000000:VVe02YY]@01@2YY]@00`000000]K3D000000050<:X_`050000003=
Xj`0cJ>/0<fS[00000000P3V]9l00`000000oooo0?ooo`0;0?ooo`8000001@2LU/d2000000@0cZ6Y
00@000000?K2U03f`Y@000003P3oool00`000000j:jE0>R^U@020>R^U@030000003oool0oooo0080
oooo00<000000?ooo`3oool01@3oool003T0oooo00<000000?ooo`3oool04P3oool2000000D0V=;l
00<000000:fli@2]_>D00`2]_>D2000000<0_;SE00<000000<jb_P3>/[h01@00000307_2o@030000
002YY]@0ZJKD00D0ZJKD00<000000<:X_`32Z;l00`32Z;l01@000000cJ>/0<fS[03=Xj`000000080
i[BO00<000000?ooo`3oool03@3oool8000000@0cZ6Y00@000000?K2U03f`Y@000003`3oool01P00
0000j:jE0>R^U@000000oooo000000<0oooo00<000000?ooo`3oool01@3oool003X0oooo00<00000
0?ooo`3oool04P3oool2000000D0V=;l00<000000:fli@2]_>D00P0000040;bhe@050000003>/[h0
c[:n0<jb_P0000000P3J[JT010000000gJVP00000000000207_2o@030000002YY]@0ZJKD0080ZJKD
0`0000050<:X_`050000003=Xj`0cJ>/0<fS[00000000P3V]9l00`000000oooo0?ooo`0=0?ooo`03
0000002BPkl0TX>o00@0TX>o00<000000<jQZ@3>XJT00P3>XJT010000000m/:D0?K2U000000?0?oo
o`040000003X[YD0j:jE00000080oooo00@000000?ooo`3oool000001`3oool003/0oooo00<00000
0?ooo`3oool04`3oool8000000D0_;SE00D000000<jb_P3>/[h0c[:n000000030=Z]Z@040000003M
ZJ00gJVP0=fYX0<000000P2YY]@2000000<0ZIO300D000000<:X_`32Z;l0`ZRo000000040<fS[004
0000003V]9l0i[BO000000l0oooo0P00000609:3_`070000003>XJT0cZ6Y0<jQZ@000000m/:D0000
000A0?ooo`030000003X[YD000000080oooo00@000000?ooo`3oool000001`3oool003`0oooo0P00
000I0?ooo`8000001@2l^=D01@000000c[:n0<jb_P3>/[h0000000<0fZfY00@000000=fYX03MZJ00
gJVP1@0000050:VG``0500000032Z;l0`ZRo0<:X_`000000103=Xj`010000000i[BO0>JdW`00000@
0?ooo`030000002BPkl0TX>o00@0TX>o00L000000<jQZ@3>XJT0cZ6Y0000003f`Y@000000140oooo
00<000000>R^U@0000000`3oool00`000000oooo000000070?ooo`00?P3oool00`000000oooo0?oo
o`0G0?ooo`8000000`2l^=D01@000000c[:n0<jb_P3>/[h0000000<0fZfY00D000000=fYX03MZJ00
gJVP000000020?ooo`8000001`2YUl<00`000000`ZRo000000050<fS[0040000003V]9l0i[BO0000
0100oooo00<0000009:3_`2BPkl0102BPkl010000000cZ6Y0<jQZ@0000020?K2U0030000003oool0
oooo00l0oooo00<000000>R^U@000000103oool00`000000oooo000000060?ooo`00?`3oool00`00
0000oooo0?ooo`0H0?ooo`030000002l^=D0000000@0c[:n00D000000=Z]Z@3J[JT0fZfY00000003
0=fYX0060000003oool0oooo0000001^000000001P2YUl<00`000000`ZRo000000040<fS[0050000
003V]9l0i[BO0>JdW`000000403oool00`000000TX>o09:3_`0409:3_`040000003>XJT0cZ6Y0000
0080m/:D00<000000?ooo`3oool0403oool2000000D0oooo0P0000060?ooo`00@03oool00`000000
oooo0?ooo`0H0?ooo`030000003>/[h0c[:n0080c[:n00<000000=Z]Z@3J[JT00P3J[JT01@000000
gJVP0=fYX03MZJ00000000<0oooo0P0000070:VG``030000003=Xj`0cJ>/00<0cJ>/00@000000>Jd
W`3V]9l000004P3oool00`000000TX>o09:3_`0409:3_`030000003>XJT000000080m/:D00<00000
0?ooo`3oool0403oool2000000D0oooo0P0000060?ooo`00@@3oool2000001P0oooo00<000000<jb
_P3>/[h00P3>/[h00`000000fZfY0=Z]Z@020=Z]Z@050000003MZJ00gJVP0=fYX0000000103oool0
0`000000ZIO30:VG``050:VG``030000003=Xj`0cJ>/00<0cJ>/00@000000>JdW`3V]9l000004P3o
ool00`000000TX>o09:3_`0409:3_`030000003>XJT000000080m/:D00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`030?ooo`8000001P3oool004<0oooo00<000000?ooo`3oool05P3oool0
1@000000c[:n0<jb_P3>/[h0000000@0fZfY00D000000=fYX03MZJ00gJVP000000040?ooo`800000
102YUl<3000000D0cJ>/00@000000>JdW`3V]9l000004P3oool00`000000TX>o09:3_`0409:3_`03
0000003>XJT000000080m/:D00<000000?ooo`3oool04@3oool00`000000oooo00000003000000P0
oooo00140?ooo`030000003oool0oooo01D0oooo00@000000<jb_P3>/[h00000103J[JT00`000000
gJVP0=fYX0020=fYX0030000003oool0oooo00<0oooo00D000000:VG``2YUl<0ZIO3000000030:^=
]`030000003=Xj`0cJ>/0080cJ>/00@000000>JdW`3V]9l000004`3oool00`000000TX>o09:3_`03
09:3_`8000000`3f`Y@00`000000oooo0?ooo`0?0?ooo`@00000303oool004D0oooo00<000000?oo
o`3oool05@3oool00`000000c[:n000000040=Z]Z@050000003MZJ00gJVP0=fYX00000001P3oool4
000000@0Zhfg00D000000<fS[03=Xj`0cJ>/000000030>JdW`030000003oool0oooo0140oooo1000
000309:3_`040000003f`Y@0m/:D000000h0oooo1000000@0?ooo`00AP3oool2000001D0oooo0P00
00050=Z]Z@050000003MZJ00gJVP0=fYX00000001`3oool00`000000Zhfg0:^=]`050:^=]`040000
003=Xj`0cJ>/000000<0i[BO00<000000?ooo`3oool04P3oool00`000000Oh_F07n;eP0400000080
m/:D00<000000?ooo`3oool02@3oool3000001@0oooo00180?ooo`030000003oool0oooo01<0oooo
00<000000=Z]Z@3J[JT00`3J[JT01@000000gJVP0=fYX03MZJ00000000L0oooo00<000000:^=]`2[
SKL01@2[SKL010000000cJ>/0<fS[00000030>JdW`030000003oool0oooo0180oooo00<0000007n;
eP1oRmH0101oRmH00`000000m/:D000000070?ooo`@000005`3oool004T0oooo00<000000?ooo`3o
ool04`3oool01@000000fZfY0=Z]Z@3J[JT0000000@0gJVP00<000000?ooo`3oool01P3oool00`00
0000Zhfg0:^=]`040:^=]`040000003=Xj`0cJ>/00000080i[BO00<000000?ooo`3oool0503oool0
0`000000Oh_F07n;eP0407n;eP8000000`3oool4000001/0oooo001:0?ooo`030000003oool0oooo
0180oooo00D000000=Z]Z@3J[JT0fZfY000000040=fYX0030000003oool0oooo00H0oooo00<00000
0:^=]`2[SKL01@2[SKL00`000000cJ>/000000020>JdW`030000003oool0oooo01D0oooo00<00000
07n;eP1oRmH00`1oRmH5000001l0oooo001;0?ooo`030000003oool0oooo0140oooo0P0000020=Z]
Z@050000003MZJ00gJVP0=fYX00000002P3oool00`000000Zhfg0:^=]`040:^=]`8000000`3V]9l0
0`000000oooo0?ooo`0E0?ooo`030000001oRmH0Oh_F00@000008`3oool004`0oooo0P00000A0?oo
o`8000000P3J[JT01@000000gJVP0=fYX03MZJ00000000X0oooo00<000000:^=]`2[SKL01@2[SKL0
1@000000i[BO0>JdW`3V]9l0000001L0oooo1000000V0?ooo`00CP3oool00`000000oooo0?ooo`0>
0?ooo`040000003oool00000000000@0gJVP00<000000?ooo`3oool0203oool00`000000Zhfg0:^=
]`050:^=]`050000003V]9l0i[BO0>JdW`0000004`3oool4000002X0oooo001?0?ooo`030000003o
ool0oooo00d0oooo00@000000?ooo`0000000000103MZJ000`000000oooo0?ooo`090?ooo`030000
002[SKL0Zhfg0080Zhfg0`0000030>JdW`030000003oool0oooo00d0oooo1000000^0?ooo`00D03o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo000000@0gJVP00<000000?ooo`3oool0
2@3oool01@000000Zhfg0:^=]`2[SKL0000000<0b/WI00@000000>JdW`3V]9l00000303oool30000
0380oooo001A0?ooo`800000303oool010000000oooo0?ooo`0000030=fYX0030000003oool0oooo
00/0oooo0`0000040<[9f@030000003V]9l0000000T0oooo1000000e0?ooo`00D`3oool00`000000
oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000000P3MZJ000`000000oooo0?ooo`0;0?oo
o`030000003:bMT0b/WI00D0b/WI0P0000050?ooo`@00000>@3oool005@0oooo00<000000?ooo`3o
ool0203oool01@000000oooo0?ooo`3oool000000080gJVP00<000000?ooo`3oool0303oool00`00
0000b/WI0<[9f@040<[9f@80000000<0oooo0000000000000P00000m0?ooo`00E@3oool00`000000
oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000000P3MZJ000`000000oooo0?ooo`0=0?oo
o`030000003:bMT0b/WI0080b/WI100000110?ooo`00EP3oool2000000L0oooo00<000000?ooo`3o
ool00P3oool00`000000gJVP0000000@0?ooo`D00000A03oool005P0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003MZJ00000000d0oooo100000180?ooo`00F@3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`@00000C03o
ool005X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00D0oooo0`00001@0?ooo`00F`3oool01@000000oooo0?ooo`3oool0000000D0oooo00@00000
0?ooo`3oool0oooo1000001C0?ooo`00G03oool2000000030?ooo`000000oooo00@0oooo1000001G
0?ooo`00GP3oool2000000030?ooo`000000000000800000F`3oool005l0oooo0P00001O0?ooo`00
`03oool00<00oooo00300?ooo`00`03oool00<00oooo00300?ooo`00`03oool00<00oooo00300?oo
o`00`03oool00<00oooo0000\
\>"],
  ImageRangeCache->{{{0, 191.75}, {155.313, 0}} -> {-0.231457, -0.0790669, \
0.00638924, 0.00638924}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[178]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(a = 1\/8\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. apr[\([1]\)])\))\) /. 
        a \[Rule] 1/8, {x, \(-1\), 1}]\)], "Input",
  CellLabel->"In[179]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.316035 3.89772e+008 [
[.02381 .30354 -6 -9 ]
[.02381 .30354 6 0 ]
[.2619 .30354 -12 -9 ]
[.2619 .30354 12 0 ]
[.7381 .30354 -9 -9 ]
[.7381 .30354 9 0 ]
[.97619 .30354 -3 -9 ]
[.97619 .30354 3 0 ]
[.4875 .00422 -43.5 -6.25 ]
[.4875 .00422 0 6.25 ]
[.4875 .08217 -43.5 -6.25 ]
[.4875 .08217 0 6.25 ]
[.4875 .16013 -43.5 -6.25 ]
[.4875 .16013 0 6.25 ]
[.4875 .23808 -43.5 -6.25 ]
[.4875 .23808 0 6.25 ]
[.4875 .39399 -37.5 -6.25 ]
[.4875 .39399 0 6.25 ]
[.4875 .47194 -37.5 -6.25 ]
[.4875 .47194 0 6.25 ]
[.4875 .5499 -37.5 -6.25 ]
[.4875 .5499 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .31604 m
.02381 .32229 L
s
[(-1)] .02381 .30354 0 1 Mshowa
.2619 .31604 m
.2619 .32229 L
s
[(-0.5)] .2619 .30354 0 1 Mshowa
.7381 .31604 m
.7381 .32229 L
s
[(0.5)] .7381 .30354 0 1 Mshowa
.97619 .31604 m
.97619 .32229 L
s
[(1)] .97619 .30354 0 1 Mshowa
.125 Mabswid
.07143 .31604 m
.07143 .31979 L
s
.11905 .31604 m
.11905 .31979 L
s
.16667 .31604 m
.16667 .31979 L
s
.21429 .31604 m
.21429 .31979 L
s
.30952 .31604 m
.30952 .31979 L
s
.35714 .31604 m
.35714 .31979 L
s
.40476 .31604 m
.40476 .31979 L
s
.45238 .31604 m
.45238 .31979 L
s
.54762 .31604 m
.54762 .31979 L
s
.59524 .31604 m
.59524 .31979 L
s
.64286 .31604 m
.64286 .31979 L
s
.69048 .31604 m
.69048 .31979 L
s
.78571 .31604 m
.78571 .31979 L
s
.83333 .31604 m
.83333 .31979 L
s
.88095 .31604 m
.88095 .31979 L
s
.92857 .31604 m
.92857 .31979 L
s
.25 Mabswid
0 .31604 m
1 .31604 L
s
.5 .00422 m
.50625 .00422 L
s
gsave
.4875 .00422 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.5 .08217 m
.50625 .08217 L
s
gsave
.4875 .08217 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.5 .16013 m
.50625 .16013 L
s
gsave
.4875 .16013 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.5 .23808 m
.50625 .23808 L
s
gsave
.4875 .23808 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.5 .39399 m
.50625 .39399 L
s
gsave
.4875 .39399 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.5 .47194 m
.50625 .47194 L
s
gsave
.4875 .47194 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.5 .5499 m
.50625 .5499 L
s
gsave
.4875 .5499 -37.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-10) show
grestore
.125 Mabswid
.5 .02371 m
.50375 .02371 L
s
.5 .04319 m
.50375 .04319 L
s
.5 .06268 m
.50375 .06268 L
s
.5 .10166 m
.50375 .10166 L
s
.5 .12115 m
.50375 .12115 L
s
.5 .14064 m
.50375 .14064 L
s
.5 .17961 m
.50375 .17961 L
s
.5 .1991 m
.50375 .1991 L
s
.5 .21859 m
.50375 .21859 L
s
.5 .25757 m
.50375 .25757 L
s
.5 .27706 m
.50375 .27706 L
s
.5 .29655 m
.50375 .29655 L
s
.5 .33552 m
.50375 .33552 L
s
.5 .35501 m
.50375 .35501 L
s
.5 .3745 m
.50375 .3745 L
s
.5 .41348 m
.50375 .41348 L
s
.5 .43297 m
.50375 .43297 L
s
.5 .45246 m
.50375 .45246 L
s
.5 .49143 m
.50375 .49143 L
s
.5 .51092 m
.50375 .51092 L
s
.5 .53041 m
.50375 .53041 L
s
.5 .56939 m
.50375 .56939 L
s
.5 .58888 m
.50375 .58888 L
s
.5 .60836 m
.50375 .60836 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02846 .17991 L
.03279 .30378 L
.03754 .41024 L
.04262 .49423 L
.04518 .52618 L
.04795 .55382 L
.05058 .57373 L
.05183 .58126 L
.053 .58723 L
.05518 .5957 L
.05634 .59886 L
.05758 .6013 L
.05889 .60281 L
.06012 .60332 L
.06123 .60304 L
.06244 .60199 L
.06316 .60101 L
.06382 .59988 L
.0653 .59659 L
.06799 .58812 L
.07044 .5779 L
.07302 .56479 L
.08429 .48689 L
.10458 .31008 L
.11478 .22462 L
.12444 .15407 L
.13385 .09849 L
.14255 .0602 L
.14708 .04551 L
.1519 .03386 L
.15439 .02942 L
.15673 .02623 L
.15807 .02483 L
.15929 .02381 L
.16064 .02298 L
.16132 .02268 L
.16206 .02243 L
.16274 .02229 L
.16347 .02222 L
.16417 .02224 L
.16481 .02232 L
.16602 .02265 L
.1673 .02326 L
.16796 .02368 L
.16868 .0242 L
.16996 .02535 L
.1729 .02889 L
.1756 .03326 L
.17816 .03837 L
Mistroke
.18298 .05032 L
.19259 .08253 L
.20282 .12696 L
.22122 .22436 L
.24123 .33964 L
.26286 .45419 L
.27303 .4992 L
.28376 .53828 L
.29293 .56389 L
.29813 .57504 L
.30297 .58315 L
.30541 .58639 L
.308 .5892 L
.30935 .59042 L
.31083 .59156 L
.3122 .59242 L
.31345 .59306 L
.31465 .59352 L
.31592 .59387 L
.31718 .59406 L
.3179 .5941 L
.31857 .5941 L
.31979 .59398 L
.32089 .59375 L
.32216 .59335 L
.32337 .59284 L
.32562 .59151 L
.32801 .5896 L
.33228 .5849 L
.33688 .57806 L
.34193 .56849 L
.35212 .54309 L
.36142 .5135 L
.38233 .42951 L
.42214 .24052 L
.44034 .16066 L
.4507 .1213 L
.46044 .08969 L
.46994 .06467 L
.47483 .05423 L
.48019 .04482 L
.48552 .0376 L
.48843 .0346 L
.49114 .03239 L
.49245 .03154 L
.49368 .03085 L
.4948 .03034 L
.49599 .0299 L
.49729 .02955 L
.49849 .02935 L
Mistroke
.49977 .02926 L
.5005 .02927 L
.50119 .02932 L
.50243 .0295 L
.50313 .02965 L
.50376 .02983 L
.505 .03026 L
.50616 .03077 L
.50876 .03232 L
.51158 .0346 L
.51672 .04037 L
.52145 .04747 L
.53046 .0656 L
.53998 .09092 L
.55963 .16053 L
.57797 .24104 L
.6169 .42605 L
.63672 .50694 L
.64718 .54107 L
.65291 .55661 L
.65828 .56894 L
.66342 .57856 L
.66813 .58542 L
.67068 .58832 L
.67336 .59075 L
.67605 .59254 L
.67757 .59325 L
.67831 .59352 L
.67899 .59372 L
.68019 .59398 L
.68149 .5941 L
.68263 .59407 L
.68385 .59391 L
.68493 .59365 L
.68595 .59331 L
.68706 .59281 L
.68825 .59216 L
.69091 .59021 L
.69342 .58774 L
.69815 .58148 L
.7032 .57244 L
.70777 .56222 L
.71801 .53249 L
.73641 .45767 L
.77655 .23706 L
.79498 .13762 L
.80543 .09039 L
.81053 .07095 L
.81517 .0557 L
.8198 .04305 L
Mistroke
.82483 .0325 L
.82759 .02821 L
.8288 .02668 L
.83014 .02524 L
.83132 .02421 L
.83258 .02333 L
.83328 .02296 L
.83391 .02268 L
.83516 .02232 L
.83646 .02222 L
.83719 .02228 L
.83784 .02241 L
.83912 .02287 L
.84033 .02355 L
.84174 .02465 L
.84304 .02596 L
.84597 .02999 L
.84835 .03436 L
.85097 .0403 L
.85625 .05595 L
.86148 .07633 L
.86645 .10002 L
.87575 .15534 L
.89666 .32096 L
.91487 .48014 L
.91986 .51877 L
.92524 .55477 L
.92771 .56873 L
.93032 .58129 L
.93276 .59079 L
.93498 .59728 L
.93619 .5999 L
.93734 .60172 L
.93855 .60291 L
.93986 .60332 L
.94101 .60288 L
.94223 .60157 L
.94327 .59973 L
.94441 .59691 L
.94576 .59247 L
.94699 .5873 L
.94975 .57157 L
.95231 .55149 L
.95474 .5271 L
.95995 .45532 L
.96479 .36175 L
.9701 .2244 L
.97575 .03206 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[179]:=",
  ImageSize->{207.188, 128},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003?0000P2000`400?l00000o`00003oc`3oool0
0<l0oooo003?0?ooo`00@@3oool2000000<0oooo00H000000?ooo`3oool0oooo0000003oool50000
0080oooo0P00001j0?ooo`00@03oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo07L0oooo00100?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0M`3oool003X0oooo100000030?ooo`800000103oool0
0`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo06D0oooo00100?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0?0?ooo`800000IP3oool00440oooo0P00000:0?ooo`800000103oool200000180oooo
00<000000?ooo`3oool0I@3oool000X0oooo00<000000?ooo`3oool0D03oool00`30`<00T92@0<30
`0020?ooo`03092@T030`<00X:2P0080oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`070?ooo`002P3oool00`000000oooo0?ooo`0G0?ooo`<00000=`3oool01`30`<00oooo0?ooo`3o
ool0/;2`0?ooo`2PX:000P3oool00`000000oooo0?ooo`0o0?ooo`8000006P3oool00`000000oooo
0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool000000300oooo00@0
h>3P0820P020P800P8200`3oool01`30`<00oooo0?ooo`3oool0`<300?ooo`20P8000P3oool20000
03l0oooo1000000I0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo01H0
oooo00D000000?ooo`3oool0oooo0000000f0?ooo`080<30`03oool0oooo0?ooo`2`/;00oooo092@
T03oool4000003d0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`030000003oool0oooo00L0
oooo000:0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0b0?ooo`80/;2`0`3oool01P2PX:00/;2`000000000000oooo00000080oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool01`3oool000X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03P0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00L0oooo000:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0g0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?oo
o`002P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000>@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3oool000X0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0
oooo000:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0oooo
000:0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0C0?ooo`<000000`3oool01P000000oooo0?ooo`3oool000000?ooo`D000000P3oool2000000`0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00L0
oooo000:0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0C0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00@000000?ooo`3o
ool00000103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0303oool400000080oooo0`0000040?ooo`030000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0C0?ooo`<000002@3oool2000000@0oooo0P000008
0?ooo`030<30`02@T90000000080oooo00<0T92@0<30`02PX:000P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00L0oooo000:0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0_0?ooo`070<30`0000000oooo0?ooo`2`/;00oooo0:2P
X0020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool01`3oool000X0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0oooo00@0h>3P
0820P020P800P8200`3oool01`30`<0000000?ooo`3oool0`<300?ooo`20P8000P3oool2000000L0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02l0oooo00L000000?ooo`3oool0oooo0;2`/03oool0T92@
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`002P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0;P3oool00`2`/;00
00000?ooo`020?ooo`030:2PX02`/;00/;2`0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`070?ooo`002P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01P3oool2000000P0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool01`3oool000X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0180oooo0`0000000`3oool00000
0?ooo`020?ooo`030000003oool0000000@000000P3oool2000000P0oooo00<000000?ooo`3oool0
1`3oool2000000T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0180oooo00L000000?ooo`3oool0oooo
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00P0oooo000:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0?0?ooo`D000000`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool02@3oool400000080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo0P00000:0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00P0oooo000:0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool000000080oooo00D000000?ooo`3oool0oooo00000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`002P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool2
000000T0oooo0P0000040?ooo`8000001`3oool010000000`<30092@T030`<020?ooo`03092@T030
`<00X:2P0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`080?ooo`002P3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0:P3oool0
10000000oooo0?ooo`30`<030?ooo`030;2`/03oool0X:2P0080oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool09@3oool01@3Ph>00P8200820P020P80000000080oooo00L0
`<300?ooo`3oool0oooo0<30`03oool0P8200080oooo0P00000;0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0
oooo000:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0Y0?ooo`040000003oool0oooo0<30`0<0oooo00<0/;2`0?ooo`2@T9000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Y0?ooo`040000003oool0/;2`0;2`/0<0
oooo00<0X:2P0;2`/02`/;000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00P0
oooo000:0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0:0?ooo`800000303oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`080?ooo`002P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0203oool000X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00P0oooo000:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0;0?ooo`800000
3@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool03@3oool400000080oooo00H000000?ooo`3oool0oooo
0000003oool500000080oooo0P0000040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`080?ooo`002P3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?oo
o`0000003@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo000:0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00P0oooo000:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`060?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000h0oooo0P00
000>0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00P0oooo000;0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool000/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00d0
oooo0P00000:0?ooo`800000103oool2000000<0oooo00<000000?ooo`3oool00P3oool00`30`<00
T92@0<30`0020?ooo`03092@T030`<00X:2P0080oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`080?ooo`002`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`040?ooo`070<30`03oool0oooo0?ooo`2`
/;00oooo0:2PX0020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool000/0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02<0
oooo00@000000820P020P800P8200`3oool01`30`<00oooo0?ooo`3oool0`<300?ooo`20P8000P3o
ool2000000l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0203oool000/0oooo1@00000:0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool00P0000040?ooo`800000103oool2000001D0oooo00<00000
0?ooo`3oool0103oool01`30`<00oooo0?ooo`3oool0/;2`0?ooo`2@T9000P3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01@0oooo0P0000040?ooo`800000103oool3000001H0oooo
00<000000?ooo`3oool0303oool5000000L0oooo000;0?ooo`030000003oool0000000`0oooo00<0
00000?ooo`3oool05@3oool200000080oooo00<000000?ooo`3oool01P3oool010000000oooo0?oo
o`00000D0?ooo`030000003oool0oooo00<0oooo0P2`/;030?ooo`030:2PX02`/;00/;2`0080oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000005P3oool00`000000oooo0?ooo`0=0?ooo`8000002@3oool000/0
oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`0E0?ooo`8000000P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03P3oool2000000l0
oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool03@3oool2000000T0oooo00050?ooo`@000000P3oool00`000000
oooo0000000<0?ooo`030000003oool0oooo0100oooo100000000`3oool00000000000020?ooo`03
0000003oool0oooo00L0oooo0P00000D0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000000T0oooo0`00000F0?oo
o`030000003oool0oooo00d0oooo0P0000090?ooo`002`3oool00`000000oooo0000000<0?ooo`03
0000003oool0oooo01D0oooo0P0000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool04P3oool010000000oooo0?ooo`0000090?ooo`8000005`3oool00`000000oooo0?ooo`0=0?oo
o`8000002@3oool000/0oooo0`00000;0?ooo`030000003oool0oooo01H0oooo00@000000?ooo`00
000000002P3oool3000001<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo01<0oooo0P00000:0?ooo`<000005P3oool00`000000oooo0?ooo`0=0?oo
o`8000002@3oool000/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool03P3oool200000100oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02@3oool000/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool02@3oool000D0ooooaP0000040?ooo`002P3oool2000000L0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
00H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?ooo`3oool01P3o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
2@3oool000/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00T0oooo000;0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`8000004P3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02@3oool000/0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`002`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0A
0?ooo`8000004P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00303oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool000`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`00303o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01`3o
ool400000080oooo00H000000?ooo`3oool0oooo0000003oool5000000040?ooo`00000000000000
0180oooo0P00000C0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo000<0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo000<0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03`3oool2000001@0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool000`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`00303oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool2000000X0oooo0P0000020?oo
o`040000003oool00000000000P0oooo00<0`<30092@T030`<000P3oool00`2@T900`<300:2PX002
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool000`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool02P3oool01`30`<00oooo0?ooo`3oool0/;2`0?ooo`2PX:000P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00X0oooo000<0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00@0h>3P
0820P020P800P8200`3oool01`30`<00oooo0?ooo`3oool0`<300?ooo`20P8000P3oool2000001@0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02P3oool000`0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool01`30`<00oooo
0?ooo`3oool0/;2`0?ooo`2@T9000P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00X0oooo000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo0P2`/;030?ooo`030:2PX02`/;00/;2`0080
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`00303oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool000`0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0503oool2000001D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool000`0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00X0oooo000<0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?oo
o`00303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool02P3oool000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool05@3oool2000001H0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
2P3oool000d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00H0oooo0`0000000`3oool000000?ooo`020?ooo`030000003oool0000000@000000P3o
ool200000180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`003@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool0
1`000000oooo0?ooo`3oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0
oooo000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`030?ooo`D000000`3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool02P3oool000d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo000000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0?0?ooo`8000005`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0:0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0103oool00`000000oooo000000020?ooo`050000003oool0oooo0?oo
o`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo000=0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`8000002@3oool20000
00@0oooo0P0000080?ooo`030<30`02@T900`<300080oooo00<0T92@0<30`02PX:000P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00X0oooo000=0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0
oooo00L0`<300?ooo`3oool0oooo0;2`/03oool0X:2P0080oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0:0?ooo`003@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?ooo`040>3Ph020P800P820
0820P0<0oooo00L0`<300?ooo`3oool0oooo0<30`03oool0P8200080oooo0P00000H0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00/0oooo000=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00L0`<300?ooo`3oool0oooo
0;2`/03oool0T92@0080oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0;0?ooo`00
3@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0>0?ooo`80/;2`0`3oool00`2PX:00/;2`0;2`/0020?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool000d0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603o
ool2000001T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool02`3oool000h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00/0oooo000>0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`003P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool000h0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool06@3oool2000001X0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02`3oool000h0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00<000000`3o
ool010000000oooo0?ooo`3oool700000080oooo0P00000B0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02`3oool000h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0V0?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool0oooo0000003oool20000
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`003P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02H0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`003P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02P0oooo00<000000?ooo`0000000P000004
0?ooo`040000003oool00000000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00l0oooo0P00000L0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0:03oool010000000oooo0?ooo`0000040?ooo`030000
003oool0oooo008000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo000>0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool00`000000oooo00000002000000D0oooo
00@000000?ooo`3oool0oooo0P0000040?ooo`800000203oool00`30`<00T92@0<30`0020?ooo`03
092@T030`<00X:2P0080oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`00
3P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0C0?ooo`070<30`03oool0oooo0?ooo`2`/;00oooo0:2PX0020?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool000l0oooo00D000000?ooo`3o
ool0oooo0000000[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0303oool0103P
h>00P8200820P020P8030?ooo`070<30`03oool0oooo0?ooo`30`<00oooo0820P0020?ooo`800000
7@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0<0?ooo`003`3oool01@000000oooo0?ooo`3oool0000002`0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0D0?ooo`070<30`03oool0oooo0?ooo`2`
/;00oooo092@T0020?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303oool000l0
oooo00D000000?ooo`3oool0oooo0000000/0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool04`3oool20;2`/0<0oooo00<0X:2P0;2`/02`/;000P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`00000?
0?ooo`003`3oool010000000oooo0?ooo`00000]0?ooo`800000103oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/
0?ooo`040000003oool0oooo000000l0oooo000?0?ooo`040000003oool0oooo000002h0oooo0P00
00020?ooo`030000003oool0oooo01l0oooo0P00000P0?ooo`80000000<0oooo000000000000;P3o
ool010000000oooo0?ooo`00000?0?ooo`00403oool00`000000oooo0000000`0?ooo`<000008@3o
ool00`000000oooo0?ooo`0P0?ooo`<00000<03oool00`000000oooo0000000?0?ooo`00403oool2
000005D0oooo00<000000?ooo`3oool0D`3oool200000100oooo000@0?ooo`800000E@3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo00h0oooo001W0?ooo`800000IP3oool006L0oooo
00<000000?ooo`3oool0I@3oool00001\
\>"],
  ImageRangeCache->{{{0, 206.188}, {127, 0}} -> {-1.10756, -8.81513*^-10, \
0.0106751, 1.30419*^-11}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[179]="]
}, Open  ]],

Cell["Example 5", "Subsubsection"],

Cell["Boundary value problem.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(bvp = {\(y''\)[x] + \[Lambda]*x*\(y'\)[x] + \[Lambda]^2*y[x] \[Equal] 
          0, y[0] \[Equal] 0, y[1] \[Equal] \[Lambda]}\)], "Input",
  CellLabel->"In[180]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\[Lambda]\^2\ y[x]\), "+", 
            RowBox[{"x", " ", "\[Lambda]", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{
              SuperscriptBox["y", "\[Prime]\[Prime]",
                MultilineFunction->None], "[", "x", "]"}]}], "==", "0"}], 
        ",", \(y[0] == 0\), ",", \(y[1] == \[Lambda]\)}], "}"}]], "Output",
  CellLabel->"Out[180]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[bvp, y[x], {x, 0, 1}, 3]\)], "Input",
  CellLabel->"In[181]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(2304\ x\^2\ \[Lambda]\^3\ \((\(-800\) - 800\ \
\[Lambda] + 3\ \[Lambda]\^2 + 3\ \[Lambda]\^3)\)\)\/\(31457280 - 9011200\ \
\[Lambda] - 918528\ \[Lambda]\^2 + 278912\ \[Lambda]\^3 + 768\ \[Lambda]\^4 - \
1118\ \[Lambda]\^5 + 3\ \[Lambda]\^6 + \[Lambda]\^7\) + \(48\ \[Lambda]\^3\ \
\((\(-288\) - 278\ \[Lambda] + 15\ \[Lambda]\^2 + 5\ \
\[Lambda]\^3)\)\)\/\(31457280 - 9011200\ \[Lambda] - 918528\ \[Lambda]\^2 + \
278912\ \[Lambda]\^3 + 768\ \[Lambda]\^4 - 1118\ \[Lambda]\^5 + 3\ \
\[Lambda]\^6 + \[Lambda]\^7\) - \(5120\ x\^3\ \[Lambda]\^2\ \((1 + \[Lambda])\
\)\ \((3072 - 640\ \[Lambda] - 320\ \[Lambda]\^2 + 2\ \[Lambda]\^3 + \
\[Lambda]\^4)\)\)\/\(\((3 + \[Lambda])\)\ \((31457280 - 9011200\ \[Lambda] - \
918528\ \[Lambda]\^2 + 278912\ \[Lambda]\^3 + 768\ \[Lambda]\^4 - 1118\ \
\[Lambda]\^5 + 3\ \[Lambda]\^6 + \[Lambda]\^7)\)\) - \(96\ x\ \[Lambda]\ \
\((\(-983040\) - 209920\ \[Lambda] - 64640\ \[Lambda]\^2 - 24640\ \
\[Lambda]\^3 - 4958\ \[Lambda]\^4 + 135\ \[Lambda]\^5 + 27\ \[Lambda]\^6)\)\)\
\/\(\((3 + \[Lambda])\)\ \((31457280 - 9011200\ \[Lambda] - 918528\ \[Lambda]\
\^2 + 278912\ \[Lambda]\^3 + 768\ \[Lambda]\^4 - 1118\ \[Lambda]\^5 + 3\ \
\[Lambda]\^6 + \[Lambda]\^7)\)\)}}\)], "Output",
  CellLabel->"Out[181]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the BVP."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[bvp, y[x], x]\)], "Input",
  CellLabel->"In[182]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \(\[ExponentialE]\^\(\[Lambda]\/2 - \(x\^2\ \
\[Lambda]\)\/2\)\ \[Lambda]\ \((2\ Gamma[\(2 - \[Lambda]\)\/2]\ HermiteH[\(-1\
\) + \[Lambda], \(x\ \@\[Lambda]\)\/\@2] - 2\^\[Lambda]\ \@\[Pi]\ \
Hypergeometric1F1[\(1 - \[Lambda]\)\/2, 1\/2, \(x\^2\ \
\[Lambda]\)\/2])\)\)\/\(2\ Gamma[\(2 - \[Lambda]\)\/2]\ HermiteH[\(-1\) + \
\[Lambda], \@\[Lambda]\/\@2] - 2\^\[Lambda]\ \@\[Pi]\ Hypergeometric1F1[\(1 - \
\[Lambda]\)\/2, 1\/2, \[Lambda]\/2]\)}}\)], "Output",
  CellLabel->"Out[182]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[
      Chop[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\)], {x, 0, 1}, {\[Lambda], \(-1\)/4, 
        1/4}]\)], "Input",
  CellLabel->"In[183]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.55041e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -6 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -16.7601 -9 ]
[.3345 .12542 1.2399 0 ]
[.50253 .05935 -21.0959 -9 ]
[.50253 .05935 2.90415 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.73498 .04732 0 -6.2105 ]
[.73498 .04732 24 2.7895 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.95881 .39008 0 -5.88604 ]
[.95881 .39008 18 3.11396 ]
[.02083 .28566 -39 -3.83288 ]
[.02083 .28566 0 8.66712 ]
[.00688 .37313 -6 -2.83381 ]
[.00688 .37313 0 6.16619 ]
[-0.00789 .46569 -33 -4.04543 ]
[-0.00789 .46569 0 8.45457 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(0.25)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0.5)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.75)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.72272 .05198 m
.71658 .05431 L
s
[(-0.2)] .73498 .04732 -1 .38011 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.94627 .39394 m
.94 .39587 L
s
[(0.2)] .95881 .39008 -1 .30801 Mshowa
.125 Mabswid
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.81573 .19425 m
.81201 .19555 L
s
.87123 .27915 m
.8675 .28039 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03307 .28092 m
.03919 .27856 L
s
gsave
.02083 .28566 -39 -1.83288 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.01918 .36858 m
.02534 .3663 L
s
[(0)] .00688 .37313 1 -0.37026 Mshowa
.00449 .46133 m
.01067 .45914 L
s
gsave
-0.00789 .46569 -33 -2.04543 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.03036 .29807 m
.03403 .29666 L
s
.02761 .3154 m
.03129 .314 L
s
.02483 .33293 m
.02852 .33154 L
s
.02202 .35065 m
.02571 .34927 L
s
.01631 .38671 m
.02001 .38535 L
s
.0134 .40504 m
.0171 .4037 L
s
.01047 .42359 m
.01417 .42225 L
s
.00749 .44235 m
.0112 .44103 L
s
.03576 .26397 m
.03943 .26254 L
s
.00144 .48053 m
.00516 .47923 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.887 .7 .643 r
.37509 .77627 .39787 .81114 .44135 .61482 .41859 .62433 Metetra
.928 .962 .772 r
.41859 .62433 .44135 .61482 .47922 .5767 .45765 .56857 Metetra
.151 .649 .912 r
.45765 .56857 .47922 .5767 .51696 .56535 .49573 .57255 Metetra
.744 .277 .142 r
.49573 .57255 .51696 .56535 .55576 .61343 .53482 .60989 Metetra
.785 .292 .033 r
.53482 .60989 .55576 .61343 .59726 .69985 .57576 .65793 Metetra
.096 .299 .778 r
.57576 .65793 .59726 .69985 .6404 .74764 .61848 .69623 Metetra
.491 .501 .795 r
.61848 .69623 .6404 .74764 .68296 .7365 .66202 .70827 Metetra
.728 .729 .851 r
.66202 .70827 .68296 .7365 .72618 .72519 .70501 .68501 Metetra
.813 .698 .737 r
.70501 .68501 .72618 .72519 .76787 .68213 .74622 .62795 Metetra
.82 .663 .689 r
.74622 .62795 .76787 .68213 .80311 .56202 .78534 .54993 Metetra
.945 .853 .721 r
.78534 .54993 .80311 .56202 .83874 .46853 .82355 .47352 Metetra
.782 .991 .759 r
.82355 .47352 .83874 .46853 .88163 .45563 .86428 .4313 Metetra
.069 .4 .856 r
.86428 .4313 .88163 .45563 .92518 .44266 .91326 .45994 Metetra
.901 .502 .245 r
.91326 .45994 .92518 .44266 1 .6535 .98292 .63004 Metetra
.804 .635 .673 r
.35319 .71413 .37509 .77627 .41859 .62433 .39519 .62435 Metetra
.857 .95 .874 r
.39519 .62435 .41859 .62433 .45765 .56857 .43462 .58746 Metetra
.354 0 0 r
.43462 .58746 .45765 .56857 .49573 .57255 .47351 .58458 Metetra
.578 .076 .024 r
.47351 .58458 .49573 .57255 .53482 .60989 .5131 .60052 Metetra
.388 0 0 r
.5131 .60052 .53482 .60989 .57576 .65793 .554 .62204 Metetra
.37 .51 .868 r
.554 .62204 .57576 .65793 .61848 .69623 .59619 .63769 Metetra
.568 .524 .766 r
.59619 .63769 .61848 .69623 .66202 .70827 .63922 .63865 Metetra
.649 .548 .726 r
.63922 .63865 .66202 .70827 .70501 .68501 .68237 .62021 Metetra
.713 .592 .72 r
.68237 .62021 .70501 .68501 .74622 .62795 .72493 .58299 Metetra
.785 .675 .742 r
.72493 .58299 .74622 .62795 .78534 .54993 .76667 .53357 Metetra
.878 .853 .814 r
.76667 .53357 .78534 .54993 .82355 .47352 .80812 .48426 Metetra
.433 .82 .588 r
.80812 .48426 .82355 .47352 .86428 .4313 .85108 .45295 Metetra
.527 .051 .068 r
.85108 .45295 .86428 .4313 .91326 .45994 .89911 .46436 Metetra
.834 .366 .066 r
.89911 .46436 .91326 .45994 .98292 .63004 .95888 .55567 Metetra
.773 .649 .725 r
.33038 .66687 .35319 .71413 .39519 .62435 .37122 .61658 Metetra
.771 .898 .932 r
.37122 .61658 .39519 .62435 .43462 .58746 .4109 .59208 Metetra
.4109 .59208 .43462 .58746 .47351 .58458 .45049 .58454 Metetra
.064 0 0 r
.45049 .58454 .47351 .58458 .5131 .60052 .49068 .58631 Metetra
.29 .678 .973 r
.49068 .58631 .5131 .60052 .554 .62204 .53181 .59064 Metetra
.526 .627 .895 r
.53181 .59064 .554 .62204 .59619 .63769 .57394 .59187 Metetra
.605 .588 .808 r
.57394 .59187 .59619 .63769 .63922 .63865 .61686 .58576 Metetra
.652 .589 .772 r
.61686 .58576 .63922 .63865 .68237 .62021 .66023 .57008 Metetra
.695 .621 .769 r
.66023 .57008 .68237 .62021 .72493 .58299 .70372 .54508 Metetra
.745 .69 .799 r
.70372 .54508 .72493 .58299 .76667 .53357 .74718 .51378 Metetra
.793 .828 .879 r
.74718 .51378 .76667 .53357 .80812 .48426 .79084 .4822 Metetra
.624 .955 .921 r
.79084 .4822 .80812 .48426 .85108 .45295 .83555 .45939 Metetra
.155 0 0 r
.83555 .45939 .85108 .45295 .89911 .46436 .88308 .45799 Metetra
.517 0 0 r
.88308 .45799 .89911 .46436 .95888 .55567 .93661 .49576 Metetra
.732 .673 .793 r
.30659 .63028 .33038 .66687 .37122 .61658 .3467 .60266 Metetra
.704 .836 .946 r
.3467 .60266 .37122 .61658 .4109 .59208 .38662 .58537 Metetra
.539 .873 .992 r
.38662 .58537 .4109 .59208 .45049 .58454 .4268 .57494 Metetra
.49 .828 .998 r
.4268 .57494 .45049 .58454 .49068 .58631 .46758 .56821 Metetra
.557 .765 .975 r
.46758 .56821 .49068 .58631 .53181 .59064 .50911 .56239 Metetra
.605 .691 .903 r
.50911 .56239 .53181 .59064 .57394 .59187 .55144 .55516 Metetra
.633 .649 .848 r
.55144 .55516 .57394 .59187 .61686 .58576 .5945 .54484 Metetra
.655 .639 .822 r
.5945 .54484 .61686 .58576 .66023 .57008 .63819 .53052 Metetra
.678 .658 .823 r
.63819 .53052 .66023 .57008 .70372 .54508 .68236 .51228 Metetra
.704 .708 .851 r
.68236 .51228 .70372 .54508 .74718 .51378 .72694 .49132 Metetra
.719 .794 .911 r
.72694 .49132 .74718 .51378 .79084 .4822 .77204 .47004 Metetra
.662 .887 .98 r
.77204 .47004 .79084 .4822 .83555 .45939 .81799 .45219 Metetra
.437 .843 .972 r
.81799 .45219 .83555 .45939 .88308 .45799 .8655 .44302 Metetra
.259 .659 .966 r
.8655 .44302 .88308 .45799 .93661 .49576 .91585 .44964 Metetra
.688 .703 .858 r
.2818 .60085 .30659 .63028 .3467 .60266 .32164 .58417 Metetra
.669 .79 .939 r
.32164 .58417 .3467 .60266 .38662 .58537 .36182 .57029 Metetra
.635 .82 .971 r
.36182 .57029 .38662 .58537 .4268 .57494 .40251 .55824 Metetra
.625 .804 .968 r
.40251 .55824 .4268 .57494 .46758 .56821 .44381 .54712 Metetra
.633 .766 .943 r
.44381 .54712 .46758 .56821 .50911 .56239 .48579 .53611 Metetra
.642 .726 .909 r
.48579 .53611 .50911 .56239 .55144 .55516 .52847 .52455 Metetra
.649 .699 .882 r
.52847 .52455 .55144 .55516 .5945 .54484 .57186 .51196 Metetra
.657 .689 .869 r
.57186 .51196 .5945 .54484 .63819 .53052 .61592 .49808 Metetra
.665 .698 .871 r
.61592 .49808 .63819 .53052 .68236 .51228 .66064 .48291 Metetra
.673 .725 .889 r
.66064 .48291 .68236 .51228 .72694 .49132 .706 .4668 Metetra
.674 .768 .921 r
.706 .4668 .72694 .49132 .77204 .47004 .75204 .45042 Metetra
.658 .813 .958 r
.75204 .45042 .77204 .47004 .81799 .45219 .79886 .43485 Metetra
.619 .826 .98 r
.79886 .43485 .81799 .45219 .8655 .44302 .84668 .4216 Metetra
.581 .771 .97 r
.84668 .4216 .8655 .44302 .91585 .44964 .89586 .41269 Metetra
.661 .731 .901 r
.25604 .57562 .2818 .60085 .32164 .58417 .29598 .56255 Metetra
.657 .764 .928 r
.29598 .56255 .32164 .58417 .36182 .57029 .33649 .54965 Metetra
.653 .775 .938 r
.33649 .54965 .36182 .57029 .40251 .55824 .37761 .5368 Metetra
.652 .77 .936 r
.37761 .5368 .40251 .55824 .44381 .54712 .41937 .52388 Metetra
.653 .758 .926 r
.41937 .52388 .44381 .54712 .48579 .53611 .4618 .51079 Metetra
.654 .744 .915 r
.4618 .51079 .48579 .53611 .52847 .52455 .5049 .49745 Metetra
.655 .733 .906 r
.5049 .49745 .52847 .52455 .57186 .51196 .5487 .48379 Metetra
.656 .728 .902 r
.5487 .48379 .57186 .51196 .61592 .49808 .5932 .46978 Metetra
.658 .73 .903 r
.5932 .46978 .61592 .49808 .66064 .48291 .63842 .45542 Metetra
.658 .74 .91 r
.63842 .45542 .66064 .48291 .706 .4668 .68437 .44073 Metetra
.658 .756 .922 r
.68437 .44073 .706 .4668 .75204 .45042 .73107 .4258 Metetra
.656 .771 .934 r
.73107 .4258 .75204 .45042 .79886 .43485 .77855 .41076 Metetra
.652 .778 .941 r
.77855 .41076 .79886 .43485 .84668 .4216 .82686 .39577 Metetra
.648 .765 .934 r
.82686 .39577 .84668 .4216 .89586 .41269 .87604 .38108 Metetra
.656 .748 .918 r
.2294 .55199 .25604 .57562 .29598 .56255 .26965 .53911 Metetra
.656 .753 .922 r
.26965 .53911 .29598 .56255 .33649 .54965 .31053 .52602 Metetra
.656 .755 .923 r
.31053 .52602 .33649 .54965 .37761 .5368 .35206 .51273 Metetra
.656 .754 .922 r
.35206 .51273 .37761 .5368 .41937 .52388 .39424 .49923 Metetra
.656 .752 .921 r
.39424 .49923 .41937 .52388 .4618 .51079 .43709 .48551 Metetra
.656 .75 .92 r
.43709 .48551 .4618 .51079 .5049 .49745 .48064 .47158 Metetra
.656 .749 .918 r
.48064 .47158 .5049 .49745 .5487 .48379 .52489 .45741 Metetra
.656 .748 .918 r
.52489 .45741 .5487 .48379 .5932 .46978 .56986 .44302 Metetra
.656 .748 .918 r
.56986 .44302 .5932 .46978 .63842 .45542 .61558 .42839 Metetra
.656 .75 .919 r
.61558 .42839 .63842 .45542 .68437 .44073 .66205 .41351 Metetra
.656 .752 .921 r
.66205 .41351 .68437 .44073 .73107 .4258 .70931 .39839 Metetra
.656 .754 .922 r
.70931 .39839 .73107 .4258 .77855 .41076 .75736 .38301 Metetra
.656 .755 .923 r
.75736 .38301 .77855 .41076 .82686 .39577 .80623 .36736 Metetra
.656 .754 .922 r
.80623 .36736 .82686 .39577 .87604 .38108 .85595 .35145 Metetra
.651 .747 .92 r
.20199 .52772 .2294 .55199 .26965 .53911 .24256 .51496 Metetra
.654 .752 .922 r
.24256 .51496 .26965 .53911 .31053 .52602 .28382 .50166 Metetra
.656 .754 .922 r
.28382 .50166 .31053 .52602 .35206 .51273 .32575 .48792 Metetra
.657 .754 .921 r
.32575 .48792 .35206 .51273 .39424 .49923 .36836 .47384 Metetra
.658 .753 .92 r
.36836 .47384 .39424 .49923 .43709 .48551 .41165 .4595 Metetra
.657 .751 .919 r
.41165 .4595 .43709 .48551 .48064 .47158 .45565 .44496 Metetra
.657 .749 .918 r
.45565 .44496 .48064 .47158 .52489 .45741 .50036 .43028 Metetra
.656 .748 .918 r
.50036 .43028 .52489 .45741 .56986 .44302 .54581 .41547 Metetra
.654 .748 .919 r
.54581 .41547 .56986 .44302 .61558 .42839 .59203 .40054 Metetra
.654 .749 .92 r
.59203 .40054 .61558 .42839 .66205 .41351 .63904 .38543 Metetra
.654 .751 .921 r
.63904 .38543 .66205 .41351 .70931 .39839 .68685 .37007 Metetra
.655 .753 .922 r
.68685 .37007 .70931 .39839 .75736 .38301 .73549 .35433 Metetra
.657 .755 .922 r
.73549 .35433 .75736 .38301 .80623 .36736 .78495 .33802 Metetra
.661 .756 .92 r
.78495 .33802 .80623 .36736 .85595 .35145 .83522 .32092 Metetra
.616 .723 .922 r
.17399 .50086 .20199 .52772 .24256 .51496 .21459 .49109 Metetra
.642 .757 .933 r
.21459 .49109 .24256 .51496 .28382 .50166 .25615 .47853 Metetra
.659 .771 .932 r
.25615 .47853 .28382 .50166 .32575 .48792 .29854 .464 Metetra
.669 .771 .926 r
.29854 .464 .32575 .48792 .36836 .47384 .34166 .44828 Metetra
.671 .761 .918 r
.34166 .44828 .36836 .47384 .41165 .4595 .38546 .43205 Metetra
.668 .749 .911 r
.38546 .43205 .41165 .4595 .45565 .44496 .42994 .41587 Metetra
.662 .738 .907 r
.42994 .41587 .45565 .44496 .50036 .43028 .47511 .40015 Metetra
.654 .731 .906 r
.47511 .40015 .50036 .43028 .54581 .41547 .52103 .3851 Metetra
.646 .73 .91 r
.52103 .3851 .54581 .41547 .59203 .40054 .56774 .37071 Metetra
.64 .735 .918 r
.56774 .37071 .59203 .40054 .63904 .38543 .6153 .3567 Metetra
.639 .747 .927 r
.6153 .3567 .63904 .38543 .68685 .37007 .66375 .34246 Metetra
.646 .763 .934 r
.66375 .34246 .68685 .37007 .73549 .35433 .71305 .32706 Metetra
.666 .778 .933 r
.71305 .32706 .73549 .35433 .78495 .33802 .76308 .30916 Metetra
.698 .781 .915 r
.76308 .30916 .78495 .33802 .83522 .32092 .81358 .28698 Metetra
.511 .657 .926 r
.14559 .46981 .17399 .50086 .21459 .49109 .18557 .46829 Metetra
.604 .762 .955 r
.18557 .46829 .21459 .49109 .25615 .47853 .22728 .45826 Metetra
.667 .804 .949 r
.22728 .45826 .25615 .47853 .29854 .464 .27023 .44234 Metetra
.697 .802 .93 r
.27023 .44234 .29854 .464 .34166 .44828 .31406 .42304 Metetra
.703 .778 .91 r
.31406 .42304 .34166 .44828 .38546 .43205 .35854 .4026 Metetra
.692 .747 .894 r
.35854 .4026 .38546 .43205 .42994 .41587 .40359 .38287 Metetra
.672 .72 .885 r
.40359 .38287 .42994 .41587 .47511 .40015 .44921 .36516 Metetra
.648 .701 .886 r
.44921 .36516 .47511 .40015 .52103 .3851 .49552 .35018 Metetra
.623 .695 .896 r
.49552 .35018 .52103 .3851 .56774 .37071 .54268 .33789 Metetra
.603 .705 .916 r
.54268 .33789 .56774 .37071 .6153 .3567 .59081 .32742 Metetra
.596 .733 .94 r
.59081 .32742 .6153 .3567 .66375 .34246 .63998 .31687 Metetra
.62 .778 .957 r
.63998 .31687 .66375 .34246 .71305 .32706 .69006 .30317 Metetra
.688 .822 .947 r
.69006 .30317 .71305 .32706 .76308 .30916 .74064 .28195 Metetra
.779 .826 .889 r
.74064 .28195 .76308 .30916 .81358 .28698 .79089 .24753 Metetra
.238 .483 .889 r
.11702 .43328 .14559 .46981 .18557 .46829 .15533 .44723 Metetra
.508 .752 .984 r
.15533 .44723 .18557 .46829 .22728 .45826 .19692 .44224 Metetra
.679 .849 .964 r
.19692 .44224 .22728 .45826 .27023 .44234 .2406 .42407 Metetra
.746 .842 .923 r
.2406 .42407 .27023 .44234 .31406 .42304 .28546 .3985 Metetra
.752 .797 .889 r
.28546 .3985 .31406 .42304 .35854 .4026 .33091 .37067 Metetra
.727 .746 .867 r
.33091 .37067 .35854 .4026 .40359 .38287 .37668 .34479 Metetra
.686 .699 .857 r
.37668 .34479 .40359 .38287 .44921 .36516 .42277 .32381 Metetra
.637 .664 .86 r
.42277 .32381 .44921 .36516 .49552 .35018 .46939 .30929 Metetra
.583 .646 .879 r
.46939 .30929 .49552 .35018 .54268 .33789 .51687 .30121 Metetra
.531 .652 .912 r
.51687 .30121 .54268 .33789 .59081 .32742 .56551 .29764 Metetra
.503 .695 .955 r
.56551 .29764 .59081 .32742 .63998 .31687 .61546 .29434 Metetra
.556 .787 .985 r
.61546 .29434 .63998 .31687 .69006 .30317 .66646 .28428 Metetra
.727 .884 .953 r
.66646 .28428 .69006 .30317 .74064 .28195 .71761 .25738 Metetra
.88 .863 .819 r
.71761 .25738 .74064 .28195 .79089 .24753 .76706 .20095 Metetra
0 .062 .618 r
.08853 .39034 .11702 .43328 .15533 .44723 .12369 .42842 Metetra
.275 .67 .97 r
.12369 .42842 .15533 .44723 .19692 .44224 .16474 .43159 Metetra
.696 .9 .97 r
.16474 .43159 .19692 .44224 .2406 .42407 .20938 .41014 Metetra
.808 .879 .898 r
.20938 .41014 .2406 .42407 .28546 .3985 .25574 .37497 Metetra
.809 .813 .854 r
.25574 .37497 .28546 .3985 .33091 .37067 .3026 .33591 Metetra
.767 .743 .831 r
.3026 .33591 .33091 .37067 .37668 .34479 .34935 .30078 Metetra
.703 .679 .825 r
.34935 .30078 .37668 .34479 .42277 .32381 .39596 .275 Metetra
.621 .625 .833 r
.39596 .275 .42277 .32381 .46939 .30929 .44276 .26139 Metetra
.521 .582 .857 r
.44276 .26139 .46939 .30929 .51687 .30121 .49036 .25997 Metetra
.404 .562 .897 r
.49036 .25997 .51687 .30121 .56551 .29764 .53935 .26734 Metetra
.315 .598 .946 r
.53935 .26734 .56551 .29764 .61546 .29434 .59006 .2757 Metetra
.415 .761 .995 r
.59006 .2757 .61546 .29434 .66646 .28428 .64212 .27174 Metetra
.778 .948 .931 r
.64212 .27174 .66646 .28428 .71761 .25738 .69391 .23624 Metetra
.953 .864 .714 r
.69391 .23624 .71761 .25738 .76706 .20095 .74211 .14609 Metetra
.786 .381 0 r
.06034 .34046 .08853 .39034 .12369 .42842 .09044 .41225 Metetra
0 .379 .738 r
.09044 .41225 .12369 .42842 .16474 .43159 .13036 .42725 Metetra
.715 .946 .955 r
.13036 .42725 .16474 .43159 .20938 .41014 .17625 .40129 Metetra
.868 .901 .854 r
.17625 .40129 .20938 .41014 .25574 .37497 .22477 .35267 Metetra
.859 .818 .807 r
.22477 .35267 .25574 .37497 .3026 .33591 .27364 .29805 Metetra
.804 .739 .791 r
.27364 .29805 .3026 .33591 .34935 .30078 .32175 .25032 Metetra
.72 .663 .792 r
.32175 .25032 .34935 .30078 .39596 .275 .36896 .2181 Metetra
.603 .586 .807 r
.36896 .2181 .39596 .275 .44276 .26139 .41579 .20585 Metetra
.434 .502 .83 r
.41579 .20585 .44276 .26139 .49036 .25997 .46322 .21368 Metetra
.2 .415 .847 r
.46322 .21368 .49036 .25997 .53935 .26734 .51227 .23641 Metetra
0 .386 .843 r
.51227 .23641 .53935 .26734 .59006 .2757 .56363 .26154 Metetra
.146 .636 .916 r
.56363 .26154 .59006 .2757 .64212 .27174 .61684 .26669 Metetra
.829 .99 .867 r
.61684 .26669 .64212 .27174 .69391 .23624 .66941 .21914 Metetra
.987 .838 .609 r
.66941 .21914 .69391 .23624 .74211 .14609 .71613 .08235 Metetra
.932 .571 .157 r
.03267 .28346 .06034 .34046 .09044 .41225 .05535 .39897 Metetra
.601 .03 0 r
.05535 .39897 .09044 .41225 .13036 .42725 .09336 .42997 Metetra
.735 .979 .918 r
.09336 .42997 .13036 .42725 .17625 .40129 .14088 .3981 Metetra
.915 .904 .798 r
.14088 .3981 .17625 .40129 .22477 .35267 .1924 .33174 Metetra
.897 .813 .757 r
.1924 .33174 .22477 .35267 .27364 .29805 .24409 .25694 Metetra
.836 .733 .751 r
.24409 .25694 .27364 .29805 .32175 .25032 .29405 .1932 Metetra
.738 .65 .762 r
.29405 .1932 .32175 .25032 .36896 .2181 .34198 .15295 Metetra
.582 .548 .782 r
.34198 .15295 .36896 .2181 .41579 .20585 .38867 .14244 Metetra
.318 .403 .792 r
.38867 .14244 .41579 .20585 .46322 .21368 .43554 .16203 Metetra
0 .2 .727 r
.43554 .16203 .46322 .21368 .51227 .23641 .48422 .20474 Metetra
0 .073 .59 r
.48422 .20474 .51227 .23641 .56363 .26154 .53593 .25229 Metetra
0 .372 .676 r
.53593 .25229 .56363 .26154 .61684 .26669 .59033 .27005 Metetra
.866 .995 .77 r
.59033 .27005 .61684 .26669 .66941 .21914 .64395 .20655 Metetra
.997 .806 .527 r
.64395 .20655 .66941 .21914 .71613 .08235 .6893 .00968 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(0)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(0.25)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0.5)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.75)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[183]:=",
  ImageSize->{202.938, 164.563},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003:0000Y2000`400?l00000o`00003obP3oool0
0<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3o
ool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00R@3oool5000003`0oooo002;0?oo
o`030000003oool0oooo03`0oooo002;0?ooo`030000003oool0oooo03`0oooo002;0?ooo`030000
003oool0oooo03`0oooo002;0?ooo`030000003oool0oooo03`0oooo002:0?ooo`800000?P3oool0
0<X0oooo003:0?ooo`00bP3oool008d0oooo0P00000k0?ooo`00R`3oool2000000030?ooo`000000
000003X0oooo001N0?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool00P3oool20000
01H0oooo0`0000030?ooo`800000>P3oool005d0oooo00@000000?ooo`3oool000002P3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool04@3oool3000000D0oooo00<00000
0?ooo`000000303oool2000000@0oooo0P0000030?ooo`@000007P3oool005d0oooo00@000000?oo
o`3oool000002P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00h0oooo0`000008
0?ooo`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`0000080?ooo`030000003o
ool0oooo01l0oooo001M0?ooo`040000003oool0oooo000000/0oooo00@000000?ooo`3oool0oooo
0P00000?0?ooo`<000002@3oool3000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool0
00002@3oool00`000000oooo0?ooo`0N0?ooo`00G@3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool02`3oool3000000`0oooo0`0000020?oo
o`040000003oool0oooo0?ooo`@000000P3oool010000000oooo0?ooo`00000:0?ooo`030000003o
ool0oooo01d0oooo001N0?ooo`8000002@3oool4000000<0oooo0`0000090?ooo`8000003`3oool2
000000040?o>QP000000oooo000000T0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000N0?ooo`00N@3oool300000140oooo0P0000001@3ocXH000000?ooo`3oool0000000T0
oooo0P00000:0?ooo`8000007`3oool007L0oooo0P00000C0?ooo`030000003ocXH000000080olj6
0P0000000`3oool000000?ooo`0d0?ooo`00M03oool3000000030?ooo`000000oooo0180oooo00H0
00000?o>QP3ocXH000000?o>QP0000020?ooo`030000003oool0oooo03<0oooo001a0?ooo`<00000
603oool01P000000olj60?o>QP000000olj6000000<0oooo00<000000?ooo`3oool0<P3oool004P0
oooo0P0000040?ooo`800000103oool2000001T0oooo0P0000020?ooo`030000003oool0oooo01H0
oooo00@000000?o>QP3ocXH000000P3ocXH01@000000oooo0?ooo`3oool0000003<0oooo00170?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000005@3oool3000001`0oooo00D0
00000?o>QP3ocXH0olj6000000020?o>QP050000003oool0oooo0?ooo`000000<`3oool004L0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0A0?ooo`80000000<0oooo0000003o
ool0703oool01@000000olj60?o>QP3ocXH000000080olj600<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0`0?ooo`00A`3oool010000000oooo0?ooo`0000090?ooo`8000004@3oool30000
0240oooo00T000000?o>QP3ocXH0olj60000003ocXH000000?cFV`000000103oool00`000000oooo
0?ooo`0_0?ooo`00A`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00h0oooo
0P0000000`3oool000000?ooo`0Q0?ooo`090000003ocXH0olj60?o>QP000000olj60000003leY/0
000000<0oooo0P00000a0?ooo`00B03oool2000000X0oooo0`00000;0?ooo`<000009@3oool00`00
0000olj60?o>QP020?o>QP030000003ocXH000000080o=JK00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0^0?ooo`00H03oool2000000030?ooo`000000oooo02D0oooo00<000000?o>QP3o
cXH00P3ocXH2000000<0o=JK00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`00
G@3oool3000002X0oooo00<000000?o>QP3ocXH00P3ocXH2000000<0o=JK00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0]0?ooo`00F`3oool2000000030?ooo`000000oooo02X0oooo00<0
00000?o>QP3ocXH00P3ocXH2000000@0o=JK00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0/0?ooo`00:@3oool2000000@0oooo0P0000030?ooo`@000000`3oool2000001/0oooo0`00000_
0?ooo`030000003ocXH0olj60080olj600<000000?cFV`3leY/00`3leY/00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo02`0oooo000X0?ooo`040000003oool0oooo000000P0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`00000H0?ooo`80000000<0oooo0000003oool00`3o
ool3000002P0oooo00<000000?o>QP3ocXH00`3ocXH00`000000o=JK0?cFV`040?cFV`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0:`3oool002P0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0oooo0`0000040?ooo`@0000000<0
U8c80000001AIlX00P00000V0?ooo`030000003ocXH0olj600<0olj600<000000?cFV`3leY/0103l
eY/00`000000oooo0?ooo`040?ooo`030000003oool0oooo02X0oooo000X0?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool00P3oool2000001@0oooo0P0000000`3oool000000?oo
o`020?ooo`8000001P2DS<P00`000000DFO:055WbP03000002<0oooo00<000000?o>QP3ocXH00P3o
cXH2000000D0o=JK0P0000050?ooo`800000;03oool002P0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0100oooo0`0000060?ooo`800000
1`2DS<P00`000000DFO:055WbP03055WbP8000008@3oool00`000000olj60?o>QP020?o>QP800000
1@3leY/00`000000lmff000000060?ooo`030000003oool0oooo02T0oooo000Y0?ooo`8000002P3o
ool2000000@0oooo0`00000>0?ooo`80000000<0oooo0000003oool01@3oool010000000_:K30;bV
``00000709B<b0030000001AIlX0DFO:00<0DFO:0P00000O0?ooo`030000003ocXH0olj600<0olj6
0P0000040?cFV`040000003cgKH0lmff000000L0oooo00<000000?ooo`3oool0:03oool004T0oooo
0`0000080?ooo`8000000`2lY/<00`000000U8c809B<b00509B<b0030000001AIlX0DFO:00@0DFO:
0P00000N0?ooo`030000003ocXH0olj60080olj600<000000?cFV`000000103leY/01@000000lmff
0??M]P3cgKH0000000H0oooo00<000000?ooo`3oool0:03oool004L0oooo0P0000000`3oool00000
0?ooo`070?ooo`030000002lY/<0_:K300@0_:K300<0000009B<b02DS<P01@2DS<P00`000000DFO:
055WbP03055WbP0300000000<kX0000001d0oooo00<000000?o>QP3ocXH00P3ocXH00`000000o=JK
000000030?cFV`030000003cgKH0lmff0080lmff00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0W0?ooo`00A03oool3000000/0oooo00<000000;bV``2lY/<01@2lY/<00`000000U8c809B<
b00509B<b0030000001AIlX0DFO:00@0DFO:00<00000000c^P000000703oool00`000000olj60?o>
QP020?o>QP040000003leY/0o=JK00000080o=JK00<000000??M]P3cgKH00`3cgKH00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02H0oooo00110?ooo`<000003@3oool00`000000_:K30;bV
``060;bV``030000002DS<P0U8c800H0U8c800<00000055WbP1AIlX00`1AIlX01000000003>j000c
^P00000J0?ooo`030000003ocXH0olj60080olj600L000000?cFV`3leY/0o=JK0000003leY/00000
00H0lmff00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`00903oool2000001T0
oooo0P00000?0?ooo`8000002@2lY/<00`000000U8c809B<b00509B<b0030000001AIlX0DFO:00@0
DFO:00@00000000c^P00<kX000006@3oool00`000000olj60?o>QP020?o>QP070000003leY/0o=JK
0?cFV`000000o=JK000000070??M]P030000003oool0oooo00@0oooo0P00000W0?ooo`008`3oool0
10000000oooo0?ooo`00000E0?ooo`<000000P3oool00`000000oooo0?ooo`0;0?ooo`040000003F
^l00e[_0000000P0_:K300<0000009B<b02DS<P01@2DS<P500000080DFO:00D00000000c^P00<kX0
03>j0000000H0?ooo`030000003ocXH0olj60080olj600@000000?cFV`3leY/0o=JK0P0000070??M
]P800000203oool00`000000oooo0?ooo`040?ooo`8000007P3oool002<0oooo00@000000?ooo`3o
ool000004`3oool300000180oooo00@000000=Jk`03F^l0000002@2lY/<00`000000U8c809B<b004
0000000309ZFcP000000Kh3D0080Kh3D10000003000c^P030000003oool0oooo01@0oooo00H00000
0=gna@00000000000?o>QP0000040?cFV`8000001P3cgKH010000000hMcA0>7Ld@0000070?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000007@3oool002<0oooo00@000000?ooo`3o
ool00000403oool3000001@0oooo00<000000=Jk`03F^l000P3F^l000`000000_:K30;bV``060;bV
``<000001P2JU/h00`000000Kh3D06n0e00306n0e0<000000P00<kX00`000000oooo0?ooo`0B0?oo
o`030000003Mo/D0gOk50080gOk50P0000040?cFV`030000003cgKH0lmff00@0lmff00D000000>7L
d@3Qg=40hMcA000000080?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000007@3o
ool002<0oooo00@000000?ooo`3oool000003P3oool3000001D0oooo00<000000=Jk`03F^l000`3F
^l000`000000_:K30;bV``040;bV``<00000202JU/h00`000000Kh3D06n0e00406n0e0030000000c
J]P0000000<000004`3oool00`000000gOk50=gna@020=gna@030000003DoMd0000000<0o=JK00<0
00000??M]P3cgKH00`3cgKH00`000000hMcA0>7Ld@020>7Ld@030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000M0?ooo`00903oool2000000`0oooo0`00
000G0?ooo`030000003F^l00e[_000D0e[_000<000000;bV``2lY/<00P2lY/<01@000000^:W:0;RY
bP2hZLX0000000P0VYK>00<0000006n0e01_P=@00`1_P=@010000000<f[H03=Zf00cJ]P400000100
oooo00<000000=gna@3Mo/D00P3Mo/D010000000e?gM0=Cmg@3DoMd4000000D0lmff00<000000>7L
d@3Qg=400`3Qg=400`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0K0?ooo`00<03oool3000001P0oooo00<000000=Jk`03F^l001P3F^l001@00
0000_:K30;bV``2lY/<0000000@0^:W:00<0000009ZFcP2JU/h01P2JU/h00`000000Kh3D06n0e004
06n0e0030000000cJ]P0<f[H0080<f[H00<00000000BU`0000003P3oool00`000000gOk50=gna@02
0=gna@030000003DoMd0e?gM00@0e?gM0P0000040??M]P030000003Qg=40hMcA00@0hMcA00<00000
0?ooo`3oool01P3oool2000000<0oooo0P00000N0?ooo`00;@3oool3000001/0oooo00<000000=Jk
`03F^l001`3F^l03000000H0^:W:00<0000009ZFcP2JU/h01P2JU/h00`000000Kh3D06n0e00306n0
e0030000000cJ]P0<f[H00<0<f[H0`00000<0?ooo`030000003Mo/D0gOk50080gOk500<000000=Cm
g@3DoMd00`3DoMd4000000<0lmff00<000000>7Ld@3Qg=401P3Qg=400`000000oooo0?ooo`060?oo
o`030000003oool0oooo0240oooo000[0?ooo`8000007@3oool00`000000e[_00=Jk`0080=Jk`003
0000002hZLX0^:W:00H0^:W:00<0000009ZFcP2JU/h01P2JU/h00`000000Kh3D06n0e00406n0e003
0000000cJ]P0<f[H00<0<f[H100000090?ooo`030000003Mo/D0gOk50080gOk500<000000=Cmg@3D
oMd00`3DoMd300000080ao;^00<000000??M]P0000002@3Qg=400`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0200oooo000Y0?ooo`8000007P3oool00`000000e[_00=Jk`0080=Jk`0800000
2@2hZLX00`000000VYK>09ZFcP0609ZFcP030000001_P=@0Kh3D00<0Kh3D00<0000003=Zf00cJ]P0
100cJ]P00`00000006;G00000003000000H0oooo00D000000=gna@3Mo/D0gOk5000000030=Cmg@<0
00001@37l^h2000000P0hMcA0P0000000`37dn<000000?ooo`080?ooo`030000003oool0oooo01l0
oooo000Y0?ooo`8000007@3oool00`000000iM31000000080=Jk`0040000003=_LX0cKg:000000P0
^:W:00<0000009ZFcP2JU/h01@2JU/h<000000<0<f[H00<00000001Re`00H]L01P0000000`3oool0
00000=gna@020=gna@030000003DoMd0000000<000001P37l^h4000000H0hMcA00D000000<OCh`37
dn<0am?S000000090?ooo`030000003oool0oooo01l0oooo000Y0?ooo`030000003oool0000001`0
oooo00@000000>G@`@3Ud<4000001P3F^l001@000000cKg:0<fmbP3=_LX0000000T0^:W:00<00000
09ZFcP2JU/h01000000209jOe@0300000025U=/0QICK00@0QICK00<0000006N?i@1WSnD02P000000
0`0UX^X0000000000008000000H0ao;^0P0000030;[Rl`800000103Qg=400`000000am?S0<OCh`03
0<OCh`030000003oool0oooo00L0oooo00<000000?ooo`3oool07P3oool002P0oooo0P0000020?oo
o`030000003oool0oooo01P0oooo00D000000>G@`@3Ud<40iM31000000050=Jk`0030000003=_LX0
cKg:00<0cKg:00<000000;RYbP2hZLX01P2hZLX3000000H0WYoE00<0000008FDf`25U=/01025U=/0
0`000000IhoU06N?i@0506N?i@030000001@VO80D9Wb00T00000101Z`_h200000080ao;^0P000006
0;[Rl`80000000<0hMcA0000000000001`37dn<00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01d0oooo00080?ooo`8000000`3oool01P000000oooo0?ooo`3oool000000?ooo`D000000P3o
ool2000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003U
d<40iM3100<0iM3100D000000=Jk`03F^l00e[_0000000060<fmbP030000002hZLX0^:W:00@0^:W:
0P0000000`2c[M<0000009jOe@0709jOe@0300000025U=/0QICK00@0QICK00<0000006N?i@1WSnD0
1@1WSnD00`000000D9Wb052IlP02052IlP<00000201Z`_h3000000P0^^;c0`0000090<OCh`030000
003oool0oooo00H0oooo0P00000O0?ooo`001`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0
oooo0P0000040?ooo`030000003oool0oooo01D0oooo00<000000>G@`@3Ud<40103Ud<400`000000
e[_0000000080<fmbP040000002hZLX0^:W:0;RYbP8000000`2c[M<00`000000WYoE09jOe@0609jO
e@0300000025U=/0QICK00D0QICK00<0000006N?i@1WSnD01@1WSnD400000080D9Wb0P00000306[2
oP@000000P2>bO`00`000000^^;c0;[Rl`050;[Rl`<0000000<0/=;b00000037dn<01`37dn<20000
00T0oooo00<000000?ooo`3oool0703oool000X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?oo
o`8000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003Ud<40iM3100H0iM3100<000000<fm
bP3=_LX01`3=_LX010000000^:W:0000000000060;>]d`030000002NWmD0WYoE00H0WYoE00<00000
08FDf`25U=/01025U=/00`000000IhoU06N?i@0306N?i@d000001`2>bO`200000080^^;c0`000003
0;3BlP8000001P37dn<200000080//OZ00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K
0?ooo`0000<0oooo0000000000000P0000030?ooo`800000103oool00`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`<000001@3oool2
00000180oooo00<000000>G@`@3Ud<401P3Ud<400`000000fm7>000000090<fmbP030000002c[M<0
/jgC00L0/jgC00<0000009jOe@2NWmD01@2NWmD00`000000QICK08FDf`0208FDf`P000001027Y^T0
0`000000P;7d082am004082am0030000002>bO`0S/Wl00L0S/Wl0`0000070;3BlP8000000P37dn<3
000000@0//OZ00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0K0?ooo`00203oool00`00
0000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool3000000L0oooo00<000000?ooo`3oool03`3o
ool00`000000iM310>G@`@050>G@`@040000003KdLh0fm7>000000L0cKg:0P0000000`34_]@00000
0;>]d`080;>]d`030000002NWmD0WYoE00@0WYoE1@00000209FUh@<000002027Y^T00`000000P;7d
082am004082am08000000`2>bO`400000080W/Od00<000000;3BlP2`d_801@2`d_84000000P0//OZ
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`00203oool3000000T0oooo0P00
00040?ooo`800000203oool00`30`<00/;2`092@T003000000030>jB:0000000oooo00H0oooo00<0
00000?ooo`3oool03@3oool00`000000iM310>G@`@050>G@`@030000003KdLh0fm7>0080fm7>00<0
00000<fmbP3=_LX00`3=_LX01@000000a;kD0<Bne034_]@0000000T0/jgC00<0000009jOe@2NWmD0
100000020:>Yg0030000002EYN40UJGQ008000000P2EYN400`000000QjKY08NVj@0608NVj@030000
0020/O@0P;7d00D0P;7d1000000609k7m0030000002`d_80/=;b00@0/=;b0`0000000`2Zanh00000
0;;7jP070;;7jP030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool002@0oooo00P0
X:2P0?ooo`30`<0000000?ooo`000000kY8X000000P0oooo00<000000?ooo`3oool02`3oool00`00
0000iM310>G@`@050>G@`@030000003KdLh0fm7>00@0fm7>00D000000<fmbP3=_LX0cKg:00000005
0<Bne0030000002c[M<0/jgC00L0/jgC0P0000060:>Yg0<000001@2EYN400`000000QjKY08NVj@06
08NVj@0300000020/O@0P;7d00@000000P2H^o000`000000W/Od09k7m00609k7m0030000002`d_80
/=;b00<000000`2Zanh00`000000Z/O^000000070;;7jP800000203oool2000001/0oooo000N0?oo
o`040>3Ph020P800P8200820P080oooo00@0H61P092@T02PX:0000000P3oool00`000000kY8X0000
00080?ooo`030000003oool0oooo00X0oooo00<000000>G@`@3Ud<401@3Ud<400`000000fm7>0=_A
cP040=_AcP040000003=_LX00000000000H0a;kD00<000000;>]d`2c[M<01@2c[M<2000000030:nb
f`000000XjWL0080XjWL0`0000000`2SZM`0000009FUh@0609FUh@0300000027Y^T0QjKY00D0QjKY
0`00000709Rkl0030000002Nao@0W/Od00D0W/Od0`0000060:[7kP030000002Zanh0000000D0//OZ
0P0000020:W1j`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool002@0oooo00<0
X:2P0?ooo`3oool00P000000103oool000000>jB:00000090?ooo`030000003oool0oooo00P0oooo
00<000000>G@`@3Ud<401@3Ud<400`000000fm7>0=_AcP060=_AcP0300000034_]@0a;kD00L0a;kD
00<000000;>]d`2c[M<00P2c[M<2000000<0[k;K100000040:>Yg0030000002EYN40UJGQ00D0UJGQ
00@0000008NVj@27Y^T0QjKY1000000209ZdjP030000002H^o00V;_`00H0V;_`00<0000009k7m02N
ao@0100000020:G3k`030000002Zanh0Z/O^00D0Z/O^00<000000:[7kP0000000P2banX2000000D0
ZL7[00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0H0?ooo`009@3oool00`2PX:00/;2`
000000020?ooo`040000003^TRP0kY8X000000T0oooo00<000000?ooo`3oool01P3oool010000000
j^O<0000000000040>G@`@030000003KdLh0fm7>00H0fm7>00<000000<o@fP0000002034_]@00`00
0000/jgC0;>]d`02000000<0[k;K100000070:>Yg0030000002EYN40UJGQ00@0UJGQ1000000609Zd
jP030000002H^o00V;_`00H0V;_`0`0000070:G3k`030000002Zanh0Z/O^00D0Z/O^100000070:W1
j`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool002L0oooo00@000000?ooo`3o
ool000000P3^TRP00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000>[W
c03Zil`00P3Zil`2000000030>G@`@000000fm7>00L0fm7>00@000000<o@fP3?d=X000002@34_]@2
00000080[k;K0`0000030:nbf`030000002SZM`0XjWL00D0XjWL00<0000009FUh@2EYN4010000002
09nai@030000002J]>X0V[CZ00H0V[CZ00<0000009Rkl02H^o000`2H^o0200000080Xko]00<00000
0:G3k`2U`nl01P2U`nl010000000Z/O^0:[7kP2Zanh5000000030:S1k0000000ZL7[00L0ZL7[00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`009P3oool200000080oooo00D00000
0>jB:03^TRP0kY8X0000000:0?ooo`030000003oool0oooo00<0oooo00<000000>[Wc03Zil`0103Z
il`00`000000fm7>0=_AcP050=_AcP800000103?d=X00`000000a;kD0<Bne0040<Bne080000000@0
^[kM00000000000000001`2_/]/00`000000XjWL0:>Yg0040:>Yg0<000001`2O/ND00`000000V[CZ
09ZdjP0509ZdjP030000002H^o00V;_`00<00000102S_nd00`000000YL?_0:G3k`060:G3k`@00000
102X`N`00`000000Z<7/000000080:W1j`800000203oool00`000000oooo0?ooo`0F0?ooo`009P3o
ool00`000000oooo0?ooo`020?ooo`040000003^TRP0kY8X000000/0oooo00D000000?ooo`3oool0
oooo000000060>[Wc0040000003Ni]X00000000000@0fm7>00<000000<o@fP3?d=X01@3?d=X01000
0000a;kD0<Bne034_]@5000000030;Zng@000000[k;K00L0[k;K00<000000:>Yg02SZM`010000002
0:FchP030000002O/ND0Wk7U00D0Wk7U00<0000009ZdjP2J]>X01@2J]>X3000000P0Xko]00<00000
0:G3k`2U`nl00`2U`nl200000080Yl3/00<000000:S1k02X`N`0102X`N`00`000000Z<7/00000003
0:W1j`@000000P2W`N`00`000000oooo0?ooo`050?ooo`8000005`3oool002H0oooo0P0000030?oo
o`030000003^TRP0kY8X008000002`3oool00`000000oooo000000060>[Wc0030000003Ni]X0g^KJ
0080g^KJ0P0000000`3KdLh000000<o@fP070<o@fP0300000034_]@0000000<00000102j_]d00`00
0000[k;K0:nbf`060:nbf`<000001`2U/n800`000000Wk7U09nai@0509nai@030000002J]>X0V[CZ
00@000000P2S_>/00`000000Xko]0:>ok@060:>ok@030000002U`nl0YL?_00<00000102W`>`00`00
0000Z<7/0:S1k0050:S1k0D000001P2W`N`00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`8000000`3oool400000080oooo000P0?ooo`800000103oool00`000000
oooo0?ooo`020?ooo`050000003^TRP0kY8X0>jB:0000000303oool00`000000j^O<0>[Wc0040>[W
c0030000003Ni]X0g^KJ00D0g^KJ00<000000<o@fP3?d=X0203?d=X3000000L0^[kM00<000000:nb
f`2_/]/00`2_/]/200000080[;SR00<000000:FchP2U/n801@2U/n800`000000Wk7U09nai@0509na
i@<000001`2S_>/00`000000Xko]0:>ok@050:>ok@<00000202W`>`00`000000Z<7/0:S1k0030:S1
k0<0000000<0Yl7/0000002W`N`01`2W`N`00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`007`3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0oooo0080oooo00@000000>jB:03^TRP0kY8X0P00
000:0?ooo`030000003Zil`0j^O<00@0j^O<00<000000=kVfP3Ni]X01@3Ni]X00`000000c^7U0000
00060<o@fP<0000000<0`<cS0000002j_]d0202j_]d00`000000[k;K0:nbf`02000000D0[;SR00<0
00000:FchP2U/n801@2U/n800`000000Wk7U09nai@0400000080YK[X00<000000:>lj`2S_>/01P2S
_>/00`000000Xko]0:>ok@0400000080Yl3[00<000000:O0k02W`>`01P2W`>`00`000000Z<7/0:S1
k00300000080Yl7/00<000000:O1k0000000202W`N`2000000P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool001l0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`050000003^TRP0kY8X0>jB:000
00002P3oool00`000000j^O<0>[Wc0030>[Wc0030000003Ni]X0g^KJ00D0g^KJ00D000000<kQi@3>
hND0c^7U000000020<o@fP@000001030c><00`000000^[kM0;Zng@060;Zng@<000001`2/^>800`00
0000YK?R0:FchP050:FchP<000001`2U^^P00`000000Xkc[0:>lj`050:>lj`<000001`2W`>/00`00
0000Yl3/0:O0k0050:O0k0<000001P2W`N`00`000000Yl7/000000050:O1k08000000P2U`nl00`00
0000oooo0?ooo`060?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`010?ooo`007`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo00@0oooo00@000000>jB:03^TRP0kY8X0P0000080?ooo`030000003Zil`0j^O<00<0j^O<00<0
00000=kVfP3Ni]X0103Ni]X2000000@0c^7U1@0000070<3<h`030000002j_]d0^[kM00<0^[kM0P00
00020;6oi0030000002/^>80[;SR00H0[;SR00<000000:FchP2U/n80100000020:Nki`030000002U
^^P0YK[X00H0YK[X00<000000:>lj`2S_>/0100000020:Noj`030000002W`>/0Yl3[00H0Yl3[00<0
00000:O0k02W`>`0100000020:O1k0030000002W`N`0Yl7/00D0Yl7/0P0000020:O1k0<00000102U
`nl00`000000oooo0?ooo`060?ooo`80000000D0oooo0000003oool0oooo000000080?ooo`040000
003oool0oooo00000080oooo000O0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0103oool200000080kY8X00<000000<UQ000000001P3oool8000000D0g^KJ00@000000<kQi@3>
hND0c^7U0`0000020<kQi@0300000030c><0`<cS00P0`<cS00<000000;Zng@2j_]d00P0000050;6o
i0030000002/^>80[;SR00D0[;SR0`0000070:Nki`030000002U^^P0YK[X00D0YK[X0`0000070:No
j`030000002W`>/0Yl3[00D0Yl3[0`0000070:O1k0030000002W`N`0Yl7/00D0Yl7/0`0000080:G3
k`030000003oool0oooo00D0oooo0P0000020?ooo`8000002P3oool2000000<0oooo000P0?ooo`80
00000`3oool2000000H0oooo0`000000103^TRP000000<UQ000000030?ooo`800000102ln^/20000
0080]o;d0P0000020=kVfP030000003>hND00000008000000`3>hND2000000030;kGk0000000`<cS
00P0`<cS0`0000070;6oi0030000002/^>80[;SR00<0[;SR0P0000020:Vlj0030000002W^nL0Yk_W
00D0Yk_W00<000000:Fjj02U^^P00`2U^^P200000080Yko[00<000000:Noj`2W_n/01P2W_n/00`00
0000Yl3[0:O0j`0400000080Yl3[00<000000:O1k02W`N`01P2W`N`00`000000Yl7/0:O1k0050000
00030:K7l0000000YL?_00L0YL?_00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?oo
o`009@3oool00`000000oooo0?ooo`060?ooo`030000002I1`00000000<000000P3oool00`000000
_?[[0;cjj`020;cjj`8000001P2gl_@4000000@0c^7U0P0000040;kGk08000001@30c><200000080
/lOX00<000000;6oi02a_n@01P2a_n@00`000000[;SR0:bhhP02000000D0ZKcX00<000000:Nki`2W
^nL01@2W^nL00`000000YK[X0:Fjj002000000@0Yko[00<000000:Noj`2W_n/01P2W_n/3000000H0
Yl3[00<000000:O1k02W`N`01P2W`N`3000000D0Y/O`0P0000080:G3k`800000203oool00`000000
oooo0?ooo`0@0?ooo`009@3oool00`000000oooo0?ooo`070?ooo`8000000P2I1`03000000<0_?[[
0P0000060;Obm0<0000000<0/^Kh0000000000000P3>hND2000000P0_]O/00<000000<3<h`30c><0
0P0000050;?7j0030000002a_n@0/KoT00D0/KoT0`0000070:Vlj0030000002W^nL0Yk_W00D0Yk_W
0`0000070:Noj`030000002W_n/0Yko[00<0Yko[0P0000020:Noj`030000002W`>/0Yl3[00D0Yl3[
00@000000:O1k02W`N`0Yl7/100000020:O5k`030000002Vao00Y/O`00@0Y/O`0P0000030:G3k`@0
000000<0U<Gh0000003oool0203oool00`000000oooo0?ooo`0?0?ooo`009@3oool00`000000oooo
0?ooo`090?ooo`030000002I1`00000000H000001@2gl_@3000000D0/^Kh0P00000:0;kGk0<00000
202canP00`000000/KoT0;6oi00400000080ZkoY00<000000:Vlj02Y_>P01P2Y_>P00`000000Yk_W
0:Nki`0400000080Yko[00<000000:Noj`2W_n/01@2W_n/00`000000Yko[0:Noj`03000000@0Yko[
00<000000:O0j`2W`>/01@2W`>/4000000H0YlG_00<000000:K7l02Vao00102Vao05000000H0U<Gh
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`00903oool00`000000oooo0?oo
o`0;0?ooo`d000001`2bi_P2000000030:gImP000000000000H0_]O/0P0000020;;=kP030000002c
anP0/lOX00H0/lOX0`0000070:^oj@030000002Y_>P0ZKcX00D0ZKcX0`0000060:Noj`030000002W
_n/0Yko[00D0Yko[0`0000080:Noj`030000002W`>/0Yl3[00@000000P2X`N`00`000000YlG_0:O5
k`060:O5k`030000002Vao00Y/O`00D0000000<0W]?j0000002DaOP01P2DaOP00`000000oooo0?oo
o`060?ooo`800000403oool002@0oooo00<000000?ooo`3oool03`3oool6000000<0AZ_h0P000003
0;;Vn08000001@2]fOH200000080_]O/0P0000050;;=kP030000002canP0/lOX00<0/lOX0P000002
0:_2j`030000002[_nT0ZkoY00H0ZkoY00<000000:Vlj02Y_>P0100000020:Roj`030000002W_n/0
Yko[00D0Yko[00<000000:Noj`2W_n/0100000020:Noj`030000002W_n/0Yko[00H0Yko[0`000006
0:S1k0030000002WaNl0YlG_00H0YlG_0`00000509kCnP030000002NdoX0000000L0U<Gh00@00000
0?ooo`3oool0oooo100000000`3oool000000?ooo`0?0?ooo`00903oool200000100oooo1@000004
04J[n0D00000202]fOH3000000P0//g^00<000000;?7j02canP00P0000050:_2j`030000002[_nT0
ZkoY00D0ZkoY0`0000060:Roj`030000002W_n/0Yko[00D0Yko[0`0000070:Noj`030000002W_n/0
Yko[00<0Yko[0P0000020:Rmj0030000002X`N`0Z<7/00D0Z<7/00@000000:O5k`2WaNl0YlG_1000
00020:S@m@800000102NdoX7000000<0U<Gh100000050?ooo`030000003oool0oooo00h0oooo000T
0?ooo`030000003oool0oooo00`0oooo0`000000103oool0000003akh`0lNn<5000000@0P/3k0P00
00030:gImP@000000P2ZcO800`000000//g^0;;=kP060;;=kP<00000202[`^/00`000000ZkoY0:^o
j@0400000080Z<3[00<000000:Roj`2X_n/01@2X_n/00`000000Yko[0:Noj`0400000080Yko[00<0
00000:Noj`2W_n/01P2W_n/00`000000Yko[0:Noj`02000000@0Z;gX00<000000:S1k02X`N`01@2X
`N`4000000L0Z=3e1@000000101_eoP0000006oGn01_eoP20000000304:Xm`000000000000@00000
1P3oool00`000000oooo0?ooo`0>0?ooo`000`3oool2000000<0oooo00H000000?ooo`3oool0oooo
0000003oool500000080oooo0P00000=0?ooo`8000002P3oool3000000D0oooo00@0000003akh`0l
Nn<0?7_S0P00000708;0n`<000001`2ZcO8200000080//g^100000020:_5k@030000002[`^/0Zl;[
00H0Zl;[0`0000070:S0j`030000002X_n/0Z;o[00@0Z;o[0`0000070:Noj`030000002W_n/0Yko[
00D0Yko[0`0000070:Rmj0030000002X`N`0Z<7/0080Z<7/0P0000020:c4j`030000002Xd?D0Z=3e
00@0Z=3e0P0000020:WSnPX000001012Z?L00`000000iX0n000000060?ooo`030000003oool0oooo
00d0oooo00020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`07
0?ooo`8000002@3oool00`000000?7_S03akh`0203akh`8000000P22`?/300000080V/?d0P000007
0:[=lP<000001`2[aNd00`000000Zl;[0:_2j`030:_2j`8000000P2X`>/00`000000Z<3[0:S0j`06
0:S0j`030000002X_n/0Z;o[00<000000P2W_n/00`000000Yko[0:Noj`060:Noj`030000002W_n/0
Yko[00@000000P2X^^L00`000000Z;gX0:Rmj0050:Rmj0030000002X`N`0Z<7/008000001@2/a>/2
00000080Z=3e0P0000030:WSnP@0000000<0b?g20000000000000P0000020?ooo`0300000012Z?L0
@ZSg0080@ZSg0P0000060?ooo`030000003oool0oooo00d0oooo00050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`050?ooo`<00000303oool8000000L0V/?d0P000002
0:[=lP<000000P2XaNh00`000000ZlG]0:_5k@060:_5k@030000002[`^/0Zl;[008000001@2X`>/0
0`000000Z<3[0:S0j`050:S0j`<000001P2W_n/00`000000Yko[0:Noj`050:Noj`<000001P2X^^L0
0`000000Z;gX0:Rmj0050:Rmj0<00000202/a>/3000000<0ZN?j0P0000000`2Om>/0000000000002
000000<0oooo00@000000?ooo`3oool0oooo0P00000204:Xm`8000001P3oool00`000000oooo0?oo
o`0=0?ooo`000`3oool2000000@0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool2000000<0oooo0`00000@0?ooo`0300000022
Z>d0PZS]00<0PZS]00<0000009[3m02J`o@01P2J`o@3000000H0Z<G^0P0000060:_5k@<00000202X
`>/00`000000Z<3[0:S0j`0400000080Yko[00<000000:Noj`2W_n/01@2W_n/00`000000Yko[0:No
j`0400000080Yk[V00<000000:Rji`2X^^L01@2X^^L00`000000Z;gX0:Rmj00400000080[;WS00<0
00000:c4j`2/a>/0102/a>/200000080^<_Y00D000000:WSnP000000000009odj`05000000@0oooo
00<000000?ooo`3oool00P3oool200000080@ZSg0P0000050?ooo`030000003oool0oooo00d0oooo
00030?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`D00000503oool00`000000
PZS]08:Xk@0308:Xk@8000000P2J`o@400000080Y<7^00<000000:S5kP2XaNh01P2XaNh00`000000
ZlG]0:_5k@0300000080Z<7[00<000000:S0j`2X`>/01P2X`>/3000000H0Yko[00<000000:Noj`2W
_n/01@2W_n/3000000H0Yk[V00<000000:Rji`2X^^L01@2X^^L3000000L0[;WS0P0000020:c4j`80
00001@2hbnT6000000030?7J^0000000oooo00D0oooo00<000000?ooo`3oool00P3oool200000003
04:Xm`000000000000D0oooo00<000000?ooo`3oool03@3oool000<0oooo0`0000090?ooo`800000
103oool2000000`0oooo0P00000G0?ooo`0300000022Z>d0PZS]00@0PZS]0`0000070:C1kP030000
002XaNh0Z<G^00D0Z<G^0`0000060:S1j`030000002X`>/0Z<3[00<0Z<3[0P0000020:O0j`030000
002W_n/0Yko[00D0Yko[00<000000:Noj`2W_n/0100000020:Nki`030000002W^^H0Yk[V00D0Yk[V
00<000000:Rji`2X^^L0100000020:ZbgP030000002/^N<0[;WS00L0[;WS0P0000060;S;j@040000
003;dn40bm?Q00000080h=[@00<000000?7J^00000001`3oool00`000000oooo0?ooo`020?ooo`D0
0000103oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`30`<00/;2`092@T0020?ooo`030000
003oool0oooo01H0oooo00<0000008:Xk@22Z>d00`00000209fik0030000002T`Nh0Y<7^00H0Y<7^
00<000000:S5kP2XaNh0100000020:O1k0030000002X`N/0Z<7[00D0Z<7[00<000000:S0j`2X`>/0
0P0000050:O0j`030000002W_n/0Yko[00@0Yko[0`0000070:Nki`030000002W^^H0Yk[V00D0Yk[V
0P0000070:ZbgP030000002/^N<0[;WS00@0[;WS0P0000000`2d]MT000000;S;j@040;S;j@040000
003;dn40bm?Q00000080h=[@00<000000?7J^0000000203oool00`000000oooo0?ooo`020?ooo`03
000000240000Q00000800000103oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`2PX:00oooo
0<30`0030?ooo`8000005`3oool2000000H0WKW/0P0000060:C1kP<000001`2W`N`00`000000Z<7[
0:S1j`040:S1j`<00000202W`>/00`000000Yko[0:Noj`0300000080YkkZ00<000000:Nki`2W^nL0
1@2W^nL00`000000Yk[V0:NjiP030:NjiP80000000<0Z;3N0000002Z/]h01P2Z/]h00`000000[;WS
0:bih`020:bih`8000000`2d]MT010000000^<_Y0;S;j@2hbnT2000000<0bm?Q00H000000>3Jd03P
f]0000000?7J^00000090?ooo`030000003oool0oooo0080oooo00@0000008@00000000000001@3o
ool00`000000oooo0?ooo`0<0?ooo`006@3oool0103Ph>00P8200820P020P8020?ooo`03061PH02@
T900X:2P00D0oooo00<000000?ooo`3oool05@3oool00`000000WKW/09fik00609fik0030000002T
`Nh0Y<7^00<000000P2W`>`00`000000Yl7/0:O1k0060:O1k0030000002X`N/0Z<7[00<000000P2W
`N`00`000000Yl3[0:O0j`060:O0j`<000001P2W_^X00`000000Yk_W0:Nki`050:Nki`030000002W
^^H0Yk[V00800000102X/=h00`000000Z[;N0:ZbgP050:ZbgP040000002/^N<00000000000H0];GI
00<000000;S;j@000000103;dn401P000000h=[@0>3Jd0000000lMZh000000/0oooo00D000000?oo
o`3oool0oooo0000000208@000800000103oool00`000000oooo0?ooo`0<0?ooo`007`3oool00`2P
X:00oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<0000009fik02M^N`01@2M^N`30000
00H0Yl3/00<000000:O1k02W`N`01@2W`N`3000000H0Yl7/0P0000020:O0j`@000000P2W`^d00`00
0000YkkZ0:NnjP050:NnjP030000002W^nL0Yk_W0080Yk_W1@0000060:R`gP030000002Z/]h0Z[;N
00D0Z[;N0P0000090;Bef@030000003;dn40bm?Q0080bm?Q00L000000>3Jd03Pf]00h=[@0000003a
f[P0000000`0oooo00H000000?ooo`3oool0oooo000000240002000000@0oooo00<000000?ooo`3o
ool0303oool00200oooo00<0X:2P0;2`/03oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000
002M^N`0WKW/00@000000P2V_n/00`000000Yl3/0:O0k0050:O0k0030000002W`N`0Yl7/00@00000
0P2W`N`00`000000Yl7/0:O1k0050:O1k0<000001P2W`^d00`000000YkkZ0:NnjP050:NnjPD00000
102V/^400`000000Z;3N0:R`gP050:R`gP030000002Z/]h0Z[;N00@000000P2]Z=800`000000];GI
0;Bef@040;Bef@80000000D0_[3<0000003;dn40bm?Q000000030>3Jd0040000003af[P0lMZh0000
00`0oooo00<000000?ooo`3oool00P3oool3000000@0oooo00<000000?ooo`3oool0303oool002X0
oooo0P00000F0?ooo`8000001`2V_n/00`000000Yl3/0:O0k0040:O0k0<000001`2W`N`200000080
Yl7/0`0000020:K5k`030000002W`^d0Yl;]00D0Yl;]00<000000:NnjP2W_^X0100000020:Bij003
0000002V/^40Y[;Q00@0Y[;Q00<000000:R`gP2X/=h01@2X/=h3000000H0[JSB00<000000;Bef@2d
]MT00`2d]MT00`000000_[3<0;j`c0020;j`c0030000003;dn40000000<0h=[@00<000000?7J^000
00003P3oool01P000000oooo0?ooo`3oool0000008@0008000000`3oool00`000000oooo0?ooo`0<
0?ooo`00;03oool00`000000oooo0?ooo`0D0?ooo`030000002V_n/0Y[o[00H0Y[o[00<000000:O0
k02W`>`00`0000020:O0k0030000002W`N`0Yl7/00H0Yl7/0`0000060:K5k`030000002W`^d0Yl;]
00@0Yl;]0`0000060:Bij0030000002V/^40Y[;Q00D0Y[;Q00<000000:R`gP2X/=h00P2X/=h20000
00030:NSdP000000[JSB00L0[JSB00D000000;Bef@2d]MT0];GI000000060;j`c0050000003Pf]00
h=[@0>3Jd00000000P3af[P00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo0?ooo`<00000
0`3oool00`000000oooo0?ooo`0<0?ooo`00;@3oool00`000000oooo0?ooo`0D0?ooo`8000001P2V
_n/3000000H0Yl3/0P0000020:O1k0@000000P2Wa_000`000000Y/G_0:K5k`050:K5k`030000002W
`^d0Yl;]00<000000P2Ra?400`000000Y;WX0:Bij0050:Bij0030000002V/^40Y[;Q00@0Y[;Q00<0
00000:R`gP2X/=h00P0000040:NSdP030000002]Z=80[JSB00D0[JSB00@000000;Bef@0000000000
1P2n/<`020000000b:bm000000000000h=[@0000003af[P000004@3oool00`000000oooo0?ooo`02
000000050>J0?P000000oooo0?ooo`0000003P3oool002h0oooo00<000000?ooo`3oool05@3oool0
0`000000Y[o[0:Joj`0300000080Yko[00<000000:O0k02W`>`01@2W`>`3000000H0YlK`00<00000
0:K5k`2VaNl01@2VaNl3000000H0X/Ca00<000000:Bij02T^NP0102T^NP00`000000Y[;Q0:Jbh@02
0:Jbh@D000001P2WXm800`000000[JSB0:fXdP050:fXdP8000001`2n/<`00`000000b:bm0<R/_@02
0<R/_@040000003af[P0lMZh00000140oooo00@000000?ooo`3oool0oooo0`0000030?ooo`030000
003oool0oooo00/0oooo000_0?ooo`8000005P3oool2000000H0Yko[0P0000020:O0k0<000000P2X
`nd00`000000YlK`0:O6l0050:O6l0030000002VaNl0Y/G_00@000000P2OcOL00`000000X/Ca0:;4
l@050:;4l@030000002T^NP0Y;WX0080Y;WX1P0000040::Vf@030000002WXm80Yj?B00D0Yj?B00<0
00000:fXdP2]Z=800P2]Z=8200000080/Ik400<000000;j`c02n/<`00`2n/<`00`000000b:bm0<R/
_@020<R/_@040000003AZK000000000001<0oooo00<000000?ooo`3oool00`0000030?ooo`030000
003oool0oooo00/0oooo000a0?ooo`030000003oool0oooo01@0oooo00<000000:Noj`2W_n/01@2W
_n/3000000H0Z<?]00<000000:O6l02Wa_00102Wa_03000000L0Wlgg0P0000040:;4l@H000000`2J
/>L00`000000XZKI0::Vf@040::Vf@030000002WXm80Yj?B00D0Yj?B00<000000:fXdP2]Z=800P00
00040;6Na0030000002n/<`0_[3<0080_[3<00<000000<R/_@38[;d00`38[;d010000000dJV`0=6Y
/000000D0?ooo`060000003oool0oooo0000003VP3h000000P3oool00`000000oooo0?ooo`0;0?oo
o`00<P3oool00`000000oooo0?ooo`0D0?ooo`8000000P2W_n/300000080ZK_V00<000000:S3k@2X
`nd01@2X`nd00`000000YlK`0:O6l00300000080X]7h0P00000509o=m`L000000`2>`oT00`000000
V[3W09Z`i`0309Z`i`030000002RY]T0XZKI00D0XZKI00<000000:NSdP2WXm801@2WXm82000000L0
/Ik400@000000;j`c02n/<`000001@38[;d01@000000dJV`0=6Y/03AZK00000001D0oooo00<00000
0?ooo`0000000P0000020?ooo`030000003oool0oooo00/0oooo000c0?ooo`030000003oool0oooo
01D0oooo0P0000060:VkiP030000002X`nd0Z<?]00@0Z<?]0`0000070:;An0D00000101mdol00`00
0000S/?i08k3n@0308k3n@030000002J/>L0V[3W00@0V[3W00<000000::Vf@2RY]T01@2RY]T00`00
0000Yj?B0:NSdP020:NSdP<00000202aW/@00`000000_[3<000000060<R/_@040000003AZK00dJV`
000001H0oooo00<000000?ooo`0000000P0000020?ooo`030000003oool0oooo00/0oooo000d0?oo
o`030000003oool0oooo01D0oooo00<000000:VkiP2Y^nH01@2Y^nH00`000000Z<?]0:S3k@030000
0080Zl[`0P0000030:;An0<000000P29god2000000H0OM?o00<0000008k3n@2>`oT00`2>`oT00`00
0000V[3W09Z`i`0409Z`i`030000002RY]T0XZKI00@0XZKI00<000000:NSdP2WXm800P0000030:JF
a@030000002aW/@0/Ik400H0/Ik400<000000<R/_@38[;d01038[;d01@000000dJV`0=6Y/03AZK00
000001L0oooo00L000000?ooo`000000iX0n0000003oool0000000d0oooo000e0?ooo`8000005P3o
ool00`000000ZK_V0:VkiP040:VkiP<000001`2[b_03000000H0RMom2`00000208k3n@030000002J
/>L0V[3W00@0V[3W00<000000::Vf@2RY]T00P2RY]T5000000D0YYK500<000000;6Na02aW/@01@2a
W/@00`000000]YNh000000050<R/_@050000003AZK00dJV`0=6Y/0000000603oool400000080oooo
00<000000?ooo`3oool02P3oool003L0oooo00<000000?ooo`3oool0503oool00`000000ZK_V0:Vk
iP0300000080/;?K00<000000:_:l02[b_00102[b_0200000080]=Kb1`0000030>gfa@030000003o
ool0oooo018000000`2JU/h00`000000YYK50:JFa@050:JFa@030000002aW/@0/Ik400<0/Ik400@0
00000;JG^02fUkP000001038[;d00`000000dJV`0=6Y/0020=6Y/0030000003oool0oooo01H0oooo
00L000000?ooo`000000iX0n0000003oool0000000`0oooo000h0?ooo`030000003oool0oooo01@0
oooo0P0000060;2cf`8000000P2[b_02000000@0]=Kb0P0000001P35iNh000000=_cg`3Klml00000
0>gfa@8000001`3oool200000080BZgi00<0000008JPi@26X>D00`26X>D00`000000VYK>09ZFcP05
09ZFcP030000002VU/D0YYK500@0YYK500<000000;6Na02aW/@00P2aW/@00`000000]YNh0;JG^002
0;JG^00500000038[;d0b:bm0<R/_@0000000`3AZK000`000000oooo0?ooo`0H0?ooo`80000000@0
iX0n0000003oool00000303oool003T0oooo00<000000?ooo`3oool0503oool00`000000/;?K0;2c
f`060;2cf`8000001@2de_8010000000aNG^0<GUkP0000020=_cg`030000003]m/D0000000/0oooo
0P0000000`1:[OT0000008JPi@0408JPi@030000002JU/h0VYK>00@0VYK>00<000000:JFa@2VU/D0
1@2VU/D010000000/Ik40;6Na00000050;JG^00400000038[;d0b:bm000000@0dJV`00<000000?oo
o`3oool06@3oool3000000030?ooo`000000oooo00/0oooo000j0?ooo`8000005@3oool00`000000
/;?K0;2cf`030;2cf`80000000<0^jc;0000000000000P2de_8200000080aNG^00H000000=_cg`3K
lml000000>gfa@00000>0?ooo`8000001@26X>D00`000000VYK>09ZFcP0409ZFcP030000002VU/D0
YYK500D0YYK500<000000;6Na00000001`2fUkP00`000000b:bm000000040=6Y/0030000003oool0
oooo01X0oooo00@000000>J0?P0000000000303oool003`0oooo00<000000?ooo`3oool04P3oool0
0`000000/;?K0;2cf`020;2cf`030000002k[</0^jc;00<0^jc;0`0000020<GUkP040000003Klml0
fo?O0=_cg`<000003`3oool2000000D0QZ3U00<0000009ZFcP2JU/h0102JU/h00`000000YYK50:JF
a@040:JFa@800000202fUkP2000000D0dJV`00<000000?ooo`3oool06P3oool010000000iX0n0000
0000000<0?ooo`00?@3oool00`000000oooo0?ooo`0B0?ooo`040000002`/m/00000000000H0^jc;
00<000000<FV^@35Y[T01P0000020>>cY0030000003oool0oooo00h0oooo0`00000308JPi@030000
002JU/h0VYK>00@0VYK>00<000000:JFa@2VU/D00P2VU/D2000000030:J<^@000000]YNh00P0]YNh
00<000000=6Y/03AZK000P3AZK000`000000oooo0?ooo`0L0?ooo`<00000303oool003h0oooo00<0
00000?ooo`3oool04P3oool00`000000^jc;0;^/b`050;^/b`0300000035Y[T0aJJi0080aJJi00L0
00000<fR[03=XZ`0cJ:/0000003S/j@000000180oooo1@0000000`26X>D0000009ZFcP0509ZFcP04
0000002VU/D00000000000@0YXbi00<000000;JG^02fUkP01@2fUkP2000000@0dJV`00<000000?oo
o`3oool0703oool4000000/0oooo000o0?ooo`8000004`3oool00`000000^jc;0;^/b`030;^/b`03
00000035Y[T0aJJi0080aJJi00D000000<fR[03=XZ`0cJ:/000000020>>cY0030000003oool0oooo
0100oooo0P00000305j2gPX000001P2VS;T00`000000]YNh0;JG^0040;JG^0040000003@/[`0d;:l
000000<0dJV`00<000000?ooo`3oool07@3oool3000000/0oooo00110?ooo`030000003oool0oooo
0100oooo00<000000;^/b`2k[</00P2k[</00`000000aJJi0<FV^@030<FV^@050000003=XZ`0cJ:/
0<fR[00000000P3S/j@00`000000oooo0?ooo`0A0?ooo`8000000`1NP]h00`000000THK40966a004
0966a0030000002VS;T0YXbi00D0YXbi00<000000;JG^02fUkP0102fUkP010000000d;:l0=2b_000
00030=6Y/0030000003oool0oooo01h0oooo0P00000;0?ooo`00@P3oool00`000000oooo0?ooo`0@
0?ooo`040000002k[</0^jc;000000D0aJJi00<000000<fR[03=XZ`00P3=XZ`010000000hk>T0>>c
Y000000D0?ooo`030000001NP]h0GX;N0080GX;N00<000000966a02AQ/@0102AQ/@00`000000YXbi
0:J<^@040:J<^@030000002fUkP0]YNh00<0]YNh00D000000=2b_03@/[`0d;:l000000020=6Y/003
0000003oool0oooo01l0oooo0P00000;0?ooo`00@`3oool00`000000oooo0?ooo`0?0?ooo`030000
002k[</0000000H0aJJi00D000000<fR[03=XZ`0cJ:/000000030>>cY0030000003oool0oooo01<0
oooo00D0000005j2gP1NP]h0GX;N000000060966a0030000002VS;T0YXbi00D0YXbi00D000000;JG
^02fUkP0]YNh000000050=2b_0030000003AZK00000001d0oooo1000000=0?ooo`00A03oool20000
0100oooo00<000000<FV^@35Y[T01035Y[T00`000000cJ:/0<fR[0020<fR[0040000003S/j@0hk>T
000001L0oooo00D0000005j2gP1NP]h0GX;N000000050966a0030000002VS;T0YXbi00D0YXbi00@0
00000;JG^02fUkP000001P3@/[`00`000000dJV`0000000I0?ooo`@000004@3oool004H0oooo00<0
00000?ooo`3oool03@3oool00`000000aJJi0<FV^@040<FV^@030000003=XZ`0cJ:/0080cJ:/00@0
00000>>cY03S/j@000005`3oool200000080GX;N00<000000966a02AQ/@0102AQ/@00`000000YXbi
0:J<^@040:J<^@040000002fUkP0]YNh000000H0d;:l00<000000=6Y/00000005@3oool4000001D0
oooo00170?ooo`030000003oool0oooo00d0oooo00<000000<FV^@35Y[T00`35Y[T00`000000cJ:/
0<fR[0020<fR[0040000003S/j@0hk>T000001P0oooo0`0000000`1NP]h000000966a0040966a003
0000002VS;T0YXbi00D0YXbi0P0000080=2b_0030000003oool0oooo0140oooo0`00000I0?ooo`00
B03oool00`000000oooo0?ooo`0<0?ooo`0300000035Y[T0aJJi0080aJJi00<000000<fR[03=XZ`0
0P3=XZ`01@000000hk>T0>>cY03S/j@0000001P0oooo00<0000001Q<a`0HC<L00P0000060966a003
0000002VS;T0YXbi00@0YXbi00<000000=2b_03@/[`01`3@/[`00`000000oooo0?ooo`0=0?ooo`@0
0000703oool004T0oooo0P00000=0?ooo`0500000035Y[T0aJJi0<FV^@000000103=XZ`01@000000
hk>T0>>cY03S/j@0000001T0oooo00<0000001Q<a`0HC<L00P0000050966a0030000002VS;T0YXbi
0080YXbi0`0000080=2b_0030000003oool0oooo00X0oooo1000000P0?ooo`00B`3oool00`000000
oooo0?ooo`0:0?ooo`0400000035Y[T0aJJi000000D0cJ:/00@000000>>cY03S/j@000006P3oool0
1000000064c701Q<a`0HC<L2000000@0THK400D000000:J<^@2VS;T0YXbi000000030;Zjf@030000
003@/[`0d;:l00@0d;:l00<000000?ooo`3oool0203oool3000002@0oooo001<0?ooo`030000003o
ool0oooo00X0oooo00<000000<FV^@000000103=XZ`01@000000hk>T0>>cY03S/j@0000001/0oooo
00D0000001Q<a`0HC<L0000007f0b`04000000040966a00000000000000000@0^[[I00<000000=2b
_03@/[`00P3@/[`2000000L0oooo1000000W0?ooo`00C@3oool00`000000oooo0?ooo`090?ooo`80
00001@3=XZ`01@000000hk>T0>>cY03S/j@0000001`0oooo00@0000001Q<a`0HC<L00000101mP</2
000000L0^[[I00@000000=2b_03@/[`000001@3oool4000002/0oooo001>0?ooo`8000002P3oool0
0`000000cJ:/0<fR[0030<fR[0050000003S/j@0hk>T0>>cY00000007@3oool00`00000064c70000
000607f0b`030000002j^]T0^[[I00@0^[[I00<000000=2b_00000000P3oool4000002l0oooo001@
0?ooo`030000003oool0oooo00L0oooo00<000000<fR[03=XZ`00P3=XZ`00`000000hk>T0>>cY002
0>>cY0030000003oool0oooo01`0oooo0P00000607f0b`030000002j^]T0^[[I00@0^[[I1@00000c
0?ooo`00D@3oool00`000000oooo0?ooo`070?ooo`050000003=XZ`0cJ:/0<fR[0000000103S/j@0
0`000000oooo0?ooo`0L0?ooo`030000000HC<L0000000H0OH3;00<000000;Zjf@2j^]T01@00000f
0?ooo`00DP3oool00`000000oooo0?ooo`060?ooo`050000003=XZ`0cJ:/0<fR[00000000`3S/j@0
0`000000oooo0?ooo`0N0?ooo`8000001P1mP</4000003X0oooo001C0?ooo`030000003oool0oooo
00D0oooo00D000000<fR[03=XZ`0cJ:/000000030>>cY0030000003oool0oooo01l0oooo0P000000
0`1mP</0000000000002000003h0oooo001D0?ooo`8000001P3oool00`000000cJ:/000000040>>c
Y0030000003oool0oooo01l0oooo100000110?ooo`00EP3oool00`000000oooo0?ooo`030?ooo`03
0000003=XZ`0000000@0hk>T00<000000?ooo`3oool06`3oool4000004D0oooo001G0?ooo`030000
003oool0oooo0080oooo00<000000<fR[0000000103S/j@00`000000oooo0?ooo`0G0?ooo`@00000
B@3oool005P0oooo00<000000?ooo`3oool00P3oool00`000000hk>T0>>cY0020>>cY0030000003o
ool0oooo01D0oooo0`00001=0?ooo`00F@3oool200000080oooo00<000000>>cY03S/j@00P3S/j@0
0`000000oooo0?ooo`0A0?ooo`@00000D03oool005/0oooo00@000000?ooo`3oool000000`3S/j@0
0`000000oooo0?ooo`0=0?ooo`@00000E03oool005`0oooo00<000000?ooo`0000000`3S/j@00`00
0000oooo0?ooo`0:0?ooo`<00000F03oool005d0oooo00<000000?ooo`0000000P3S/j@00`000000
oooo0?ooo`060?ooo`@00000F`3oool005h0oooo100000050?ooo`@00000G`3oool00600oooo0P00
00000`3oool0000000000002000006<0oooo001Q0?ooo`800000I`3oool00<X0oooo003:0?ooo`00
bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?ooo`00bP3oool00<X0oooo003:0?oo
o`00bP3oool00<X0oooo0000\
\>"],
  ImageRangeCache->{{{0, 201.938}, {163.563, 0}} -> {-0.220591, -0.0860628, \
0.00616486, 0.00616486}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[183]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(\[Lambda] = 1\/16\)]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot[
      Chop[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                  apr[\([1]\)])\))\)] /. \[Lambda] \[Rule] 1/16, {x, 0, 
        1}]\)], "Input",
  CellLabel->"In[184]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.305904 2.10521e+006 [
[.21429 .2934 -9 -9 ]
[.21429 .2934 9 0 ]
[.40476 .2934 -9 -9 ]
[.40476 .2934 9 0 ]
[.59524 .2934 -9 -9 ]
[.59524 .2934 9 0 ]
[.78571 .2934 -9 -9 ]
[.78571 .2934 9 0 ]
[.97619 .2934 -3 -9 ]
[.97619 .2934 3 0 ]
[.01131 .09538 -39 -6.25 ]
[.01131 .09538 0 6.25 ]
[.01131 .20064 -39 -6.25 ]
[.01131 .20064 0 6.25 ]
[.01131 .41116 -33 -6.25 ]
[.01131 .41116 0 6.25 ]
[.01131 .51643 -33 -6.25 ]
[.01131 .51643 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .3059 m
.21429 .31215 L
s
[(0.2)] .21429 .2934 0 1 Mshowa
.40476 .3059 m
.40476 .31215 L
s
[(0.4)] .40476 .2934 0 1 Mshowa
.59524 .3059 m
.59524 .31215 L
s
[(0.6)] .59524 .2934 0 1 Mshowa
.78571 .3059 m
.78571 .31215 L
s
[(0.8)] .78571 .2934 0 1 Mshowa
.97619 .3059 m
.97619 .31215 L
s
[(1)] .97619 .2934 0 1 Mshowa
.125 Mabswid
.07143 .3059 m
.07143 .30965 L
s
.11905 .3059 m
.11905 .30965 L
s
.16667 .3059 m
.16667 .30965 L
s
.2619 .3059 m
.2619 .30965 L
s
.30952 .3059 m
.30952 .30965 L
s
.35714 .3059 m
.35714 .30965 L
s
.45238 .3059 m
.45238 .30965 L
s
.5 .3059 m
.5 .30965 L
s
.54762 .3059 m
.54762 .30965 L
s
.64286 .3059 m
.64286 .30965 L
s
.69048 .3059 m
.69048 .30965 L
s
.7381 .3059 m
.7381 .30965 L
s
.83333 .3059 m
.83333 .30965 L
s
.88095 .3059 m
.88095 .30965 L
s
.92857 .3059 m
.92857 .30965 L
s
.25 Mabswid
0 .3059 m
1 .3059 L
s
.02381 .09538 m
.03006 .09538 L
s
gsave
.01131 .09538 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.02381 .20064 m
.03006 .20064 L
s
gsave
.01131 .20064 -39 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .41116 m
.03006 .41116 L
s
gsave
.01131 .41116 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02381 .51643 m
.03006 .51643 L
s
gsave
.01131 .51643 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.125 Mabswid
.02381 .11643 m
.02756 .11643 L
s
.02381 .13749 m
.02756 .13749 L
s
.02381 .15854 m
.02756 .15854 L
s
.02381 .17959 m
.02756 .17959 L
s
.02381 .2217 m
.02756 .2217 L
s
.02381 .24275 m
.02756 .24275 L
s
.02381 .2638 m
.02756 .2638 L
s
.02381 .28485 m
.02756 .28485 L
s
.02381 .32696 m
.02756 .32696 L
s
.02381 .34801 m
.02756 .34801 L
s
.02381 .36906 m
.02756 .36906 L
s
.02381 .39011 m
.02756 .39011 L
s
.02381 .43222 m
.02756 .43222 L
s
.02381 .45327 m
.02756 .45327 L
s
.02381 .47432 m
.02756 .47432 L
s
.02381 .49537 m
.02756 .49537 L
s
.02381 .53748 m
.02756 .53748 L
s
.02381 .55853 m
.02756 .55853 L
s
.02381 .57958 m
.02756 .57958 L
s
.02381 .60063 m
.02756 .60063 L
s
.02381 .07433 m
.02756 .07433 L
s
.02381 .05328 m
.02756 .05328 L
s
.02381 .03223 m
.02756 .03223 L
s
.02381 .01117 m
.02756 .01117 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .54974 m
.04262 .41758 L
.06244 .30377 L
.08255 .21297 L
.09409 .17124 L
.10458 .1394 L
.11396 .11559 L
.12415 .09448 L
.13491 .07724 L
.14017 .07061 L
.14509 .06542 L
.15002 .06119 L
.15453 .05812 L
.15954 .0556 L
.1623 .0546 L
.16368 .0542 L
.16493 .0539 L
.16614 .05365 L
.16745 .05344 L
.16817 .05335 L
.16883 .05329 L
.17014 .0532 L
.17126 .05317 L
.17249 .05318 L
.17378 .05324 L
.17498 .05335 L
.17566 .05344 L
.1764 .05354 L
.17775 .05378 L
.18028 .05438 L
.18323 .05533 L
.18596 .05644 L
.19059 .05882 L
.19558 .06206 L
.20462 .0696 L
.21537 .08119 L
.22522 .09408 L
.26485 .1633 L
.30295 .2468 L
.34352 .3414 L
.38256 .42737 L
.40247 .46632 L
.42406 .50326 L
.4431 .53043 L
.45392 .54335 L
.46404 .55367 L
.47443 .5624 L
.48392 .56868 L
.48877 .57125 L
.49406 .57354 L
Mistroke
.49696 .57458 L
.49965 .5754 L
.50242 .57609 L
.50496 .5766 L
.50744 .57698 L
.50868 .57713 L
.51005 .57725 L
.51076 .5773 L
.51143 .57734 L
.5122 .57738 L
.5129 .5774 L
.51417 .57741 L
.51489 .57741 L
.51555 .57739 L
.51674 .57734 L
.51785 .57727 L
.51908 .57717 L
.52039 .57703 L
.52307 .57663 L
.52552 .57614 L
.52986 .57499 L
.5346 .57332 L
.54414 .56861 L
.55444 .56156 L
.56379 .5534 L
.58475 .52919 L
.60398 .50014 L
.62479 .46195 L
.66576 .36996 L
.70521 .26813 L
.74315 .16916 L
.76427 .11861 L
.78355 .07822 L
.7931 .06097 L
.8035 .04474 L
.81326 .0323 L
.82242 .02337 L
.82694 .02005 L
.83181 .01733 L
.83444 .01625 L
.83587 .01578 L
.83721 .01541 L
.83845 .01514 L
.83958 .01495 L
.84083 .0148 L
.84152 .01475 L
.84217 .01472 L
.84338 .01472 L
.84407 .01474 L
.84472 .01478 L
Mistroke
.84601 .01493 L
.84674 .01504 L
.84741 .01517 L
.8486 .01544 L
.84989 .01581 L
.85224 .0167 L
.85499 .01807 L
.85791 .01994 L
.86317 .02441 L
.86854 .0305 L
.87347 .03751 L
.8846 .05866 L
.89441 .08385 L
.90477 .11769 L
.92443 .20439 L
.94277 .31508 L
.96025 .4509 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[184]:=",
  ImageSize->{204.75, 126.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003<0000OR000`400?l00000o`00003oc03oool0
0<`0oooo003<0?ooo`00c03oool00<`0oooo003<0?ooo`00c03oool00<`0oooo003<0?ooo`00c03o
ool00<`0oooo000Y0?ooo`030000003oool0oooo0:00oooo000Y0?ooo`030000003oool0oooo0:00
oooo000Y0?ooo`030000003oool0oooo0:00oooo000Y0?ooo`030000003oool0oooo08<0oooo1@00
000H0?ooo`00:@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool05@3oool002T0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01@0oooo000Y0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0D0?ooo`00:@3oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool04`3oool002T0oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo000Y0?ooo`030000003oool0
oooo01@0oooo1000001V0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool0
02T0oooo00<000000?ooo`3oool04P3oool2000000@0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo000Y0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool04@3oool002T0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`070?ooo`800000H03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100oooo
00070?ooo`D0000000<0oooo0000003oool00P3oool00`000000oooo0000000400000080oooo0P00
000=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`1L0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0403oool000T0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3o
ool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool03`3oool000030?ooo`000000000000800000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo0P00000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo00090?ooo`050000003oool0
oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0
0000303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00l0oooo00080?ooo`800000
2P3oool2000000@0oooo0P0000090?ooo`050;2`/03oool0oooo0?ooo`0000003P3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0>0?ooo`009@3oool01@2`/;00oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool03P3oool001h0oooo00@0h>3P0820P020P800P8200`3oool01@3Ph>00`<300?ooo`3oool00000
00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool03P3oool002H0oooo00@0X:2P0?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0>0?ooo`008`3oool01030`<00L71`0820P020P8020?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool03@3oool002T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0=0?ooo`00:@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00d0oooo
000Y0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03@3oool002T0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`0<0?ooo`00:@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00`0oooo000Y0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool0303oool002T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0;0?ooo`00203o
ool2000000<0oooo00H000000?ooo`3oool0oooo0000003oool500000080oooo0P00000=0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool000L0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool02`3oool000X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool02`3oool000030?ooo`0000000000008000000`3oool2000000@0oooo00<000000?ooo`00
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00080?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`800000203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0:0?ooo`00203oool30000
00T0oooo0P0000040?ooo`8000003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00X0oooo000T0?ooo`03092@T030`<00X:2P0080oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`0:0?ooo`00903oool00`2`/;00oooo0:2PX0020?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool02P3oool001h0oooo00@0h>3P0820P020P800P8200P3oool00`20P800T92@
0;2`/0020?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool02@3oool002@0oooo00<0
/;2`0?ooo`2`/;000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00T0oooo000T
0?ooo`030:2PX02`/;00/;2`0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`09
0?ooo`00:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo0P0000040?oo
o`8000000`3oool4000000L0oooo00<000000?ooo`3oool01`3oool2000000@0oooo0P0000050?oo
o`<00000403oool2000000@0oooo0P0000030?ooo`<00000303oool00`000000oooo0?ooo`030?oo
o`800000103oool2000000@0oooo0P00000A0?ooo`030000003oool0oooo0080oooo1@0000020?oo
o`00:@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3o
ool00000203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool00000403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo000Y0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0303oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3oool01000
0000oooo0?ooo`0000080?ooo`D000003`3oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`00:@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3o
ool000002P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000@0?ooo`040000003oool0oooo000000P0oooo
0`00000;0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002@3oool200000180
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0000000@0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00004@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool2000000X0oooo0P00000:0?ooo`030000
003oool0oooo00D0oooo0P00000;0?ooo`8000004@3oool2000000X0oooo0`00000:0?ooo`030000
003oool0oooo00@0oooo0P00000:0?ooo`8000004P3oool00`000000oooo0?ooo`020?ooo`800000
103oool002T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00:@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000Y0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0203oool002T0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`070?ooo`009@3ooonW00000000:@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0000000H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo00L0oooo000Y0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool01`3oool002T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`07
0?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo000Y0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool01P3oool002T0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`060?ooo`00:@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00H0oooo000Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01P3oool0
02T0oooo00D000000?ooo`3oool0oooo0000000b0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`060?ooo`00:@3oool01@000000oooo0?ooo`3oool0
00000380oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00H0oooo000Y0?ooo`050000003oool0oooo0?ooo`000000<`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool01P3oool002T0oooo00D000000?oo
o`3oool0oooo0000000c0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`060?ooo`00:@3oool01@000000oooo0?ooo`3oool0000003<0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00D0oooo00080?oo
o`8000000`3oool01P000000oooo0?ooo`3oool000000?ooo`D000000P3oool2000000d0oooo00D0
00000?ooo`3oool0oooo0000000d0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`050?ooo`001`3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0
oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool01@3oool000X0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`040000003oool0oooo000003H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00D0oooo00080?ooo`800000103oool00`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80000000<0oooo
0000003oool0=@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool01@3oool000P0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00@0
00000?ooo`3oool00000=`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool01@3oool000P0oooo0`0000090?ooo`800000103oool2000000P0oooo00<0
T92@0<30`02PX:000P3oool010000000oooo0?ooo`00000g0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`050?ooo`00903oool00`2`/;00oooo0:2P
X0020?ooo`040000003oool0oooo000003P0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo00@0oooo000N0?ooo`040>3Ph020P800P8200820P080oooo
00<0P820092@T02`/;000P3oool010000000oooo0?ooo`00000h0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`040?ooo`00903oool00`2`/;00oooo
0;2`/0020?ooo`030000003oool0000003X0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0d0?ooo`030000003oool0oooo00@0oooo000T0?ooo`030:2PX02`/;00/;2`0080oooo00<0
00000?ooo`000000>P3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool0103oool002T0oooo00<000000?ooo`000000>`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0103oool002T0oooo00<000000?oo
o`000000>`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool0103oool002T0oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0103oool002T0oooo00<000000?ooo`000000
?03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
103oool002T0oooo00<000000?ooo`000000?@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0103oool002T0oooo0P00000n0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`040?ooo`00:@3oool20000
03l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00<0oooo00070?ooo`D0000000<0oooo0000003oool00P3oool00`000000oooo0000000400000080
oooo0P00000=0?ooo`800000?`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool00`3oool000T0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000@03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool00`3oool000T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000@@3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool00`3oool000T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000@@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool00`3oool000T0oooo00D000000?ooo`3oool0
oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00000<
0?ooo`800000@P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool00`3oool000P0oooo0P00000:0?ooo`800000103oool2000000T0oooo00@0/;2`0?oo
o`3oool0oooo0P0000120?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`030?ooo`009@3oool01@2`/;00oooo0?ooo`3oool0000004@0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00<0oooo000N0?oo
o`040>3Ph020P800P8200820P0<0oooo00D0h>3P0<30`03oool0oooo000000150?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`030?ooo`009P3oool0
102PX:00oooo0?ooo`0000160?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`030?ooo`008`3oool01030`<00L71`0820P020P8020?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00<0oooo000Y0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo00<0oooo000Y0?ooo`030000003oool0oooo
04L0oooo0P00000<0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool00`3oool002T0
oooo00<000000?ooo`3oool0B@3oool2000000P0oooo0P0000160?ooo`030000003oool0oooo0080
oooo000Y0?ooo`030000003oool0oooo04/0oooo200000180?ooo`030000003oool0oooo0080oooo
000Y0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool00P3oool002T0oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3o
ool00P3oool002T0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`020?ooo`00:@3o
ool00`000000oooo0?ooo`2P0?ooo`00:@3oool00`000000oooo0?ooo`2P0?ooo`00c03oool00<`0
oooo003<0?ooo`00c03oool00<`0oooo003<0?ooo`00c03oool00<`0oooo003<0?ooo`00c03oool0
0<`0oooo0000\
\>"],
  ImageRangeCache->{{{0, 203.75}, {125.5, 0}} -> {-0.258879, -1.774*^-07, \
0.00630127, 2.85065*^-09}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[184]="]
}, Open  ]],

Cell["Example 6", "Subsubsection"],

Cell["Initial value problem.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {x^2*\(y'''\)[x] - 
            2*\((n + 1)\)*x*\(y''\)[x] + \((a*x^2 + 6*n)\)*\(y'\)[x] - 
            2*a*x*y[x] == 0, 
        y[0] \[Equal] \(Sqrt[a]^\((\(-n\) - 1/2)\)/2^\((\(-n\) - 1/2)\)\)/
            Gamma[\(-n\) + 1/2], \(y'\)[0] \[Equal] 0}\)], "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\(-2\)\ a\ x\ y[x]\), "+", 
            RowBox[{\((6\ n + a\ x\^2)\), " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "-", 
            RowBox[{"2", " ", \((1 + n)\), " ", "x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{\(x\^2\), " ", 
              RowBox[{
                SuperscriptBox["y", 
                  TagBox[\((3)\),
                    Derivative],
                  MultilineFunction->None], "[", "x", "]"}]}]}], "==", "0"}], 
        ",", \(y[
            0] == \(2\^\(1\/2 + n\)\ a\^\(1\/2\ \((\(-\(1\/2\)\) - \
n)\)\)\)\/Gamma[1\/2 - n]\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "==", "0"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[185]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the BVP.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[ivp, y[x], {x, 0, 1}, 3]\)], "Input",
  CellLabel->"In[186]:="],

Cell[BoxData[
    \(LdeApprox::"regsp" \(\(:\)\(\ \)\) 
      "regular singular point encountered: \!\(x\) = \!\(0\)"\)], "Message",
  CellLabel->"From In[186]:="],

Cell[BoxData[
    \({y[x] \[Rule] \(2\^\(1\/2 + n\)\ a\^\(1\/4\ \((\(-1\) - 2\ \
n)\)\)\)\/Gamma[1\/2 - n] + \(2\^\(\(-\(1\/2\)\) + n\)\ a\^\(1\/4\ \((3 - 2\ \
n)\)\)\ x\^2\)\/\(\((\(-1\) + 2\ n)\)\ Gamma[1\/2 - n]\)}\)], "Output",
  CellLabel->"Out[186]="]
}, Open  ]],

Cell[TextData[{
  "Unfortunately ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " can not find exact solution of the IVP."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[187]:="],

Cell[BoxData[
    RowBox[{"DSolve", "[", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{\(\(-2\)\ a\ x\ y[x]\), "+", 
                RowBox[{\((6\ n + a\ x\^2)\), " ", 
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}]}], "-", 
                RowBox[{"2", " ", \((1 + n)\), " ", "x", " ", 
                  RowBox[{
                    SuperscriptBox["y", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}]}], "+", 
                RowBox[{\(x\^2\), " ", 
                  RowBox[{
                    SuperscriptBox["y", 
                      TagBox[\((3)\),
                        Derivative],
                      MultilineFunction->None], "[", "x", "]"}]}]}], "==", 
              "0"}], ",", \(y[
                0] == \(2\^\(1\/2 + n\)\ a\^\(1\/2\ \((\(-\(1\/2\)\) - n)\)\)\
\)\/Gamma[1\/2 - n]\), ",", 
            RowBox[{
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], "==", "0"}]}], 
          "}"}], ",", \(y[x]\), ",", "x"}], "]"}]], "Output",
  CellLabel->"Out[187]="]
}, Open  ]],

Cell["Nevertheless the exact solution is as follows.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = {{y[x] \[Rule] 
            x^\((1/2 + n)\)*BesselJ[\(-n\) - 1/2, Sqrt[a]*x]}}\)], "Input",
  CellLabel->"In[188]:="],

Cell[BoxData[
    \({{y[x] \[Rule] 
          x\^\(1\/2 + n\)\ BesselJ[\(-\(1\/2\)\) - n, \@a\ x]}}\)], "Output",
  CellLabel->"Out[188]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {n \[Rule] \(-9\)/2}, {x, \(-1\), 
        1}, {a, 1/8, 
        1}, \[IndentingNewLine]PlotRange \[Rule] {\(-10^\((\(-6\))\)\), 
          10^\((\(-6\))\)}]\)], "Input",
  CellLabel->"In[189]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.1984e-017 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.73022 .04002 0 -6.21768 ]
[.73022 .04002 18 2.78232 ]
[.80278 .15113 0 -6.10957 ]
[.80278 .15113 18 2.89043 ]
[.86829 .25145 0 -6.01427 ]
[.86829 .25145 18 2.98573 ]
[.92773 .34248 0 -5.92962 ]
[.92773 .34248 18 3.07038 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02494 .25992 -39 -3.80269 ]
[.02494 .25992 0 8.69731 ]
[.01611 .31527 -39 -3.86767 ]
[.01611 .31527 0 8.63233 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -33 -4.00565 ]
[-0.00254 .43215 0 8.49435 ]
[-0.0124 .49393 -33 -4.079 ]
[-0.0124 .49393 0 8.421 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.71796 .0447 m
.71183 .04704 L
s
[(0.2)] .73022 .04002 -1 .38171 Mshowa
.79042 .15555 m
.78425 .15776 L
s
[(0.4)] .80278 .15113 -1 .35768 Mshowa
.85585 .25563 m
.84964 .25773 L
s
[(0.6)] .86829 .25145 -1 .3365 Mshowa
.91523 .34645 m
.90897 .34844 L
s
[(0.8)] .92773 .34248 -1 .31769 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.7368 .07352 m
.73311 .0749 L
s
.75514 .10158 m
.75145 .10294 L
s
.77301 .12891 m
.76931 .13025 L
s
.8074 .18151 m
.80369 .18282 L
s
.82395 .20683 m
.82023 .20812 L
s
.8401 .23153 m
.83637 .23281 L
s
.87123 .27915 m
.8675 .28039 L
s
.88624 .30212 m
.8825 .30334 L
s
.90091 .32455 m
.89716 .32575 L
s
.92922 .36786 m
.92547 .36904 L
s
.9429 .38878 m
.93914 .38994 L
s
.95627 .40924 m
.95251 .41038 L
s
.69861 .0151 m
.69494 .01653 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -39 -1.80269 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -39 -1.86767 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -33 -2.00565 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -33 -2.079 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.645 .763 .934 r
.37443 .79219 .39787 .81114 .43683 .80094 .41374 .78172 Metetra
.867 .769 .752 r
.41374 .78172 .43683 .80094 .4768 .75701 .45466 .71939 Metetra
.787 .682 .749 r
.45466 .71939 .4768 .75701 .51664 .7006 .49487 .67299 Metetra
.755 .723 .822 r
.49487 .67299 .51664 .7006 .55625 .66816 .53492 .64502 Metetra
.707 .746 .882 r
.53492 .64502 .55625 .66816 .59621 .64897 .57532 .62728 Metetra
.67 .752 .912 r
.57532 .62728 .59621 .64897 .63677 .6357 .61629 .6141 Metetra
.657 .751 .92 r
.61629 .6141 .63677 .6357 .67796 .62396 .6579 .60207 Metetra
.655 .751 .921 r
.6579 .60207 .67796 .62396 .71977 .6123 .70013 .59005 Metetra
.642 .746 .925 r
.70013 .59005 .71977 .6123 .76233 .6022 .74309 .5792 Metetra
.591 .722 .935 r
.74309 .5792 .76233 .6022 .80608 .59817 .78712 .57303 Metetra
.466 .645 .936 r
.78712 .57303 .80608 .59817 .85204 .60795 .83297 .57751 Metetra
.24 .469 .878 r
.83297 .57751 .85204 .60795 .90203 .64308 .88203 .60146 Metetra
.169 .35 .802 r
.88203 .60146 .90203 .64308 .95255 .66592 .9349 .64283 Metetra
.645 .763 .934 r
.9349 .64283 .95255 .66592 1 .6535 .98292 .63004 Metetra
.773 .781 .859 r
.35034 .77273 .37443 .79219 .41374 .78172 .39066 .745 Metetra
.817 .694 .729 r
.39066 .745 .41374 .78172 .45466 .71939 .43205 .68434 Metetra
.773 .691 .773 r
.43205 .68434 .45466 .71939 .49487 .67299 .47258 .64604 Metetra
.739 .728 .841 r
.47258 .64604 .49487 .67299 .53492 .64502 .51303 .62168 Metetra
.696 .747 .89 r
.51303 .62168 .53492 .64502 .57532 .62728 .55385 .60508 Metetra
.666 .751 .914 r
.55385 .60508 .57532 .62728 .61629 .6141 .59525 .5919 Metetra
.656 .751 .92 r
.59525 .5919 .61629 .6141 .6579 .60207 .63727 .57956 Metetra
.655 .751 .921 r
.63727 .57956 .6579 .60207 .70013 .59005 .67994 .56718 Metetra
.645 .747 .924 r
.67994 .56718 .70013 .59005 .74309 .5792 .72333 .55564 Metetra
.608 .73 .932 r
.72333 .55564 .74309 .5792 .78712 .57303 .76768 .54762 Metetra
.518 .675 .936 r
.76768 .54762 .78712 .57303 .83297 .57751 .81356 .54767 Metetra
.354 .55 .906 r
.81356 .54767 .83297 .57751 .88203 .60146 .86198 .56241 Metetra
.151 .358 .813 r
.86198 .56241 .88203 .60146 .9349 .64283 .91469 .60116 Metetra
.524 .576 .849 r
.91469 .60116 .9349 .64283 .98292 .63004 .96532 .60586 Metetra
.848 .771 .777 r
.32559 .75273 .35034 .77273 .39066 .745 .36751 .69967 Metetra
.774 .658 .735 r
.36751 .69967 .39066 .745 .43205 .68434 .40892 .65141 Metetra
.757 .699 .797 r
.40892 .65141 .43205 .68434 .47258 .64604 .44972 .61959 Metetra
.724 .732 .857 r
.44972 .61959 .47258 .64604 .51303 .62168 .49056 .59809 Metetra
.687 .747 .897 r
.49056 .59809 .51303 .62168 .55385 .60508 .5318 .58233 Metetra
.664 .751 .915 r
.5318 .58233 .55385 .60508 .59525 .5919 .57361 .56909 Metetra
.656 .751 .92 r
.57361 .56909 .59525 .5919 .63727 .57956 .61607 .55642 Metetra
.655 .751 .92 r
.61607 .55642 .63727 .57956 .67994 .56718 .65918 .54367 Metetra
.648 .749 .923 r
.65918 .54367 .67994 .56718 .72333 .55564 .703 .53149 Metetra
.621 .736 .929 r
.703 .53149 .72333 .55564 .76768 .54762 .74772 .52188 Metetra
.557 .697 .934 r
.74772 .52188 .76768 .54762 .81356 .54767 .79374 .51824 Metetra
.442 .609 .919 r
.79374 .51824 .81356 .54767 .86198 .56241 .8418 .52547 Metetra
.285 .463 .86 r
.8418 .52547 .86198 .56241 .91469 .60116 .89316 .55031 Metetra
.338 .427 .806 r
.89316 .55031 .91469 .60116 .96532 .60586 .94718 .58093 Metetra
.806 .691 .738 r
.30124 .71487 .32559 .75273 .36751 .69967 .34378 .65878 Metetra
.76 .669 .762 r
.34378 .65878 .36751 .69967 .40892 .65141 .38521 .62021 Metetra
.74 .708 .821 r
.38521 .62021 .40892 .65141 .44972 .61959 .42627 .59346 Metetra
.709 .736 .872 r
.42627 .59346 .44972 .61959 .49056 .59809 .46748 .57417 Metetra
.679 .748 .903 r
.46748 .57417 .49056 .59809 .5318 .58233 .50912 .55901 Metetra
.662 .751 .917 r
.50912 .55901 .5318 .58233 .57361 .56909 .55136 .54563 Metetra
.656 .751 .92 r
.55136 .54563 .57361 .56909 .61607 .55642 .59425 .53262 Metetra
.655 .751 .92 r
.59425 .53262 .61607 .55642 .65918 .54367 .63781 .51948 Metetra
.65 .749 .922 r
.63781 .51948 .65918 .54367 .703 .53149 .68209 .50669 Metetra
.631 .74 .927 r
.68209 .50669 .703 .53149 .74772 .52188 .72721 .49573 Metetra
.586 .713 .931 r
.72721 .49573 .74772 .52188 .79374 .51824 .77347 .48905 Metetra
.507 .652 .924 r
.77347 .48905 .79374 .51824 .8418 .52547 .82139 .49021 Metetra
.393 .546 .888 r
.82139 .49021 .8418 .52547 .89316 .55031 .87186 .504 Metetra
.274 .41 .818 r
.87186 .504 .89316 .55031 .94718 .58093 .92627 .53684 Metetra
.753 .641 .736 r
.27726 .66482 .30124 .71487 .34378 .65878 .31941 .62152 Metetra
.744 .681 .79 r
.31941 .62152 .34378 .65878 .38521 .62021 .36086 .59038 Metetra
.723 .716 .843 r
.36086 .59038 .38521 .62021 .42627 .59346 .40217 .56751 Metetra
.696 .739 .884 r
.40217 .56751 .42627 .59346 .46748 .57417 .44374 .54985 Metetra
.673 .748 .908 r
.44374 .54985 .46748 .57417 .50912 .55901 .4858 .53508 Metetra
.66 .751 .918 r
.4858 .53508 .50912 .55901 .55136 .54563 .52847 .52151 Metetra
.656 .751 .92 r
.52847 .52151 .55136 .54563 .59425 .53262 .5718 .50812 Metetra
.656 .751 .92 r
.5718 .50812 .59425 .53262 .63781 .51948 .61582 .49458 Metetra
.652 .75 .922 r
.61582 .49458 .63781 .51948 .68209 .50669 .66057 .48123 Metetra
.638 .743 .925 r
.66057 .48123 .68209 .50669 .72721 .49573 .70613 .46909 Metetra
.608 .725 .928 r
.70613 .46909 .72721 .49573 .77347 .48905 .7527 .45993 Metetra
.554 .682 .924 r
.7527 .45993 .77347 .48905 .82139 .49021 .80066 .45624 Metetra
.475 .607 .903 r
.80066 .45624 .82139 .49021 .87186 .504 .85062 .46136 Metetra
.382 .501 .855 r
.85062 .46136 .87186 .504 .92627 .53684 .90353 .47965 Metetra
.739 .655 .767 r
.25246 .62091 .27726 .66482 .31941 .62152 .29431 .58715 Metetra
.727 .694 .818 r
.29431 .58715 .31941 .62152 .36086 .59038 .33582 .56157 Metetra
.707 .723 .863 r
.33582 .56157 .36086 .59038 .40217 .56751 .3774 .54157 Metetra
.685 .741 .894 r
.3774 .54157 .40217 .56751 .44374 .54985 .41934 .52508 Metetra
.668 .749 .911 r
.41934 .52508 .44374 .54985 .4858 .53508 .4618 .5105 Metetra
.659 .751 .918 r
.4618 .5105 .4858 .53508 .52847 .52151 .50491 .49667 Metetra
.656 .751 .92 r
.50491 .49667 .52847 .52151 .5718 .50812 .54869 .4829 Metetra
.656 .751 .92 r
.54869 .4829 .5718 .50812 .61582 .49458 .59318 .46895 Metetra
.653 .75 .921 r
.59318 .46895 .61582 .49458 .66057 .48123 .6384 .45504 Metetra
.644 .746 .923 r
.6384 .45504 .66057 .48123 .70613 .46909 .68443 .4419 Metetra
.624 .733 .925 r
.68443 .4419 .70613 .46909 .7527 .45993 .73138 .43072 Metetra
.588 .704 .923 r
.73138 .43072 .7527 .45993 .80066 .45624 .77953 .4232 Metetra
.535 .652 .91 r
.77953 .4232 .80066 .45624 .85062 .46136 .82928 .42161 Metetra
.468 .574 .878 r
.82928 .42161 .85062 .46136 .90353 .47965 .88128 .42883 Metetra
.723 .672 .8 r
.22678 .58188 .25246 .62091 .29431 .58715 .26844 .55504 Metetra
.71 .706 .844 r
.26844 .55504 .29431 .58715 .33582 .56157 .31006 .53348 Metetra
.693 .73 .879 r
.31006 .53348 .33582 .56157 .3774 .54157 .35191 .51552 Metetra
.676 .743 .902 r
.35191 .51552 .3774 .54157 .41934 .52508 .39422 .49979 Metetra
.664 .749 .914 r
.39422 .49979 .41934 .52508 .4618 .5105 .4371 .48524 Metetra
.658 .751 .919 r
.4371 .48524 .4618 .5105 .50491 .49667 .48064 .47111 Metetra
.656 .751 .92 r
.48064 .47111 .50491 .49667 .54869 .4829 .52489 .45693 Metetra
.656 .751 .92 r
.52489 .45693 .54869 .4829 .59318 .46895 .56985 .44254 Metetra
.654 .751 .921 r
.56985 .44254 .59318 .46895 .6384 .45504 .61557 .42811 Metetra
.648 .748 .922 r
.61557 .42811 .6384 .45504 .68443 .4419 .66208 .41408 Metetra
.635 .739 .923 r
.66208 .41408 .68443 .4419 .73138 .43072 .70947 .40126 Metetra
.612 .72 .922 r
.70947 .40126 .73138 .43072 .77953 .4232 .75792 .39075 Metetra
.578 .684 .914 r
.75792 .39075 .77953 .4232 .82928 .42161 .80771 .38404 Metetra
.532 .629 .893 r
.80771 .38404 .82928 .42161 .88128 .42883 .85924 .38298 Metetra
.706 .689 .831 r
.20017 .54661 .22678 .58188 .26844 .55504 .24175 .52462 Metetra
.694 .717 .866 r
.24175 .52462 .26844 .55504 .31006 .53348 .28352 .50583 Metetra
.68 .735 .892 r
.28352 .50583 .31006 .53348 .35191 .51552 .32567 .48921 Metetra
.669 .745 .908 r
.32567 .48921 .35191 .51552 .39422 .49979 .36835 .4739 Metetra
.661 .75 .916 r
.36835 .4739 .39422 .49979 .4371 .48524 .41166 .45925 Metetra
.657 .751 .919 r
.41166 .45925 .4371 .48524 .48064 .47111 .45565 .44477 Metetra
.656 .751 .92 r
.45565 .44477 .48064 .47111 .52489 .45693 .50036 .43016 Metetra
.656 .751 .92 r
.50036 .43016 .52489 .45693 .56985 .44254 .54581 .41533 Metetra
.655 .751 .921 r
.54581 .41533 .56985 .44254 .61557 .42811 .59203 .40037 Metetra
.651 .749 .921 r
.59203 .40037 .61557 .42811 .66208 .41408 .63904 .38556 Metetra
.643 .743 .922 r
.63904 .38556 .66208 .41408 .70947 .40126 .68692 .3714 Metetra
.629 .731 .921 r
.68692 .3714 .70947 .40126 .75792 .39075 .73577 .3586 Metetra
.607 .708 .915 r
.73577 .3586 .75792 .39075 .80771 .38404 .78577 .34805 Metetra
.579 .67 .901 r
.78577 .34805 .80771 .38404 .85924 .38298 .83719 .34091 Metetra
.69 .705 .859 r
.17258 .51415 .20017 .54661 .24175 .52462 .21419 .49536 Metetra
.681 .726 .884 r
.21419 .49536 .24175 .52462 .28352 .50583 .25616 .47835 Metetra
.671 .74 .902 r
.25616 .47835 .28352 .50583 .32567 .48921 .29864 .46252 Metetra
.663 .747 .912 r
.29864 .46252 .32567 .48921 .36835 .4739 .34171 .44737 Metetra
.659 .75 .918 r
.34171 .44737 .36835 .4739 .41166 .45925 .38544 .4325 Metetra
.656 .751 .92 r
.38544 .4325 .41166 .45925 .45565 .44477 .42989 .41763 Metetra
.656 .751 .92 r
.42989 .41763 .45565 .44477 .50036 .43016 .47508 .40258 Metetra
.656 .751 .92 r
.47508 .40258 .50036 .43016 .54581 .41533 .52102 .38728 Metetra
.655 .751 .92 r
.52102 .38728 .54581 .41533 .59203 .40037 .56775 .37179 Metetra
.653 .75 .921 r
.56775 .37179 .59203 .40037 .63904 .38556 .61529 .35627 Metetra
.648 .746 .921 r
.61529 .35627 .63904 .38556 .68692 .3714 .66369 .34102 Metetra
.64 .739 .92 r
.66369 .34102 .68692 .3714 .73577 .3586 .71301 .32644 Metetra
.628 .724 .916 r
.71301 .32644 .73577 .3586 .78577 .34805 .76337 .31307 Metetra
.61 .699 .907 r
.76337 .31307 .78577 .34805 .83719 .34091 .81494 .30156 Metetra
.677 .719 .881 r
.14399 .48365 .17258 .51415 .21419 .49536 .18572 .4668 Metetra
.67 .734 .898 r
.18572 .4668 .21419 .49536 .25616 .47835 .22795 .45081 Metetra
.664 .743 .909 r
.22795 .45081 .25616 .47835 .29864 .46252 .27078 .43534 Metetra
.66 .748 .915 r
.27078 .43534 .29864 .46252 .34171 .44737 .31425 .42013 Metetra
.657 .75 .919 r
.31425 .42013 .34171 .44737 .38544 .4325 .35842 .40495 Metetra
.656 .751 .92 r
.35842 .40495 .38544 .4325 .42989 .41763 .40333 .38965 Metetra
.656 .751 .92 r
.40333 .38965 .42989 .41763 .47508 .40258 .449 .37412 Metetra
.656 .751 .92 r
.449 .37412 .47508 .40258 .52102 .38728 .49545 .35834 Metetra
.655 .751 .92 r
.49545 .35834 .52102 .38728 .56775 .37179 .5427 .34231 Metetra
.654 .751 .921 r
.5427 .34231 .56775 .37179 .61529 .35627 .59078 .32614 Metetra
.652 .749 .921 r
.59078 .32614 .61529 .35627 .66369 .34102 .63972 .30998 Metetra
.647 .744 .92 r
.63972 .30998 .66369 .34102 .71301 .32644 .68958 .29404 Metetra
.641 .735 .917 r
.68958 .29404 .71301 .32644 .76337 .31307 .74041 .2786 Metetra
.631 .72 .911 r
.74041 .2786 .76337 .31307 .81494 .30156 .79232 .26403 Metetra
.667 .731 .898 r
.11438 .45438 .14399 .48365 .18572 .4668 .15631 .43854 Metetra
.663 .741 .908 r
.15631 .43854 .18572 .4668 .22795 .45081 .19885 .42298 Metetra
.66 .746 .914 r
.19885 .42298 .22795 .45081 .27078 .43534 .24205 .40755 Metetra
.658 .749 .918 r
.24205 .40755 .27078 .43534 .31425 .42013 .28594 .39211 Metetra
.657 .751 .919 r
.28594 .39211 .31425 .42013 .35842 .40495 .33056 .37655 Metetra
.656 .751 .92 r
.33056 .37655 .35842 .40495 .40333 .38965 .37593 .36078 Metetra
.656 .751 .92 r
.37593 .36078 .40333 .38965 .449 .37412 .42209 .34476 Metetra
.656 .751 .92 r
.42209 .34476 .449 .37412 .49545 .35834 .46905 .32846 Metetra
.656 .751 .92 r
.46905 .32846 .49545 .35834 .5427 .34231 .51684 .3119 Metetra
.655 .751 .92 r
.51684 .3119 .5427 .34231 .59078 .32614 .56548 .29511 Metetra
.654 .75 .92 r
.56548 .29511 .59078 .32614 .63972 .30998 .61499 .27815 Metetra
.652 .747 .92 r
.61499 .27815 .63972 .30998 .68958 .29404 .66541 .26114 Metetra
.648 .742 .918 r
.66541 .26114 .68958 .29404 .74041 .2786 .71679 .2442 Metetra
.644 .734 .914 r
.71679 .2442 .74041 .2786 .79232 .26403 .76919 .2275 Metetra
.661 .74 .909 r
.08373 .42571 .11438 .45438 .15631 .43854 .12594 .41021 Metetra
.659 .745 .914 r
.12594 .41021 .15631 .43854 .19885 .42298 .16882 .39469 Metetra
.657 .748 .917 r
.16882 .39469 .19885 .42298 .24205 .40755 .21241 .37906 Metetra
.657 .75 .919 r
.21241 .37906 .24205 .40755 .28594 .39211 .25673 .36326 Metetra
.656 .751 .92 r
.25673 .36326 .28594 .39211 .33056 .37655 .3018 .34725 Metetra
.656 .751 .92 r
.3018 .34725 .33056 .37655 .37593 .36078 .34766 .33099 Metetra
.656 .751 .92 r
.34766 .33099 .37593 .36078 .42209 .34476 .39431 .31445 Metetra
.656 .751 .92 r
.39431 .31445 .42209 .34476 .46905 .32846 .4418 .29762 Metetra
.656 .751 .92 r
.4418 .29762 .46905 .32846 .51684 .3119 .49013 .28049 Metetra
.655 .751 .92 r
.49013 .28049 .51684 .3119 .56548 .29511 .53933 .26309 Metetra
.655 .751 .92 r
.53933 .26309 .56548 .29511 .61499 .27815 .58943 .24542 Metetra
.654 .749 .92 r
.58943 .24542 .61499 .27815 .66541 .26114 .64045 .22754 Metetra
.653 .747 .919 r
.64045 .22754 .66541 .26114 .71679 .2442 .69243 .20948 Metetra
.651 .742 .917 r
.69243 .20948 .71679 .2442 .76919 .2275 .74542 .19131 Metetra
.657 .746 .915 r
.05202 .39711 .08373 .42571 .12594 .41021 .09457 .38153 Metetra
.657 .748 .917 r
.09457 .38153 .12594 .41021 .16882 .39469 .13783 .36576 Metetra
.656 .75 .919 r
.13783 .36576 .16882 .39469 .21241 .37906 .18182 .34976 Metetra
.656 .751 .92 r
.18182 .34976 .21241 .37906 .25673 .36326 .22658 .33352 Metetra
.656 .751 .92 r
.22658 .33352 .25673 .36326 .3018 .34725 .27212 .31702 Metetra
.656 .751 .92 r
.27212 .31702 .3018 .34725 .34766 .33099 .31846 .30023 Metetra
.656 .751 .92 r
.31846 .30023 .34766 .33099 .39431 .31445 .36562 .28314 Metetra
.656 .751 .92 r
.36562 .28314 .39431 .31445 .4418 .29762 .41363 .26575 Metetra
.656 .751 .92 r
.41363 .26575 .4418 .29762 .49013 .28049 .46252 .24804 Metetra
.656 .751 .92 r
.46252 .24804 .49013 .28049 .53933 .26309 .5123 .23002 Metetra
.656 .751 .92 r
.5123 .23002 .53933 .26309 .58943 .24542 .563 .21169 Metetra
.655 .751 .92 r
.563 .21169 .58943 .24542 .64045 .22754 .61465 .19304 Metetra
.655 .749 .919 r
.61465 .19304 .64045 .22754 .69243 .20948 .66727 .17409 Metetra
.654 .747 .918 r
.66727 .17409 .69243 .20948 .74542 .19131 .72091 .15486 Metetra
.656 .749 .919 r
.01925 .36816 .05202 .39711 .09457 .38153 .06217 .35223 Metetra
.656 .75 .919 r
.06217 .35223 .09457 .38153 .13783 .36576 .10583 .33604 Metetra
.656 .751 .92 r
.10583 .33604 .13783 .36576 .18182 .34976 .15025 .31958 Metetra
.656 .751 .92 r
.15025 .31958 .18182 .34976 .22658 .33352 .19545 .30283 Metetra
.656 .751 .92 r
.19545 .30283 .22658 .33352 .27212 .31702 .24146 .28579 Metetra
.656 .751 .92 r
.24146 .28579 .27212 .31702 .31846 .30023 .28829 .26844 Metetra
.656 .751 .92 r
.28829 .26844 .31846 .30023 .36562 .28314 .33597 .25079 Metetra
.656 .751 .92 r
.33597 .25079 .36562 .28314 .41363 .26575 .38452 .2328 Metetra
.656 .751 .92 r
.38452 .2328 .41363 .26575 .46252 .24804 .43397 .21449 Metetra
.656 .751 .92 r
.43397 .21449 .46252 .24804 .5123 .23002 .48434 .19584 Metetra
.656 .751 .92 r
.48434 .19584 .5123 .23002 .563 .21169 .53566 .17684 Metetra
.656 .751 .92 r
.53566 .17684 .563 .21169 .61465 .19304 .58795 .15748 Metetra
.656 .751 .92 r
.58795 .15748 .61465 .19304 .66727 .17409 .64124 .13777 Metetra
.655 .75 .919 r
.64124 .13777 .66727 .17409 .72091 .15486 .69557 .11769 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[189]:=",
  ImageSize->{206.25, 167.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003>0000Yb000`400?l00000o`00003ocP3oool0
0<h0oooo003>0?ooo`00cP3oool00<h0oooo003>0?ooo`00cP3oool00<h0oooo003>0?ooo`00cP3o
ool00<h0oooo003>0?ooo`00cP3oool008l0oooo1@00000j0?ooo`00T@3oool00`000000oooo0?oo
o`0j0?ooo`00T@3oool00`000000oooo0?ooo`0j0?ooo`00T@3oool00`000000oooo0?ooo`0j0?oo
o`00T@3oool00`000000oooo0?ooo`0j0?ooo`00T03oool2000003`0oooo003>0?ooo`00cP3oool0
0<h0oooo003>0?ooo`00T`3oool2000003T0oooo001X0?ooo`800000103oool2000000@0oooo0P00
000K0?ooo`80000000<0oooo000000000000>03oool006L0oooo00@000000?ooo`3oool00000203o
ool010000000oooo0?ooo`00000G0?ooo`<000000`3oool2000000L0oooo0P0000040?ooo`800000
0`3oool400000280oooo001W0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
4P3oool4000000D0oooo00<000000?ooo`0000001@3oool010000000oooo0?ooo`0000080?ooo`03
0000003oool0oooo02<0oooo001W0?ooo`040000003oool0oooo000000T0oooo0P00000B0?ooo`<0
00002@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000T0oooo00<00000
0?ooo`3oool08P3oool006L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0?
0?ooo`<000002`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool08@3oool006P0oooo0P00000:0?ooo`<000003@3oool2000000h0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000008P3oool00840oooo0`00000@0?ooo`040000003oool0oooo0?ooo`8000000`3oool20000
00X0oooo0P00000S0?ooo`00O`3oool2000001<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0b0?ooo`00O03oool3000001D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0a0?ooo`00N@3oool3000001P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0`0?ooo`00M`3oool2000001`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0`
0?ooo`00E`3oool2000001/0oooo0`0000000`3oool000000?ooo`0K0?ooo`030000003oool0oooo
00<0oooo0P00000a0?ooo`00EP3oool010000000oooo0?ooo`00000G0?ooo`<000008@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02h0oooo001F0?ooo`040000003oool0oooo0000
01D0oooo1000000R0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0;P3oool005H0
oooo00@000000?ooo`3oool000004P3oool3000002H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0]0?ooo`00EP3oool010000000oooo0?ooo`00000@0?ooo`<00000:03oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02`0oooo001G0?ooo`8000003P3oool3000002/0
oooo00<000000?ooo`3oool01P3oool2000002h0oooo001U0?ooo`<00000;@3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02/0oooo001R0?ooo`<00000;`3oool2000000X0oooo00<0
00000?ooo`3oool0:`3oool00600oooo0P00000_0?ooo`<0000000<0Yko[0000000000002P3oool0
0`000000oooo0?ooo`040?ooo`800000103oool2000000D0oooo0`00000F0?ooo`00G@3oool30000
02h0oooo0`0000040:Noj`8000002P3oool2000000@0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0?ooo`0E0?ooo`00<@3oool2000000@0oooo0P0000040?ooo`8000006`3oool30000
02h0oooo0`0000070:Noj`030000002W_n/0000000X0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000080?ooo`D000005P3oool00300oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000H0?ooo`8000000P3oool00`000000oooo0?ooo`0Y0?ooo`<000000P2W
`>/00`000000Yko[0:Noj`050:Noj`040000002W_n/0Yko[000000X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000005`3oool00300
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0C0?ooo`<00000;@3oool30000
00D0Yl3[00<000000:Noj`2W_n/01@2W_n/010000000Yko[0:Noj`00000;0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0000000G0?ooo`00:P3oool4
00000080oooo00@000000?ooo`3oool000002@3oool2000001@0oooo0P00000^0?ooo`8000002@2W
`>/00`000000Yko[0:Noj`040:Noj`030000002W_n/0Yko[008000002@3oool2000000<0oooo0P00
000;0?ooo`8000005`3oool00300oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`0@0?ooo`<00000;P3oool2000000030:O0j`000000Yl3[00T0Yl3[00<000000:Noj`2W_n/00`2W
_n/300000080Yko[00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V0?ooo`00<@3oool2
000000X0oooo0`00000=0?ooo`<00000;`3oool2000000@0Yl3[00<000000:O0j`2W`>/01`2W`>/0
0`000000Yko[0:Noj`04000000@0Yko[00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0U
0?ooo`00B`3oool3000002l0oooo0P0000060:O0j`030000002W`>/0Yl3[00L0Yl3[0`0000030:No
j`030000002W_n/0Yko[00<0Yko[00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0U0?oo
o`00B03oool3000002l0oooo0`0000090:O0j`030000002W`>/0Yl3[00@0Yl3[0P0000020:Noj`05
0000002W_n/0Yko[0:Noj`0000001P2W_n/00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02@0oooo00160?ooo`<00000;`3oool200000080Yl3[00<000000:O0j`2W`>/0202W`>/00`000000
Yl3[0:O0j`03000000@0Yko[00D000000:Noj`2W_n/0Yko[000000060:Noj`030000003oool0oooo
00P0oooo0P00000U0?ooo`00@`3oool3000002l0oooo0`0000050:O0j`030000002W`>/0Yl3[00L0
Yl3[0`0000080:Noj`050000002W_n/0Yko[0:Noj`0000001@2W_n/2000000X0oooo00<000000?oo
o`3oool08`3oool002<0oooo1@00000H0?ooo`<00000;`3oool3000000P0Yl3[00<000000:O0j`2W
`>/0102W`>/300000080Yl3[00<000000:Noj`2W_n/01`2W_n/010000000Yko[0:Noj`0000020:No
j`<000000P2V_NX00`000000oooo0?ooo`080?ooo`030000003oool0oooo0280oooo000U0?ooo`03
0000003oool0oooo01H0oooo0P0000030?ooo`030000003oool0oooo02T0oooo0`0000020:O0j`03
0000002W`>/0Yl3[00L0Yl3[00<000000:O0j`2W`>/00`0000050:O0j`030000002W_n/0Yko[00L0
Yko[00<000000:Noj`2W_n/00`0000050:JmjP030000003oool0oooo00T0oooo00<000000?ooo`3o
ool08@3oool002D0oooo00<000000?ooo`3oool04`3oool4000002d0oooo0`0000060:O0j`030000
002W`>/0Yl3[00H0Yl3[0`0000090:O0j`030000002W_n/0Yko[00H0Yko[100000080:JmjP030000
003oool0oooo00L0oooo0P00000S0?ooo`007@3oool4000000@0oooo00<000000?ooo`3oool04@3o
ool2000002h0oooo0`0000090:O0j`030000002W`>/0Yl3[00@0Yl3[0P0000020:O0j`030000002W
`>/0Yl3[00P0Yl3[00<000000:Noj`2W_n/00`2W_n/200000080Yko[0P0000090:JmjP030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0803oool002D0oooo00<000000?ooo`3oool03P3oool4
000002d0oooo0P0000020:O0j`030000002W`>/0Yl3[00P0Yl3[00<000000:O0j`2W`>/00`000005
0:O0j`030000002W`>/0Yl3[00L0Yl3[00<000000:Noj`2W_n/00`0000040:Noj`8000002@2V_NX0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01l0oooo000T0?ooo`8000003P3oool20000
02h0oooo0`0000050:O0j`030000002W`>/0Yl3[00L0Yl3[0`0000080:O0j`030000002W`>/0Yl3[
00L0Yl3[0`0000080:Noj`030000002V_NX0Y[gZ00L0Y[gZ0P00000:0?ooo`8000001@3oool20000
00@0oooo0P0000030?ooo`<000003@3oool00340oooo1000000/0?ooo`<000002@2W`>/00`000000
Yl3[0:O0j`040:O0j`8000000P2W`>/00`000000Yl3[0:O0j`070:O0j`030000002W`>/0Yl3[00@0
Yl3[0P0000020:Noj`030000002W_n/0Yko[00H0Yko[0P0000050:JmjP<000000P2T^nT00`000000
oooo0?ooo`070?ooo`800000103oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo
000000`0oooo000^0?ooo`<00000;P3oool200000080Yl3[00<000000:O0j`2W`>/0202W`>/00`00
0000Yl3[0:O0j`03000000D0Yl3[00<000000:O0j`2W`>/01`2W`>/00`000000Yl3[0:O0j`030000
00D0Yko[00<000000:Noj`2W_n/01@2W_n/200000080Y[gZ0`0000050:Bkj@030000003oool0oooo
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00H0oooo00@00000
0?ooo`3oool00000303oool002`0oooo0P0000000`3oool000000?ooo`0/0?ooo`8000001@2W`>/0
0`000000Yl3[0:O0j`070:O0j`<00000202W`>/00`000000Yl3[0:O0j`070:O0j`<00000202W_n/0
0`000000Yko[0:Noj`040:Noj`D000002@2T^nT00`000000oooo0?ooo`080?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`060?ooo`<000003@3oool000P0oooo1@000000
0`3oool000000?ooo`020?ooo`030000003oool0000000@000000P3oool2000000d0oooo0P00000^
0?ooo`<00000202W`>/00`000000Yl3[0:O0j`040:O0j`8000000P2W`>/00`000000Yl3[0:O0j`07
0:O0j`030000002W`>/0Yl3[00@0Yl3[0P0000020:O0j`030000002W_n/0Yko[00L0Yko[00<00000
0:Noj`2W_n/01P0000000`2U_N/000000:Bkj@090:Bkj@030000003oool0oooo00P0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo000:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02P3oool2000002X0oooo100000020:O0j`030000002W
`>/0Yl3[00L0Yl3[00<000000:O0j`2W`>/00`0000050:O0j`030000002W`>/0Yl3[00L0Yl3[00<0
00000:O0j`2W`>/00`0000050:O0j`030000002W_n/0Yko[00H0Yko[100000040:Fmj`040000002U
_N/0YKg[000000T0Y;_Y00<000000?ooo`3oool01`3oool00`000000oooo000000020?ooo`800000
2P3oool3000000`0oooo000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool00`000000oooo
0000000U0?ooo`@000001`2W`>/00`000000Yl3[0:O0j`060:O0j`<000002@2W`>/00`000000Yl3[
0:O0j`060:O0j`<00000202W`>/00`000000Yko[0:Noj`030:Noj`<000000P2V_n/00`000000YKg[
0:Fmj`040:Fmj`030000002U_N/0000000P0Y;_Y0`00000:0?ooo`030000003oool0oooo01/0oooo
00020?ooo`@00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00@000000?ooo`3oool0
00008P3oool200000080Yl3[00<000000:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`040:O0j`80
00000P2W`>/00`000000Yl3[0:O0j`080:O0j`040000002W`>/0Yl3[0:O0j`@000000P2W`>/00`00
0000Yl3[0:O0j`070:O0j`030000002W_n/0000000<00000102V_n/00`000000YKg[0:Fmj`050:Fm
j`030000002U_N/0000000<0Y;_Y100000020:6hj@030000003oool0oooo00T0oooo00<000000?oo
o`3oool06P3oool000X0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000`3oool010000000oooo0?ooo`00000;0?ooo`8000000`3oool00`000000oooo0?oo
o`0L0?ooo`<000001@2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00<000001@2W
`>/00`000000Yl3[0:O0j`070:O0j`@000001`2W`>/00`000000Yl3[0:O0j`050:O0j`@00000202V
_n/00`000000YKg[0:Fmj`050:Fmj`D000001`2Q^>T00`000000oooo0?ooo`080?ooo`8000006`3o
ool000T0oooo0P00000:0?ooo`800000103oool2000000`0oooo0P0000040?ooo`030000003oool0
oooo01P0oooo0`0000080:O0j`030000002W`>/0Yl3[00H0Yl3[0`0000090:O0j`030000002W`>/0
Yl3[00@0Yl3[0P0000020:O0j`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/00`2W`>/3
00000080Yko[00<000000:Joj`2V_n/01`2V_n/00`000000YKg[0:Fmj`030:Fmj`8000000P2T_>X0
0`000000XKSY0:6hj@060:6hj@030000003oool0oooo00T0oooo00<000000?ooo`3oool06@3oool0
02D0oooo00D0`<300;2`/02@T900oooo000000060?ooo`030000003oool0oooo01D0oooo0P000002
0:O0j`030000002W`>/0Yl3[00L0Yl3[00<000000:O0j`2W`>/00`2W`>/200000080Yl3[00<00000
0:O0j`2W`>/0202W`>/00`000000Yl3[0:O0j`03000000@0Yl3[00<000000:O0j`2W`>/01`2W`>/0
0`000000Yl3[00000003000000D0Yko[00<000000:Joj`2V_n/01P2V_n/00`000000YKg[0:Fmj`03
00000080Y;cZ00<000000:BljP0000002@2Q^>T00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01P0oooo000U0?ooo`050:2PX03oool0`<300?ooo`0000001`3oool2000001<0oooo0P000005
0:O0j`030000002W`>/0Yl3[00L0Yl3[00<000000:O0j`2W`>/00P0000050:O0j`030000002W`>/0
Yl3[00L0Yl3[0`0000080:O0j`030000002W`>/0Yl3[00D0Yl3[100000080:Noj`030000002V_n/0
Y[o[00H0Y[o[0`0000060:BljP030000002T_>X0000000P0XKSY00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0G0?ooo`007`3oool0103Ph>00P8200820P020P8020?ooo`05061PH02@T900
X:2P0?ooo`0000002@3oool00`000000oooo0?ooo`0=0?ooo`<00000202W`>/00`000000Yl3[0:O0
j`060:O0j`<00000202W`>/00`000000Yl3[0:O0j`040:O0j`8000000P2W`>/00`000000Yl3[0:O0
j`070:O0j`040000002W`>/0Yl3[0:O0j`@000000P2W`>/00`000000Yko[0:Noj`070:Noj`040000
002V_n/0Y[o[0:Joj`@000000P2U_^/00`000000Y;cZ0:BljP050:BljP030000002T_>X0000000L0
XKSY0P00000:0?ooo`8000006@3oool000P0oooo0P0000030?ooo`060000003oool0oooo0?ooo`00
0000oooo1@0000020?ooo`8000002@3oool00`2PX:00oooo0?ooo`02000000X0oooo00<000000?oo
o`3oool02P3oool200000080Yl3[00<000000:O0j`2W`>/01`2W`>/010000000Yl3[0:O0j`2W`>/4
00000080Yl3[00<000000:O0j`2W`>/01`2W`>/00`000000Yl3[0:O0j`03000000D0Yl3[00<00000
0:O0j`2W`>/01P2W`>/6000000D0Yl3[00<000000:Noj`2W_n/01P2W_n/4000000L0YKk[00<00000
0:BljP2T_>X0102T_>X00`000000Y;cZ000000030:6hj@@000000P2L/^P00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo01H0oooo00070?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`000000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3o
ool00`2PX:00/;2`0000000<0?ooo`030000003oool0oooo00H0oooo0`0000050:O0j`030000002W
`>/0Yl3[00H0Yl3[100000070:O0j`030000002W`>/0Yl3[00H0Yl3[0`0000080:O0j`030000002W
`>/0Yl3[00@0Yl3[1@0000080:O0j`030000002W_n/0Yko[00@0Yko[0P0000020:Joj`030000002U
_^/0YKk[00H0YKk[00<000000:BljP2T_>X01@2T_>X5000000H0W;;X00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0E0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo0P00
000<0?ooo`030000003oool0oooo0080oooo0`0000090:O0j`030000002W`>/0Yl3[00<0Yl3[0P00
00020:O0j`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/0102W`>/200000080Yl3[00<0
00000:O0j`2W`>/01`2W`>/00`000000Yl3[0:O0j`0500000080Yl3[00<000000:O0j`2W`>/01`2W
`>/00`000000Yko[0:Noj`03000000D0Y[o[00<000000:Fnj`2U_^/01P2U_^/010000000Y;cZ0:Bl
jP2T_>X5000000030:2ijP000000W;;X00L0W;;X00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`040?ooo`800000103oool2000000@0oooo0P0000030?ooo`0000<0oooo0000000000000P00
00030?ooo`800000103oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo100000020:O0j`030000
002W`>/0Yl3[00P0Yl3[00<000000:O0j`2W`>/00P0000050:O0j`030000002W`>/0Yl3[00H0Yl3[
00<000000:O0j`2W`>/00`0000050:O0j`030000002W`>/0Yl3[00H0Yl3[100000070:O0j`030000
002W`>/0Yl3[00H0Yl3[0`0000080:Joj`030000002U_^/0YKk[00H0YKk[100000050:2ijP030000
002P^NX0000000P0W;;X00<000000?ooo`3oool0203oool2000000@0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000020?ooo`00203oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02@3oool2000000X0oooo0`0000070:O0j`030000002W`>/0Yl3[00L0Yl3[0`000008
0:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000090:O0j`030000002W`>/0Yl3[0080Yl3[0`000002
0:O0j`030000002W`>/0Yl3[00L0Yl3[00@000000:O0j`2W`>/0Yl3[100000020:O0j`030000002V
_n/0Y[o[00L0Y[o[00@000000:Fnj`2U_^/0YKk[100000020:>mj`030000002P^NX0X;WZ00@0X;WZ
00<000000:2ijP000000202L/^P00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`00203oool3000000T0
oooo0P0000040?ooo`8000002@3oool0102`/;00oooo0?ooo`0000090?ooo`8000000P2W_n/00`00
0000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00@0Yl3[0P0000020:O0j`030000002W`>/0Yl3[
00L0Yl3[00<000000:O0j`2W`>/0100000020:O0j`030000002W`>/0Yl3[00P0Yl3[1@0000050:O0
j`030000002W`>/0Yl3[00H0Yl3[100000070:O0j`030000002V_n/0Y[o[00H0Y[o[100000070:>m
j`030000002P^NX0X;WZ00@0X;WZ00<000000:2ijP0000001@2L/^P4000000/0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo0P0000030?ooo`009@3oool0102`
/;00oooo0?ooo`0000070?ooo`8000001@2W_n/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0
Yl3[00<000001@2W`>/00`000000Yl3[0:O0j`060:O0j`<000001`2W`>/2000000H0Yl3[1@000007
0:O0j`030000002W`>/0Yl3[00@0Yl3[0P0000020:O0j`030000002W`>/0Yl3[00H0Yl3[00<00000
0:Joj`2V_n/0102V_n/200000080YKk[00<000000:>mj`2S_N/01P2S_N/00`000000X;WZ0:2ijP05
0:2ijPL00000102DZnH00`000000oooo0?ooo`080?ooo`8000000P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo000N0?ooo`040>3Ph020P800P8200820P0<0oooo
00<0h>3P0<30`00000001@3oool3000000P0Yko[00<000000:O0j`2W`>/01@2W`>/3000000T0Yl3[
00<000000:O0j`2W`>/00`2W`>/200000080Yl3[00<000000:O0j`2W`>/01`2W`>/00`000000Yl3[
0:O0j`0500000080Yl3[00<000000:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`03000000D0Yl3[
00<000000:O0j`2W`>/01P2W`>/00`000000Y[o[0:Joj`03000000D0YKk[00<000000:>mj`2S_N/0
1P2S_N/010000000X;WZ0:2ijP2P^NX6000000P0U:_V00<000000?ooo`3oool02@3oool010000000
oooo0?ooo`3oool2000000X0oooo0P0000030?ooo`009P3oool00`2PX:000000000000020?ooo`80
00000P2W_n/00`000000Yko[0:Noj`070:Noj`030000002W`>/0Yl3[00@000000P2W_n/00`000000
Yl3[0:O0j`080:O0j`030000002W`>/0Yl3[008000001@2W`>/00`000000Yl3[0:O0j`060:O0j`@0
00001`2W`>/00`000000Yl3[0:O0j`050:O0j`<00000202W`>/00`000000Yl3[0:O0j`060:O0j`<0
0000202U_^/00`000000Xkg[0:>mj`060:>mj`@00000102K]NX00`000000VkGZ0000000809B[iP03
0000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool002<0oooo00@0`<30071`L020P800
P820100000050:Noj`030000002W_n/0Yko[00H0Yko[0`0000070:Noj`800000202W`>/3000000P0
Yl3[00<000000:O0j`2W`>/00`2W`>/200000080Yl3[00<000000:O0j`2W`>/01P2W`>/00`000000
Yl3[0:O0j`030:O0j`8000000P2W`>/00`000000Yl3[0:O0j`070:O0j`040000002W`>/0Yl3[0:O0
j`@000000P2W_n/00`000000YKk[0:Fnj`070:Fnj`040000002S_N/0Xkg[0:>mj`@000000P2Q^n/0
0`000000VkGZ09^ejP0409^ejP800000202DZnH00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0100oooo000W0?ooo`800000202W_n/00`000000Yko[0:Noj`030:Noj`8000000P2X_nX00`00
0000Yko[0:Noj`070:Noj`040000002W`>/0Yl3[0:O0j`@000000P2X_n/00`000000Yl3[0:O0j`07
0:O0j`030000002W`>/00000008000001@2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0
Yl3[008000001@2W`>/00`000000Yl3[0:O0j`060:O0j`@000001`2W_n/00`000000YKk[0:Fnj`06
0:Fnj`@000001P2Q^n/00`000000VkGZ09^ejP0509^ejP800000202DZnH00`000000oooo0?ooo`08
0?ooo`8000004P3oool00240oooo0P0000040?ooo`8000002@2W_n/00`000000Yko[0:Noj`020000
00D0Z;oZ00<000000:Noj`2W_n/01P2W_n/4000000L0Z;o[00<000000:O0j`2W`>/01@2W`>/40000
00L0Yl3[00<000000:O0j`2W`>/01P2W`>/3000000P0Yl3[00<000000:O0j`2W`>/00`2W`>/20000
0080Yl3[00<000000:Noj`2W_n/01P2W_n/00`000000YKk[0:Fnj`040:Fnj`8000000P2T_^`00`00
0000XK_[0:6kj`060:6kj`030000002K]NX0VkGZ00D0VkGZ00<0000009B[iP2DZnH01P2DZnH00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00l0oooo000P0?ooo`040000003oool0oooo0000
00<0oooo00@000000?ooo`00000000001`2W_n/3000000P0Z;oZ00<000000:Noj`2W_n/00`2W_n/2
00000080Z;oZ00<000000:Roj`2X_n/01P2X_n/00`000000Yl3[0:O0j`020:O0j`@000000P2X`>/0
0`000000Yl3[0:O0j`060:O0j`040000002W`>/0Yl3[0:O0j`@000000P2W`>/00`000000Yl3[0:O0
j`070:O0j`030000002W`>/0Yl3[008000001@2W`>/00`000000Yko[0:Noj`060:Noj`030000002U
_^/0YKk[00<00000102T_^`00`000000XK_[0:6kj`060:6kj`030000002K]NX0VkGZ00<0VkGZ3@00
000<0?ooo`030000003oool0oooo00h0oooo000P0?ooo`040000003oool0oooo000000<0oooo00D0
00000?ooo`3oool0oooo000000020:Noj`@000000P2X_^X00`000000Z;oZ0:RojP070:RojP030000
002W_n/0Yko[008000001@2X_nX00`000000Z;o[0:Roj`060:Roj`H000001@2X`>/00`000000Yl3[
0:O0j`050:O0j`@000001`2W`>/00`000000Yl3[0:O0j`060:O0j`<000001`2W`>/00`000000Yko[
0:Noj`060:Noj`<00000202T_^`00`000000XK_[0:6kj`050:6kj`H000000`2C[nT2000000L0R:7T
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0>0?ooo`00803oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo00<0oooo0P0000070:RnjP030000002X_nX0Z;oZ00H0Z;oZ
0`0000080:RojP030000002X_n/0Z;o[00<0Z;o[1@0000080:S0j`030000002W`>/0Yl3[00<0Yl3[
0P0000020:O0j`030000002W`>/0Yl3[00L0Yl3[00@000000:O0j`2W`>/0Yl3[100000020:O0j`03
0000002W`>/0Yl3[00H0Yl3[00@000000:Noj`2W_n/0Yko[100000020:Joj`030000002T_^`0Y;k/
00H0Y;k/00@000000:6kj`2Q^n/0XK_[1000000209bhk0030000002C[nT0TjoY00D0TjoY00<00000
08RQi028XN@01P28XN@00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo000P0?oo
o`040000003oool0oooo00000080oooo0P0000050?ooo`030000002X_^X0Z;kZ00H0Z;kZ00<00000
0:RojP2X_nX00`2X_nX200000080Z;kY00<000000:RojP2X_nX01`2X_nX00`000000Z;o[00000004
00000080Z;o[00<000000:S0j`2X`>/01`2X`>/00`000000Yl3[0:O0j`02000000D0Yl3[00<00000
0:O0j`2W`>/01P2W`>/4000000L0Yl3[00<000000:O0j`2W`>/01@2W`>/4000000L0Y[o[00<00000
0:Bnk02T_^`01@2T_^`4000000H0W;S/00<0000009>_j@2C[nT01P2C[nT00`000000R:7T08RQi005
08RQi0030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool5000000@0oooo000Q0?oo
o`8000000`3oool00`000000oooo0?ooo`050?ooo`030000002X_^X0Z;kZ00H0Z;kZ00<000000:Ro
jP2X_nX00P0000050:Rnj@030000002X_nX0Z;oZ00D0Z;oZ100000070:Roj`8000001`2X`>/30000
00P0Yl3[00<000000:O0j`2W`>/00`2W`>/200000080Yl3[00<000000:O0j`2W`>/01`2W`>/00`00
0000Yl3[0:O0j`0400000080Yl3[00<000000:Joj`2V_n/01`2V_n/00`000000Y;k/0:Bnk0040000
0080X[g/00<0000009bhk02L^>`01P2L^>`00`000000TjoY09>_j@0509>_j@8000001P28XN@00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool002H0
oooo00<000000?ooo`3oool01P3oool00`000000Z;kZ0:RnjP050:RnjP<00000202X_^T010000000
Z;oZ0:RojP2X_nX400000080Z;kY00<000000:Roj`2X_n/01`2X_n/00`000000Z<3[0:S0j`040000
0080Z;o[00<000000:O0j`2W`>/01`2W`>/00`000000Yl3[0:O0j`02000000D0Yl3[00<000000:O0
j`2W`>/01P2W`>/3000000L0Yl3[00<000000:Joj`2V_n/01P2V_n/3000000L0X[g/00<0000009bh
k02L^>`01P2L^>`00`000000TjoY09>_j@0509>_j@0300000028XN@0R:7T00D0R:7T00<000000?oo
o`3oool02P3oool2000000H0oooo00<000000?ooo`3oool0103oool002H0oooo00<000000?ooo`3o
ool01`3oool00`000000Z;kZ0:RnjP0400000080ZKgX00<000000:Rnj@2X_^T01`2X_^T5000000D0
Z;kY00<000000:Roj`2X_n/01P2X_n/3000000L0Z;o[0P0000070:O0j`<000001`2W`>/00`000000
Yl3[0:O0j`040:O0j`8000000P2W`>/00`000000Yl3[0:O0j`060:O0j`040000002V_n/0Y[o[0:Jo
j`@000000P2U_n`00`000000X[g/0::mk0050::mk0030000002L^>`0W;S/00H0W;S/00<0000009>_
j@2C[nT00`2C[nT5000000D0R:7T00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00040?ooo`8000000`3oool01P000000oooo0?ooo`3oool00000
0?ooo`D000000P3oool2000000d0oooo0P00000:0?ooo`8000001`2Y_NP2000000@0Z;kY1P000008
0:Rnj@030000002X_n/0Z;o[00<0Z;o[0P0000020:RojP030000002X_n/0Z;o[00L0Z;o[00<00000
0:O0j`2W`>/0100000020:O0j`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/00`000005
0:O0j`030000002W`>/0Yl3[00D0Yl3[100000060:Fok0030000002R_N`0X[g/00H0X[g/00<00000
09bhk02L^>`00`2L^>`8000000<0R:KX1P00000208RQi0030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`000`3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000ZKgX0:Vmj0070:Vmj0L000000P2Y
_NP00`000000Z;kY0:Rnj@070:Rnj@030000002X_n/0Z;o[008000001@2X_nX00`000000Z;o[0:Ro
j`060:Roj`<000001`2W`>/00`000000Yl3[0:O0j`050:O0j`<00000202W`>/00`000000Yl3[0:O0
j`030:O0j`8000000P2W`>/00`000000YKo/0:Fok0060:Fok0030000002R_N`0X[g/00D0X[g/1P00
000409Jdk00300000028Y^P0R:KX00D0R:KX00<0000007NBh01gT^000P1gT^03000000`0oooo0`00
00030?ooo`8000001P3oool000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000303o
ool00`000000ZKgX0:Vmj0040:Vmj0D000001`2Y_NP2000000L0Z;kY0`0000070:RojP030000002X
_n/0Z;o[00@0Z;o[0P0000020:Roj`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/01000
00020:O0j`030000002W`>/0Yl3[00L0Yl3[00<000000:O0j`2W`>/00P0000050:O0j`030000002U
_n`0YKo/00D0YKo/00@000000::mk02R_N`0X[g/1000000209nkk0030000002F]>`0U[C/00D0U[C/
00<0000008RVj028Y^P01@28Y^P2000000D0Mi;P00<000000?ooo`3oool01`3oool4000000030?oo
o`000000oooo00X0oooo00040?ooo`800000103oool00`000000oooo000000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00`0oooo
00@000000:Vmj02Y_NP0ZKgX100000020:Zki@030000002Y_NP0ZKgX00L0ZKgX00<000000:Rnj@2X
_^T0100000020:Vnj0030000002X_nX0Z;oZ00H0Z;oZ00<000000:Roj`2X_n/00`0000050:Roj`03
0000002W`>/0Yl3[00D0Yl3[0`0000070:O0j`030000002W`>/0Yl3[00H0Yl3[0`0000070:O0j`03
0000002U_n`0YKo/00D0YKo/1000000609nkk0030000002F]>`0U[C/00H0U[C/00<0000008RVj028
Y^P01@28Y^P2000000D0Mi;P00<000000?ooo`3oool00`3oool3000000D0oooo00<000000?ooo`3o
ool02@3oool000@0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool03@3oool5000000D0Z[_U00<000000:Vmj02Y_NP01P2Y_NP3000000L0ZKkX00<000000:Ro
jP2X_nX01@2X_nX3000000T0Z;o[00<000000:O0j`2W`>/0100000020:S0j`030000002W`>/0Yl3[
00H0Yl3[00@000000:O0j`2W`>/0Yl3[100000020:O0j`030000002W`>/0Yl3[00H0Yl3[00<00000
0:Fok02U_n`0100000020:Bnk0030000002O^n`0Wk_/00H0Wk_/00<0000009Jdk02F]>`01@2F]>`0
0`000000R:KX08RVj00508RVj08000001@1gT^000`000000oooo0?ooo`03000000P0oooo00<00000
0?ooo`3oool02@3oool000@0oooo0`0000090?ooo`800000103oool2000000T0oooo00D0/;2`0?oo
o`3oool0oooo0000000<0?ooo`<0000000<0oooo000000000000202Z^nD00`000000ZKgX0:Vmj003
0:Vmj08000000P2[^nD00`000000ZKkX0:Vnj0060:Vnj0030000002X_nX0Z;oZ00@000000P2Y_nT0
0`000000Z;o[0:Roj`070:Roj`<000001`2X`>/00`000000Yl3[0:O0j`050:O0j`@000001P2W`>/0
0`000000Yl3[0:O0j`060:O0j`<000001`2T_^`00`000000Wk_/09nkk00509nkk0030000002F]>`0
U[C/00<0U[C/1`00000408RVj08000001@1gT^02000000`0oooo00<000000?ooo`3oool0203oool0
0240oooo00D0/;2`0?ooo`3oool0oooo000000090?ooo`<000001@3oool00`000000Z[_U0:Zki@07
0:Zki@030000002Y_NP0ZKgX008000001@2[^nD00`000000ZKkX0:Vnj0060:Vnj08000001`2Y_nT2
000000D0Z;o[0P0000020:VojP030000002X`>/0Z<3[00H0Z<3[00<000000:O0j`2W`>/010000002
0:O0j`030000002W`>/0Yl3[00H0Yl3[00@000000:O0j`2W`>/0Yl3[100000020:Noj`030000002T
_^`0Y;k/00H0Y;k/00<0000009nkk02O^n`00P2O^n`8000000<0SJk/00@0000007VKi`1iVnL0NI_W
1`00000407NBh0030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool001X0oooo00@0
h>3P0820P020P800P8200`3oool0103Ph>00`<300?ooo`0000070?ooo`<000002@3oool2000000L0
Z[_U0`0000080:^ki@030000002Y_^P0ZKkX00<0ZKkX0P0000000`2[_NH000000:Voj@080:Voj@03
0000002X_n/0Z;o[008000001@2Y_nX00`000000Z<3[0:S0j`050:S0j`<000001`2W`>/00`000000
Yl3[0:O0j`050:O0j`@000001P2W_n/00`000000Y;k/0:Bnk0060:Bnk0D00000102K^Nd00`000000
SJk/08f^k00508f^k0030000001iVnL0NI_W00D0NI_W1000000307NBh0030000003oool0oooo00X0
oooo00<000000?ooo`3oool0203oool00280oooo00@0X:2P0?ooo`00000000000`3oool3000000h0
oooo00<000000:Zki@2Z^nD0100000020:fhh@030000002[^nD0Zk_U00L0Zk_U00<000000:Vnj02Y
_^P00P0000040:^miP8000001`2Y_nT3000000L0ZKoZ00<000000:S0j`2X`>/00`2X`>/200000080
Z<3[00<000000:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<000000:Noj`2W
_n/01P2W_n/010000000Y;k/0:Bnk02T_^`400000080Xkk/00<0000009^ik@2K^Nd01@2K^Nd00`00
0000SJk/08f^k00408f^k0030000001iVnL0NI_W00D0NI_W00@000000660fP000000HH3J1000000<
0?ooo`030000003oool0oooo00P0oooo000O0?ooo`070<30`01`L700P8200820P03oool000000?oo
o`0300000180oooo0P0000070:fhh@8000001`2[^nD3000000P0ZkgV00<000000:Voj@2Y_nT01000
00020:^nj0030000002Y_nX0ZKoZ00H0ZKoZ00<000000:S0j`2X`>/00P0000050:S0j`030000002W
`>/0Yl3[00D0Yl3[0`0000070:O0j`030000002W_n/0Yko[00D0Yko[100000060:>nk0030000002K
^Nd0VkW]00H0VkW]00<0000008f^k02=[^`0102=[^`00`000000NI_W07VKi`0507VKi`030000001Q
P=X0000000<0HH3J0P00000;0?ooo`030000003oool0oooo00P0oooo00020?ooo`D0000000<0oooo
0000003oool00P3oool00`000000oooo0000000400000080oooo0P00000=0?ooo`8000005P3oool0
0`000000[KSQ0:fhh@070:fhh@030000002[^nD0Zk_U00@000000P2^^N800`000000ZkgV0:^miP06
0:^miP<000001`2[_^P00`000000ZKoZ0:VojP050:VojP<000001`2X`>/00`000000Yl3[0:O0j`03
0:O0j`8000000P2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W_n/0Yko[00@000000P2V_n`0
0`000000Xkk/0:>nk0060:>nk0030000002K^Nd0VkW]00<0VkW]1`00000208f^k0030000001iVnL0
NI_W00D0NI_W00@000000660fP1QP=X000000`1QP=X00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00P0oooo00040?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0E0?ooo`030000002]^>40[KSQ00H0[KSQ0`0000070:jihP030000002[_NH0ZkgV00<0ZkgV0P00
00020:jli0030000002[_^P0ZkkX00H0ZkkX00<000000:VojP2Y_nX0100000020:Voj@030000002X
`>/0Z<3[00H0Z<3[00<000000:O0j`2W`>/00P0000050:O0j`030000002W`>/0Yl3[00D0Yl3[0`00
00070:Jok0030000002S_^`0Xkk/00D0Xkk/1P00000409JfkP0300000021Y^`0PJK/00H000001@1i
VnL010000000HH3J0660fP0000030660fP030000003oool0oooo00P0oooo00<000000?ooo`3oool0
203oool000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`8000005P3oool00`000000[KSQ
0:fhh@030:fhh@8000000P2`]=/00`000000[[WR0:jihP060:jihP030000002[_NH0ZkgV00800000
1@2^_>@00`000000ZkkX0:^nj0050:^nj0<000001`2Y_nT00`000000Z<3[0:S0j`050:S0j`<00000
202W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<000000:Jok02V_n`01P2V_n`00`000000Xkk/
0:>nk00400000080XKg]00<0000009JfkP2F]^h01@2F]^h00`000000PJK/086Vk004086Vk0030000
001TRn<0000000<0000000D0NI_W0000001QP=X0HH3J000000030660fP030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo01@0oooo00<000000:fhh@2]^>400P0000050;2df`030000002^^N80[[WR00D0
[[WR0`0000070:jli0030000002[_^P0ZkkX00<0ZkkX0P0000020:fniP030000002Y_nT0ZKoY00H0
ZKoY00<000000:S0j`2X`>/0100000020:S0j`030000002W`>/0Yl3[00H0Yl3[0`0000070:O0j`03
0000002V_n`0Y[o/00D0Y[o/0`0000060:6mk@030000002F]^h0U[K^00H0U[K^00<00000086Vk021
Y^`01021Y^`00`000000I8_S06B;h`0206B;h`<000000P1QP=X01@000000HH3J0660fP1QP=X00000
00X0oooo00<000000?ooo`3oool01`3oool000@0oooo00D000000?ooo`3oool0oooo000000030?oo
o`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00000A0?ooo`030000003o
ool0oooo01@0oooo0P0000070;2df`030000002^^N80[[WR00<0[[WR0P0000020;6gg@030000002^
_>@0[[cT00H0[[cT00<000000:^nj02[_^P00P0000050:fniP030000002Y_nT0ZKoY00D0ZKoY0`00
00070:S0j`030000002W`>/0Yl3[00<0Yl3[0P0000020:O0j`030000002W`>/0Yl3[00H0Yl3[00<0
00000:Jok02V_n`0100000020:Jok0030000002Q_Nd0XKg]00D0XKg]00<0000009JfkP2F]^h01@2F
]^h00`000000PJK/086Vk004086Vk0030000001TRn<0I8_S00@0I8_S0`0000001@1QP=X000000660
fP1QP=X0000000X0oooo00<000000?ooo`3oool01`3oool000<0oooo0P00000:0?ooo`800000103o
ool2000000P0oooo00<0`<300;2`/02@T900203oool00`000000oooo0?ooo`0D0?ooo`030000002`
]=/0/;CK00H0/;CK00<000000:jihP2^^N800P0000050;6gg@030000002^_>@0[[cT00D0[[cT0`00
00080:fniP030000002Y_nT0ZKoY00@000000P2[_nT00`000000Z<3[0:S0j`060:S0j`030000002W
`>/0Yl3[008000001@2W`>/00`000000Yl3[0:O0j`050:O0j`<000001P2V_n`00`000000XKg]0:6m
k@050:6mk@030000002F]^h0U[K^00<0U[K^1`000003086Vk0030000001TRn<0I8_S00@0I8_S00<0
000004IXd@0000000P0000020660fP030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3o
ool001l0oooo00<0X:2P0?ooo`30`<002@3oool00`000000oooo0?ooo`0C0?ooo`030000002`]=/0
/;CK00L0/;CK0P0000070;6gg@030000002^_>@0[[cT00<0[[cT0P0000020;6jh@030000002]_^H0
[KkV00H0[KkV0`0000070:^oj@030000002X`>/0Z<3[00D0Z<3[0`0000080:O0j`030000002W`>/0
Yl3[00@000000P2W`>/00`000000Y[o/0:Jok0050:Jok0030000002Q_Nd0XKg]0080XKg]20000004
08jbk`030000001aVn/0LI_[00D000001@1TRn<010000000AVSA04IXd@16J=42000000030660fP00
0000oooo00P0oooo00<000000?ooo`3oool01`3oool001T0oooo00@0h>3P0820P020P800P8200P3o
ool00`1PH600T92@0:2PX00:0?ooo`800000503oool00`000000/;CK0;2df`040;2df`80000000<0
];3D0000002a]md01`2a]md00`000000[[cT0:jli002000000D0/K[Q00<000000:fniP2]_^H00`2]
_^H200000080[kgT00<000000:^oj@2[_nT01P2[_nT00`000000Z<3[0:S0j`0400000080Z<3[00<0
00000:O0j`2W`>/01P2W`>/3000000H0Yl3[00<000000:Jok02V_n`01@2V_n`5000000@0W[c]00<0
000008jbk`2>/^l01@2>/^l00`000000LI_[076Kj`04076Kj`<00000101TRn<010000000AVSA04IX
d@16J=44000000P0oooo00<000000?ooo`3oool01`3oool001l0oooo00<0X:2P0?ooo`3oool0303o
ool00`000000oooo0?ooo`0B0?ooo`040000002`]=/0/;CK0;2df`800000102d/=@00`000000/KOM
0;6gg@060;6gg@800000202a^^400`000000[KkV0:fniP02000000D0[kgT00<000000:^oj@2[_nT0
1@2[_nT3000000L0Z<3[00<000000:O0j`2W`>/00`2W`>/200000080Yl3[00<000000:O0j`2W`>/0
1@2W`>/00`000000Y[o/0:Jok00400000080YKo/00<0000009jlk@2N_>d01@2N_>d00`000000S[;_
08jbk`0508jbk`030000001aVn/0LI_[00@0LI_[00@0000004Qfg000000000000P1TRn<00`000000
AVSA04IXd@0204IXd@0300000016J=40000000P0oooo00<000000?ooo`3oool01`3oool00200oooo
00<0X:2P0;2`/03oool0303oool00`000000oooo0?ooo`0A0?ooo`040000002`]=/00000000000L0
];3D00<000000;6gg@2a]md00`2a]md2000000030;Fdf0000000/K[Q00L0/K[Q0`0000080:nmi003
0000002[_nT0ZkoY00@000000P2/_nP00`000000Z<3[0:S0j`060:S0j`030000002W`>/0Yl3[0080
0000102W`>/00`000000Yl3[0:O0j`050:O0j`<000001`2U_n`00`000000W[c]09jlk@0509jlk@03
0000002>/^l0S[;_00@0S[;_00<00000076Kj`1aVn/0101aVn/010000000B7KL04Qfg018M]`20000
000306B;h`000000AVSA00<0AVSA0P0000080?ooo`030000003oool0oooo00L0oooo000`0?ooo`03
0000003oool0oooo0140oooo00<000000;B`e02d/=@0202d/=@00`000000/KOM0;6gg@02000000@0
]KCH00<000000;6jh@2a^^400`2a^^4200000080];WL00<000000:nmi02__N@01P2__N@3000000L0
[;oX00<000000:S0j`2X`>/01@2X`>/3000000L0Yl3[00<000000:O0j`2W`>/0100000020:O0j`03
0000002U_n`0YKo/00H0YKo/00<0000009jlk@2N_>d00P2N_>d<000000D0LI_[00<0000004Qfg018
M]`00P18M]`2000000@0AVSA00<0000004IXd@000000203oool00`000000oooo0?ooo`060?ooo`00
<@3oool200000180oooo00<000000;B`e02d/=@0202d/=@2000000L0]KCH00<000000;6jh@2a^^40
0P0000050;Big0030000002__N@0[kgT00<0[kgT0P0000020;:mhP030000002/_nP0[;oX00H0[;oX
00<000000:S0j`2X`>/0100000020:W0jP030000002W`>/0Yl3[00D0Yl3[0`0000060:O0j`030000
002U_n`0YKo/00H0YKo/1@00000409^jkP0300000024[>l0Q:c_00@0Q:c_1@0000000`1aVn/00000
04Qfg00404Qfg0<000000`16J=42000000P0oooo00<000000?ooo`3oool01P3oool003<0oooo00<0
00000?ooo`3oool0403oool00`000000];3D0;B`e0050;B`e080000000<0^Jc<0000002e]=P01`2e
]=P2000000P0];WL00<000000:nmi02__N@00P0000050;:mhP030000002/_nP0[;oX00D0[;oX0`00
00070:W0jP030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`050:O0j`040000002U
_n`0YKo/0:Fok0@000000P2U_n`00`000000Vk[^09^jkP0409^jkP0300000024[>l0Q:c_00@0Q:c_
00<0000005Z<i`1JS>L00P1JS>L3000000D0B7KL00@0000005I]cP00000000000P16J=42000000L0
oooo00<000000?ooo`3oool01P3oool003@0oooo00<000000?ooo`3oool0403oool00`000000];3D
0;B`e0020;B`e0800000102i[<`00`000000]KCH0;Fdf0030;Fdf080000000<0^[7A0000002d^M`0
202d^M`2000000P0/[gR00<000000:boj02/_nP0100000020:foi`030000002Y`>X0ZL3Z00D0ZL3Z
0`0000070:O0j`030000002W`>/0Yl3[00@0Yl3[100000060:Fok0030000002K^^h0Vk[^00D0Vk[^
00<0000008B/k`24[>l01024[>l00`000000FXcW05Z<i`0305Z<i`8000001018M]`010000000EVg>
05I]cP1FKLh20000000304IXd@000000oooo00H0oooo00<000000?ooo`3oool01P3oool003D0oooo
00<000000?ooo`3oool0403oool010000000];3D0000000000060;V/c0030000002e]=P0]KCH0080
]KCH00<000000;Zad@2j/M400P2j/M400`000000];WL0;Big0040;Big080000000<0^KOG0000002b
_N801`2b_N83000000H0[KoW00<000000:W0jP2Y`>X00`2Y`>X200000080ZL3Z00<000000:O0j`2W
`>/01P2W`>/00`000000Yl3[0:O0j`0300000080Yl3[00<000000:Fok02U_n`01P2U_n`00`000000
Vk[^09^jkP0209^jkPL000000P24[>l00`000000FXcW05Z<i`0405Z<i`<000000`18M]`00`000000
EVg>05I]cP0205I]cP<000001P3oool00`000000oooo0?ooo`060?ooo`00=P3oool200000140oooo
00<000000;V/c02i[<`01`2i[<`010000000]KCH0000000000060;Zad@030000002d^M`0];WL0080
];WL00<000000;Vge`2i]mL00P2i]mL00`000000/[gR0;:mhP030;:mhP8000000P2e_=l00`000000
[KoW0:foi`050:foi`030000002Y`>X0ZL3Z008000001@2Y`>X00`000000Yl3[0:O0j`050:O0j`<0
00001P2W`>/00`000000YKo/0:Fok0050:Fok0D00000102G^>l00`000000MjG_07NUk`04000000D0
FXcW00@0000002IKd00VFm0000000P18M]`00`000000EVg>05I]cP0405I]cP030000003oool0oooo
00@0oooo00<000000?ooo`3oool01P3oool003P0oooo00<000000?ooo`3oool03`3oool00`000000
^Jc<0;V/c0070;V/c0030000002j/M40^[7A00L0^[7A00@000000;Big000000000001P2i]mL00`00
0000/[gR0;:mhP02000000D0]KcO00<000000:foi`2]_nL0102]_nL3000000P0ZL3Z00<000000:O0
j`2W`>/0100000020:O0j`030000002W`>/0Yl3[00D0Yl3[00<000000:Fok02U_n`0100000020:Bn
k0030000002G^>l0UkS_00@0UkS_00<0000007NUk`1gYNl0101gYNl2000000@0FXcW00@0000002IK
d00VFm0000000P18M]`00`000000EVg>05I]cP0405I]cP030000003oool0oooo00<0oooo00<00000
0?ooo`3oool01P3oool003T0oooo00<000000?ooo`3oool03P3oool00`000000^Jc<0;V/c0060;V/
c0030000002mYl@0000000T0^[7A00<000000;Vge`2i]mL01`2i]mL2000000P0]KcO00<000000:fo
i`2]_nL00`0000020:noi@030000002Y`>X0ZL3Z00H0ZL3Z0`0000060:O0j`030000002W`>/0Yl3[
00D0Yl3[0`0000060:Bnk0030000002G^>l0UkS_00D0UkS_00<0000007NUk`1gYNl00`1gYNl01000
0000?GSP00000000000205Z<i`040000000VFm009U_@02IKd0<000001P1FKLh2000000D0oooo00<0
00000?ooo`3oool01@3oool003X0oooo00<000000?ooo`3oool03P3oool00`000000^Jc<0;V/c004
0;V/c0040000002mYl@0_JO4000000L0^[7A0P0000000`2n[/X000000;Vge`060;Vge`030000002m
]M80000000T0]KcO0P0000060:noi@8000000P2Y`>X400000080Z/3Y00<000000:O0j`2W`>/01@2W
`>/00`000000Yl3[0:O0j`0400000080Yl3[00<000000:Bnk02T_^`01@2T_^`00`000000UkS_09Nh
k`0209Nhk`D00000101gYNl00`000000?GSP03ehh0020000000305Z<i`0000009U_@00<09U_@0P00
000605I]cP030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool003/0oooo00<00000
0?ooo`3oool03@3oool00`000000^Jc<0;V/c0020;V/c0800000102mYl@00`000000^[7A0;Zad@03
0;Zad@030000002n[/X0_Zk:0080_Zk:00<000000;Vge`2i]mL00`2i]mL01@000000_KGB0;fedP2m
]M80000000H0]KcO0P0000000`2i^m/000000:noi@060:noi@<000001P2Z`>T00`000000Yl3[0:O0
j`050:O0j`<000001`2W`>/00`000000Y;k/0:Bnk0020:Bnk0L000001@3oool5000000@0?GSP0P00
000502IKd0T00000103oool00`000000oooo0?ooo`050?ooo`00?03oool2000000h0oooo00@00000
0;V/c02i[<`000001`2mYl@01@000000^[7A0;Zad@2j/M40000000D0_Zk:00@000000;Vge`2i]mL0
^KOG0P0000040;fedP030000002e_=l0]KcO0080]KcO0P0000030;Vkf`030000002__nD0[koU00<0
[koU0P0000020;:oh`030000002Z`>T0Z/3Y00D0Z/3Y00<000000:O0j`2W`>/0100000020:S0j`03
0000002W`>/0Yl3[00D0Yl3[1@00000@0?ooo`8000001@0mN>02000000<09U_@00<0000008JCf@26
TmT01P26TmT01@000000oooo0?ooo`3oool0000000L0oooo000n0?ooo`030000003oool0oooo00/0
oooo00<000000;V/c0000000202mYl@010000000^[7A0000000000070;j^bP030000002i]mL00000
00L0_KGB00@000000;Flg`00000000001P2i^m/00`000000[koU0:noi@02000000@0/[oS00<00000
0:[0j@2Z`>T01@2Z`>T3000000L0Z<3[00<000000:O0j`2W`>/01000000G0?ooo`8000000`0mN>00
0`000000:eW=0000000302IKd00300000026TmT0QY?I00D0QY?I0P0000020?ooo`030000003oool0
oooo00D0oooo000o0?ooo`030000003oool0oooo00/0oooo00<000000;fWa02mYl@0202mYl@00`00
0000_Zk:0;j^bP080;j^bP030000002m]M80_KGB00L0_KGB00<000000;Vkf`2i^m/01`2i^m/20000
00L0/[oS00<000000:[0j@2Z`>T0100000020:_0j@030000002X`>/0Z<3[00D0Z<3[0`00000M0?oo
o`8000000P0mN>001P000000:eW=0000000000009U_@000000P0QY?I00@000000?ooo`3oool00000
1`3oool00400oooo00<000000?ooo`3oool02`3oool00`000000_JO40;fWa0060;fWa00300000030
Y;`0000000P0_Zk:00<000000<:[``0000001P2m]M82000000030<6bc0000000^K_K00D0^K_K0P00
00000`2m^]L000000;:oh`070;:oh`8000001`2[`>T00`000000Z<3[0:S0j`0400000280oooo0P00
00001`0mN>00000002]Ic@0[FLd0000002IKd00000001`26TmT2000000030?ooo`000000oooo00H0
oooo00110?ooo`8000002`3oool00`000000_JO40;fWa0050;fWa00400000030Y;`0`:Bl000000L0
_Zk:00@000000<:[``32Zl<000001@2m]M800`000000`K;<0<6bc0020<6bc0030000002i^m/0^K_K
0080^K_K00<000000;fje`2m^]L00P2m^]L00`000000/[oS0;:oh`030;:oh`80000000<0];kQ0000
002[`>T01P2[`>T3000002P0oooo0P00000302]Ic@8000000`26TmT400000080YL?_00<000000?oo
o`0000001P3oool004<0oooo00<000000?ooo`3oool02@3oool00`000000_JO40;fWa0030;fWa003
00000030Y;`0`:Bl0080`:Bl00<000000;j^bP2n[/X00P2n[/X2000000@0`Z_300D000000;fedP2m
]M80_KGB000000060<6bc0040000002i^m/00000000000H0_K[G00<000000;:oh`2b_n<00P000004
0;Bnh@8000000P2[`>T3000002d0oooo00<0000002]Ic@0[FLd00P0[FLd3000000H0YL?_0`000006
0?ooo`00A03oool00`000000oooo0?ooo`080?ooo`030000002mYl@0_JO40080_JO400<000000<2T
_030Y;`01030Y;`010000000_Zk:0;j^bP0000060<:[``040000002m]M800000000000P0`K;<00<0
00000;fje`2m^]L01`2m^]L2000000L0];kQ0`00000a0?ooo`8000000`0[FLd00`000000YL?_0:G3
k`060:G3k`8000001P3oool004D0oooo00<000000?ooo`3oool0203oool010000000_JO40;fWa000
00070<2T_0030000002n[/X0000000P0`Z_300<000000<6bc031//`01`31//`00`000000aK350000
00060;fje`80000000<0`KWB0000002d_^40102d_^42000003H0oooo0P0000000`0[FLd000000:G3
k`070:G3k`8000001P3oool004H0oooo00<000000?ooo`3oool01`3oool00`000000_JO400000009
0<2T_00300000032Zl<0`Z_300H0`Z_300<000000<JX_00000001`31//`010000000aK350<F`a@00
00040;fje`8000001031^M800`000000];kQ0;Bnh@02000003X0oooo0`0000030:G3k`@00000203o
ool004L0oooo0P0000080?ooo`0300000030Y;`0`:Bl00L0`:Bl00<000000<j`_00000001P32Zl<0
1@000000aZRl0<JX_036Z;`0000000@0`K;<0P0000040<F`a@040000002m^]L00000000000L0`KWB
0P00000n0?ooo`@00000303oool004T0oooo00<000000?ooo`3oool01@3oool00`000000`:Bl0<2T
_0060<2T_0040000003>/;`0c[2l000000H0`Z_300D000000<JX_036Z;`0aZRl000000030<6bc003
00000035/<D0aK3500D0aK3500<000000<6idP31^M801P31^M800`000000oooo0?ooo`0j0?ooo`@0
0000403oool004X0oooo00<000000?ooo`3oool01@3oool00`000000`:Bl0<2T_0050<2T_0050000
003>/;`0c[2l0<j`_00000001032Zl<00`000000aZRl0<JX_0030<JX_00300000031//`0000000L0
aK3500<000000<V^_`0000001P31^M800`000000oooo0?ooo`0h0?ooo`<00000503oool004/0oooo
00<000000?ooo`3oool0103oool00`000000`:Bl0<2T_0040<2T_0030000003>/;`0c[2l0080c[2l
00D000000<:[``32Zl<0`Z_3000000070<JX_00300000035/<D0aK3500D0aK3500D000000<V^_`39
[[l0bJjo000000040<6idP030000003oool0oooo03D0oooo1000000G0?ooo`00C03oool2000000D0
oooo00<000000<2T_030Y;`00P30Y;`00`000000c[2l0<j`_0040<j`_00300000032Zl<0000000L0
aZRl00<000000=6a^P0000001P35/<D01@000000bJjo0<V^_`39[[l0000000<0`KWB00<000000?oo
o`3oool0<P3oool4000001/0oooo001>0?ooo`030000003oool0oooo0080oooo00D000000<2T_030
Y;`0`:Bl000000070<j`_00300000032Zl<0000000L0aZRl00<000000=6a^P0000001@35/<D00`00
0000bJjo0<V^_`030<V^_`0300000031^M8000000340oooo1000000O0?ooo`00C`3oool00`000000
oooo0?ooo`020?ooo`0400000030Y;`0`:Bl000000P0c[2l00<000000<JX_036Z;`01@36Z;`01@00
0000dK6j0=6a^P3A/KX0000000<0aK3500<000000<V^_`39[[l01@39[[l00`000000oooo0?ooo`0/
0?ooo`@000008`3oool00500oooo00L000000?ooo`3oool0oooo00000030Y;`0000000P0c[2l0P00
00060<JX_0030000003A/KX0dK6j00<0dK6j00<000000<F`a@0000001`39[[l00`000000oooo0?oo
o`0Z0?ooo`<000009`3oool00540oooo00D000000?ooo`3oool0oooo000000080<j`_0040000003I
aLH0fLG6000000@0aZRl00<000000=6a^P3A/KX0103A/KX00`000000aK35000000060<V^_`030000
003oool0oooo02L0oooo1000000Z0?ooo`00DP3oool200000080oooo00<000000<j`_03>/;`0103>
/;`01@000000fLG60=W5aP3IaLH0000000@0aZRl00<000000=6a^P3A/KX01@3A/KX00`000000bJjo
0<V^_`050<V^_`030000003oool0oooo02<0oooo1000000^0?ooo`00E03oool00`000000oooo0000
00050<j`_0030000003IaLH0fLG600<0fLG600@000000<JX_036Z;`000001`3A/KX2000000H0bJjo
00<000000?ooo`3oool0803oool400000380oooo001E0?ooo`030000003oool0000000@0c[2l00<0
00000=W5aP3IaLH00`3IaLH00`000000aZRl000000080=6a^P030000003Ma<00000000@0bJjo00<0
00000?ooo`3oool07P3oool3000003H0oooo001F0?ooo`030000003oool000000080c[2l00<00000
0=W5aP3IaLH01@3IaLH2000000L0dK6j00@000000=g4`03Ma<0000000`39[[l00`000000oooo0?oo
o`0K0?ooo`@00000>@3oool005L0oooo0P0000000`3>/;`000000=W5aP070=W5aP030000003A/KX0
dK6j00D0dK6j00<000000=g4`03Ma<000P3Ma<0010000000bJjo0<V^_`00000I0?ooo`@00000?@3o
ool005T0oooo00<000000=W5aP3IaLH01@3IaLH2000000030<G7f`000000dK6j00@0dK6j00<00000
0=g4`03Ma<000`3Ma<000`000000bJjo0000000F0?ooo`@00000@@3oool005X0oooo00<000000=W5
aP3IaLH00`3IaLH01@000000aLOK0<G7f`35am/0000000D0dK6j00<000000=g4`03Ma<00103Ma<00
0`000000oooo0?ooo`0B0?ooo`<00000A@3oool005/0oooo0P0000000`3IaLH00000000000050<G7
f`050000003A/KX0dK6j0=6a^P0000001P3Ma<000`000000oooo0?ooo`0?0?ooo`@00000B03oool0
05`0oooo0P0000080<G7f`030000003A/KX0000000H0gLC000<000000?ooo`3oool0303oool40000
04`0oooo001N0?ooo`0300000035am/0aLOK00D0aLOK00<000000=6a^P0000001@3Ma<000`000000
oooo0?ooo`090?ooo`@00000D03oool005l0oooo00<000000<G7f`35am/01035am/2000000H0gLC0
00<000000?ooo`3oool01@3oool4000005@0oooo001P0?ooo`0300000035am/0aLOK00<000000P2U
`nl00`000000gLC00=g4`0020=g4`0030000003oool0oooo00<0oooo0`00001H0?ooo`00H@3oool2
000000H0YL?_0P000000103Ma<0000000?ooo`3oool4000005/0oooo001R0?ooo`030000002U`nl0
YL?_00D0YL?_1@00001O0?ooo`00H`3oool200000080YL?_1000001S0?ooo`00I@3oool2000006L0
oooo003>0?ooo`00cP3oool00<h0oooo003>0?ooo`00cP3oool00<h0oooo003>0?ooo`00cP3oool0
0<h0oooo003>0?ooo`00cP3oool00001\
\>"],
  ImageRangeCache->{{{0, 205.25}, {166.25, 0}} -> {-0.21311, -0.0674348, \
0.00585773, 0.00585773}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[189]="]
}, Open  ]],

Cell["Example 7", "Subsubsection"],

Cell["Initial value problem.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ivp = {x*\(y''\)[x] - \((2*m + 3)\)*x*\(y'\)[x] + \[Lambda]*y[x] == 0, 
        y[0] \[Equal] 0, \(y'\)[0] \[Equal] 2*m + 3}\)], "Input",
  CellLabel->"In[190]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{\(\[Lambda]\ y[x]\), "-", 
            RowBox[{\((3 + 2\ m)\), " ", "x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}], "+", 
            RowBox[{"x", " ", 
              RowBox[{
                SuperscriptBox["y", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "x", "]"}]}]}], "==", "0"}], 
        ",", \(y[0] == 0\), ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "==", \(3 + 2\ m\)}]}], "}"}]], "Output",
  CellLabel->"Out[190]="]
}, Open  ]],

Cell["Finding polynomial approximation for solution of the IVP.", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(apr = ApproxSol[ivp, y[x], {x, 0, 1}, 5]\)], "Input",
  CellLabel->"In[191]:="],

Cell[BoxData[
    \(LdeApprox::"regsp" \(\(:\)\(\ \)\) 
      "regular singular point encountered: \!\(x\) = \!\(0\)"\)], "Message",
  CellLabel->"From In[191]:="],

Cell[BoxData[
    \({y[x] \[Rule] \((3 + 2\ m)\)\ x + 
          1\/2\ \((3 + 2\ m)\)\ x\^2\ \((3 + 2\ m - \[Lambda])\) + 
          1\/12\ \((3 + 2\ m)\)\ x\^3\ \((3 + 2\ m - \[Lambda])\)\ \((6 + 
                4\ m - \[Lambda])\) + \(56\ \((3 + 2\ m)\)\ x\^5\ \((3 + 2\ m \
- \[Lambda])\)\ \((6 + 4\ m - \[Lambda])\)\ \((108 + 48\ m\^2 - 21\ \[Lambda] \
+ \[Lambda]\^2 - 2\ m\ \((\(-72\) + 7\ \[Lambda])\))\)\)\/\(9\ \((8740 + 400\ \
m\^2 + 537\ \[Lambda] + 5\ \[Lambda]\^2 - 30\ m\ \((184 + 3\ \
\[Lambda])\))\)\) - \(14\ \((3 + 2\ m)\)\ x\^4\ \((\(-5670\) + 1440\ m\^4 + \
2979\ \[Lambda] - 333\ \[Lambda]\^2 - 19\ \[Lambda]\^3 + 3\ \[Lambda]\^4 - 24\
\ m\^3\ \((\(-200\) + 61\ \[Lambda])\) + 4\ m\^2\ \((540 - 767\ \[Lambda] + \
123\ \[Lambda]\^2)\) + m\ \((\(-6480\) + 678\ \[Lambda] + 516\ \[Lambda]\^2 - \
66\ \[Lambda]\^3)\))\)\)\/\(9\ \((8740 + 400\ m\^2 + 537\ \[Lambda] + 5\ \
\[Lambda]\^2 - 30\ m\ \((184 + 3\ \[Lambda])\))\)\)}\)], "Output",
  CellLabel->"Out[191]="]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["DSolve",
    FontFamily->"Courier New"],
  " to get exact solution of the IVP."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = DSolve[ivp, y[x], x]\)], "Input",
  CellLabel->"In[192]:="],

Cell[BoxData[
    \({{y[
            x] \[Rule] \((3 + 2\ m)\)\ x\ Hypergeometric1F1[
              1 - \[Lambda]\/\(3 + 2\ m\), 
              2, \((3 + 2\ m)\)\ x]}}\)], "Output",
  CellLabel->"Out[192]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 1/2*\((2*m + 3)\)\)]],
  " using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {\[Lambda] \[Rule] 
            1/2*\((2*m + 3)\)}, {x, \(-1\), 
        1}, {m, \(-1.6\), \(-1.4\)}, \[IndentingNewLine]PlotRange \[Rule] \
{\(-10^\((\(-8\))\)\), 10^\((\(-8\))\)}]\)], "Input",
  CellLabel->"In[193]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-5.87475e-016 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 24 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 30 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 24 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 30 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 24 3.14607 ]
[.02494 .25992 -39 -3.80269 ]
[.02494 .25992 0 8.69731 ]
[.01611 .31527 -39 -3.86767 ]
[.01611 .31527 0 8.63233 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -33 -4.00565 ]
[-0.00254 .43215 0 8.49435 ]
[-0.0124 .49393 -33 -4.079 ]
[-0.0124 .49393 0 8.421 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-1.6)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-1.55)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(-1.5)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(-1.45)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(-1.4)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
gsave
.02494 .25992 -39 -1.80269 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.02837 .31059 m
.0345 .30825 L
s
gsave
.01611 .31527 -39 -1.86767 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
gsave
-0.00254 .43215 -33 -2.00565 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-9) show
grestore
0 .48963 m
.0062 .48748 L
s
gsave
-0.0124 .49393 -33 -2.079 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-8) show
grestore
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.755 .78 .873 r
.37443 .79219 .39787 .81114 .43683 .80094 .41416 .7682 Metetra
.841 .708 .717 r
.41416 .7682 .43683 .80094 .47657 .77416 .45511 .69682 Metetra
.695 .557 .694 r
.45511 .69682 .47657 .77416 .51665 .6986 .49498 .66034 Metetra
.697 .649 .798 r
.49498 .66034 .51665 .6986 .55622 .66508 .5349 .64004 Metetra
.676 .722 .884 r
.5349 .64004 .55622 .66508 .59619 .64794 .5753 .62613 Metetra
.66 .747 .915 r
.5753 .62613 .59619 .64794 .63677 .63561 .61629 .61401 Metetra
.656 .751 .92 r
.61629 .61401 .63677 .63561 .67796 .62396 .6579 .60207 Metetra
.656 .751 .92 r
.6579 .60207 .67796 .62396 .71976 .61218 .70013 .58995 Metetra
.656 .752 .92 r
.70013 .58995 .71976 .61218 .76218 .60009 .74299 .57761 Metetra
.659 .753 .92 r
.74299 .57761 .76218 .60009 .80516 .58696 .78648 .56473 Metetra
.666 .761 .921 r
.78648 .56473 .80516 .58696 .84858 .5717 .83056 .55089 Metetra
.67 .78 .932 r
.83056 .55089 .84858 .5717 .89242 .55478 .87523 .53628 Metetra
.649 .8 .956 r
.87523 .53628 .89242 .55478 .93731 .54162 .92073 .52304 Metetra
.553 .762 .975 r
.92073 .52304 .93731 .54162 .98557 .54796 .96798 .51741 Metetra
.759 .622 .708 r
.35217 .73518 .37443 .79219 .41416 .7682 .393 .68262 Metetra
.674 .535 .688 r
.393 .68262 .41416 .7682 .45511 .69682 .43292 .65142 Metetra
.684 .618 .775 r
.43292 .65142 .45511 .69682 .49498 .66034 .4728 .63144 Metetra
.678 .697 .86 r
.4728 .63144 .49498 .66034 .5349 .64004 .51305 .61673 Metetra
.664 .738 .905 r
.51305 .61673 .5349 .64004 .5753 .62613 .55384 .60404 Metetra
.657 .75 .918 r
.55384 .60404 .5753 .62613 .61629 .61401 .59525 .59183 Metetra
.656 .751 .92 r
.59525 .59183 .61629 .61401 .6579 .60207 .63727 .57956 Metetra
.656 .751 .92 r
.63727 .57956 .6579 .60207 .70013 .58995 .67994 .56711 Metetra
.656 .751 .92 r
.67994 .56711 .70013 .58995 .74299 .57761 .72326 .55445 Metetra
.657 .752 .92 r
.72326 .55445 .74299 .57761 .78648 .56473 .76724 .54147 Metetra
.659 .755 .921 r
.76724 .54147 .78648 .56473 .83056 .55089 .81187 .52804 Metetra
.66 .763 .926 r
.81187 .52804 .83056 .55089 .87523 .53628 .85718 .51422 Metetra
.654 .772 .935 r
.85718 .51422 .87523 .53628 .92073 .52304 .90325 .50071 Metetra
.628 .762 .943 r
.90325 .50071 .92073 .52304 .96798 .51741 .95039 .48961 Metetra
.658 .538 .707 r
.33077 .65996 .35217 .73518 .393 .68262 .37028 .63775 Metetra
.67 .614 .784 r
.37028 .63775 .393 .68262 .43292 .65142 .40994 .62087 Metetra
.671 .686 .856 r
.40994 .62087 .43292 .65142 .4728 .63144 .45 .60678 Metetra
.664 .729 .898 r
.45 .60678 .4728 .63144 .51305 .61673 .4906 .59394 Metetra
.658 .746 .915 r
.4906 .59394 .51305 .61673 .55384 .60404 .53179 .58149 Metetra
.656 .751 .92 r
.53179 .58149 .55384 .60404 .59525 .59183 .57361 .56904 Metetra
.656 .751 .92 r
.57361 .56904 .59525 .59183 .63727 .57956 .61607 .55642 Metetra
.656 .751 .92 r
.61607 .55642 .63727 .57956 .67994 .56711 .65918 .54361 Metetra
.656 .751 .92 r
.65918 .54361 .67994 .56711 .72326 .55445 .70296 .5306 Metetra
.656 .752 .92 r
.70296 .5306 .72326 .55445 .76724 .54147 .74742 .51735 Metetra
.657 .753 .921 r
.74742 .51735 .76724 .54147 .81187 .52804 .79258 .50383 Metetra
.657 .755 .922 r
.79258 .50383 .81187 .52804 .85718 .51422 .83845 .49004 Metetra
.655 .759 .926 r
.83845 .49004 .85718 .51422 .90325 .50071 .88506 .47617 Metetra
.649 .756 .928 r
.88506 .47617 .90325 .50071 .95039 .48961 .93252 .46277 Metetra
.661 .646 .824 r
.30706 .62285 .33077 .65996 .37028 .63775 .34637 .6091 Metetra
.663 .698 .873 r
.34637 .6091 .37028 .63775 .40994 .62087 .38618 .59614 Metetra
.66 .73 .901 r
.38618 .59614 .40994 .62087 .45 .60678 .42656 .58354 Metetra
.658 .744 .914 r
.42656 .58354 .45 .60678 .4906 .59394 .46753 .571 Metetra
.656 .75 .919 r
.46753 .571 .4906 .59394 .53179 .58149 .50912 .55838 Metetra
.656 .751 .92 r
.50912 .55838 .53179 .58149 .57361 .56904 .55136 .54559 Metetra
.656 .751 .92 r
.55136 .54559 .57361 .56904 .61607 .55642 .59425 .53262 Metetra
.656 .751 .92 r
.59425 .53262 .61607 .55642 .65918 .54361 .63781 .51944 Metetra
.656 .751 .92 r
.63781 .51944 .65918 .54361 .70296 .5306 .68206 .50605 Metetra
.656 .751 .92 r
.68206 .50605 .70296 .5306 .74742 .51735 .72701 .49244 Metetra
.656 .752 .92 r
.72701 .49244 .74742 .51735 .79258 .50383 .77268 .4786 Metetra
.656 .752 .921 r
.77268 .4786 .79258 .50383 .83845 .49004 .81909 .46453 Metetra
.656 .753 .922 r
.81909 .46453 .83845 .49004 .88506 .47617 .86625 .45026 Metetra
.655 .753 .922 r
.86625 .45026 .88506 .47617 .93252 .46277 .91421 .43587 Metetra
.658 .726 .899 r
.28202 .59773 .30706 .62285 .34637 .6091 .32156 .58538 Metetra
.657 .74 .911 r
.32156 .58538 .34637 .6091 .38618 .59614 .36169 .57293 Metetra
.656 .747 .917 r
.36169 .57293 .38618 .59614 .42656 .58354 .40243 .56034 Metetra
.656 .75 .919 r
.40243 .56034 .42656 .58354 .46753 .571 .4438 .54758 Metetra
.656 .751 .92 r
.4438 .54758 .46753 .571 .50912 .55838 .48581 .53463 Metetra
.656 .751 .92 r
.48581 .53463 .50912 .55838 .55136 .54559 .52847 .52148 Metetra
.656 .751 .92 r
.52847 .52148 .55136 .54559 .59425 .53262 .5718 .50812 Metetra
.656 .751 .92 r
.5718 .50812 .59425 .53262 .63781 .51944 .61582 .49455 Metetra
.656 .751 .92 r
.61582 .49455 .63781 .51944 .68206 .50605 .66055 .48077 Metetra
.656 .751 .92 r
.66055 .48077 .68206 .50605 .72701 .49244 .706 .46676 Metetra
.656 .751 .92 r
.706 .46676 .72701 .49244 .77268 .4786 .75218 .45252 Metetra
.656 .752 .92 r
.75218 .45252 .77268 .4786 .81909 .46453 .79913 .43805 Metetra
.656 .752 .921 r
.79913 .43805 .81909 .46453 .86625 .45026 .84685 .42334 Metetra
.656 .752 .921 r
.84685 .42334 .86625 .45026 .91421 .43587 .89536 .4084 Metetra
.656 .749 .918 r
.25611 .5748 .28202 .59773 .32156 .58538 .29599 .56227 Metetra
.656 .75 .919 r
.29599 .56227 .32156 .58538 .36169 .57293 .33649 .54955 Metetra
.656 .751 .92 r
.33649 .54955 .36169 .57293 .40243 .56034 .37762 .53663 Metetra
.656 .751 .92 r
.37762 .53663 .40243 .56034 .4438 .54758 .41938 .52351 Metetra
.656 .751 .92 r
.41938 .52351 .4438 .54758 .48581 .53463 .46181 .51019 Metetra
.656 .751 .92 r
.46181 .51019 .48581 .53463 .52847 .52148 .50491 .49665 Metetra
.656 .751 .92 r
.50491 .49665 .52847 .52148 .5718 .50812 .54869 .4829 Metetra
.656 .751 .92 r
.54869 .4829 .5718 .50812 .61582 .49455 .59318 .46893 Metetra
.656 .751 .92 r
.59318 .46893 .61582 .49455 .66055 .48077 .63839 .45473 Metetra
.656 .751 .92 r
.63839 .45473 .66055 .48077 .706 .46676 .68435 .4403 Metetra
.656 .751 .92 r
.68435 .4403 .706 .46676 .75218 .45252 .73106 .42562 Metetra
.656 .751 .92 r
.73106 .42562 .75218 .45252 .79913 .43805 .77855 .41071 Metetra
.656 .751 .92 r
.77855 .41071 .79913 .43805 .84685 .42334 .82683 .39554 Metetra
.656 .751 .92 r
.82683 .39554 .84685 .42334 .89536 .4084 .87594 .38012 Metetra
.656 .751 .92 r
.22944 .55152 .25611 .5748 .29599 .56227 .26969 .53863 Metetra
.656 .751 .92 r
.26969 .53863 .29599 .56227 .33649 .54955 .31056 .52554 Metetra
.656 .751 .92 r
.31056 .52554 .33649 .54955 .37762 .53663 .35208 .51225 Metetra
.656 .751 .92 r
.35208 .51225 .37762 .53663 .41938 .52351 .39426 .49875 Metetra
.656 .751 .92 r
.39426 .49875 .41938 .52351 .46181 .51019 .43711 .48503 Metetra
.656 .751 .92 r
.43711 .48503 .46181 .51019 .50491 .49665 .48064 .47109 Metetra
.656 .751 .92 r
.48064 .47109 .50491 .49665 .54869 .4829 .52489 .45693 Metetra
.656 .751 .92 r
.52489 .45693 .54869 .4829 .59318 .46893 .56985 .44253 Metetra
.656 .751 .92 r
.56985 .44253 .59318 .46893 .63839 .45473 .61556 .4279 Metetra
.656 .751 .92 r
.61556 .4279 .63839 .45473 .68435 .4403 .66203 .41302 Metetra
.656 .751 .92 r
.66203 .41302 .68435 .4403 .73106 .42562 .70928 .39789 Metetra
.656 .751 .92 r
.70928 .39789 .73106 .42562 .77855 .41071 .75733 .38251 Metetra
.656 .751 .92 r
.75733 .38251 .77855 .41071 .82683 .39554 .80619 .36687 Metetra
.656 .751 .92 r
.80619 .36687 .82683 .39554 .87594 .38012 .8559 .35095 Metetra
.656 .751 .92 r
.202 .52758 .22944 .55152 .26969 .53863 .24262 .51431 Metetra
.656 .751 .92 r
.24262 .51431 .26969 .53863 .31056 .52554 .28388 .50084 Metetra
.656 .751 .92 r
.28388 .50084 .31056 .52554 .35208 .51225 .32579 .48716 Metetra
.656 .751 .92 r
.32579 .48716 .35208 .51225 .39426 .49875 .36838 .47325 Metetra
.656 .751 .92 r
.36838 .47325 .39426 .49875 .43711 .48503 .41166 .45912 Metetra
.656 .751 .92 r
.41166 .45912 .43711 .48503 .48064 .47109 .45565 .44476 Metetra
.656 .751 .92 r
.45565 .44476 .48064 .47109 .52489 .45693 .50036 .43016 Metetra
.656 .751 .92 r
.50036 .43016 .52489 .45693 .56985 .44253 .54581 .41533 Metetra
.656 .751 .92 r
.54581 .41533 .56985 .44253 .61556 .4279 .59203 .40024 Metetra
.656 .751 .92 r
.59203 .40024 .61556 .4279 .66203 .41302 .63902 .3849 Metetra
.656 .751 .92 r
.63902 .3849 .66203 .41302 .70928 .39789 .68682 .36929 Metetra
.656 .751 .92 r
.68682 .36929 .70928 .39789 .75733 .38251 .73543 .35342 Metetra
.656 .751 .92 r
.73543 .35342 .75733 .38251 .80619 .36687 .78489 .33727 Metetra
.656 .751 .92 r
.78489 .33727 .80619 .36687 .8559 .35095 .83521 .32084 Metetra
.657 .754 .921 r
.17373 .50324 .202 .52758 .24262 .51431 .21474 .48941 Metetra
.657 .753 .921 r
.21474 .48941 .24262 .51431 .28388 .50084 .2564 .47546 Metetra
.656 .752 .92 r
.2564 .47546 .28388 .50084 .32579 .48716 .29872 .46133 Metetra
.656 .752 .92 r
.29872 .46133 .32579 .48716 .36838 .47325 .34173 .44699 Metetra
.656 .751 .92 r
.34173 .44699 .36838 .47325 .41166 .45912 .38545 .43243 Metetra
.656 .751 .92 r
.38545 .43243 .41166 .45912 .45565 .44476 .42989 .41762 Metetra
.656 .751 .92 r
.42989 .41762 .45565 .44476 .50036 .43016 .47508 .40258 Metetra
.656 .751 .92 r
.47508 .40258 .50036 .43016 .54581 .41533 .52102 .38727 Metetra
.656 .751 .92 r
.52102 .38727 .54581 .41533 .59203 .40024 .56775 .37171 Metetra
.656 .751 .92 r
.56775 .37171 .59203 .40024 .63902 .3849 .61528 .35588 Metetra
.656 .751 .92 r
.61528 .35588 .63902 .3849 .68682 .36929 .66363 .33977 Metetra
.656 .751 .92 r
.66363 .33977 .68682 .36929 .73543 .35342 .71283 .32339 Metetra
.656 .751 .92 r
.71283 .32339 .73543 .35342 .78489 .33727 .76289 .30671 Metetra
.656 .751 .92 r
.76289 .30671 .78489 .33727 .83521 .32084 .81384 .28975 Metetra
.675 .782 .93 r
.14429 .48109 .17373 .50324 .21474 .48941 .1859 .46505 Metetra
.665 .765 .925 r
.1859 .46505 .21474 .48941 .2564 .47546 .22804 .4498 Metetra
.66 .757 .922 r
.22804 .4498 .2564 .47546 .29872 .46133 .27081 .43487 Metetra
.657 .753 .921 r
.27081 .43487 .29872 .46133 .34173 .44699 .31426 .41996 Metetra
.656 .752 .92 r
.31426 .41996 .34173 .44699 .38545 .43243 .35843 .40491 Metetra
.656 .751 .92 r
.35843 .40491 .38545 .43243 .42989 .41762 .40333 .38964 Metetra
.656 .751 .92 r
.40333 .38964 .42989 .41762 .47508 .40258 .449 .37412 Metetra
.656 .751 .92 r
.449 .37412 .47508 .40258 .52102 .38727 .49545 .35833 Metetra
.656 .751 .92 r
.49545 .35833 .52102 .38727 .56775 .37171 .5427 .34227 Metetra
.656 .751 .92 r
.5427 .34227 .56775 .37171 .61528 .35588 .59078 .32592 Metetra
.656 .751 .92 r
.59078 .32592 .61528 .35588 .66363 .33977 .6397 .30928 Metetra
.656 .751 .92 r
.6397 .30928 .66363 .33977 .71283 .32339 .68949 .29233 Metetra
.656 .751 .92 r
.68949 .29233 .71283 .32339 .76289 .30671 .74016 .2751 Metetra
.655 .751 .92 r
.74016 .2751 .76289 .30671 .81384 .28975 .79177 .25768 Metetra
.755 .899 .942 r
.11223 .47152 .14429 .48109 .1859 .46505 .1555 .44575 Metetra
.707 .82 .935 r
.1555 .44575 .1859 .46505 .22804 .4498 .19859 .42558 Metetra
.678 .779 .927 r
.19859 .42558 .22804 .4498 .27081 .43487 .24198 .40829 Metetra
.663 .76 .922 r
.24198 .40829 .27081 .43487 .31426 .41996 .28592 .39225 Metetra
.658 .754 .921 r
.28592 .39225 .31426 .41996 .35843 .40491 .33055 .37656 Metetra
.656 .752 .92 r
.33055 .37656 .35843 .40491 .40333 .38964 .37593 .36078 Metetra
.656 .751 .92 r
.37593 .36078 .40333 .38964 .449 .37412 .42209 .34476 Metetra
.656 .751 .92 r
.42209 .34476 .449 .37412 .49545 .35833 .46905 .32846 Metetra
.656 .751 .92 r
.46905 .32846 .49545 .35833 .5427 .34227 .51684 .31187 Metetra
.656 .751 .92 r
.51684 .31187 .5427 .34227 .59078 .32592 .56547 .29496 Metetra
.657 .751 .92 r
.56547 .29496 .59078 .32592 .6397 .30928 .61497 .27768 Metetra
.657 .751 .919 r
.61497 .27768 .6397 .30928 .68949 .29233 .66536 .26005 Metetra
.656 .75 .919 r
.66536 .26005 .68949 .29233 .74016 .2751 .71666 .24223 Metetra
.65 .747 .921 r
.71666 .24223 .74016 .2751 .79177 .25768 .76897 .22478 Metetra
.807 .98 .696 r
.07322 .50303 .11223 .47152 .1555 .44575 .12181 .44364 Metetra
.818 .95 .906 r
.12181 .44364 .1555 .44575 .19859 .42558 .16742 .40734 Metetra
.736 .842 .93 r
.16742 .40734 .19859 .42558 .24198 .40829 .21203 .383 Metetra
.685 .782 .924 r
.21203 .383 .24198 .40829 .28592 .39225 .25665 .36416 Metetra
.663 .759 .921 r
.25665 .36416 .28592 .39225 .33055 .37656 .30179 .34737 Metetra
.657 .752 .92 r
.30179 .34737 .33055 .37656 .37593 .36078 .34765 .33099 Metetra
.656 .751 .92 r
.34765 .33099 .37593 .36078 .42209 .34476 .39431 .31445 Metetra
.656 .751 .92 r
.39431 .31445 .42209 .34476 .46905 .32846 .4418 .29762 Metetra
.656 .751 .92 r
.4418 .29762 .46905 .32846 .51684 .31187 .49013 .28047 Metetra
.657 .752 .92 r
.49013 .28047 .51684 .31187 .56547 .29496 .53933 .2629 Metetra
.659 .752 .919 r
.53933 .2629 .56547 .29496 .61497 .27768 .58941 .24475 Metetra
.661 .75 .917 r
.58941 .24475 .61497 .27768 .66536 .26005 .6404 .22611 Metetra
.656 .745 .916 r
.6404 .22611 .66536 .26005 .71666 .24223 .69233 .20768 Metetra
.634 .736 .922 r
.69233 .20768 .71666 .24223 .76897 .22478 .74543 .19152 Metetra
.633 .962 .824 r
.03435 .51739 .07322 .50303 .12181 .44364 .08055 .48591 Metetra
.866 .966 .64 r
.08055 .48591 .12181 .44364 .16742 .40734 .13308 .4049 Metetra
.85 .945 .881 r
.13308 .4049 .16742 .40734 .21203 .383 .18051 .36196 Metetra
.738 .83 .921 r
.18051 .36196 .21203 .383 .25665 .36416 .22631 .33634 Metetra
.678 .772 .921 r
.22631 .33634 .25665 .36416 .30179 .34737 .27209 .31739 Metetra
.659 .754 .92 r
.27209 .31739 .30179 .34737 .34765 .33099 .31845 .30024 Metetra
.656 .752 .92 r
.31845 .30024 .34765 .33099 .39431 .31445 .36562 .28314 Metetra
.656 .751 .92 r
.36562 .28314 .39431 .31445 .4418 .29762 .41363 .26575 Metetra
.656 .752 .92 r
.41363 .26575 .4418 .29762 .49013 .28047 .46252 .24799 Metetra
.659 .752 .919 r
.46252 .24799 .49013 .28047 .53933 .2629 .5123 .22956 Metetra
.665 .753 .915 r
.5123 .22956 .53933 .2629 .58941 .24475 .56298 .21005 Metetra
.669 .749 .91 r
.56298 .21005 .58941 .24475 .6404 .22611 .61455 .18967 Metetra
.655 .736 .909 r
.61455 .18967 .6404 .22611 .69233 .20768 .66711 .17059 Metetra
.588 .706 .924 r
.66711 .17059 .69233 .20768 .74543 .19152 .72118 .15896 Metetra
.645 .763 .934 r
0 .48963 .03435 .51739 .08055 .48591 .04439 .47421 Metetra
.811 .892 .902 r
.04439 .47421 .08055 .48591 .13308 .4049 .09238 .43741 Metetra
.928 .969 .692 r
.09238 .43741 .13308 .4049 .18051 .36196 .14653 .35074 Metetra
.833 .901 .887 r
.14653 .35074 .18051 .36196 .22631 .33634 .19469 .31 Metetra
.71 .796 .918 r
.19469 .31 .22631 .33634 .27209 .31739 .24137 .28676 Metetra
.664 .758 .92 r
.24137 .28676 .27209 .31739 .31845 .30024 .28829 .26848 Metetra
.656 .752 .92 r
.28829 .26848 .31845 .30024 .36562 .28314 .33597 .25079 Metetra
.656 .751 .92 r
.33597 .25079 .36562 .28314 .41363 .26575 .38452 .23281 Metetra
.657 .752 .92 r
.38452 .23281 .41363 .26575 .46252 .24799 .43397 .21437 Metetra
.664 .754 .917 r
.43397 .21437 .46252 .24799 .5123 .22956 .48436 .19472 Metetra
.679 .755 .909 r
.48436 .19472 .5123 .22956 .56298 .21005 .53564 .17283 Metetra
.687 .747 .897 r
.53564 .17283 .56298 .21005 .61455 .18967 .58777 .14927 Metetra
.654 .717 .895 r
.58777 .14927 .61455 .18967 .66711 .17059 .64092 .12952 Metetra
.471 .627 .92 r
.64092 .12952 .66711 .17059 .72118 .15896 .69623 .12906 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[193]:=",
  ImageSize->{218.125, 176.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003J0000/2000`400?l00000o`00003ofP3oool0
0=X0oooo003J0?ooo`00fP3oool00=X0oooo003J0?ooo`00fP3oool00=X0oooo003J0?ooo`00fP3o
ool00=X0oooo003J0?ooo`00fP3oool00=X0oooo003J0?ooo`00fP3oool00=X0oooo003J0?ooo`00
S@3oool5000004P0oooo002?0?ooo`030000003oool0oooo04P0oooo002?0?ooo`030000003oool0
oooo04P0oooo002?0?ooo`030000003oool0oooo04P0oooo002?0?ooo`030000003oool0oooo04P0
oooo002>0?ooo`8000002`3oool500000080oooo0P0000030?ooo`<00000<03oool009d0oooo00<0
00000?ooo`3oool01`3oool010000000oooo0?ooo`00000_0?ooo`00W@3oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo000002l0oooo002E0?ooo`@00000103oool00`000000oooo0?oo
o`070?ooo`<00000<03oool009d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_
0?ooo`00T@3oool2000000T0oooo0P00000:0?ooo`<00000;`3oool008l0oooo1@0000160?ooo`00
IP3oool2000000@0oooo0P0000040?ooo`800000603oool3000000<0oooo0P0000160?ooo`00I@3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001D0oooo0`0000050?ooo`03
0000003oool0000004D0oooo001U0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3o
ool0403oool3000000P0oooo00@000000?ooo`3oool00000A03oool006D0oooo00@000000?ooo`3o
ool000002@3oool200000140oooo0`00000:0?ooo`040000003oool00000000004@0oooo001U0?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool03@3oool3000000d0oooo00D00000
0?ooo`3oool0oooo000000130?ooo`00IP3oool2000000X0oooo0`00000:0?ooo`<00000403oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo001m0?ooo`8000004`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo001j0?ooo`<000005@3oool00`000000
oooo0?ooo`020?ooo`800000@@3oool007P0oooo0P0000000`3oool000000?ooo`0F0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0?P3oool007D0oooo0`00000K0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0?P3oool005H0oooo0P00000K0?ooo`80000000<0oooo
0000003oool06`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo001E0?oo
o`040000003oool0oooo000001L0oooo0`00000P0?ooo`030000003oool0oooo00<0oooo0P00000o
0?ooo`00E@3oool010000000oooo0?ooo`00000E0?ooo`<000008P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo03`0oooo001E0?ooo`040000003oool0oooo00000180oooo0`00000U
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02@3oool500000080oooo0P000004
0?ooo`800000103oool2000001d0oooo001E0?ooo`040000003oool0oooo00000100oooo0`00000W
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000703oool005H0oooo0P00
000>0?ooo`<00000:P3oool00`000000oooo0?ooo`060?ooo`800000303oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool006@0oooo0`00000/
0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0oooo100000040?ooo`030000003o
ool0oooo00P0oooo0P0000040?ooo`8000007@3oool00640oooo0`00000_0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0703oool005l0oooo0P00000b0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool01`3oool2000000X0oooo0`0000030?ooo`<00000703oool005`0
oooo0`00000Z0?ooo`/000002P3oool00`000000oooo0000000i0?ooo`00<03oool2000000@0oooo
0P0000040?ooo`8000006`3oool3000002/0oooo0P0000020:Ngi@030000001hX>/0N:3[00D0N:3[
0P00000;0?ooo`030000003oool0oooo03L0oooo000_0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool00000603oool200000080oooo00<000000?ooo`3oool09P3oool3000000@0
YkOU00<0000007RPj`1hX>/01@1hX>/00`000000N:3[0000000;0?ooo`030000003oool0oooo03H0
oooo000_0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool04`3oool3000002X0
oooo0`0000080:Ngi@030000001hX>/0N:3[00@0N:3[00<0000007RPj`0000002`3oool2000003L0
oooo000Y0?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000503oool2000002/0
oooo0P0000020:noi@030000002W]nD0YkOU00L0YkOU00<0000007RPj`1hX>/00`1hX>/010000000
N:3[07RPj`00000;0?ooo`030000003oool0oooo03D0oooo000_0?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0403oool3000002/0oooo0P0000040:noi@030000002W]nD0YkOU
00L0YkOU00<0000007RPj`1hX>/00`1hX>/5000000/0oooo00<000000?ooo`3oool0=03oool00300
oooo0P00000:0?ooo`<000003P3oool2000002`0oooo0P0000070:noi@030000002W]nD0YkOU00H0
YkOU1`00000409Jdk0030000003oool0oooo00T0oooo00<000000?ooo`3oool0<`3oool004X0oooo
0`00000[0?ooo`<000002P2__nD00`000000YkOU0:Ngi@030:Ngi@8000000P2W_>P01@000000U[C/
09Jdk02F]>`0000000D0U[C/00<000000?ooo`3oool01`3oool2000003D0oooo00180?ooo`800000
;03oool200000080[L7X00<000000:noi@2__nD0202__nD00`000000YkOU0:Ngi@03000000@0YkcX
00D0000009Jdk02F]>`0U[C/0000000509Jdk0030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0<P3oool004D0oooo0`00000[0?ooo`<000001@2]`NP00`000000[koU0:noi@080:noi@800000
202W_>P01@000000U[C/09Jdk02F]>`0000000D0U[C/00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`0a0?ooo`00@`3oool2000002/0oooo0`0000080:g1j0030000002__nD0[koU00H0[koU
0P0000000`2[_nP000000:Nlj0080:Nlj0040000002F]>`0U[C/000000@0U[C/0`00000:0?ooo`03
0000003oool0oooo0340oooo000S0?ooo`D00000603oool3000002/0oooo0P0000020:W1jP030000
002]`NP0[L7X00L0[L7X00<000000:noi@2__nD00`2__nD2000000<0ZkoX00<000000:Nlj02W_>P0
1`2W_>P00`000000U[C/09Jdk005000000<0X[c/00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0`0?ooo`009@3oool00`000000oooo0?ooo`0F0?ooo`800000:`3oool3000000D0ZL7Z00<0
00000:g1j02]`NP01`2]`NP00`000000[koU0:noi@02000000H0ZkoX00<000000:Nlj02W_>P01P2W
_>P4000000P0X[c/00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`D000000P3o
ool2000000@0oooo0P00000G0?ooo`009@3oool00`000000oooo0?ooo`0C0?ooo`<00000:P3oool3
000000P0ZL7Z00<000000:g1j02]`NP01`2]`NP3000000T0ZkoX00<000000:Nlj02W_>P00`2W_>P2
00000080YkkZ0P0000080::lk0030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`040000003oool0oooo000001H0oooo000M0?ooo`@00000103oool0
0`000000oooo0?ooo`0@0?ooo`<00000:`3oool200000080Z<3[00<000000:W1jP2Y`NX01`2Y`NX0
0`000000[L7X0:g1j0040:g1j08000000P2Z`>X00`000000ZkoX0:^oj0070:^oj0030000002W_>P0
YkcX00<00000102W_^X2000000T0X[c/00<000000?ooo`3oool01`3oool2000000`0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`009@3oool00`000000oooo0?ooo`0>0?oo
o`<00000:P3oool3000000D0Z<3[00<000000:W1jP2Y`NX01`2Y`NX00`000000[L7X0:g1j0030000
00D0Z/3Z00<000000:^oj02[_nP01P2[_nP3000000P0YkkZ00<000000::lk02R_>`01`2R_>`20000
00T0oooo00<000000?ooo`3oool00P3oool4000000@0oooo00<000000?ooo`3oool0203oool20000
01L0oooo000T0?ooo`8000003@3oool3000002X0oooo0`0000080:S0j`030000002Y`NX0ZL7Z00L0
ZL7Z0`0000080:[0jP030000002[_nP0ZkoX00@0ZkoX0P0000020:VojP030000002W_^X0YkkZ00H0
YkkZ0P0000050::lk0<000000P2V_n/00`000000oooo0?ooo`070?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0F0?ooo`00<@3oool2000000030?oo
o`000000oooo02P0oooo0P0000020:O0j`030000002X`>/0Z<3[00L0Z<3[00<000000:W1jP2Y`NX0
102Y`NX200000080Z<3[00<000000:[0jP2Z`>X01`2Z`>X00`000000ZkoX0:^oj003000000@0ZKoZ
00<000000:NnjP2W_^X01P2W_^X200000080X[c/0`0000050:Joj`030000003oool0oooo00L0oooo
0P0000090?ooo`8000002P3oool3000001H0oooo000^0?ooo`<00000:`3oool2000000D0Yl3[00<0
00000:S0j`2X`>/01`2X`>/00`000000ZL7Z0:W1jP03000000D0Z<3[00<000000:[0jP2Z`>X01P2Z
`>X3000000P0ZKoZ00<000000:NnjP2W_^X0102W_^X5000000T0Y[o[00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0/0?ooo`00;03oool2000000030?ooo`000000oooo02P0oooo0`000007
0:O0j`030000002X`>/0Z<3[00L0Z<3[0`0000080:S0j`030000002Z`>X0Z/3Z00@0Z/3Z0P000002
0:S0j`030000002Y_nX0ZKoZ00L0ZKoZ00<000000:NnjP2W_^X01P0000000`2W_n/000000:Joj`08
0:Joj`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:`3oool000P0oooo1@0000000`3o
ool000000?ooo`020?ooo`030000003oool0000000@000000P3oool2000000d0oooo0P00000[0?oo
o`8000000P2W`>/00`000000Yl3[0:O0j`060:O0j`030000002X`>/0Z<3[00@0Z<3[0P0000020:O0
j`030000002X`>/0Z<3[00L0Z<3[00<000000:[0jP2Z`>X00`0000040:S0j`030000002Y_nX0ZKoZ
00L0ZKoZ1P0000020:Noj`040000002W_n/0Yko[000000P0Y[o[0P00000:0?ooo`030000003oool0
oooo02X0oooo000:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000002P0oooo0`000005
0:O0j`030000002W`>/0Yl3[00H0Yl3[00<000000:S0j`2X`>/00`0000050:O0j`030000002X`>/0
Z<3[00H0Z<3[0`0000080:S0j`030000002Y_nX0ZKoZ00<0ZKoZ1P0000060:Noj`030000002W_n/0
000000H0Y[o[0P0000020:O0j`030000003oool0oooo00H0oooo0P00000/0?ooo`002P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`000000903oool3000000P0Yl3[00<00000
0:O0j`2W`>/01P2W`>/3000000P0Yl3[00<000000:S0j`2X`>/0102X`>/200000080Z<3[00<00000
0:S0j`2X`>/01`2X`>/00`000000ZKoZ0:VojP02000000030:VojP00000000000080Z<3[00<00000
0:Noj`2W_n/01@2W_n/00`000000Yko[000000020:Joj`<000001@2W`>/00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo02T0oooo00020?ooo`@00000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00T0oooo0P0000020?ooo`030000003oool0oooo01l0oooo0P0000020:W2j`030000002W`>/0
Yl3[00L0Yl3[00@000000:O0j`2W`>/0Yl3[100000020:O0j`030000002W`>/0Yl3[00L0Yl3[00<0
00000:S0j`2X`>/00`0000050:S0j`030000002X`>/0Z<3[00H0Z<3[1P0000050:S0j`030000002W
_n/0Yko[00D0Yko[100000080:O0j`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:03o
ool000X0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool06`3oool3000000D0ZL;[00<000000:O0j`2W`>/01P2W`>/4000000L0Yl3[00<000000:O0j`2W
`>/01P2W`>/3000000P0Z<3[00<000000:S0j`2X`>/00`2X`>/6000000P0Z<3[00<000000:Noj`2W
_n/0102W_n/200000080Yl3[00<000000:O0j`2W`>/01`2W`>/00`000000oooo0?ooo`060?ooo`80
0000:P3oool000T0oooo0P00000:0?ooo`800000103oool2000000P0oooo00@0T92@0<30`02PX:00
oooo0P0000040?ooo`030000003oool0oooo01P0oooo0P0000090:W2j`030000002W`>/0Yl3[00<0
Yl3[0P0000020:O0j`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/0102W`>/200000080
Yl3[00<000000:S0j`2X`>/01`2X`>/00`000000Z<3[0000000500000080Z<3[00<000000:S0j`2X
`>/01`2X`>/00`000000Yko[0:Noj`0300000080Yl3[00@000000:O0j`2W`>/00000202W`>/20000
00T0oooo00<000000?ooo`3oool09`3oool002D0oooo00D0/;2`0?ooo`2PX:00oooo000000060?oo
o`030000003oool0oooo01D0oooo0P0000000`2ebn/000000:W2j`090:W2j`030000002W`>/0Yl3[
008000001@2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00<000001@2W`>/00`00
0000Z<3[0:S0j`050:S0j`D000001`2X`>/00`000000Z<3[0:S0j`060:S0j`<000001P2W`>/00`00
0000Yl3[000000060:O0j`8000000P2W`>/00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02H0oooo000O0?ooo`040>3Ph020P800P8200820P080oooo00D0P820092@T02`/;00oooo00000007
0?ooo`8000004`3oool2000000@0]L_[00<000000:W2j`2Y`^/01`2Y`^/3000000P0Yl3[00<00000
0:O0j`2W`>/01@2W`>/3000000P0Yl3[00<000000:S0j`2X`>/00P2X`>/400000080Yl3[00<00000
0:S0j`2X`>/01P2X`>/00`000000Z<3[0:S0j`040:S0j`8000000P2W`>/00`000000Yl3[0:O0j`05
0:O0j`030000002W`>/000000080Yl3[0`0000040:O0j`030000003oool0oooo00H0oooo0P00000X
0?ooo`009@3oool01@2`/;00oooo0;2`/03oool0000000T0oooo00<000000?ooo`3oool03P3oool2
000000L0]L_[00<000000:W2j`2Y`^/0102Y`^/200000080Z<7[00<000000:O0j`2W`>/01`2W`>/0
0`000000Yl3[0:O0j`0400000080Yl3[00<000000:O0j`2W`>/01`2W`>/6000000D0Yl3[00<00000
0:S0j`2X`>/01P2X`>/00`000000Z<3[0:S0j`03000000D0Yl3[00<000000:O0j`2W`>/0102W`>/0
0`000000Yl3[00000002000000P0Yl3[00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0U
0?ooo`00203oool2000000<0oooo00H000000?ooo`3oool0oooo0000003oool500000080oooo0P00
00090?ooo`030:2PX02`/;00/;2`008000002P3oool00`000000oooo0?ooo`0<0?ooo`030000002e
bn/0]L_[00P0]L_[00<000000:W2j`2Y`^/00`0000050:S1j`030000002W`>/0Yl3[00H0Yl3[0`00
00070:O0j`030000002W`>/0Yl3[00@0Yl3[1@0000080:O0j`030000002X`>/0Z<3[00H0Z<3[0`00
00080:O0j`030000002W`>/0Yl3[00@0Yl3[0P0000020:O0j`030000002W`>/0Yl3[00H0Yl3[00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`D000000P3oool2000000D0oooo0`00
00020?ooo`8000001`3oool000L0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`800000
2`3oool00`000000oooo0?ooo`0:0?ooo`030000003Ei^<0000000T0]L_[0`0000080:S1j`030000
002W`>/0Yl3[00@0Yl3[0P0000020:O0j`030000002W`>/0Yl3[00H0Yl3[00@000000:O0j`2W`>/0
Yl3[100000020:O0j`030000002W`>/0Yl3[00L0Yl3[00@000000:S0j`2X`>/0Z<3[100000020:O0
j`030000002W`>/0Yl3[00L0Yl3[00<000000:O0j`2W`>/00`0000020:O0j`030000002W`>/00000
00P0Yl3[0P0000090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool01000
0000oooo0?ooo`0000020?ooo`030000003oool0oooo00@0oooo000:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00L0oooo0P000003
0=GVh`8000001@2ebn/200000080[LG[00<000000:S1j`2X`N/01`2X`N/00`000000Yl3[0:O0j`03
000000D0Yl3[00<000000:O0j`2W`>/01P2W`>/5000000D0Yl3[00<000000:O0j`2W`>/01P2W`>/4
000000L0Yl3[00<000000:O0j`2W`>/01P2W`>/3000000D0Yl3[00@000000:O0j`2W`>/000001@2W
`>/200000080Yl3[00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo1@0000040?ooo`030000003oool0oooo00@0oooo00000`3oool0000000000002
000000<0oooo0P0000040?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`050?ooo`030000003Ei^<0eNKS00D0eNKS00<000000;G;j`2ebn/00P0000050:g5j`030000002X
`N/0Z<7[00H0Z<7[0`0000080:O0j`030000002W`>/0Yl3[00<0Yl3[1P0000080:O0j`030000002W
`>/0Yl3[00<0Yl3[0P0000020:O0j`030000002W`>/0Yl3[00L0Yl3[00@000000:O0j`2W`>/0Yl3[
100000020:O0j`030000002W`>/0Yl3[00@0Yl3[00<000000:O0j`0000000P2W`>/3000000D0Yl3[
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`04000000@0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000030?ooo`8000001`3oool000P0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`030000003Ei^<0eNKS00L0eNKS0P0000080:g5j`030000002X`N/0Z<7[00<0Z<7[0P0000020:S0
j`030000002W`>/0Yl3[00L0Yl3[00<000000:O0j`0000001@0000020:O0j`030000002W`>/0Yl3[
00L0Yl3[00<000000:O0j`2W`>/00P0000050:O0j`030000002W`>/0Yl3[00H0Yl3[100000060:O0
j`030000002W`>/0Yl3[00D0Yl3[100000080:O0j`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool01P3oool000P0oooo0`0000090?ooo`800000103oool2000000P0oooo00D0`<300;2`/02`
/;00oooo0000000@0?ooo`030000003oool0oooo00800000203Ei^<2000000030;cDj`000000[LG[
00P0[LG[00<000000:S1j`2X`N/00P0000050:S0j`030000002W`>/0Yl3[00D0Yl3[1@0000070:O0
j`030000002W`>/0Yl3[00H0Yl3[0`0000070:O0j`030000002W`>/0Yl3[00@0Yl3[0P0000020:O0
j`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/00`2W`>/3000000030:O0j`000000Yl3[
00P0Yl3[00<000000?ooo`3oool01@3oool00`000000oooo000000080?ooo`8000002`3oool20000
00<0oooo0`0000060?ooo`009P3oool00`2`/;00oooo0000000A0?ooo`<000001`3Ei^<2000000@0
_=C[0P0000070:g5j`<00000202X`>/010000000Yl3[0:O0j`2W`>/400000080Yl3[00<000000:O0
j`2W`>/01`2W`>/010000000Yl3[0:O0j`2W`>/400000080Yl3[00<000000:O0j`2W`>/01P2W`>/0
0`000000Yl3[0:O0j`03000000D0Yl3[00<000000:O0j`2W`>/01@2W`>/00`000000Yl3[0:O0j`03
00000080Yl3[00@000000:O0j`2W`>/00000202W`>/2000000T0oooo00<000000?ooo`3oool0803o
ool001h0oooo00@0h>3P0820P020P800P8200P3oool00`2PX:00`<30061PH00200000140oooo00<0
00000>gh/@3]n;400`0000020=GVh`800000202le>/00`000000[LG[0:g5j`0400000080ZL;[00<0
00000:S0j`2X`>/01`2X`>/5000000D0Yl3[00<000000:O0j`2W`>/01P2W`>/4000000L0Yl3[00<0
00000:O0j`2W`>/01@2W`>/3000000P0Yl3[00<000000:O0j`2W`>/01@2W`>/3000000H0Yl3[00<0
00000:O0j`0000001P2W`>/200000080Yl3[00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0P0?ooo`00903oool0102@T900oooo0:2PX000000B0?ooo`030000003]n;40kORa00<0kORa0P00
000:0;cDj`<000001`2Y`^/2000000D0Z<3[1@0000080:O0j`030000002W`>/0Yl3[00<0Yl3[0P00
00020:O0j`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/00`2W`>/200000080Yl3[00<0
00000:O0j`2W`>/01`2W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<000000:O0j`2W`>/01@2W
`>/00`000000Yl3[000000020:O0j`<00000102W`>/00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01l0oooo000T0?ooo`030:2PX02`/;00`<3000800000403oool00`000000kORa0>gh/@04
0>gh/@040000003IlN400000000000H0_=C[0P0000020:o8k0030000002Y`^/0ZL;[00L0ZL;[00<0
00000:S0j`000000100000020:O0j`030000002W`>/0Yl3[00L0Yl3[00<000000:O0j`2W`>/00P00
00050:O0j`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/00P0000050:O0j`030000002W
`>/0Yl3[00H0Yl3[0`0000070:O0j`030000002W`>/0Yl3[00D0Yl3[100000080:O0j`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool07`3oool00240oooo0P0000040?ooo`030000003oool0
oooo00l0oooo00<000000>gh/@3]n;400`3]n;400`000000fO7Q0=Wah@020=Wah@8000000P2le>/2
000000D0[lS/00<000000:W2j`2Y`^/01@2Y`^/4000000L0Yl3[00<000000:O0j`2W`>/01P2W`>/3
000000L0Yl3[00<000000:O0j`2W`>/01P2W`>/3000000L0Yl3[00<000000:O0j`2W`>/0102W`>/2
00000080Yl3[00<000000:O0j`2W`>/01P2W`>/010000000Yl3[0:O0j`2W`>/400000080Yl3[00<0
00000:O0j`2W`>/01P2W`>/00`000000oooo0?ooo`060?ooo`800000803oool00200oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003]n;40kORa00<0kORa00<0
00000=Wah@3IlN401@3IlN42000000P0[lS/00@000000:W2j`2Y`^/0ZL;[100000020:S1j`030000
002W`>/0Yl3[00H0Yl3[00@000000:O0j`2W`>/0Yl3[100000020:O0j`030000002W`>/0Yl3[00H0
Yl3[00@000000:O0j`2W`>/0Yl3[100000020:O0j`030000002W`>/0Yl3[00H0Yl3[00<000000:O0
j`2W`>/00`0000040:O0j`030000002W`>/0Yl3[00H0Yl3[100000040:O0j`030000002W`>/00000
00P0Yl3[0P0000090?ooo`030000003oool0oooo01d0oooo000P0?ooo`040000003oool0oooo0000
00<0oooo00<000000?ooo`3oool03P3oool010000000kORa0>gh/@3]n;42000000H0fO7Q0P000000
0`2lenh000000:o8k0080:o8k0D000001@2X`N/00`000000Yl3[0:O0j`050:O0j`@000001`2W`>/0
0`000000Yl3[0:O0j`050:O0j`@000001P2W`>/00`000000Yl3[0:O0j`060:O0j`<00000202W`>/0
0`000000Yl3[0:O0j`030:O0j`8000000P2W`>/00`000000Yl3[0:O0j`040:O0j`030000002W`>/0
000000<0Yl3[100000020:O0j`030000003oool0oooo00H0oooo00<000000?ooo`3oool07@3oool0
0200oooo00@000000?ooo`3oool000000P3oool2000000l0oooo00D000000>gh/@3]n;40kORa0000
00060=Wah@800000102lenh2000000@0[lS/1P0000070:S1j`030000002W`>/0Yl3[00<0Yl3[0P00
00020:O0j`030000002W`>/0Yl3[00L0Yl3[00<000000:O0j`2W`>/0100000020:O0j`030000002W
`>/0Yl3[00H0Yl3[00@000000:O0j`2W`>/0Yl3[100000020:O0j`030000002W`>/0Yl3[00H0Yl3[
00<000000:O0j`2W`>/00`0000040:O0j`030000002W`>/0Yl3[00@0Yl3[00<000000:O0j`000000
0`0000060:O0j`030000003oool0oooo00H0oooo0P00000N0?ooo`00803oool010000000oooo0?oo
o`0000020?ooo`8000003P3oool01@000000kORa0>gh/@3]n;40000000D0fO7Q0P0000080;cGkPL0
00000P2Y`^`00`000000Z<7[0:S1j`060:S1j`030000002W`>/0Yl3[008000001@2W`>/00`000000
Yl3[0:O0j`060:O0j`<000001`2W`>/00`000000Yl3[0:O0j`050:O0j`@000001`2W`>/00`000000
Yl3[0:O0j`050:O0j`<00000202W`>/00`000000Yl3[0:O0j`030:O0j`8000000P2W`>/00`000000
Yl3[0:O0j`060:O0j`030000003oool0oooo00L0oooo00<000000?ooo`3oool02@3oool500000080
oooo0P0000050?ooo`<000000@3oool00240oooo0P0000030?ooo`030000003oool0oooo00d0oooo
00<000000>gh/@3]n;401`0000080;cGkPD000001`2Y`^`00`000000Z<7[0:S1j`050:S1j`<00000
202W`>/00`000000Yl3[0:O0j`030:O0j`8000000P2W`>/00`000000Yl3[0:O0j`060:O0j`030000
002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`070:O0j`030000002W`>/0Yl3[00@00000
0P2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00<000000P2W`>/00`000000Yl3[
000000080:O0j`800000203oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00X0oooo
0@0000010?ooo`40oooo000V0?ooo`030000003oool0oooo00`0oooo00@000000>gh/@3]n;400000
1@3Mmj<010000000dO?W0000000000040;cGkP@000000P2]and00`000000ZL;/0:W2k0060:W2k003
0000002X`N/0Z<7[00@000000P2W`>/00`000000Yl3[0:O0j`070:O0j`030000002W`>/0Yl3[0080
00001@2W`>/00`000000Yl3[0:O0j`050:O0j`<000001`2W`>/00`000000Yl3[0:O0j`060:O0j`<0
00001`2W`>/00`000000Yl3[0:O0j`050:O0j`<000001P2W`>/00`000000Yl3[000000050:O0j`80
00000P2W`>/00`000000oooo0?ooo`050?ooo`800000303oool00`000000oooo0?ooo`070?ooo`D0
00000@3oool002H0oooo00<000000?ooo`3oool0303oool010000000kORa0000000000030=ggX`80
0000103AlnL6000000D0[LO]00<000000:W2k02Y`^`01@2Y`^`3000000L0Yl3[00<000000:O0j`2W
`>/01P2W`>/3000000L0Yl3[00<000000:O0j`2W`>/00`2W`>/200000080Yl3[00<000000:O0j`2W
`>/01@2W`>/00`000000Yl3[0:O0j`040:O0j`8000000P2W`>/00`000000Yl3[0:O0j`060:O0j`03
0000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`040:O0j`030000002W`>/000000080
Yl3[0`0000040:O0j`030000003oool0oooo00L0oooo00@000000?ooo`3oool0oooo100000040?oo
o`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000P3oool000D0oooo0P0000030?oo
o`060000003oool0oooo0?ooo`000000oooo1@0000020?ooo`800000303oool2000000d0oooo1000
00030=ggX`030000003AlnL0dO?W0080dO?W1P0000070:g7k@030000002Y`^`0ZL;/00<0ZL;/0P00
00020:S0j`030000002W`>/0Yl3[00H0Yl3[00@000000:O0j`2W`>/0Yl3[100000020:O0j`030000
002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/00P0000050:O0j`030000002W`>/0Yl3[00D0Yl3[
00<000000:O0j`2W`>/00`0000040:O0j`030000002W`>/0Yl3[00H0Yl3[0`0000060:O0j`030000
002W`>/0Yl3[00D0Yl3[100000080:O0j`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`080?ooo`030000003oool000000080oooo00040?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`000000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`040000003?i>H0cnCV0000
0080gONS00<000000=7ci`3AlnL00`0000000`3AlnL00000000000020;CAk`030000002]and0[LO]
00H0[LO]00<000000:W2k02Y`^`00P0000050:S0j`030000002W`>/0Yl3[00D0Yl3[100000070:O0
j`030000002W`>/0Yl3[00D0Yl3[0`0000070:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000080:O0
j`040000002W`>/0Yl3[0:O0j`@000000P2W`>/00`000000Yl3[0:O0j`050:O0j`040000002W`>/0
Yl3[0:O0j`D0000000<0Yl3[0000002W`>/01`2W`>/00`000000oooo0?ooo`060?ooo`8000002@3o
ool2000000/0oooo0P0000020?ooo`001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo0P00
000<0?ooo`050000003?i>H0cnCV0000003Mmj<01@0000020=7ci`8000001@2ddNl00`000000[LO]
0:g7k@050:g7k@<000001`2X`>/00`000000Yl3[0:O0j`030:O0j`8000000P2W`>/00`000000Yl3[
0:O0j`070:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`060:O0j`030000
002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`060:O0j`@000001P2W`>/00`000000Yl3[
0:O0j`050:O0j`@000001@2W`>/2000000P0Yl3[0P0000040?ooo`<0000000<0oooo0000003oool0
6@3oool000D0oooo0P0000040?ooo`030000003oool0000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool01@000000cnCV
0<oTiP000000gONS00P00000202ddNl00`000000[LO]0:g7k@0400000080Z<7/00<000000:S0j`2X
`>/01P2X`>/00`000000Yl3[0:O0j`02000000D0Yl3[0P0000070:O0j`<000001`2W`>/00`000000
Yl3[0:O0j`050:O0j`<000001`2W`>/00`000000Yl3[0:O0j`030:O0j`8000000P2W`>/00`000000
Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`040:O0j`03
0000002W`>/0000000<0Yl3[100000020:O0k0@00000103oool00`000000oooo0?ooo`0H0?ooo`00
1@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`080?oo
o`8000000P3?i>H3000000@0c_Zb0P0000000`31i_400000000000070;CAk`<000001`2X`N`20000
00H0Z<3[0`0000090:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`060:O0
j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[
008000001@2W`>/00`000000Yl3[0:O0j`050:O0j`<000001`2W`>/00`000000Yl3[0:O0j`040:O0
j`D000001P2W`>`00`000000oooo0?ooo`050?ooo`030000003oool0oooo01P0oooo00050?ooo`<0
00002@3oool2000000@0oooo0P0000080?ooo`050<30`02`/;00/;2`0?ooo`0000002@3oool00`00
0000cnCV00000004000000<0c_Zb0P0000050<7Vl@8000000P2ddNl300000080Z/?/00<000000:S1
k02X`N`01`2X`N`00`000000Z<3[0:S0j`0300000080Yl3[00<000000:O0j`2W`>/01`2W`>/30000
00L0Yl3[00<000000:O0j`2W`>/01@2W`>/3000000L0Yl3[00<000000:O0j`2W`>/01@2W`>/30000
00L0Yl3[00<000000:O0j`2W`>/00`2W`>/200000080Yl3[00<000000:O0j`2W`>/01P2W`>/00`00
0000Yl3[0:O0j`05000000030:O0k0000000Yl3/00L0Yl3/00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0G0?ooo`008`3oool00`2`/;00oooo000000080?ooo`<000000P3?i>H300000003
0<kj/P000000000000P0`NKa0`0000060:[3k08000001`2X`N`3000000H0Yl3[0P0000050:O0j`80
00000P2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000
Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`060:O0j`03
0000002W`>/0Yl3[00800000102W`>/00`000000Yl3[0:O0j`060:O0j`<00000102W`>`00`000000
Yl3/000000080:O0k08000001P3oool00`000000oooo0?ooo`0G0?ooo`006`3oool0103Ph>00P820
0820P020P8020?ooo`040:2PX030`<00H61P000000L0oooo0`0000040<oTiP80000000<0c_Zb0000
000000001`31i_4200000080[<S^00<000000:[3k02Z`n`01P2Z`n`00`000000Z<7/0:S1k0040000
0080Yl3[00<000000:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`02000000D0Yl3[00<000000:O0
j`2W`>/01@2W`>/3000000H0Yl3[00<000000:O0j`2W`>/01P2W`>/3000000H0Yl3[00<000000:O0
j`2W`>/01P2W`>/3000000L0Yl3[00<000000:O0j`2W`>/00`2W`>/200000080Yl3[00<000000:O0
k02W`>`00`2W`>`00`000000Yl3/000000030:O0k0@000000P2V`Nd00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01L0oooo000Q0?ooo`03092@T03oool0X:2P008000000`3oool4000000D0
cnCV0P000000103>n[8000000?ooo`3oool2000000<0`NKa0P0000050:c8kP030000002Z`n`0Z/?/
00D0Z/?/0`0000070:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000070:O0j`030000002W`>/0Yl3[
00<0Yl3[0P0000020:O0j`030000002W`>/0Yl3[00D0Yl3[00@000000:O0j`2W`>/0Yl3[10000002
0:O0j`030000002W`>/0Yl3[00D0Yl3[00@000000:O0j`2W`>/0Yl3[100000020:O0j`030000002W
`>/0Yl3[00D0Yl3[00<000000:O0j`2W`>/00`0000040:O0j`030000002W`>`0Yl3/00@0Yl3/1@00
00060:K1k@030000003oool0oooo00<0oooo00<000000?ooo`3oool05`3oool00240oooo00D0X:2P
0;2`/030`<0000000?ooo`04000000<0YL?_0`0000020<oTiP030000003>n[80000000D0oooo0`00
00080:c8kP030000002Z`n`0Z/?/00@000000P2X`>/00`000000Yl3[0:O0j`060:O0j`030000002W
`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[008000001@2W
`>/00`000000Yl3[0:O0j`040:O0j`@000001P2W`>/00`000000Yl3[0:O0j`050:O0j`@000001P2W
`>/00`000000Yl3[0:O0j`050:O0j`<00000202W`>/00`000000Yl3/0:O0k005000000030:O2k@00
0000Y/7]00L0Y/7]00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`000P3oool5
000000030?ooo`000000oooo0080oooo00<000000?ooo`000000100000020?ooo`8000003@3oool2
000000X0YL?_100000080?ooo`030000002/b>h0[<S^00L0[<S^0P0000070:S0j`030000002W`>/0
Yl3[00D0Yl3[0`0000070:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000080:O0j`030000002W`>/0
Yl3[00<000000P2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00@000000P2W`>/0
0`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`06
0:O0j`<00000102W`^d00`000000Yl;]000000080:K1k@8000000`3oool00`000000oooo0?ooo`0G
0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo00<000000:G3k`2U`nl01`2U`nl3
000000/0oooo0P0000050:c8kP80000000<0Z<7[0000002X`>/01`2X`>/00`000000Yl3[0:O0j`04
00000080Yl3[00<000000:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<00000
0:O0j`2W`>/01P2W`>/3000000H0Yl3[00<000000:O0j`2W`>/01@2W`>/3000000L0Yl3[00<00000
0:O0j`2W`>/01@2W`>/3000000H0Yl3[00<000000:O0j`2W`>/0102W`>/200000080Z<7/00<00000
0:O2k@2W`^d00`2W`^d00`000000Yl;]000000030:K1k@@0000000<0X<?a0000003oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`00103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<00000
0:G3k`2U`nl01@2U`nl3000000h0oooo00<000000:c8kP2/b>h00P0000040:S1j`8000001P2X`>/3
000000L0Yl3[00<000000:O0j`2W`>/01@2W`>/3000000L0Yl3[00<000000:O0j`2W`>/00`2W`>/2
00000080Yl3[00<000000:O0j`2W`>/01@2W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<00000
0:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<000000:O0j`2W`>/01@2W`>/0
0`000000Yl3[0:O0j`03000000@0Z<7/00<000000:O2k@2W`^d0102W`^d5000000H0X<?a00D00000
0?ooo`3oool0oooo0000000H0?ooo`00103oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00d0oooo00<0
00000:G3k`2U`nl00P2U`nl300000140oooo0P0000080:S1j`030000002X`>/0Z<3[00<000000P2W
`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0
j`060:O0j`030000002W`>/0Yl3[00800000102W`>/00`000000Yl3[0:O0j`050:O0j`<000001`2W
`>/00`000000Yl3[0:O0j`050:O0j`<000001P2W`>/00`000000Yl3[0:O0j`050:O0j`<00000202X
`N`00`000000Yl;]0:O2k@05000000030:O5k`000000X<?a00H0X<?a00D000000?ooo`3oool0oooo
0000000H0?ooo`00103oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0
oooo000000030?ooo`040000003oool0oooo00000100oooo00<000000:G3k`0000000P00000D0?oo
o`030000002X`N/0Z<7[00H0Z<7[0`0000060:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000070:O0
j`030000002W`>/0Yl3[00D0Yl3[0`0000070:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`00
0000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`050:O0
j`030000002W`>/0Yl3[00@000000P2X`>/00`000000Z<7/0:S1k0060:S1k0<00000102WaNl00`00
0000YlG_000000080:33l@040000003oool0oooo000001P0oooo00030?ooo`8000002P3oool20000
00@0oooo0P0000080?ooo`03092@T030`<00X:2P00L0oooo0P00000G0?ooo`8000000P2X`N/40000
0080Yl3[00<000000:O0j`2W`>/01@2W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<000000:O0
j`2W`>/01P2W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<000000:O0j`2W`>/01@2W`>/30000
00L0Yl3[00<000000:O0j`2W`>/01@2W`>/3000000H0Yl3[00<000000:O0j`2W`>/01@2W`>/30000
00L0Z<3[00@000000:S1k02X`N`0Z<7/100000020:S3k@030000002WaNl0YlG_00<0YlG_00<00000
0:O5k`000000102P`o4400000080oooo00<000000?ooo`3oool05P3oool001l0oooo00<0/;2`0?oo
o`2PX:002@3oool00`000000oooo0?ooo`0F0?ooo`8000001`2W`>/00`000000Yl3[0:O0j`040:O0
j`<000001`2W`>/00`000000Yl3[0:O0j`050:O0j`<000001P2W`>/00`000000Yl3[0:O0j`030:O0
j`8000000P2W`>/00`000000Yl3[0:O0j`060:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`00
0000Yl3[0:O0j`050:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Z<3[0:S0j`050:S0
j`@000001P2X`nd00`000000YlG_0:O5k`040:O5k`H00000102=`oT00`000000oooo0000000H0?oo
o`006@3oool0103Ph>00P8200820P020P8020?ooo`030820P02@T900/;2`00X0oooo0P00000G0?oo
o`030000002W`>/0Yl3[00H0Yl3[00<000000:O0j`2W`>/00`0000020:O0j`030000002W`>/0Yl3[
00H0Yl3[00<000000:O0j`2W`>/0100000020:O0j`030000002W`>/0Yl3[00D0Yl3[00<000000:O0
j`2W`>/00P0000050:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000060:O0j`030000002W`>/0Yl3[
00D0Yl3[0`0000060:O0j`030000002X`>/0Z<3[00<0Z<3[0P0000020:S1j`030000002X`nd0Z<?]
00H0Z<?]00<000000:O5k`2WaNl0100000020:K<m0030000002=`oT0SL?i00@0SL?i00<000000?oo
o`000000603oool001l0oooo00<0/;2`0?ooo`2`/;00303oool00`000000oooo0?ooo`0E0?ooo`80
00001P2W`>/3000000H0Yl3[0P0000060:O0j`<000001`2W`>/00`000000Yl3[0:O0j`040:O0j`<0
0000202W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<000000:O0j`2W`>/01@2W`>/00`000000
Yl3[0:O0j`0400000080Yl3[00<000000:O0j`2W`>/01@2W`>/00`000000Z<3[0:S0j`02000000@0
Z<7[00<000000:S3k@2X`nd01P2X`nd3000000@0Y/cd00@000000:K<m02Vc?@000001P2=`oT20000
01P0oooo000O0?ooo`030:2PX02`/;00/;2`00d0oooo00<000000?ooo`3oool05P3oool00`000000
Yl3[0:O0j`0300000080Yl3[00<000000:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`0300000080
Yl3[00<000000:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`0300000080Yl3[00<000000:O0j`2W
`>/01P2W`>/3000000H0Yl3[00<000000:O0j`2W`>/01@2W`>/3000000H0Yl3[00<000000:O0j`2W
`>/01@2W`>/3000000L0Z<7[00@000000:S3k@2X`nd0Z<?]100000020:_7kP030000002Vc?@0Y/cd
00<0Y/cd00<000000:K<m00000001000000208g3n@800000603oool00300oooo00<000000?ooo`3o
ool05P3oool2000000H0Yl3[00<000000:O0j`2W`>/01@2W`>/3000000H0Yl3[00<000000:O0j`2W
`>/01@2W`>/3000000H0Yl3[0P0000020:O0j`@000000P2W`>/00`000000Yl3[0:O0j`050:O0j`03
0000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`050:O0j`030000002W`>/0Yl3[00@0
00000P2X`>/00`000000Z<7[0:S1j`050:S1j`@000001P2[anh010000000Y/cd0:K<m02Vc?@40000
00D0oooo1@00000G0?ooo`00<@3oool00`000000oooo0?ooo`0F0?ooo`030000002W`>/0Yl3[00D0
Yl3[00<000000:O0j`2W`>/0100000020:Noj`030000002W`>/0Yl3[00D0Yl3[00<000000:O0j`2W
`>/0100000020:Noj`030000002W`>/0Yl3[00D0Yl3[0`0000060:O0j`030000002W`>/0Yl3[00D0
Yl3[0`0000060:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000070:S0j`030000002X`N/0Z<7[00@0
00000P2Z`^/00`000000ZlO^0:_7kP050:_7kP@000000`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01D0oooo000b0?ooo`8000005`3oool00`000000Yl3[0:O0j`040:O0j`<00000
1`2W_n/00`000000Yl3[0:O0j`040:O0j`<000001`2W_n/200000080Yl3[0`0000020:Noj`030000
002W`>/0Yl3[00D0Yl3[00<000000:O0j`2W`>/0100000020:O0j`030000002W`>/0Yl3[00D0Yl3[
00<000000:O0j`2W`>/0100000020:O0j`030000002X`>/0Z<3[00D0Z<3[0`0000070:[2j`030000
002[anh0ZlO^00@00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo
000d0?ooo`030000003oool0oooo01D0oooo00<000000:O0j`2W`>/00`0000020:Noj`030000002W
_n/0Yko[00H0Yko[00<000000:O0j`2W`>/00`0000020:NojP030000002W_n/0Yko[00H0Yko[0`00
00060:Noj`030000002W`>/0Yl3[00@0Yl3[0`0000070:O0j`030000002W`>/0Yl3[00@0Yl3[0`00
00070:O0j`030000002X`>/0Z<3[00@000000P2X`>/00`000000Z/;[0:[2j`050:[2j`<000003@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01D0oooo000e0?ooo`030000003oool0
oooo01D0oooo0P0000060:Noj`030000002W_n/0Yko[00D0Yko[0`0000060:NojP8000000P2W_n/4
00000080Z;kY00<000000:Noj`2W_n/01@2W_n/00`000000Yl3[0:O0j`0300000080Yl3[00<00000
0:O0j`2W`>/01P2W`>/00`000000Yl3[0:O0j`0300000080Yl3[00<000000:O0j`2W`>/01@2W`>/3
000000H0Z<3[00<000000:[2j`2Z`^/00`2Z`^/200000140oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0E0?ooo`00=P3oool00`000000oooo0?ooo`0E0?ooo`030000002W_n/0Yko[
00D0Yko[00<000000:Noj`2W_n/0100000020:Rmj@030000002W_nX0YkoZ00D0YkoZ0`0000060:Rn
j@030000002W_n/0Yko[00D0Yko[0`0000060:O0j`030000002W`>/0Yl3[00D0Yl3[0`0000060:O0
j`8000000P2W`>/300000080Yl3[00<000000:S0j`2X`>/01@2X`>/00`000000Z/;[0:[2j`020000
01<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`00=`3oool00`000000
oooo0?ooo`0E0?ooo`030000002W_n/0Yko[00@0Yko[0`0000070:Rmj@8000000P2W_nX300000080
Z;[V00<000000:Rnj@2X_^T01@2X_^T00`000000Yko[0:Noj`0400000080Z;kZ00<000000:O0j`2W
`>/01@2W`>/00`000000Yl3[0:O0j`0400000080Yl3[00<000000:O0j`2W`>/01@2W`>/3000000H0
Yl3[00<000000:S0j`2X`>/0102X`>/3000001H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0E0?ooo`00>03oool2000001H0oooo00<000000:Noj`2W_n/00`0000020:RiiP030000
002X_NT0Z;gY00H0Z;gY0`0000060:RjiP030000002X_^T0Z;kY00@0Z;kY0`0000060:RnjP030000
002W`>/0Yl3[00D0Yl3[0`0000070:O0j`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[
0:O0j`050:O0j`030000002X`>/0Z<3[00<000006P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo01@0oooo000j0?ooo`030000003oool0oooo01@0oooo0P0000060:RiiP8000000P2X
_NT400000080ZK;O00<000000:RjiP2X^^H01@2X^^H00`000000Z;kY0:Rnj@0300000080ZK[U00<0
00000:RnjP2X_^X01@2X_^X00`000000Yl3[0:O0j`0400000080Z;o[00<000000:O0j`2W`>/01@2W
`>/3000000H0Yl3[00<000000:O0j`2W`>/01@2W`>/3000001d0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0D0?ooo`00>`3oool00`000000oooo0?ooo`0D0?ooo`030000002X^NH0
Z;WV00H0Z;WV0P0000060:Vbg`030000002X^^H0Z;[V00D0Z;[V0`0000060:Vji@030000002X_^X0
Z;kZ00@0Z;kZ0`0000070:Roj`030000002W`>/0Yl3[00@000000P2W`>/00`000000Yl3[0:O0j`05
0:O0j`030000002W`>/0Yl3[00@000008@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01@0oooo000l0?ooo`030000003oool0oooo01@0oooo00<000000:RiiP2X^NH00`2X^NH20000
00030:VUdP000000ZK;O00H0ZK;O00<000000:RjiP2X^^H0100000020:^_f`030000002Y^^D0ZK[U
00D0ZK[U00<000000:RnjP2X_^X00`0000020:Vli`030000002X_n/0Z;o[00D0Z;o[0`0000060:O0
j`030000002W`>/0Yl3[00D0Yl3[0`00000V0?ooo`050000003oool0oooo0?ooo`0000005P3oool0
03d0oooo0P00000E0?ooo`030000002X^NH0Z;WV00800000102YYM800`000000ZK;O0:Vbg`050:Vb
g`8000001P2[[m/00`000000ZK[U0:Vji@050:Vji@<000001P2Y_>L200000080Z;o[0`0000020:Ro
jP030000002W`>/0Yl3[00D0Yl3[00<000000:O0j`2W`>/01000000Z0?ooo`040000003oool0oooo
000001H0oooo000o0?ooo`030000003oool0oooo01<0oooo0P0000060:VUdP030000002Y/]l0ZK;O
00<0ZK;O0P0000000`2[WLP000000:^_f`060:^_f`030000002Y^^D0ZK[U00@000000P2]/]`00`00
0000ZKcW0:Vli`050:Vli`<000001P2X_nX00`000000Yl3[0:O0j`040:O0j`<00000;P3oool01000
0000oooo0?ooo`00000F0?ooo`00@03oool00`000000oooo0?ooo`0C0?ooo`030000002YYM80ZJGB
00D0ZJGB00<000000:Vbg`2Y/]l00P0000040:^Mb0030000002[[m/0ZjoK00D0ZjoK0P0000070:fb
g0030000002Y_>L0ZKcW00@000000P2]^>800`000000Z;oZ0:RojP050:RojP030000002W`>/0Yl3[
00<00000<P3oool00`000000oooo0000000F0?ooo`00@@3oool00`000000oooo0?ooo`0B0?ooo`03
0000002YYM80ZJGB00H0ZJGB0P0000060:^Mb0030000002[[m/0ZjoK00<0ZjoK0P0000000`2_W/H0
00000:fbg0070:fbg08000001P2]^>800`000000Z;oZ0:RojP050:RojP<00000=P3oool00`000000
oooo0000000E0?ooo`00@P3oool00`000000oooo0?ooo`0B0?ooo`030000002YYM80ZJGB00<0ZJGB
0P0000000`2XRK@000000:^Mb0060:^Mb0030000002[[m/0ZjoK00800000102_W/H00`000000[K;L
0:fbg0030:fbg080000000<0/ZK<0000002]^>801P2]^>800`000000Z;oZ0:RojP04000003X0oooo
0P00000E0?ooo`00@`3oool2000001<0oooo00D000000:VUdP2YYM80ZJGB000000030:R9]0030000
002[WLP0Zig800H0Zig80P0000060:nNaP030000002]/]`0[K;L0080[K;L00<000000;:Vc02bY/`0
0P2bY/`00`000000[KSR0:fhhP040:fhhP<00000?P3oool2000001D0oooo00150?ooo`030000003o
ool0oooo0100oooo00@000000:VUdP00000000001@2XRK@00`000000Zig80:^Mb0040:^Mb0030000
002/R;00000000L0[ik600@000000:fbg000000000001P2bY/`00`000000[KSR0:fhhP0300000440
oooo0P00000E0?ooo`00AP3oool00`000000oooo0?ooo`0@0?ooo`030000002XRK@0Z8Vd00D0Z8Vd
00<000000:^Mb02[WLP00`2[WLP010000000[8R`0:b8/00000080:nNaP030000002bY/`0/ZK<00L0
/ZK<0P0000100?ooo`@000005`3oool004L0oooo00<000000?ooo`3oool03`3oool00`000000Z8Vd
0:R9]0060:R9]0030000002[WLP0Zig800800000102/R;000`000000[ik60:nNaP040:nNaP800000
202bY/`00`000000oooo0?ooo`0l0?ooo`@000006`3oool004P0oooo00<000000?ooo`3oool03P3o
ool00`000000Z8Vd0:R9]0060:R9]0030000002[WLP0000000H0[8R`00<000000:nNaP2_W/H00`2_
W/H010000000/Hja0;6>/@0000060;:Vc0030000003oool0oooo03T0oooo1000000O0?ooo`00B@3o
ool2000000l0oooo00<000000:R9]02XRK@01P2XRK@00`000000[8R`0:b8/0060:b8/0030000002_
W/H0[ik6008000000`2aS[400`000000/ZK<0;:Vc0020;:Vc0800000>03oool4000002<0oooo001;
0?ooo`030000003oool0oooo00`0oooo00<000000:R9]02XRK@01@2XRK@2000000P0[8R`00<00000
0:nNaP0000001P2aS[4010000000/ZK<0;:Vc000000f0?ooo`@000009`3oool004`0oooo00<00000
0?ooo`3oool02`3oool00`000000Z8Vd0:R9]0040:R9]00300000032WkD0000000T0[8R`00<00000
0;6>/@2aS[401@2aS[400`000000/ZK<0000000c0?ooo`@00000:`3oool004d0oooo00<000000?oo
o`3oool02P3oool00`000000Z8Vd0:R9]0040:R9]00400000032WkD0`Yne000000L0[8R`0P000008
0;6>/@030000003oool0oooo02h0oooo1000000_0?ooo`00CP3oool2000000/0oooo00<000000:R9
]02XRK@00P2XRK@01@000000`Yne0<:O]@32WkD0000000L0[8R`0P0000070;6>/@030000003oool0
oooo02`0oooo0`00000c0?ooo`00D03oool00`000000oooo0?ooo`080?ooo`050000002XRK@0Z8Vd
0:R9]00000001032WkD00`000000[8R`0:b8/0040:b8/0040000003G]KL0ekFg000000H0/Hja00<0
00000?ooo`3oool0:03oool4000003H0oooo001A0?ooo`030000003oool0oooo00L0oooo00@00000
0:R9]02XRK@000001@32WkD00`000000[8R`0:b8/0040:b8/0040000003G]KL0ekFg000000D0/Hja
00<000000?ooo`3oool09@3oool4000003X0oooo001B0?ooo`030000003oool0oooo00H0oooo00@0
00000:R9]02XRK@000001@32WkD00`000000[8R`0:b8/0030:b8/0050000003G]KL0ekFg0=Ne]`00
00001@2aS[400`000000oooo0?ooo`0Q0?ooo`@00000?P3oool005<0oooo00<000000?ooo`3oool0
1P3oool2000000L0`Yne00D000000:b8/02/R;00[8R`000000040=Ne]`030000002aS[40/Hja0080
/Hja00<000000?ooo`3oool07P3oool400000480oooo001D0?ooo`8000001P3oool00`000000`Yne
0<:O]@060<:O]@050000002/R;00[8R`0:b8/00000001@3G]KL01@000000/Hja0;6>/@2aS[400000
01`0oooo100000160?ooo`00EP3oool00`000000oooo0?ooo`030?ooo`0300000032WkD0`Yne00H0
`Yne00@000000:b8/02/R;0000001P3G]KL010000000/Hja0;6>/@00000I0?ooo`@00000BP3oool0
05L0oooo00<000000?ooo`3oool00`3oool00`000000`Yne0<:O]@050<:O]@040000002/R;00[8R`
000000H0ekFg00@000000;6>/@2aS[4000005@3oool4000004h0oooo001H0?ooo`030000003oool0
oooo0080oooo00<000000<:O]@32WkD01P32WkD2000000L0ekFg00<000000;6>/@0000004P3oool4
00000580oooo001I0?ooo`030000003oool0oooo0080oooo00<000000<:O]@32WkD01@32WkD20000
00P0ekFg0P00000?0?ooo`<00000EP3oool005X0oooo0P0000020?ooo`0300000032WkD0`Yne00D0
`Yne00<000000=Ne]`3G]KL01`3G]KL00`000000oooo0?ooo`0:0?ooo`@00000F@3oool005`0oooo
00@000000?ooo`3oool000001032WkD2000000030<77g`000000ekFg00L0ekFg00<000000?ooo`3o
ool01P3oool4000005d0oooo001M0?ooo`030000003oool0000000<0`Yne00<000000<77g`31aml0
0P31aml00`000000ekFg0=Ne]`030=Ne]`8000001@3oool400000640oooo001N0?ooo`030000003o
ool00000008000001@31aml00`000000ekFg0=Ne]`020=Ne]`040000003oool0oooo0?ooo`@00000
I@3oool005l0oooo0P0000080<77g`030000003G]KL0000000D00000J@3oool00600oooo0P000007
0<77g`@00000K@3oool00680oooo00<000000<77g`31aml01000001a0?ooo`00H`3oool2000007D0
oooo003J0?ooo`00fP3oool00=X0oooo003J0?ooo`00fP3oool00=X0oooo003J0?ooo`00fP3oool0
0=X0oooo003J0?ooo`00fP3oool00=X0oooo003J0?ooo`00fP3oool00=X0oooo003J0?ooo`00fP3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 217.125}, {175.875, 0}} -> {-0.217462, -0.105939, \
0.00596931, 0.00596931}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[193]="]
}, Open  ]],

Cell[TextData[{
  "Comparing exact and approximate results using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Plot3D",
    FontFamily->"Courier New"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plot3D[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {\[Lambda] \[Rule] 
            2\ \((2*m + 3)\)}, {x, \(-1\), 
        1}, {m, \(-2\), \(-1\)}]\)], "Input",
  CellLabel->"In[194]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.79544e-016 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -23.5978 -9 ]
[.17646 .18758 .40224 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -15.8219 -9 ]
[.50253 .05935 2.17811 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 12 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 30 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 24 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 30 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.02363 .26817 -43.5 -3.81236 ]
[.02363 .26817 0 8.68764 ]
[.01136 .34506 -6 -2.80997 ]
[.01136 .34506 0 6.19003 ]
[-0.00154 .42588 -37.5 -3.99822 ]
[-0.00154 .42588 0 8.50178 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(-2)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(-1.75)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(-1.5)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(-1.25)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(-1)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03585 .2634 m
.04196 .26102 L
s
gsave
.02363 .26817 -43.5 -1.81236 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-17) show
grestore
.02364 .34044 m
.02978 .33814 L
s
[(0)] .01136 .34506 1 -0.37556 Mshowa
.01081 .42143 m
.01698 .41921 L
s
gsave
-0.00154 .42588 -37.5 -1.99822 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-17) show
grestore
.125 Mabswid
.03285 .28231 m
.03653 .28089 L
s
.02982 .30145 m
.0335 .30004 L
s
.02675 .32082 m
.03043 .31943 L
s
.02049 .36031 m
.02418 .35894 L
s
.01731 .38043 m
.021 .37907 L
s
.01408 .4008 m
.01778 .39945 L
s
.0075 .44233 m
.0112 .44101 L
s
.00414 .4635 m
.00785 .46219 L
s
.00074 .48495 m
.00446 .48366 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.888 .744 .697 r
.38006 .65682 .40257 .67679 .44011 .66604 .42036 .56711 Metetra
.217 .209 .635 r
.42036 .56711 .44011 .66604 .47635 .79059 .45634 .63458 Metetra
.601 .443 .639 r
.45634 .63458 .47635 .79059 .51678 .64407 .4953 .62323 Metetra
.658 .749 .917 r
.4953 .62323 .51678 .64407 .55593 .63285 .53482 .61171 Metetra
.927 .541 .211 r
.53482 .61171 .55593 .63285 .59565 .62147 .57694 .73823 Metetra
0 0 .167 r
.57694 .73823 .59565 .62147 .63594 .60992 .6156 .58816 Metetra
.658 .749 .917 r
.6156 .58816 .63594 .60992 .67682 .59821 .65689 .57613 Metetra
.658 .749 .917 r
.65689 .57613 .67682 .59821 .7183 .58632 .69879 .56391 Metetra
.658 .749 .917 r
.69879 .56391 .7183 .58632 .76776 .68051 .74132 .55152 Metetra
.607 .461 .657 r
.74132 .55152 .76776 .68051 .80311 .56202 .78449 .53893 Metetra
.658 .749 .917 r
.78449 .53893 .80311 .56202 .84647 .54959 .82832 .52616 Metetra
.835 .413 0 r
.82832 .52616 .84647 .54959 .90585 .67815 .88765 .65542 Metetra
.645 .763 .934 r
.88765 .65542 .90585 .67815 .95255 .66592 .9349 .64283 Metetra
.645 .763 .934 r
.9349 .64283 .95255 .66592 .98055 .51117 .98292 .63004 Metetra
.878 .602 .08 r
.3608 .5574 .38006 .65682 .42036 .56711 .39002 .76197 Metetra
.539 .291 .488 r
.39002 .76197 .42036 .56711 .45634 .63458 .43029 .75104 Metetra
0 0 .05 r
.43029 .75104 .45634 .63458 .4953 .62323 .47325 .60183 Metetra
.931 .551 .239 r
.47325 .60183 .4953 .62323 .53482 .61171 .51266 .72869 Metetra
0 0 .111 r
.51266 .72869 .53482 .61171 .57694 .73823 .55362 .57799 Metetra
.48 .356 .634 r
.55362 .57799 .57694 .73823 .6156 .58816 .59579 .61826 Metetra
.634 .823 .408 r
.59579 .61826 .6156 .58816 .65689 .57613 .63641 .55344 Metetra
.658 .749 .917 r
.63641 .55344 .65689 .57613 .69879 .56391 .67874 .54088 Metetra
.658 .749 .917 r
.67874 .54088 .69879 .56391 .74132 .55152 .72171 .52814 Metetra
.658 .749 .917 r
.72171 .52814 .74132 .55152 .78449 .53893 .76534 .5152 Metetra
.658 .749 .917 r
.76534 .5152 .78449 .53893 .82832 .52616 .80965 .50205 Metetra
.658 .749 .917 r
.80965 .50205 .82832 .52616 .88765 .65542 .85464 .48871 Metetra
.714 .516 .62 r
.85464 .48871 .88765 .65542 .9349 .64283 .89092 .39244 Metetra
.482 .341 .612 r
.89092 .39244 .9349 .64283 .98292 .63004 .94676 .46139 Metetra
.664 .741 .907 r
.33769 .53581 .3608 .5574 .39002 .76197 .37536 .52388 Metetra
.443 .302 .593 r
.37536 .52388 .39002 .76197 .43029 .75104 .41091 .59183 Metetra
.088 .071 .54 r
.41091 .59183 .43029 .75104 .47325 .60183 .44755 .71902 Metetra
0 0 .05 r
.44755 .71902 .47325 .60183 .51266 .72869 .49087 .56769 Metetra
.596 .437 .636 r
.49087 .56769 .51266 .72869 .55362 .57799 .53174 .55535 Metetra
.658 .749 .917 r
.53174 .55535 .55362 .57799 .59579 .61826 .57323 .54283 Metetra
.623 .52 .717 r
.57323 .54283 .59579 .61826 .63641 .55344 .61536 .53011 Metetra
.658 .749 .917 r
.61536 .53011 .63641 .55344 .67874 .54088 .65812 .5172 Metetra
.658 .749 .917 r
.65812 .5172 .67874 .54088 .72171 .52814 .70155 .50409 Metetra
.658 .749 .917 r
.70155 .50409 .72171 .52814 .76534 .5152 .74565 .49078 Metetra
.658 .749 .917 r
.74565 .49078 .76534 .5152 .80965 .50205 .79044 .47725 Metetra
.933 .787 .677 r
.79044 .47725 .80965 .50205 .85464 .48871 .82808 .38056 Metetra
.611 .477 .674 r
.82808 .38056 .85464 .48871 .89092 .39244 .87307 .36632 Metetra
.664 .741 .907 r
.87307 .36632 .89092 .39244 .94676 .46139 .91876 .35185 Metetra
.709 .817 .36 r
.30891 .59366 .33769 .53581 .37536 .52388 .35197 .50141 Metetra
.664 .741 .907 r
.35197 .50141 .37536 .52388 .41091 .59183 .39053 .48899 Metetra
.609 .475 .673 r
.39053 .48899 .41091 .59183 .44755 .71902 .42965 .47638 Metetra
.583 .406 .607 r
.42965 .47638 .44755 .71902 .49087 .56769 .46934 .46359 Metetra
.217 .209 .635 r
.46934 .46359 .49087 .56769 .53174 .55535 .50925 .53208 Metetra
.658 .749 .917 r
.50925 .53208 .53174 .55535 .57323 .54283 .55115 .5192 Metetra
.658 .749 .917 r
.55115 .5192 .57323 .54283 .61536 .53011 .5937 .50612 Metetra
.658 .749 .917 r
.5937 .50612 .61536 .53011 .65812 .5172 .63691 .49284 Metetra
.658 .749 .917 r
.63691 .49284 .65812 .5172 .70155 .50409 .6808 .47935 Metetra
.658 .749 .917 r
.6808 .47935 .70155 .50409 .74565 .49078 .72538 .46565 Metetra
.928 .783 .68 r
.72538 .46565 .74565 .49078 .79044 .47725 .76442 .36852 Metetra
.304 .276 .661 r
.76442 .36852 .79044 .47725 .82808 .38056 .81668 .43758 Metetra
.429 .083 .276 r
.81668 .43758 .82808 .38056 .87307 .36632 .86343 .42321 Metetra
.429 .083 .276 r
.86343 .42321 .87307 .36632 .91876 .35185 .91095 .40861 Metetra
.658 .749 .917 r
.28389 .57145 .30891 .59366 .35197 .50141 .32313 .55917 Metetra
.416 .064 .258 r
.32313 .55917 .35197 .50141 .39053 .48899 .36295 .5467 Metetra
.416 .064 .258 r
.36295 .5467 .39053 .48899 .42965 .47638 .40339 .53404 Metetra
.773 .443 .428 r
.40339 .53404 .42965 .47638 .46934 .46359 .44183 .62927 Metetra
0 0 .199 r
.44183 .62927 .46934 .46359 .50925 .53208 .48672 .45642 Metetra
.313 .325 .713 r
.48672 .45642 .50925 .53208 .55115 .5192 .52844 .49489 Metetra
.658 .749 .917 r
.52844 .49489 .55115 .5192 .5937 .50612 .57143 .48144 Metetra
.658 .749 .917 r
.57143 .48144 .5937 .50612 .63691 .49284 .61509 .46777 Metetra
.658 .749 .917 r
.61509 .46777 .63691 .49284 .6808 .47935 .65945 .45388 Metetra
.658 .749 .917 r
.65945 .45388 .6808 .47935 .72538 .46565 .70451 .43978 Metetra
.658 .749 .917 r
.70451 .43978 .72538 .46565 .76442 .36852 .7503 .42544 Metetra
.416 .064 .258 r
.7503 .42544 .76442 .36852 .81668 .43758 .79684 .41087 Metetra
.658 .749 .917 r
.79684 .41087 .81668 .43758 .86343 .42321 .84414 .39606 Metetra
.942 .797 .67 r
.84414 .39606 .86343 .42321 .91095 .40861 .88252 .29643 Metetra
.658 .749 .917 r
.25818 .54863 .28389 .57145 .32313 .55917 .29777 .536 Metetra
.6 .085 0 r
.29777 .536 .32313 .55917 .36295 .5467 .335 .57633 Metetra
.823 .954 .613 r
.335 .57633 .36295 .5467 .40339 .53404 .37878 .51016 Metetra
.658 .749 .917 r
.37878 .51016 .40339 .53404 .44183 .62927 .42022 .49695 Metetra
.653 .488 .647 r
.42022 .49695 .44183 .62927 .48672 .45642 .46281 .45728 Metetra
.6 .039 0 r
.46281 .45728 .48672 .45642 .52844 .49489 .50499 .48322 Metetra
.772 .895 .93 r
.50499 .48322 .52844 .49489 .57143 .48144 .5485 .45603 Metetra
.658 .749 .917 r
.5485 .45603 .57143 .48144 .61509 .46777 .59262 .44196 Metetra
.658 .749 .917 r
.59262 .44196 .61509 .46777 .65945 .45388 .63746 .42766 Metetra
.658 .749 .917 r
.63746 .42766 .65945 .45388 .70451 .43978 .68302 .41313 Metetra
.658 .749 .917 r
.68302 .41313 .70451 .43978 .7503 .42544 .72933 .39836 Metetra
.893 .798 .748 r
.72933 .39836 .7503 .42544 .79684 .41087 .77221 .32998 Metetra
.366 .361 .721 r
.77221 .32998 .79684 .41087 .84414 .39606 .82426 .36808 Metetra
.658 .749 .917 r
.82426 .36808 .84414 .39606 .88252 .29643 .87292 .35256 Metetra
.658 .749 .917 r
.23175 .52517 .25818 .54863 .29777 .536 .2717 .51218 Metetra
.658 .749 .917 r
.2717 .51218 .29777 .536 .335 .57633 .31226 .49899 Metetra
.617 .516 .717 r
.31226 .49899 .335 .57633 .37878 .51016 .35346 .4856 Metetra
.658 .749 .917 r
.35346 .4856 .37878 .51016 .42022 .49695 .39531 .472 Metetra
.658 .749 .917 r
.39531 .472 .42022 .49695 .46281 .45728 .43782 .45818 Metetra
.424 .867 .886 r
.43782 .45818 .46281 .45728 .50499 .48322 .48101 .44414 Metetra
.651 .657 .843 r
.48101 .44414 .50499 .48322 .5485 .45603 .52489 .42988 Metetra
.658 .749 .917 r
.52489 .42988 .5485 .45603 .59262 .44196 .56948 .41538 Metetra
.658 .749 .917 r
.56948 .41538 .59262 .44196 .63746 .42766 .6148 .40065 Metetra
.658 .749 .917 r
.6148 .40065 .63746 .42766 .68302 .41313 .66087 .38567 Metetra
.658 .749 .917 r
.66087 .38567 .68302 .41313 .72933 .39836 .70771 .37045 Metetra
.658 .749 .917 r
.70771 .37045 .72933 .39836 .77221 .32998 .75533 .35497 Metetra
.183 0 0 r
.75533 .35497 .77221 .32998 .82426 .36808 .80375 .33922 Metetra
.658 .749 .917 r
.80375 .33922 .82426 .36808 .87292 .35256 .853 .32321 Metetra
.474 .38 .668 r
.21248 .41888 .23175 .52517 .2717 .51218 .24927 .43566 Metetra
.617 .516 .717 r
.24927 .43566 .2717 .51218 .31226 .49899 .2896 .4219 Metetra
.617 .516 .717 r
.2896 .4219 .31226 .49899 .35346 .4856 .33056 .40793 Metetra
.257 .287 .702 r
.33056 .40793 .35346 .4856 .39531 .472 .36966 .44631 Metetra
.206 .538 .926 r
.36966 .44631 .39531 .472 .43782 .45818 .41166 .45912 Metetra
.846 .979 .869 r
.41166 .45912 .43782 .45818 .48101 .44414 .45622 .41762 Metetra
.658 .749 .917 r
.45622 .41762 .48101 .44414 .52489 .42988 .50057 .40293 Metetra
.499 .685 .95 r
.50057 .40293 .52489 .42988 .56948 .41538 .54572 .4016 Metetra
.772 .895 .93 r
.54572 .4016 .56948 .41538 .6148 .40065 .59146 .3728 Metetra
.886 .789 .748 r
.59146 .3728 .6148 .40065 .66087 .38567 .63613 .30369 Metetra
.333 .338 .716 r
.63613 .30369 .66087 .38567 .70771 .37045 .68541 .34166 Metetra
.658 .749 .917 r
.68541 .34166 .70771 .37045 .75533 .35497 .73359 .32569 Metetra
.658 .749 .917 r
.73359 .32569 .75533 .35497 .80375 .33922 .7826 .30945 Metetra
.942 .797 .67 r
.7826 .30945 .80375 .33922 .853 .32321 .82395 .20683 Metetra
.491 .219 .428 r
.1614 .62005 .21248 .41888 .24927 .43566 .20374 .60688 Metetra
.483 .201 .41 r
.20374 .60688 .24927 .43566 .2896 .4219 .24679 .59349 Metetra
0 0 .102 r
.24679 .59349 .2896 .4219 .33056 .40793 .30058 .43429 Metetra
.122 0 0 r
.30058 .43429 .33056 .40793 .36966 .44631 .34325 .41986 Metetra
.658 .749 .917 r
.34325 .41986 .36966 .44631 .41166 .45912 .38661 .4052 Metetra
.423 .478 .812 r
.38661 .4052 .41166 .45912 .45622 .41762 .42989 .41762 Metetra
.846 .979 .869 r
.42989 .41762 .45622 .41762 .50057 .40293 .4755 .37516 Metetra
.658 .749 .917 r
.4755 .37516 .50057 .40293 .54572 .4016 .52106 .35976 Metetra
.65 .658 .844 r
.52106 .35976 .54572 .4016 .59146 .3728 .56738 .3441 Metetra
.658 .749 .917 r
.56738 .3441 .59146 .3728 .63613 .30369 .61449 .32817 Metetra
.914 .92 .533 r
.61449 .32817 .63613 .30369 .68541 .34166 .65865 .22618 Metetra
0 0 .393 r
.65865 .22618 .68541 .34166 .73359 .32569 .71801 .41018 Metetra
0 0 .034 r
.71801 .41018 .73359 .32569 .7826 .30945 .76076 .27872 Metetra
.776 .353 0 r
.76076 .27872 .7826 .30945 .82395 .20683 .82533 .41353 Metetra
.645 .763 .934 r
.1311 .59557 .1614 .62005 .20374 .60688 .17384 .58199 Metetra
.645 .763 .934 r
.17384 .58199 .20374 .60688 .24679 .59349 .21731 .56818 Metetra
.92 .739 .641 r
.21731 .56818 .24679 .59349 .30058 .43429 .27295 .40748 Metetra
.658 .749 .917 r
.27295 .40748 .30058 .43429 .34325 .41986 .31604 .39261 Metetra
.658 .749 .917 r
.31604 .39261 .34325 .41986 .38661 .4052 .35984 .3775 Metetra
.658 .749 .917 r
.35984 .3775 .38661 .4052 .42989 .41762 .40437 .36214 Metetra
.635 .593 .79 r
.40437 .36214 .42989 .41762 .4755 .37516 .44965 .34652 Metetra
0 .11 .624 r
.44965 .34652 .4755 .37516 .52106 .35976 .49519 .38652 Metetra
.786 .933 .57 r
.49519 .38652 .52106 .35976 .56738 .3441 .54255 .31448 Metetra
.658 .749 .917 r
.54255 .31448 .56738 .3441 .61449 .32817 .59019 .29804 Metetra
.658 .749 .917 r
.59019 .29804 .61449 .32817 .65865 .22618 .63867 .28132 Metetra
.333 0 .146 r
.63867 .28132 .65865 .22618 .71801 .41018 .68801 .2643 Metetra
.032 .063 .559 r
.68801 .2643 .71801 .41018 .76076 .27872 .7488 .39933 Metetra
.445 .134 .342 r
.7488 .39933 .76076 .27872 .82533 .41353 .80256 .38225 Metetra
0 0 .283 r
.12864 .34057 .1311 .59557 .17384 .58199 .143 .55631 Metetra
.916 .736 .644 r
.143 .55631 .17384 .58199 .21731 .56818 .20167 .39492 Metetra
.571 .406 .619 r
.20167 .39492 .21731 .56818 .27295 .40748 .24447 .37984 Metetra
.899 .754 .693 r
.24447 .37984 .27295 .40748 .31604 .39261 .2943 .27964 Metetra
.092 .113 .589 r
.2943 .27964 .31604 .39261 .35984 .3775 .33223 .34894 Metetra
.658 .749 .917 r
.33223 .34894 .35984 .3775 .40437 .36214 .37723 .3331 Metetra
.658 .749 .917 r
.37723 .3331 .40437 .36214 .44965 .34652 .42299 .31698 Metetra
.88 .781 .748 r
.42299 .31698 .44965 .34652 .49519 .38652 .47051 .2463 Metetra
.396 .305 .635 r
.47051 .2463 .49519 .38652 .54255 .31448 .51691 .28391 Metetra
.877 .461 .032 r
.51691 .28391 .54255 .31448 .59019 .29804 .56708 .41864 Metetra
0 0 .018 r
.56708 .41864 .59019 .29804 .63867 .28132 .61416 .24967 Metetra
.658 .749 .917 r
.61416 .24967 .63867 .28132 .68801 .2643 .66408 .23209 Metetra
.658 .749 .917 r
.66408 .23209 .68801 .2643 .7488 .39933 .71491 .21419 Metetra
.571 .406 .619 r
.71491 .21419 .7488 .39933 .80256 .38225 .76666 .19597 Metetra
.462 .176 .393 r
.06762 .54427 .12864 .34057 .143 .55631 .11118 .52982 Metetra
.916 .736 .644 r
.11118 .52982 .143 .55631 .20167 .39492 .1719 .3669 Metetra
.658 .749 .917 r
.1719 .3669 .20167 .39492 .24447 .37984 .21511 .35136 Metetra
.931 .551 .239 r
.21511 .35136 .24447 .37984 .2943 .27964 .24649 .48491 Metetra
0 0 .151 r
.24649 .48491 .2943 .27964 .33223 .34894 .30375 .31948 Metetra
0 .046 .553 r
.30375 .31948 .33223 .34894 .37723 .3331 .34606 .35935 Metetra
.852 .969 .649 r
.34606 .35935 .37723 .3331 .42299 .31698 .39548 .2865 Metetra
.658 .749 .917 r
.39548 .2865 .42299 .31698 .47051 .2463 .44254 .26957 Metetra
.824 .405 .248 r
.44254 .26957 .47051 .2463 .51691 .28391 .48915 .36808 Metetra
.542 .172 .288 r
.48915 .36808 .51691 .28391 .56708 .41864 .53991 .38754 Metetra
.971 .745 .539 r
.53991 .38754 .56708 .41864 .61416 .24967 .58699 .12975 Metetra
.202 .197 .63 r
.58699 .12975 .61416 .24967 .66408 .23209 .63936 .19879 Metetra
.808 .384 0 r
.63936 .19879 .66408 .23209 .71491 .21419 .69935 .33462 Metetra
.42 .096 .309 r
.69935 .33462 .71491 .21419 .76666 .19597 .75456 .3163 Metetra
.645 .763 .934 r
.03435 .51739 .06762 .54427 .11118 .52982 .07833 .50246 Metetra
.645 .763 .934 r
.07833 .50246 .11118 .52982 .1719 .3669 .12308 .48727 Metetra
.761 .809 .33 r
.12308 .48727 .1719 .3669 .21511 .35136 .18483 .32197 Metetra
.658 .749 .917 r
.18483 .32197 .21511 .35136 .24649 .48491 .22921 .30566 Metetra
.714 .508 .609 r
.22921 .30566 .24649 .48491 .30375 .31948 .2813 .20292 Metetra
.07 .096 .58 r
.2813 .20292 .30375 .31948 .34606 .35935 .32031 .27219 Metetra
.605 .508 .718 r
.32031 .27219 .34606 .35935 .39548 .2865 .36706 .25502 Metetra
.844 .404 0 r
.36706 .25502 .39548 .2865 .44254 .26957 .41047 .35361 Metetra
.41047 .35361 .44254 .26957 .48915 .36808 .46309 .21973 Metetra
.574 .424 .639 r
.46309 .21973 .48915 .36808 .53991 .38754 .51242 .20161 Metetra
.563 .396 .614 r
.51242 .20161 .53991 .38754 .58699 .12975 .56264 .18316 Metetra
.264 0 .056 r
.56264 .18316 .58699 .12975 .63936 .19879 .61379 .16436 Metetra
.658 .749 .917 r
.61379 .16436 .63936 .19879 .69935 .33462 .6659 .14522 Metetra
.109 .088 .55 r
.6659 .14522 .69935 .33462 .75456 .3163 .72925 .28152 Metetra
.558 .391 .611 r
.02364 .34044 .03435 .51739 .07833 .50246 .06622 .32445 Metetra
.558 .391 .611 r
.06622 .32445 .07833 .50246 .12308 .48727 .10952 .30819 Metetra
.714 .508 .609 r
.10952 .30819 .12308 .48727 .18483 .32197 .16384 .20553 Metetra
0 .039 .548 r
.16384 .20553 .18483 .32197 .22921 .30566 .1984 .27481 Metetra
.902 .758 .692 r
.1984 .27481 .22921 .30566 .2813 .20292 .25192 .17104 Metetra
.778 .311 0 r
.25192 .17104 .2813 .20292 .32031 .27219 .29045 .24024 Metetra
.658 .749 .917 r
.29045 .24024 .32031 .27219 .36706 .25502 .33771 .22249 Metetra
.915 .77 .687 r
.33771 .22249 .36706 .25502 .41047 .35361 .38984 .11704 Metetra
.331 .205 .555 r
.38984 .11704 .41047 .35361 .46309 .21973 .43482 .18602 Metetra
.658 .749 .917 r
.43482 .18602 .46309 .21973 .51242 .20161 .48472 .16728 Metetra
.658 .749 .917 r
.48472 .16728 .51242 .20161 .56264 .18316 .53555 .14819 Metetra
.658 .749 .917 r
.53555 .14819 .56264 .18316 .61379 .16436 .58734 .12874 Metetra
.658 .749 .917 r
.58734 .12874 .61379 .16436 .6659 .14522 .64011 .10892 Metetra
.658 .749 .917 r
.64011 .10892 .6659 .14522 .72925 .28152 .69389 .08873 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-1)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-0.5)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(0.5)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(1)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[194]:=",
  ImageSize->{195.063, 158.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000330000WR000`400?l00000o`00003o``3oool0
0<<0oooo00330?ooo`00``3oool00<<0oooo00330?ooo`00``3oool00<<0oooo00330?ooo`00``3o
ool00<<0oooo00330?ooo`00``3oool00<<0oooo00330?ooo`00``3oool00<<0oooo00330?ooo`00
``3oool00<<0oooo001o0?ooo`D00000?`3oool00840oooo00<000000?ooo`3oool0?`3oool00840
oooo00<000000?ooo`3oool0?`3oool00840oooo00<000000?ooo`3oool0?`3oool00840oooo00<0
00000?ooo`3oool0?`3oool00800oooo0P00000;0?ooo`@00000<P3oool008d0oooo00<000000?oo
o`3oool0<`3oool008h0oooo00<000000?ooo`3oool0<P3oool008L0oooo100000040?ooo`030000
003oool0oooo0340oooo002=0?ooo`040000003oool0oooo00000380oooo001M0?ooo`800000103o
ool2000000@0oooo0P00000H0?ooo`<00000203oool2000003<0oooo001L0?ooo`040000003oool0
oooo000000P0oooo00@000000?ooo`3oool000005@3oool2000000030?ooo`000000000003d0oooo
001L0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0403oool3000000<0oooo
0P00000m0?ooo`00G03oool010000000oooo0?ooo`0000090?ooo`8000004@3oool2000000H0oooo
00@000000?ooo`0000000000>`3oool005`0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`0=0?ooo`<00000203oool010000000oooo0?ooo`00000k0?ooo`00G@3oool2000000X0
oooo0`00000:0?ooo`<000002`3oool010000000oooo0?ooo`00000k0?ooo`00M03oool3000000d0
oooo00D000000?ooo`3oool0oooo0000000j0?ooo`00L@3oool300000100oooo00@000000?ooo`3o
ool0oooo0P00000i0?ooo`00K`3oool300000180oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0g0?ooo`00D@3oool2000001T0oooo0`00000F0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0=P3oool00500oooo00@000000?ooo`3oool000005P3oool2000000030?oo
o`000000oooo01H0oooo00<000000?ooo`3oool00P3oool2000003L0oooo001@0?ooo`040000003o
ool0oooo000001<0oooo0`00000K0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
=@3oool00500oooo00@000000?ooo`3oool000004@3oool2000001d0oooo0P0000060?ooo`030000
003oool0oooo00T0oooo1@0000020?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`800000
5P3oool00500oooo00@000000?ooo`3oool000003P3oool3000001/0oooo100000000`2X_nX00000
0?ooo`060?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool04`3oool00540oooo0P00000<0?ooo`<00000
6`3oool3000000D0Z;oZ00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0C0?ooo`00G03o
ool4000001/0oooo0P0000020:RojP030000002X_nX0Z;oZ00<0Z;oZ0P0000070?ooo`040000003o
ool0oooo0?ooo`@00000103oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`80
00005P3oool005X0oooo1000000K0?ooo`800000102X_nX00`000000Z;oZ0:RojP030:RojP800000
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0E0?ooo`00<03oool2000000@0oooo0P0000040?ooo`800000
6P3oool2000000040?ooo`0000000000000001P0oooo0`0000070:RojP030000002X_nX0Z;oZ0080
Z;oZ0P0000070?ooo`8000002@3oool2000000T0oooo100000030?ooo`<000005@3oool002l0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000F0?ooo`<000000`3oool20000
000305@dSP000000oooo01@0oooo0P0000020:RojP030000002X_nX0Z;oZ00D0Z;oZ00<000000:Ro
jP2X_nX00P2X_nX2000000T0oooo00<000000?ooo`3oool0<03oool002l0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0B0?ooo`80000000<0oooo0000003oool00P3oool01@00
0000j/F_0000001D=8h0000001<0oooo0P0000040:RojP030000002X_nX0Z;oZ00D0Z;oZ0P000003
0:RojP8000002P3oool00`000000oooo0?ooo`0_0?ooo`00:@3oool400000080oooo00@000000?oo
o`3oool000002@3oool200000180oooo0`0000070?ooo`030000003ZaJl000000080E3B>00<00000
0?ooo`3oool03@3oool3000000L0Z;oZ00<000000:RojP2X_nX00P2X_nX2000000030:RojP000000
Z;oZ0080Z;oZ00<000000:RojP0000002@3oool00`000000oooo0?ooo`0_0?ooo`00;`3oool01000
0000oooo0?ooo`0000090?ooo`030000003oool0oooo00h0oooo0`0000090?ooo`050000003ZaJl0
j/F_0>[5[`0000000P1D=8h00`000000oooo0?ooo`080?ooo`@000000P2X_nX00`000000Z;oZ0:Ro
jP050:RojP030000002X_nX0Z;oZ008000000`2X_nX200000080Z;oZ00<000000:RojP0000002P3o
ool00`000000oooo0?ooo`0^0?ooo`00<03oool2000000X0oooo0`00000<0?ooo`80000000<0oooo
0000003oool02@3oool01@000000j/F_0>[5[`3ZaJl000000080E3B>00<000000?ooo`3oool01@3o
ool3000000H0Z;oZ00<000000:RojP2X_nX01@2X_nX3000000H0Z;oZ00H000000:RojP2X_nX00000
0:RojP00000;0?ooo`030000003oool0oooo02d0oooo00180?ooo`<000003@3oool00`000000j/F_
0>[5[`020>[5[`050000001D=8h0E3B>05@dSP000000103oool200000080Z;oZ00<000000:RojP2X
_nX01@2X_nX00`000000Z;oZ0:RojP0400000080<c:Q00<000000:RojP2X_nX0102X_nX200000004
0:RojP000000Z;oZ000000/0oooo00<000000?ooo`3oool0;@3oool004H0oooo0P000000103oool0
00000>K2/@00000<0?ooo`030000003ZaJl0j/F_0080j/F_00D0000005@dSP1D=8h0E3B>00000002
0?ooo`8000001@2X_nX00`000000Z;oZ0:RojP050:RojP80000000@0T6FM0000003h_XT000000`0c
<Z400`000000Z;oZ0:RojP030:RojP80000000@0Z;oZ0000002X_nX00000303oool00`000000oooo
0?ooo`0/0?ooo`009`3oool5000001L0oooo0`0000030?ooo`040000003V`[400000000000X0oooo
00<000000>[5[`3ZaJl00`3ZaJl00`000000E3B>05@dSP0205@dSP8000001`2X_nX00`000000Z;oZ
0:RojP030:RojP8000000P2@IId010000000n;j90?RnR@00000403<bX@030000002X_nX0Z;oZ0080
Z;oZ00@0000001/FS0000000Z;oZ0P00000=0?ooo`030000003oool0oooo02/0oooo000Y0?ooo`03
0000003oool0oooo01D0oooo0P0000050?ooo`040000003V`[40i/:a0>K2/@8000002@3oool00`00
0000j/F_0>[5[`030>[5[`030000001D=8h0E3B>00<0E3B>00<000000:RojP2X_nX01P2X_nX00`00
0000Z;oZ0:RojP02000000@0T6FM00D000000?RnR@3h_XT0n;j90000000403<bX@0;0000002X_nX0
Z;oZ0:RojP0000006aJ<0000002X_nX000000:RojP0000001@3oool2000000D0oooo00<000000?oo
o`3oool0:`3oool002T0oooo00<000000?ooo`3oool04P3oool4000000H0oooo00L000000>K2/@3V
`[40i/:a00000037C`00000000L0oooo00<000000>[5[`3ZaJl0103ZaJl00`000000E3B>05@dSP04
05@dSP030000002X_nX0Z;oZ00D0Z;oZ0`000006091UW@050000003h_XT0n;j90?RnR@000000100c
<Z400`000000Z;oZ0:RojP020:RojP070000000K5X`000000000002X_nX000000?ooo`0400000003
06/HC`000000oooo00D0oooo00<000000?ooo`3oool02@3oool500000080oooo0P0000040?ooo`80
00004P3oool00240oooo100000040?ooo`030000003oool0oooo0100oooo0`0000080?ooo`030000
003V`[40i/:a00<0i/:a00<000000<M?000000001P3oool00`000000j/F_0>[5[`040>[5[`030000
001D=8h0E3B>00D0E3B>00<000000:RojP2X_nX0100000000`2BK:<00000091UW@06091UW@050000
003h_XT0n;j90?RnR@0000001@0c<Z401P000000Z;oZ0:RojP2X_nX0000001/FS080000000<0Z;oZ
0000000000001@1[64l00`000000oooo0?ooo`040?ooo`800000303oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo00000140oooo000Y0?ooo`030000003oool0oooo00d0oooo0`000000
103oool000000000000000070?ooo`030000003V`[40i/:a00<0i/:a00<000000<M?000000001@3o
ool00`000000j/F_0>[5[`050>[5[`030000001D=8h0E3B>00H0E3B>0P000005099/X`030000002@
IId0T6FM00D0T6FM00D000000?RnR@3h_XT0n;j90000000503<bX@050000002X_nX0Z;oZ0:RojP00
00000P0K5X`00`000000Z;oZ0000000606/HC`030000003oool0oooo00<0oooo0`00000<0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03`3oool002P0oooo0P00000<0?ooo`@00000
0P3oool010000000]X:K0;J2V`0000060?ooo`030000003V`[40i/:a00<0i/:a00D000000;J2V`00
0000adl0000000030?ooo`8000001`3ZaJl00`000000E3B>05@dSP0605@dSP030000002BK:<0TVbS
00@0TVbS00<00000091UW@2@IId0102@IId00`000000n;j90?RnR@020?RnR@030000000c<Z40<c:Q
00@0<c:Q00@000000:RojP2X_nX000000P0K5X`00`000000Z;oZ0000000506/HC`030000002BIih0
000000@0oooo100000030?ooo`@00000103oool00`000000oooo0?ooo`080?ooo`8000004P3oool0
03@0oooo0P0000060?ooo`030000002fPY/0]X:K00800000103oool00`000000i/:a0>K2/@040>K2
/@040000002fPY/000000<M?00@000000P2X_nX00`000000j/F_0>[5[`040>[5[`030000001D=8h0
E3B>00D0E3B>0P000006099/X`030000002@IId0T6FM00@0T6FM00<000000?RnR@3h_XT00`3h_XT0
0`000000<c:Q03<bX@0303<bX@040000002X_nX0Z;oZ000000806aJ<0P0000000`2X_nX0000006/H
C`0306/HC`030000002BIih0000000@0oooo0`0000000`3oool000000?ooo`090?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool04@3oool00340oooo0`0000070?ooo`040000002fPY/0
]X:K0;J2V`800000103oool00`000000i/:a0>K2/@030>K2/@040000002fPY/0]X:K0;J2V`800000
1P2X_nX00`000000j/F_0>[5[`040>[5[`030000001D=8h0E3B>00@0E3B>0P000007099/X`030000
002@IId0T6FM00<0T6FM00<000000?RnR@3h_XT00`3h_XT00`000000<c:Q00000003000000040:Ro
jP000000Z;oZ000000806aJ<0P0000000`2X_nX0000006/HC`0306/HC`030000002BIih0000000<0
oooo00<000000<IJ000000000`0000090?ooo`8000002P3oool300000140oooo000_0?ooo`<00000
2@3oool010000000]X:K0;J2V`2fPY/2000000<0oooo00<000000>K2/@3V`[40103V`[4010000000
]X:K0;J2V`2fPY/2000000L0Z;oZ00<000000>[5[`3ZaJl00`3ZaJl00`000000E3B>05@dSP0305@d
SP@000001P2BK:<00`000000T6FM091UW@03091UW@030000003h_XT0n;j900<0n;j90P0000050:Ro
jP030000002X_nX0Z;oZ00<0000000<06aJ<000000000000101[64l00`000000TVNN000000030?oo
o`0400000036FP00000000000080oooo00<000000?ooo`3oool09P3oool002d0oooo0P00000;0?oo
o`030000002fPY/0]X:K0080]X:K00<000000009S00000000P3oool00`000000i/:a0>K2/@030>K2
/@030000002fPY/0]X:K0080]X:K00<00000014HU00000001P2X_nX2000000@0j/F_00<0000005@d
SP1D=8h00`1D=8h4000000H0TVbS00<00000091UW@2@IId00`2@IId00`000000n;j90?RnR@030?Rn
R@8000001@2X_nX4000000806aJ<0`00000406/HC`030000002BIih000000080oooo00H000000<IJ
0036FP0000000?7<Z`0000020?ooo`030000003oool0oooo02D0oooo00070?ooo`@000000P3oool0
1P000000oooo0?ooo`3oool000000?ooo`D000000P3oool200000140oooo0P00000;0?ooo`030000
002fPY/0]X:K0080]X:K00D000000009S0000000oooo000000060>K2/@030000002fPY/0]X:K0080
]X:K00@00000014HU00A69@000000P2X_nX30000000309Z2]`000000j/F_00<0j/F_00<0000005@d
SP1D=8h00`1D=8h4000000H0TVbS00<00000091UW@2@IId00P2@IId00`000000n;j90?RnR@030?Rn
R@040000000000@0000400000080Z;oZ100000001`2X_nX0000001/FS00K5X`0000001/FS0000000
101[64l00`000000TVNN000000020?ooo`0700000036FP00aUX00000003ac:/000000?ooo`020000
02L0oooo00070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool03P3oool00`000000oooo000000090?oo
o`030000002fPY/0]X:K00@0]X:K00@000000009S000000000001@3V`[400`000000]X:K0;J2V`04
0;J2V`030000000A69@04ARD008000001@2JP[L01@000000j/F_0>[5[`3ZaJl0000000@0E3B>1@00
0006099/X`030000002@IId0T6FM0080T6FM00<000000?RnR@3h_XT00`3h_XT00`00000000040000
1003000000060:RojP00000000000000002X_nX000000`0K5X`3000000<0JaQ?00H00000099WWP2B
Iih000000?ooo`0000020<IJ00030000003ac:/0000000<0oooo00<000000?ooo`3oool0903oool0
00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000P0oooo00<0
00000;J2V`2fPY/0102fPY/00`00000000V<000000060>K2/@030000002fPY/0]X:K00@0]X:K00@0
0000014HU00A69@000001P2JP[L01@000000j/F_0>[5[`3ZaJl0000000@0E3B>1@000006099/X`03
0000002@IId0T6FM0080T6FM00<000000?RnR@3h_XT00`3h_XT30000000400001000000000000000
0080jN^80`00000401/FS08000000`1[64l00`000000TVNN099WWP02000000<0aUX000<000000?7<
Z`0000000`3oool2000002D0oooo00000`3oool0000000000002000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`00
0000]X:K0;J2V`050;J2V`04000000002H`000V<000000@0i/:a00<000000;J2V`2fPY/01@2fPY/0
100000004ARD014HU000000709Z2]`040000003ZaJl0j/F_000000<0E3B>00<000000:RojP000000
0`000006099/X`030000002@IId0T6FM0080T6FM00<000000?RnR@3h_XT010000000100000@00000
0000000000040>W[R080000000<0Z;oZ0000000K5X`00`0K5X`010000000JaQ?06/HC`000003099W
WP8000000`36FP0010000000lLb[0?7<Z`0000030?ooo`030000003oool0oooo02<0oooo00070?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000]X:K0;J2V`050;J2V`04000000002H`000V<0009S080
00000P3V`[400`000000]X:K0;J2V`050;J2V`050000000A69@04ARD014HU00000001P2JP[L01000
0000j/F_0>[5[`00000305@dSPH000001P2BK:<00`000000T6FM091UW@02091UW@<000000P3h_XT3
000000030:RojP000000jN^800@0jN^80P0000000`2X_nX0000001/FS00301/FS080000000<0JaQ?
0000002BIih00P2BIih2000000<0aUX000@000000?7<Z`3ac:/00000103oool00`000000oooo0?oo
o`0R0?ooo`00203oool2000000X0oooo0P0000040?ooo`800000203oool00`30`<00T92@0<30`003
0?ooo`030;2`/03oool0000000H0oooo00D000000?ooo`3oool0oooo000000080;J2V`0300000000
2H`000V<00<000V<0P0000080;J2V`050000000A69@04ARD014HU00000001`2JP[L00`000000j/F_
0000000305@dSP030000003Qakl0hLNo00@000001P2BK:<4000000D0n;j900@000000:RojP2X_nX0
Z;oZ0P0000040>W[R0@000001@0K5X`00`000000JaQ?00000003099WWP0300000036FP00aUX00080
aUX000@000000?7<Z`3ac:/00000103oool2000002<0oooo000U0?ooo`030<30`03oool0oooo0080
oooo00<0/;2`0?ooo`0000001`3oool010000000oooo0000000000090;J2V`03000000002H`000V<
008000V<0P0000090;J2V`040000000A69@04ARD000000H0VX:g0P000000103ZaJl0000005@dSP1D
=8h200000080hLNo10000005099/X`8000000P2@IId00`000000n;j90?RnR@030?RnR@030000002X
_nX0Z;oZ00@00000103YjhP3000000H06aJ<0P000003099WWP0300000036FP00aUX00080aUX000@0
00000?7<Z`3ac:/00000103oool2000000/0oooo1@0000020?ooo`8000000`3oool4000000<0oooo
0P0000030?ooo`007P3oool0103Ph>00P8200820P020P8030?ooo`030<30`03oool0oooo0080oooo
00<0h>3P0<30`00000001P3oool30000000308iTW0000000]X:K00P0]X:K00<000000009S0000000
0P0000000`2X_nX000000;J2V`080;J2V`040000000A69@04ARD000000D0VX:g00P000000=[hYP3J
n:H000000>[5[`000000E3B>000000@0hLNo0`000002099/X`<0000000D0TVbS0000002@IId0T6FM
000000050?RnR@030000002X_nX0Z;oZ0080000000<0h/Vo0000000000000`3YjhP3000000H06aJ<
0P000004099WWP0300000036FP00aUX00080aUX000@000000?7<Z`3ac:/000000P3oool4000000`0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
0080oooo000U0?ooo`030<30`03oool0oooo00<0oooo0P0000030?ooo`<00000102>I9`00`000000
]X:K0;J2V`070;J2V`800000102X_nX00`000000]X:K0;J2V`070;J2V`050000000A69@04ARD014H
U00000000`2JP[L00`000000f_RV0=[hYP02000000030>[5[`000000E3B>008000000`3Qakl50000
00@0TVbS00@00000091UW@2@IId00000103h_XT00`000000Z;oZ0000000200000080h/Vo00D00000
05EF]`00000000000>W[R004000000<06aJ<0P0000000`2BIih00000099WWP03099WWP0300000036
FP00aUX00080aUX000@000000?7<Z`00000000000P3oool5000000/0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`050?ooo`4000000@3oool10?ooo`00903oool20;2`/080oooo00D0
`<30071`L020P80000000?ooo`030000000308iTW0000000SVBL00@0SVBL00<000000;J2V`2fPY/0
1`2fPY/2000000@0Z;oZ00<000000;J2V`2fPY/01`2fPY/2000000804ARD00@0000009Z2]`2JP[L0
VX:g0`0000020:RojP<0000000@0Z;oZ0000003Qakl0hLNo10000006099/X`040000002@IId0T6FM
000000@0n;j900<000000:RojP0000000P0000020>;9_`040000001EE[L0EEJg05EF]`<0000000<0
E@0U0000000K5X`00P0000001@2X_nX00000099WWP2BIih0000000<0TVNN00<000000<IJ0036FP00
0P36FP0200000080Z;oZ0`000000103ac:/000000?ooo`0000030?ooo`@00000103oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo0P0000030?ooo`00:`3oool2000000@0SVBL
00<0000008iTW02>I9`00`2>I9`00`000000]X:K0;J2V`060;J2V`0400000032ce@0`/mD000000<0
Z;oZ00<000000;J2V`2fPY/01P2fPY/400000004014HU0000000VX:g09Z2]`80000000@0Z;oZ0000
002X_nX0Z;oZ0`000000102X_nX000000000000000020>77_`8000001P2BK:<00`000000T6FM0000
00050?RnR@80000000<0Z;oZ0000003RbKl00P3RbKl00`000000EEJg05EF]`0205EF]`H000000P2X
_nX01@000000TVNN099WWP2BIih000000080TVNN00<000000<IJ0036FP000P36FP0010000000Z;oZ
0:RojP2X_nX3000000030?7<Z`000000oooo008000002P3oool00`000000oooo0?ooo`070?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00P3oool002D0oooo0P0000040?ooo`03
0000002>I9`0SVBL00<0SVBL00<0000008iTW02>I9`00`2>I9`00`000000]X:K0;J2V`060;J2V`05
00000032ce@0`/mD0<;?E00000000P2X_nX00`000000]X:K0;J2V`060;J2V`80000000D05abF0000
00000000000009Z2]`02000000<0Z;oZ00<000000:RojP2X_nX00`0000000`2X_nX0000000000003
0>77_`8000001@2BK:<00`000000T6FM000000050?RnR@030000002X_nX0000000D0h/Vo00<00000
05EF]`1EE[L00P1EE[L300000080212?00<000000:RojP000000102BIih00`000000TVNN00000004
0<IJ00030000002X_nX0Z;oZ0080Z;oZ0P0000020?7<Z`040000003oool0oooo000000P0oooo0P00
000:0?ooo`800000103oool300000080oooo000T0?ooo`040000003oool0oooo000000<0oooo00<0
000008iTW02>I9`00`2>I9`00`000000SVBL08iTW00308iTW0030000002fPY/0]X:K00D0]X:K00<0
00000<;?E032ce@00P32ce@2000000030:RojP000000]X:K00L0]X:K0P00000201LLUP@00000102X
_nX700000080XYO:00<000000>77_`3Qakl00P000005099/X`030000002@IId0000000@0n;j900@0
00000:RojP2X_nX000001@3RbKl00`000000EEJg05EF]`0305EF]`8000000P0848l00`000000Z;oZ
00000004099WWP040000002BIih00000000000<0aUX000<000000:RojP2X_nX00P2X_nX200000080
lLb[00@000000?ooo`00000000007`3oool002@0oooo00@000000?ooo`3oool000000`3oool00`00
0000SVBL08iTW00308iTW0030000002>I9`0SVBL00<0SVBL00<000000;J2V`2fPY/01@2fPY/00`00
0000`/mD00000002000000050:RojP000000Z;oZ0:RojP0000001P2fPY/00`000000i/6a00000003
01LLUP8000000P2X_nX3000000040:RojP0000000000000000H0XYO:00@000000>77_`3Qakl00000
1P2BK:<2000000@0n;j900<000000:RojP0000001P3RbKl00`000000EEJg05EF]`0405EF]`800000
0P0848l2000000D0TVNN00<00000099WWP0000000`36FP05000000@0lLb[0P0000000`1]5DH00000
0000000N0?ooo`00903oool010000000oooo0?ooo`0000030?ooo`030000002>I9`0SVBL00<0SVBL
00<0000008iTW02>I9`00`2>I9`00`000000]X:K0;J2V`050;J2V`800000102X_nX010000000Z;oZ
0:RojP0000060;J2V`030000003V`K40000000@05abF0`0000001P2X_nX00000000000000000Z;oZ
000000P0XYO:00@000000>77_`00000000001@2BK:<2000000@0n;j900<000000:RojP0000001P3R
bKl00`000000EEJg05EF]`0405EF]`8000000P0848l2000000H0TVNN0`0000020<IJ00050000002X
_nX0Z;oZ0:RojP000000103ac:/00`000000KAE606dEAP03000001d0oooo000T0?ooo`040000003o
ool0oooo00000080oooo0P00000508iTW0030000002>I9`0SVBL00<0SVBL00<000000;J2V`2fPY/0
102fPY/3000000D0Z;oZ00<000000:RojP0000001@2fPY/010000000i/6a0>K1/@3V`K4400000004
01LLUP0000000000000000D0Z;oZ00<000000::GbP2RUlX01P2RUlX00`000000hLNo000000020000
00<0TVbS00<000000?RnR@3h_XT00`3h_XT2000000P0h/Vo00<0000005EF]`0000001@00000200P@
S`<000001P2BIih200000080aUX000@000000:RojP2X_nX000001P3ac:/00`000000KAE600000002
000001d0oooo000U0?ooo`8000000`3oool2000000D0SVBL00<0000008iTW02>I9`00`2>I9`00`00
0000]X:K0;J2V`040;J2V`040000003Z_:@0j[bT000000@0Z;oZ00<000000:RojP0000001@2fPY/0
0`000000i/6a000000020000000401LLUP000000000000000080Z;oZ00<000000:RojP2X_nX00`2X
_nX00`000000XYO:0::GbP050::GbP030000003Hn]h000000080000000D0Z;oZ000000000000TVbS
000000040?RnR@80000000<0aNG^0000003RbKl01@3RbKl3000000D0Z;oZ00@0000000P@S`000000
Z;oZ0P000005099WWP80000000@0LB9G00000036FP0000000P2X_nX00`000000lLb[0?7<Z`040?7<
Z`80000000@0ZKgX0000003oool00000703oool002X0oooo0P00000508iTW0030000002>I9`0SVBL
00<0SVBL00<000000;J2V`2fPY/00`2fPY/2000000<0j[bT00<000000:RojP2X_nX00P0000000`2X
_nX000000;J2V`030;J2V`<0000000@0i/6a00000000000000001P2X_nX00`000000Z;oZ0:RojP02
0:RojP030000002RUlX0XYO:00@0XYO:00<000000=SjgP3Hn]h00P0000040:RojP800000103h_XT0
1@000000aNG^0<GUkP35iNh000000080h/Vo0`0000020:RojP030000002X_nX0Z;oZ00<0Z;oZ00@0
000000P@S`000000Z;oZ0P0000000`2BIih00000000000030000000405eL^000000000000<IJ00<0
00001`3ac:/2000000050:Vmj0000000oooo0?ooo`0000006`3oool002X0oooo0P00000508iTW003
0000002>I9`0SVBL00<0SVBL00<000000;J2V`2fPY/00`2fPY/2000000@0j[bT0P0000001@2BIih0
00000:RojP000000]X:K00L000000P2X_nX00`000000Z;oZ0:RojP050:RojP030000002X_nX0Z;oZ
0080Z;oZ00@000000::GbP2RUlX0XYO:0P0000040=SjgP030000002X_nX0Z;oZ00<0Z;oZ0P000003
0?RnR@0400000035iNh0aNG^0<GUkP<000001@2X_nX00`000000Z;oZ0:RojP030:RojP@0000000<0
i<bo000000000000103Tc;l00`000000GEbh05eL^005000000L0lLb[0P0000020:Vmj0<000002`3o
ool5000000/0oooo000Z0?ooo`8000001@2>I9`00`000000SVBL08iTW00408iTW0040000002fPY/0
]X:K0;J2V`8000001@3Z_:@010000000TVNN099WWP2BIih3000000<0]X:K00<000000:RojP2X_nX0
102X_nX00`000000Z;oZ0:RojP040:RojP<000000P2X_nX010000000XYO:0::GbP0000060=SjgPT0
00000P3h_XT400000080Z;oZ00<000000:RojP2X_nX0102X_nX00`000000Z;oZ0:RojP0400000003
0:RojP000000i<bo00L0i<bo00<0000005eL^00000000P0000020:RojP030000003ac:/0lLb[00D0
lLb[00@000000:Vmj02Y_NP000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00/0oooo000Z0?ooo`8000001@2>I9`00`000000SVBL08iTW00408iTW0040000002fPY/0]X:K0;J2
V`800000103Z_:@7000000@0]X:K00<000000:RojP2X_nX01@2X_nX00`000000Z;oZ0:RojP030000
00030:RojP000000K7[?0080000000<0Z;oZ000000000000103Hn]h300000080Z;oZ00<0000007n_
l`1o[o<0101o[o<3000000D0Z;oZ00<000000:RojP2X_nX0102X_nX3000000<0Z;oZ00@000000:Ro
jP2X_nX000001P3Tc;l3000000030:RojP00000000000080Z;oZ00<000000?7<Z`3ac:/0103ac:/2
00000080ZKgX00<000000?ooo`3oool00P00000;0?ooo`030000003oool0oooo00/0oooo00030?oo
o`@000000P3oool01P000000oooo0?ooo`3oool000000?ooo`D000000P3oool200000140oooo0`00
000608iTW0030000002>I9`0SVBL00<0SVBL00D000000;J2V`2fPY/0]X:K000000040>ZlY0<00000
0`2BIih2000000<0]X:K00<000000>^mY00000001P2X_nX3000000D0Z;oZ00<0000006ajc`1/N/l0
1`0000060:RojP030000001o[o<0Ojoc00<0000000<0Z;oZ0000000000001P2X_nX00`000000Z;oZ
0:RojP0300000080Z;oZ00<000000:RojP2X_nX0102X_nX00`000000i<bo0>C<_`040000000304e6
Z@00000000000080Z;oZ00D000000:RojP2X_nX0Z;oZ000000020?7<Z`<0000000D0NeNL0000002Y
_NP0ZKgX000000030?ooo`040000003oool0oooo0?ooo`@00000103oool00`000000oooo0?ooo`0;
0?ooo`000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000001P2>I9`0
0`000000SVBL08iTW00308iTW0030000002fPY/0]X:K008000000P3Z_:@3000000030>ZlY0000000
TVNN0080TVNN0P0000030;J2V`040000003[_J@0jkfT00000080Z;oZ1P0000050:RojP030000001/
N/l0K7[?00@0K7[?00<000000=SjgP0000001P2X_nX3000000D0Z;oZ00<000000:RojP2X_nX0102X
_nX3000000D0Z;oZ00<000000:RojP2X_nX0102X_nX300000080kLR^00D0000004e6Z@1=AZT0CDJY
000000030:RojPH000000P2fQ9h010000000NeNL07]GW00000020:Vmj0030000003oool0oooo0080
00002P3oool00`000000oooo0?ooo`0;0?ooo`00103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00h0
oooo00@000000?ooo`3oool000001@2>I9`00`000000SVBL08iTW00308iTW0030000002fPY/0]X:K
00@000000P3Z_:@00`000000j[bT00000003099WWP8000000`2fPY/010000000jkfT0>^mY03[_J@2
000000<0WHBg00<000000459/`0000001P2X_nX00`000000K7[?06ajc`0206ajc`050000003Hn]h0
f?[N0=SjgP0000000P2X_nX300000080YZSG00<000000:RojP2X_nX0102X_nX00`000000Z;oZ0:Ro
jP0300000080Z;oZ00<000000:RojP2X_nX0102X_nX00`000000Z;oZ0:RojP04000000@0kLR^00@0
000004e6Z@1=AZT0CDJY1P00000309aj[0040000002fQ9h0]XBN000000<0NeNL00<000000:Vmj000
0000100000090?ooo`8000003@3oool000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`04
0000003oool0oooo000000D0SVBL00<0000008iTW02>I9`00`2>I9`4000000D0j[bT00@000000>Zl
Y03Z_:@000000`2BIih010000000]X:K0;J2V`0000040>^mY0030000002MQ;L0WHBg0080WHBg00@0
00000459/`11BK<000001@2X_nX00`000000K7[?06ajc`02000000@0f?[N0`0000050:JXe`030000
002X_nX0Z;oZ00@0Z;oZ0`0000050:RojP030000002X_nX0Z;oZ00@0Z;oZ0`0000020:RojP030000
003]b:h0kLR^00@0kLR^00@0000004e6Z@1=AZT00000103^bJd010000000W7Z/09aj[00000030;J4
WP030000001kEi`0NeNL0080NeNL0P0000030?ooo`030000003oool0oooo01H0oooo00030?ooo`04
0000003oool0oooo00000080oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000D0SVBL
00@0000008iTW02>I9`0SVBL0`0000000`2fPY/00000000000040>ZlY0050000003Z_:@0j[bT0>Zl
Y00000000`2BIih2000000030;J2V`000000jkfT0080jkfT0P00000509f4]`0300000011BK<0@DVc
00<000000`2X_nX2000000@0f?[N0P00000206cMhP030000002VZ=L0YZSG00@0YZSG00<000000:Ro
jP2X_nX00`0000020:RojP030000002X_nX0Z;oZ00@0Z;oZ00<000000:RojP2X_nX00`0000020:Ro
jP040000002X_nX0Z;oZ000000H0kLR^00@0000004e6Z@1=AZT00000103^bJd20000000309aj[000
0000]XBN0080]XBN00<0000007]GW01kEi`00P1kEi`2000000<0oooo00<000000?ooo`3oool05P3o
ool000@0oooo0P00000:0?ooo`800000103oool2000000P0oooo00<0`<30092@T030`<000`3oool0
102`/;00oooo0?ooo`0000020?ooo`030000002>I9`0SVBL00<0SVBL1000000208iTW0040000002f
PY/00000000000@0j[bT00D000000>ZlY03Z_:@0j[bT00000003099WWP<00000103[_J@2000000D0
WHBg00H000000459/`11BK<0@DVc0000000dRNd;00000080K=gR00<000000:JXe`2VZ=L01@2VZ=L2
000000H0Z;oZ00<000000:RojP2X_nX00P2X_nX4000000H0Z;oZ0P0000070>g8[P030000001=AZT0
000000D0k/V]00@0000009aj[00000000000102fQ9h00`000000NeNL07]GW00207]GW08000000`3o
ool00`000000oooo0?ooo`0E0?ooo`008@3oool00`30`<00oooo0?ooo`020?ooo`040;2`/03oool0
000000000080oooo00@0000008iTW02>I9`0SVBL0`00000508iTW0<000001@3Z_:@01@000000j[bT
0>ZlY03Z_:@0000000<0TVNN0`0000040>^mY0030000002MQ;L0000000@0WHBg00<000000459/`11
BK<00P11BK<200000080=8W]0`0000030:RojP060000002WO:D000000000001/gN8000001@2VZ=L0
0`000000aNG^000000060:RojPD000000`2X_nX00`000000Z;oZ0:RojP040:RojP8000001`3]b:h0
0`000000CDJY000000050>k9[@030000002LNZ`0000000D0]XBN00<0000007]GW01kEi`00`1kEi`0
1@000000oooo0?ooo`3oool0000001L0oooo000J0?ooo`040>3Ph020P800P8200820P0<0oooo00<0
`<300?ooo`3oool00P3oool00`3Ph>00`<30000000030?ooo`@000000P2>I9`00`000000SVBL08iT
W00308iTW0<00000103Z_:@00`000000j[bT0>ZlY0020>ZlY0030000002BIih0TVNN0080TVNN0P00
00030>^mY0040000002MQ;L0WHBg000000@0WHBg00<000000459/`11BK<00`11BK<3000000D0Z;oZ
00@000000:MlY@2WO:D0YgbU0P000000101/gN8000000:JXe`2VZ=L2000000<0aNG^00<000000:Ro
jP2X_nX00`0000020:RojP030000002X_nX0Z;oZ00@0Z;oZ00<000000:RojP2X_nX00`0000020:Ro
jP030000003]b:h0kLR^00D0kLR^00<000000>k9[@3^bJd01@3^bJd3000000@0]XBN00<0000007]G
W01kEi`00`1kEi`01@000000oooo0?ooo`3oool0000001L0oooo000Q0?ooo`030<30`03oool0oooo
00<0oooo00<0X:2P0000003oool00`00000508iTW0030000002>I9`0SVBL00<0SVBL00<000000:G3
k`000000103Z_:@00`000000j[bT0>ZlY0020>ZlY0030000002BIih0TVNN0080TVNN00<000000>^m
Y03[_J@00P3[_J@010000000WHBg09f4]`00000509f4]`0300000011BK<00000008000000P2X_nX0
10000000Z;oZ0:RojP2X_nX2000000@0YgbU00H000000000<P00000000000:JXe`0000050<GUkP<0
00001@2X_nX00`000000Z;oZ0:RojP040:RojP<000001@2X_nX00`000000kLR^0>g8[P040>g8[P80
00001`3^bJd010000000]XBN0;J4WP0000030;J4WP030000001kEi`0NeNL00<0NeNL00D000000?oo
o`3oool0oooo0000000G0?ooo`00803oool20;2`/080oooo00@0`<30071`L020P800P8200P000002
0?ooo`030000002>I9`0SVBL00<0SVBL00<0000008iTW02>I9`00P2>I9`3000000@0j[bT00<00000
0>ZlY03Z_:@00`3Z_:@010000000TVNN099WWP2BIih2000000@0jkfT00@0000009f4]`2MQ;L00000
102MQ;L3000000H0Z;oZ00<000000:RojP0000001P2WO:D300000003051C]P000000000000<0aNG^
0P0000020:RojP030000002X_nX0Z;oZ00@0Z;oZ00<000000:RojP2X_nX00`0000020:RojP030000
002X_nX0Z;oZ00@0Z;oZ00<000000>g8[P3]b:h00`0000020:RojP030000003^bJd0k/V]00<0k/V]
0P0000030;J4WP040000002fQ9h0]XBN000000H0NeNL00@000000?ooo`3oool000005`3oool002T0
oooo00@000000?ooo`3oool000001@2>I9`00`000000SVBL0000000200000080YL?_00<000000>Zl
Y03Z_:@00P3Z_:@00`000000j[bT0>ZlY0030>ZlY0050000002BIih0TVNN099WWP000000103[_J@0
0`000000WHBg09f4]`0209f4]`040000002MQ;L0000000000080WHBg00<000000:RojP2X_nX0102X
_nX2000000L0YgbU0`000003051C]P<00000102X_nX00`000000Z;oZ0:RojP040:RojP<000001P2X
_nX00`000000Z;oZ0:RojP020:RojP@000001@2X_nX00`000000k/V]0>k9[@03000000030:RojP00
0000]XBN0080]XBN00@000000;J4WP2fQ9h000001P1kEi`010000000oooo0?ooo`00000G0?ooo`00
:P3oool3000000@0SVBL0`0000040:G3k`030000003Z_:@0j[bT00<0j[bT00<000000>ZlY03Z_:@0
0`3Z_:@01@000000TVNN099WWP2BIih0000000@0jkfT00<0000009f4]`2MQ;L01000000509f4]`80
00000P2X_nX2000000030:RojP000000YgbU00D0YgbU0P0000000`0g=J80000000000004051C]P03
0000002X_nX0Z;oZ00<0Z;oZ00<000000:RojP2X_nX00`0000020:RojP030000002X_nX0Z;oZ00@0
Z;oZ1@0000030:RojP030000002X_nX0Z;oZ00<0Z;oZ0`0000040:RojP030000002fQ9h0]XBN0080
]XBN00@000000;J4WP2fQ9h000001@1kEi`010000000oooo0?ooo`00000G0?ooo`00;03oool00`00
0000SVBL0000000200000080YL?_00<000000:G3k`2U`nl00P2U`nl00`000000j[bT0>ZlY0020>Zl
Y0030000003Z_:@0j[bT00@0j[bT00D00000099WWP2BIih0TVNN000000040>^mY0<000000P2X_nX0
0`000000WHBg09f4]`0609f4]`8000000`2X_nX00`000000YgbU0:MlY@040:MlY@80000000<0=cFR
0000000000001@1@DkH010000000Z;oZ0:RojP2X_nX4000000H0Z;oZ00<000000:RojP2X_nX00`00
00020:RojP030000002X_nX0Z;oZ00<0Z;oZ00<000000:RojP2X_nX00`0000020:RojP030000002X
_nX0Z;oZ00<0Z;oZ00<000000;J4WP2fQ9h00P2fQ9h00`000000]XBN0000000507]GW0040000003o
ool0oooo000001L0oooo000/0?ooo`8000001P2U`nl200000080YL?_00<000000>ZlY03Z_:@00P3Z
_:@00`000000j[bT0>ZlY0040>ZlY0040000002BIih0TVNN000000@0jkfT0P0000050:RojP030000
002MQ;L0WHBg00@0WHBg00<000000=;dW00000000`2X_nX00`000000YgbU0:MlY@040:MlY@800000
0P0g=J800`000000D5>f051C]P03051C]P@000000`2X_nX00`000000Z;oZ0:RojP040:RojP<00000
1@2X_nX00`000000Z;oZ0:RojP030:RojP<000001P2X_nX00`000000Z;oZ0:RojP020:RojP030000
002fQ9h0]XBN00<0]XBN0P00000607]GW0040000003oool00000000001H0oooo000]0?ooo`030000
002U`nl0YL?_00H0YL?_0P0000050>ZlY0030000003Z_:@0j[bT00@0j[bT00@00000099WWP2BIih0
0000103[_J@00`000000Z;oZ000000040:RojP030000002MQ;L0WHBg00@0WHBg00@000000=;dW03B
m9`000000`2X_nX00`000000YgbU0:MlY@030:MlY@040000002EIi/0000003LeXP80000000@0D5>f
00000000000000000P2X_nX00`000000Z;oZ0:RojP030:RojP030000002X_nX0Z;oZ00<000000P2X
_nX00`000000Z;oZ0:RojP040:RojP030000002X_nX0Z;oZ008000000P2X_nX00`000000Z;oZ0:Ro
jP040:RojP8000000`2X_nX00`000000]XBN0;J4WP030;J4WP8000001P1kEi`010000000oooo0000
0000000F0?ooo`00;P3oool2000000H0YL?_0P0000040>ZlY0030000003Z_:@0j[bT00H0j[bT00<0
0000099WWP000000103[_J@010000000Z;oZ0:RojP0000030:RojP030000002MQ;L0WHBg00<0WHBg
00@000000=;dW03Bm9`0d_BL0P0000020:RojP030000002WO:D0YgbU0080YgbU00@0000009EWV`2E
Ii/000000P0g=J82000000D0Z;oZ00<000000:RojP2X_nX00`2X_nX3000000H0Z;oZ00<000000:Ro
jP2X_nX00P2X_nX4000000D0Z;oZ00<000000:RojP2X_nX00`0000000`2X_nX000000:RojP020:Ro
jP030000002fQ9h0]XBN00@0]XBN00<0000007]GW01kEi`0101kEi`010000000oooo00000000000F
0?ooo`00<03oool00`000000YL?_0:G3k`0300000080oooo00D000000>ZlY03Z_:@0j[bT00000008
0>ZlY0800000103[_J@00`000000Z;oZ0:RojP0300000080Z;oZ00<0000009f4]`2MQ;L00P2MQ;L0
0`000000d_BL0=;dW00400000080Z;oZ00<000000:MlY@2WO:D00P2WO:D010000000UFNK09EWV`00
000303LeXP030000002X_nX0Z;oZ00@0Z;oZ00<000000:RojP2X_nX00P00000209n5]`030000002X
_nX0Z;oZ00@0Z;oZ1@0000030:RojP030000002X_nX0Z;oZ00<0Z;oZ0`0000050:RojP050000002X
_nX0Z;oZ0:RojP0000001P2fQ9h00`000000NeNL07]GW00307]GW0@000005P3oool00340oooo0P00
00060?ooo`<000002@3Z_:@2000000@0jkfT0`0000030:RojP040000002X_nX0Z;oZ000000<0WHBg
0`0000000`1aCIL000000:Vmj002000000030:RojP000000YgbU00<0YgbU00@0000009EWV`2EIi/0
0000100g=J800`000000Z;oZ0:RojP020:RojP@000001@2OQKL00`000000Z;oZ0:RojP0300000080
Z;oZ00<000000:RojP2X_nX00`2X_nX00`000000Z;oZ0:RojP0300000080VgJX00<000000:RojP2X
_nX00`2X_nX01@000000Z;oZ0:RojP2X_nX0000000H0]XBN0P00000407]GW0@000005P3oool003<0
oooo00<000000?ooo`3oool00`3oool00`0000000018000000090>ZlY0800000103[_J@00`000000
Z;oZ0:RojP040:RojP030000002X_nX000000080WHBg0P0000001@2Y_NP00000075=U`000000ZKgX
0080000000<0Z;oZ0000002WO:D00`2WO:D01@000000UFNK09EWV`2EIi/0000000<0=cFR1@000002
0:RojP030000002OQKL0WhFg00D0WhFg0P0000060:RojP040000002X_nX0Z;oZ0:RojP@000001P2K
MZP00`000000Z;oZ0:RojP02000000050?ooo`000000Z;oZ0:RojP0000001P2fQ9h2000000D0NeNL
0`00000F0?ooo`00=03oool00`000000oooo0?ooo`020?ooo`040000000004P00018000000P0j[bT
00<000000>^mY03[_J@00P3[_J@010000000oooo0000000000030:RojP@0000000H0WHBg00000000
000000000:Vmj0000002075=U`80000000<0VgV/0000000000000`2WO:D00`000000UFNK09EWV`02
09EWV`040000000g=J80000000000080V6nR00<000000:RojP2X_nX00`2X_nX00`000000WhFg09n5
]`0309n5]`030000002RdVP0000000H0Z;oZ100000020:RojP030000002KMZP0VgJX00H0VgJX0P00
00030?ooo`040000002X_nX0Z;oZ000000H0]XBN00<0000007]GW0000000101kEi`3000001H0oooo
000e0?ooo`050000003oool0oooo0?ooo`0000000`0004P00`000000j[bT0>ZlY0040>ZlY0800000
103[_J@010000000oooo0?ooo`3oool3000000030:RojP000000000000<0000000@0oooo0000002Y
_NP000000P1aCIL20000000409]i[0000000Z;oZ00000080YgbU00<0000009EWV`2EIi/00P2EIi/2
000000D0V6nR00<000000:RojP2X_nX00P2X_nX00`000000WhFg09n5]`0309n5]`040000002RdVP0
X]9X00000080Z;oZ0`0000020:RojP050000002X_nX0Z;oZ0:RojP000000202KMZP00`000000oooo
0?ooo`030?ooo`030000002X_nX0000000H0]XBN00@0000007]GW01kEi`000000`1kEi`200000003
0?ooo`000000oooo01@0oooo000f0?ooo`80000000<0oooo0000000004P00`0004P00`000000j[bT
0>ZlY00300000080YL?_00D000000>^mY03[_J@0jkfT000000040?ooo`040000002X_nX0Z;oZ0000
0080oooo00H000000?ooo`3oool000000:Vmj0000003075=U`<0000000D0Z;oZ0000002WO:D0YgbU
0000000409EWV`030000002HKj80V6nR00D0V6nR00D000000:RojP2X_nX0Z;oZ0000000409n5]`04
0000002RdVP0X]9X0:;BJ0<000001@2X_nX00`000000Z;oZ0:RojP020:RojP030000002KMZP0VgJX
00@0VgJX00<000000?ooo`3oool0103oool010000000Z;oZ0:RojP0000050;J4WP050000001kEi`0
NeNL07]GW00000000P1kEi`010000000YL?_00000000000E0?ooo`00>03oool2000000@000180`00
00060:G3k`<000001P3oool3000000D0oooo00<000000:Vmj00000000`1aCIL20000000309]i[000
000000000080YgbU00@0000009EWV`2EIi/0UFNK0P00000709Q_XP8000000P2X_nX00`000000WhFg
09n5]`0209n5]`@000000P2X_nX00`000000Z;oZ0:RojP030:RojP8000000`2X_nX00`000000VgJX
09]fZ00409]fZ0030000003oool0oooo00D0oooo00<000000:RojP0000001P2fQ9h010000000NeNL
07]GW000000307]GW0<000005@3oool003T0oooo00<000000000B00000000P0000020:G3k`030000
002U`nl0YL?_00D0YL?_0P0000070?ooo`030000003oool0oooo00D0oooo00<000000:Vmj0000000
0`1aCIL01P000000VgV/000000000000YgbU000000@0UFNK0P00000609Q_XP80000000D0NU^R0000
002X_nX0Z;oZ0000000209n5]`8000001P2X_nX00`000000Z;oZ0:RojP0200000080oooo00@00000
0:RojP2X_nX000001P2KMZP00`000000oooo0?ooo`050?ooo`030000002X_nX0000000H0]XBN00D0
000007]GW01kEi`0NeNL0000000207]GW0<000005@3oool003T0oooo0P0000060:G3k`8000000P2U
`nl300000140oooo00<000000:Vmj00000000`1aCIL01P000000VgV/000000000000YgbU000000@0
UFNK00<000000000300000001@2HKj8200000080NU^R00<000000:RojP0000000P2OQKL2000000H0
Z;oZ0`0000040?ooo`040000002X_nX0Z;oZ000000D0VgJX00<000000?ooo`3oool01P3oool00`00
0000Z;oZ000000060;J4WP030000001kEi`0NeNL0080NeNL00<0000007]GW00000000P00000E0?oo
o`00>P3oool00`000000YL?_0:G3k`050:G3k`<00000503oool00`000000ZKgX00000003075=U`80
000000@0VgV/0000002WO:D000000`2EIi/010000000000<00003000000509Q_XP030000000001`0
00000080NU^R0P0000001@2OQKL000000000:P0002X000000080Z;oZ0`0000080?ooo`040000002X
_nX0Z;oZ000000@0VgJX00<000000?ooo`3oool01`3oool2000000H0]XBN00<0000007]GW01kEi`0
0`1kEi`4000001D0oooo000k0?ooo`8000000P2U`nl3000001L0oooo00<000000:Vmj00000000`1a
CIL20000000409]i[00000000000000000<0UFNK00@000000000300000`000001@2HKj800`000000
000L0000000307YKXP<0000000<0000Z0000000000000P00000;0?ooo`040000002X_nX0Z;oZ0000
00@0VgJX00<000000?ooo`3oool01`3oool00`000000Z;oZ000000050;J4WP030000001kEi`0NeNL
00<0NeNL00@0000007]GW000000000005@3oool003d0oooo0P00000J0?ooo`030000002Y_NP00000
00@0LDfG00@0000009]i[02KNJ`00000102EIi/010000000000<00003000000409Q_XP0400000000
01`0000L000000@0NU^R0`00000@0?ooo`030000002X_nX0000000<0VgJX00<000000?ooo`3oool0
2@3oool2000000D0]XBN00<0000007]GW01kEi`0101kEi`3000001D0oooo000o0?ooo`030000003o
ool0oooo01L0oooo00<000000:Vmj0000000101aCIL010000000VgV/09]i[000000409EWV`040000
000000`0000<000000@0V6nR0P0000000`0001`0000007YKXP0407YKXP030000003oool0oooo00l0
oooo00<000000:RojP0000000`2KMZP00`000000oooo0?ooo`090?ooo`8000001P2fQ9h00`000000
NeNL07]GW00307]GW080000000<0oooo0000003oool04`3oool00400oooo00<000000?ooo`3oool0
5P3oool00`000000ZKgX00000004075=U`80000000<0VgV/0000002EIi/00P2EIi/01@000000VG6S
0000000000`0000000@0V6nR0P0000000`0001`0000007YKXP0307YKXP030000003oool0oooo0140
oooo00<000000:RojP0000000P2KMZP00`000000oooo0?ooo`0:0?ooo`030000002fQ9h0]XBN00@0
]XBN00<0000007]GW00000000`0000020?ooo`800000503oool00440oooo00<000000?ooo`3oool0
5P3oool2000000@0LDfG0P0000000`2KNJ`0000009EWV`0209EWV`050000002ILJ<0000000003000
0000102HKj8200000003000070000000NU^R00<0NU^R00<000000?ooo`3oool04@3oool00`000000
Z;oZ0000000209]fZ0030000003oool0oooo00X0oooo0P0000040;J4WP<0000000<0YL?_0000003o
ool00`3oool2000001@0oooo00120?ooo`8000005P3oool2000000@0LDfG0P0000000`2KNJ`00000
09EWV`0209EWV`030000002ILJ<000000080000<00P0000009Q_XP2HKj8000000?ooo`000000000L
000000@0NU^R00<000000?ooo`3oool04P3oool20000000309]fZ0000000oooo00d0oooo00<00000
0;J4WP0000000P0000020:G3k`030000002U`nl0000000@0oooo0P00000D0?ooo`00A03oool00`00
0000oooo0?ooo`0C0?ooo`800000101aCIL0100000005Q::00000000000209EWV`070000002ILJ<0
VG6S09UaX`000000000<0000000209Q_XP030000003oool0oooo00800000101jFj800`000000oooo
0?ooo`0B0?ooo`80000000<0VgJX0000003oool03@3oool2000000H0YL?_1P00000F0?ooo`00A@3o
ool00`000000oooo0?ooo`0B0?ooo`800000101aCIL0100000005Q::00000000000209EWV`070000
002ILJ<0VG6S09UaX`000000000<0000000209Q_XP060000003oool0oooo0000000001`000000P1j
Fj800`000000oooo0?ooo`0D0?ooo`<000003`3oool00`000000YL?_0:G3k`040:G3k`8000006P3o
ool004H0oooo00<000000?ooo`3oool04@3oool2000000D0LDfG0`00000209EWV`030000002ILJ<0
VG6S0080VG6S0P00000209Q_XP060000003oool0oooo0000000001`000000P1jFj800`000000oooo
0?ooo`0D0?ooo`800000403oool00`000000YL?_0:G3k`04000001`0oooo00170?ooo`030000003o
ool0oooo0100oooo0P000005075=U`030000000F4XX0000000<00000102ILJ<20000000309Q_XP00
0000oooo00<0oooo0P00000207YKXP030000003oool0oooo01D0oooo00<000000?ooo`3oool0303o
ool500000200oooo00180?ooo`8000004@3oool00`000000LDfG075=U`03075=U`030000000F4XX0
000000<00000102ILJ<20000000309Q_XP000000oooo00<0oooo0P00000207YKXP030000003oool0
oooo0200oooo1000000U0?ooo`00BP3oool00`000000oooo0?ooo`0>0?ooo`030000001aCIL0LDfG
00<0LDfG00<0000001HBRP0000000`00000409UaX`80000000<0V6nR0000003oool00`3oool20000
000307YKXP000000oooo01l0oooo0`00000Y0?ooo`00B`3oool00`000000oooo0?ooo`0=0?ooo`03
0000001aCIL0LDfG00<0LDfG00<0000001HBRP0000000`00000409UaX`@000001@3oool00`000000
NU^R0000000L0?ooo`@00000;03oool004`0oooo00<000000?ooo`3oool0303oool2000000@0LDfG
00<0000001HBRP0000000`00000409UaX`<000001P3oool00`000000NU^R0000000H0?ooo`@00000
<03oool004d0oooo00<000000?ooo`3oool02`3oool2000000@0LDfG00<0000001HBRP0000000P00
00001@0g=J80000009UaX`2ILJ<000000080oooo00<000000?ooo`3oool0103oool3000001D0oooo
0`00000d0?ooo`00CP3oool2000000/0oooo0P000005075=U`80000000@0oooo0000000g=J800000
0P2ILJ<010000000oooo0?ooo`0000060?ooo`8000004P3oool4000003L0oooo001@0?ooo`030000
003oool0oooo00P0oooo0P000005075=U`040000003oool0oooo0?ooo`8000000P2ILJ<00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo1000000k0?ooo`00D@3oool00`000000oooo
0?ooo`080?ooo`030000001aCIL0LDfG00<0LDfG00@000000?ooo`3oool0oooo0P00000209UaX`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool4000003l0oooo001B0?ooo`030000
003oool0oooo00L0oooo00<00000075=U`1aCIL00P1aCIL2000000<0oooo0P0000000`2ILJ<00000
0?ooo`0B0?ooo`<00000@`3oool005<0oooo00<000000?ooo`3oool01P3oool00`000000LDfG0000
0002000000H0oooo00<0000009UaX`0000003`3oool4000004H0oooo001D0?ooo`8000001P3oool2
000000T0oooo00<0000009UaX`0000002`3oool4000004X0oooo001F0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01`3oool3000000P0oooo0`00001>0?ooo`00E`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo0P0000050?ooo`@00000D@3oool005P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000<00000
E@3oool005T0oooo00D000000?ooo`3oool0oooo000000090?ooo`<00000F@3oool005X0oooo0P00
00000`3oool000000?ooo`040?ooo`@00000G03oool005`0oooo0P0000000`3oool0000000000002
00000600oooo001M0?ooo`800000I03oool00<<0oooo00330?ooo`00``3oool00<<0oooo00330?oo
o`00``3oool00<<0oooo00330?ooo`00``3oool00<<0oooo00330?ooo`00``3oool00<<0oooo0033
0?ooo`00``3oool00<<0oooo00330?ooo`00``3oool00001\
\>"],
  ImageRangeCache->{{{0, 194.063}, {157.188, 0}} -> {-0.286407, -0.144237, \
0.00710144, 0.00710144}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  SurfaceGraphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[194]="]
}, Open  ]],

Cell[TextData[{
  "In fact for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \ \((2\ m + 3)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \ 2\ \((2\ m + 3)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = \ 3\ \((2\ m + 3)\)\)]],
  " the exact and approximate solutions are the same."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {\[Lambda] \[Rule] \ \((2*m + 
                3)\)}]\)], "Input",
  CellLabel->"In[195]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[195]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {\[Lambda] \[Rule] 
            2\ \((2*m + 3)\)}]\)], "Input",
  CellLabel->"In[196]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[196]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[\((\((y[x] /. sol[\([1]\)])\) - \((y[x] /. 
                apr[\([1]\)])\))\) /. {\[Lambda] \[Rule] 
            3\ \((2*m + 3)\)}]\)], "Input",
  CellLabel->"In[197]:="],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[197]="]
}, Open  ]]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{1016, 647},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->False,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 150, 5, 39, "Subsection"],
Cell[1858, 57, 381, 12, 22, "SmallText"],
Cell[2242, 71, 228, 6, 25, "Text"],
Cell[2473, 79, 46, 0, 31, "MathCaption"],
Cell[2522, 81, 94, 2, 29, "Input"],
Cell[2619, 85, 34, 0, 35, "Subsubsection"],
Cell[2656, 87, 93, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[2774, 93, 182, 5, 29, "Input"],
Cell[2959, 100, 347, 9, 23, "Output"]
}, Open  ]],
Cell[3321, 112, 122, 3, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[3468, 119, 139, 4, 29, "Input"],
Cell[3610, 125, 649, 11, 81, "Output"]
}, Open  ]],
Cell[4274, 139, 246, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[4545, 153, 125, 4, 29, "Input"],
Cell[4673, 159, 196, 4, 39, "Output"]
}, Open  ]],
Cell[4884, 166, 253, 10, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[5162, 180, 208, 5, 29, "Input"],
Cell[5373, 187, 53193, 1199, 161, 21114, 798, "GraphicsData", "PostScript", \
"Graphics"],
Cell[58569, 1388, 163, 4, 23, "Output"]
}, Open  ]],
Cell[58747, 1395, 162, 6, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[58934, 1405, 204, 5, 29, "Input"],
Cell[59141, 1412, 25964, 683, 140, 6887, 442, "GraphicsData", "PostScript", \
"Graphics"],
Cell[85108, 2097, 156, 4, 23, "Output"]
}, Open  ]],
Cell[85279, 2104, 34, 0, 35, "Subsubsection"],
Cell[85316, 2106, 65, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[85406, 2111, 244, 5, 29, "Input"],
Cell[85653, 2118, 907, 24, 23, "Output"]
}, Open  ]],
Cell[86575, 2145, 102, 2, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[86702, 2151, 124, 3, 29, "Input"],
Cell[86829, 2156, 1103, 17, 76, "Output"]
}, Open  ]],
Cell[87947, 2176, 226, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[88198, 2189, 105, 3, 29, "Input"],
Cell[88306, 2194, 200, 4, 39, "Output"]
}, Open  ]],
Cell[88521, 2201, 233, 9, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[88779, 2214, 216, 5, 29, "Input"],
Cell[88998, 2221, 55517, 1218, 166, 20853, 785, "GraphicsData", "PostScript", \
"Graphics"],
Cell[144518, 3441, 163, 4, 23, "Output"]
}, Open  ]],
Cell[144696, 3448, 34, 0, 35, "Subsubsection"],
Cell[144733, 3450, 46, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[144804, 3454, 165, 3, 29, "Input"],
Cell[144972, 3459, 680, 19, 23, "Output"]
}, Open  ]],
Cell[145667, 3481, 82, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[145774, 3486, 99, 2, 29, "Input"],
Cell[145876, 3490, 883, 13, 121, "Output"]
}, Open  ]],
Cell[146774, 3506, 206, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[147005, 3518, 85, 2, 29, "Input"],
Cell[147093, 3522, 287, 6, 23, "Output"]
}, Open  ]],
Cell[147395, 3531, 121, 4, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[147541, 3539, 165, 3, 29, "Input"],
Cell[147709, 3544, 25140, 632, 134, 6133, 392, "GraphicsData", "PostScript", \
"Graphics"],
Cell[172852, 4178, 156, 4, 23, "Output"]
}, Open  ]],
Cell[173023, 4185, 34, 0, 35, "Subsubsection"],
Cell[173060, 4187, 46, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[173131, 4191, 234, 5, 29, "Input"],
Cell[173368, 4198, 1104, 28, 23, "Output"]
}, Open  ]],
Cell[174487, 4229, 82, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[174594, 4234, 104, 2, 29, "Input"],
Cell[174701, 4238, 2304, 35, 236, "Output"]
}, Open  ]],
Cell[177020, 4276, 152, 5, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[177197, 4285, 85, 2, 29, "Input"],
Cell[177285, 4289, 1302, 31, 23, "Output"]
}, Open  ]],
Cell[178602, 4323, 69, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[178696, 4327, 211, 4, 29, "Input"],
Cell[178910, 4333, 257, 5, 40, "Output"]
}, Open  ]],
Cell[179182, 4341, 213, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[179420, 4353, 177, 4, 29, "Input"],
Cell[179600, 4359, 61257, 1317, 163, 21665, 823, "GraphicsData", \
"PostScript", "Graphics"],
Cell[240860, 5678, 163, 4, 23, "Output"]
}, Open  ]],
Cell[241038, 5685, 121, 4, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[241184, 5693, 168, 3, 29, "Input"],
Cell[241355, 5698, 42226, 949, 134, 8137, 523, "GraphicsData", "PostScript", \
"Graphics"],
Cell[283584, 6649, 156, 4, 23, "Output"]
}, Open  ]],
Cell[283755, 6656, 34, 0, 35, "Subsubsection"],
Cell[283792, 6658, 46, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[283863, 6662, 184, 3, 29, "Input"],
Cell[284050, 6667, 552, 13, 23, "Output"]
}, Open  ]],
Cell[284617, 6683, 82, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[284724, 6688, 99, 2, 29, "Input"],
Cell[284826, 6692, 1286, 19, 144, "Output"]
}, Open  ]],
Cell[286127, 6714, 206, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[286358, 6726, 85, 2, 29, "Input"],
Cell[286446, 6730, 532, 9, 87, "Output"]
}, Open  ]],
Cell[286993, 6742, 213, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[287231, 6754, 206, 5, 29, "Input"],
Cell[287440, 6761, 60211, 1267, 171, 21022, 778, "GraphicsData", \
"PostScript", "Graphics"],
Cell[347654, 8030, 163, 4, 23, "Output"]
}, Open  ]],
Cell[347832, 8037, 130, 4, 35, "MathCaption"],

Cell[CellGroupData[{
Cell[347987, 8045, 204, 5, 29, "Input"],
Cell[348194, 8052, 23626, 614, 133, 5917, 390, "GraphicsData", "PostScript", \
"Graphics"],
Cell[371823, 8668, 156, 4, 23, "Output"]
}, Open  ]],
Cell[371994, 8675, 34, 0, 35, "Subsubsection"],
Cell[372031, 8677, 45, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[372101, 8681, 316, 6, 49, "Input"],
Cell[372420, 8689, 1073, 27, 54, "Output"]
}, Open  ]],
Cell[373508, 8719, 82, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[373615, 8724, 99, 2, 29, "Input"],
Cell[373717, 8728, 163, 3, 23, "Message"],
Cell[373883, 8733, 257, 4, 54, "Output"]
}, Open  ]],
Cell[374155, 8740, 152, 5, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[374332, 8749, 85, 2, 29, "Input"],
Cell[374420, 8753, 1252, 29, 54, "Output"]
}, Open  ]],
Cell[375687, 8785, 69, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[375781, 8789, 143, 3, 29, "Input"],
Cell[375927, 8794, 139, 3, 37, "Output"]
}, Open  ]],
Cell[376081, 8800, 213, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[376319, 8812, 305, 6, 49, "Input"],
Cell[376627, 8820, 63675, 1380, 174, 22458, 866, "GraphicsData", \
"PostScript", "Graphics"],
Cell[440305, 10202, 163, 4, 23, "Output"]
}, Open  ]],
Cell[440483, 10209, 34, 0, 35, "Subsubsection"],
Cell[440520, 10211, 45, 0, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[440590, 10215, 183, 3, 29, "Input"],
Cell[440776, 10220, 739, 19, 23, "Output"]
}, Open  ]],
Cell[441530, 10242, 82, 1, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[441637, 10247, 99, 2, 29, "Input"],
Cell[441739, 10251, 163, 3, 23, "Message"],
Cell[441905, 10256, 983, 14, 115, "Output"]
}, Open  ]],
Cell[442903, 10273, 206, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[443134, 10285, 85, 2, 29, "Input"],
Cell[443222, 10289, 207, 5, 36, "Output"]
}, Open  ]],
Cell[443444, 10297, 300, 11, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[443769, 10312, 329, 6, 49, "Input"],
Cell[444101, 10320, 61856, 1366, 183, 22522, 875, "GraphicsData", \
"PostScript", "Graphics"],
Cell[505960, 11688, 163, 4, 23, "Output"]
}, Open  ]],
Cell[506138, 11695, 213, 8, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[506376, 11707, 244, 5, 29, "Input"],
Cell[506623, 11714, 59121, 1286, 165, 21529, 817, "GraphicsData", \
"PostScript", "Graphics"],
Cell[565747, 13002, 163, 4, 23, "Output"]
}, Open  ]],
Cell[565925, 13009, 354, 11, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[566304, 13024, 203, 4, 29, "Input"],
Cell[566510, 13030, 61, 2, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[566608, 13037, 200, 4, 29, "Input"],
Cell[566811, 13043, 61, 2, 23, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[566909, 13050, 200, 4, 29, "Input"],
Cell[567112, 13056, 61, 2, 23, "Output"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

